/*
 * This file was generated automatically by ExtUtils::ParseXS version 3.44 from the
 * contents of PerlTest.xs. Do not edit this file, edit PerlTest.xs instead.
 *
 *    ANY CHANGES MADE HERE WILL BE LOST!
 *
 */

/////////////////////////////////////////////////////////////////////////////
// Name:        PerlTest.xs
// Purpose:     XS for PerlTest
// Author:      Mark Dootson
// Modified by:
// Created:     2012-09-28
// RCS-ID:      $Id:$
// Copyright:   (c) 2012 Mark Dootson
// Licence:     This program is free software; you can redistribute it and/or
//              modify it under the same terms as Perl itself
/////////////////////////////////////////////////////////////////////////////

#define PERL_NO_GET_CONTEXT

#include "cpp/wxapi.h"
#include "cpp/constants.h"
#include "cpp/overload.h"

#undef THIS

#include <cpp/src/perltest.cpp>

#ifndef PERL_UNUSED_VAR
#  define PERL_UNUSED_VAR(var) if (0) var = var
#endif

#ifndef dVAR
#  define dVAR		dNOOP
#endif


/* This stuff is not part of the API! You have been warned. */
#ifndef PERL_VERSION_DECIMAL
#  define PERL_VERSION_DECIMAL(r,v,s) (r*1000000 + v*1000 + s)
#endif
#ifndef PERL_DECIMAL_VERSION
#  define PERL_DECIMAL_VERSION \
	  PERL_VERSION_DECIMAL(PERL_REVISION,PERL_VERSION,PERL_SUBVERSION)
#endif
#ifndef PERL_VERSION_GE
#  define PERL_VERSION_GE(r,v,s) \
	  (PERL_DECIMAL_VERSION >= PERL_VERSION_DECIMAL(r,v,s))
#endif
#ifndef PERL_VERSION_LE
#  define PERL_VERSION_LE(r,v,s) \
	  (PERL_DECIMAL_VERSION <= PERL_VERSION_DECIMAL(r,v,s))
#endif

/* XS_INTERNAL is the explicit static-linkage variant of the default
 * XS macro.
 *
 * XS_EXTERNAL is the same as XS_INTERNAL except it does not include
 * "STATIC", ie. it exports XSUB symbols. You probably don't want that
 * for anything but the BOOT XSUB.
 *
 * See XSUB.h in core!
 */


/* TODO: This might be compatible further back than 5.10.0. */
#if PERL_VERSION_GE(5, 10, 0) && PERL_VERSION_LE(5, 15, 1)
#  undef XS_EXTERNAL
#  undef XS_INTERNAL
#  if defined(__CYGWIN__) && defined(USE_DYNAMIC_LOADING)
#    define XS_EXTERNAL(name) __declspec(dllexport) XSPROTO(name)
#    define XS_INTERNAL(name) STATIC XSPROTO(name)
#  endif
#  if defined(__SYMBIAN32__)
#    define XS_EXTERNAL(name) EXPORT_C XSPROTO(name)
#    define XS_INTERNAL(name) EXPORT_C STATIC XSPROTO(name)
#  endif
#  ifndef XS_EXTERNAL
#    if defined(HASATTRIBUTE_UNUSED) && !defined(__cplusplus)
#      define XS_EXTERNAL(name) void name(pTHX_ CV* cv __attribute__unused__)
#      define XS_INTERNAL(name) STATIC void name(pTHX_ CV* cv __attribute__unused__)
#    else
#      ifdef __cplusplus
#        define XS_EXTERNAL(name) extern "C" XSPROTO(name)
#        define XS_INTERNAL(name) static XSPROTO(name)
#      else
#        define XS_EXTERNAL(name) XSPROTO(name)
#        define XS_INTERNAL(name) STATIC XSPROTO(name)
#      endif
#    endif
#  endif
#endif

/* perl >= 5.10.0 && perl <= 5.15.1 */


/* The XS_EXTERNAL macro is used for functions that must not be static
 * like the boot XSUB of a module. If perl didn't have an XS_EXTERNAL
 * macro defined, the best we can do is assume XS is the same.
 * Dito for XS_INTERNAL.
 */
#ifndef XS_EXTERNAL
#  define XS_EXTERNAL(name) XS(name)
#endif
#ifndef XS_INTERNAL
#  define XS_INTERNAL(name) XS(name)
#endif

/* Now, finally, after all this mess, we want an ExtUtils::ParseXS
 * internal macro that we're free to redefine for varying linkage due
 * to the EXPORT_XSUB_SYMBOLS XS keyword. This is internal, use
 * XS_EXTERNAL(name) or XS_INTERNAL(name) in your code if you need to!
 */

#undef XS_EUPXS
#if defined(PERL_EUPXS_ALWAYS_EXPORT)
#  define XS_EUPXS(name) XS_EXTERNAL(name)
#else
   /* default to internal */
#  define XS_EUPXS(name) XS_INTERNAL(name)
#endif

#ifndef PERL_ARGS_ASSERT_CROAK_XS_USAGE
#define PERL_ARGS_ASSERT_CROAK_XS_USAGE assert(cv); assert(params)

/* prototype to pass -Wmissing-prototypes */
STATIC void
S_croak_xs_usage(const CV *const cv, const char *const params);

STATIC void
S_croak_xs_usage(const CV *const cv, const char *const params)
{
    const GV *const gv = CvGV(cv);

    PERL_ARGS_ASSERT_CROAK_XS_USAGE;

    if (gv) {
        const char *const gvname = GvNAME(gv);
        const HV *const stash = GvSTASH(gv);
        const char *const hvname = stash ? HvNAME(stash) : NULL;

        if (hvname)
	    Perl_croak_nocontext("Usage: %s::%s(%s)", hvname, gvname, params);
        else
	    Perl_croak_nocontext("Usage: %s(%s)", gvname, params);
    } else {
        /* Pants. I don't think that it should be possible to get here. */
	Perl_croak_nocontext("Usage: CODE(0x%" UVxf ")(%s)", PTR2UV(cv), params);
    }
}
#undef  PERL_ARGS_ASSERT_CROAK_XS_USAGE

#define croak_xs_usage        S_croak_xs_usage

#endif

/* NOTE: the prototype of newXSproto() is different in versions of perls,
 * so we define a portable version of newXSproto()
 */
#ifdef newXS_flags
#define newXSproto_portable(name, c_impl, file, proto) newXS_flags(name, c_impl, file, proto, 0)
#else
#define newXSproto_portable(name, c_impl, file, proto) (PL_Sv=(SV*)newXS(name, c_impl, file), sv_setpv(PL_Sv, proto), (CV*)PL_Sv)
#endif /* !defined(newXS_flags) */

#if PERL_VERSION_LE(5, 21, 5)
#  define newXS_deffile(a,b) Perl_newXS(aTHX_ a,b,file)
#else
#  define newXS_deffile(a,b) Perl_newXS_deffile(aTHX_ a,b)
#endif

#include "cpp/include/perltest.h"

/* INCLUDE_COMMAND:  Including output of '/usr/bin/perl -I../.. -MExtUtils::XSpp::Cmd -e xspp -- -t typemap.xsp -t ../../typemap.xsp XS/PerlTest.xsp' from 'PerlTest.xs' */

#include <exception>

#undef  xsp_constructor_class
#define xsp_constructor_class(c) (c)
#include "xspp/wxplperltestabstractnonobject.h"

XS_EUPXS(XS_Wx__PerlTestAbstractNonObject_CLONE); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__PerlTestAbstractNonObject_CLONE)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "CLASS");
    {
	char *	CLASS = (char *)SvPV_nolen(ST(0))
;
    wxPli_thread_sv_clone( aTHX_ CLASS, (wxPliCloneSV)wxPli_detach_object );
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__PerlTestAbstractNonObject_GetMoniker); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__PerlTestAbstractNonObject_GetMoniker)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxPerlTestAbstractNonObject *    THIS = (wxPerlTestAbstractNonObject *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::PerlTestAbstractNonObject" )
;
	wxString	RETVAL;
    try {
      RETVAL = THIS->GetMoniker();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    WXSTRING_OUTPUT( RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__PerlTestAbstractNonObject_GetMessage); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__PerlTestAbstractNonObject_GetMessage)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxPerlTestAbstractNonObject *    THIS = (wxPerlTestAbstractNonObject *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::PerlTestAbstractNonObject" )
;
	wxString	RETVAL;
    try {
      RETVAL = THIS->GetMessage();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    WXSTRING_OUTPUT( RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__PerlTestAbstractNonObject_DoGetMessage); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__PerlTestAbstractNonObject_DoGetMessage)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxPerlTestAbstractNonObject *    THIS = (wxPerlTestAbstractNonObject *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::PerlTestAbstractNonObject" )
;
	wxString	RETVAL;
    try {
      RETVAL = THIS->DoGetMessage();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    WXSTRING_OUTPUT( RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__PerlTestAbstractNonObject_EchoClassName); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__PerlTestAbstractNonObject_EchoClassName)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxPerlTestAbstractNonObject *    THIS = (wxPerlTestAbstractNonObject *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::PerlTestAbstractNonObject" )
;
	wxString	RETVAL;
    try {
      RETVAL = THIS->EchoClassName();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    WXSTRING_OUTPUT( RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__PerlTestAbstractNonObject_OnlyInBase); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__PerlTestAbstractNonObject_OnlyInBase)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxPerlTestAbstractNonObject *    THIS = (wxPerlTestAbstractNonObject *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::PerlTestAbstractNonObject" )
;
	wxString	RETVAL;
    try {
      RETVAL = THIS->OnlyInBase();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    WXSTRING_OUTPUT( RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}

#include "xspp/wxplperltestnonobject.h"

XS_EUPXS(XS_Wx__PerlTestNonObject_CLONE); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__PerlTestNonObject_CLONE)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "CLASS");
    {
	char *	CLASS = (char *)SvPV_nolen(ST(0))
;
    wxPli_thread_sv_clone( aTHX_ CLASS, (wxPliCloneSV)wxPli_detach_object );
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__PerlTestNonObject_DoGetMessage); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__PerlTestNonObject_DoGetMessage)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxPerlTestNonObject *    THIS = (wxPerlTestNonObject *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::PerlTestNonObject" )
;
	wxString	RETVAL;
    try {
      RETVAL = THIS->DoGetMessage();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    WXSTRING_OUTPUT( RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__PerlTestNonObject_EchoClassName); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__PerlTestNonObject_EchoClassName)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxPerlTestNonObject *    THIS = (wxPerlTestNonObject *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::PerlTestNonObject" )
;
	wxString	RETVAL;
    try {
      RETVAL = THIS->EchoClassName();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    WXSTRING_OUTPUT( RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}

#include "xspp/wxplperltestabstractobject.h"

XS_EUPXS(XS_Wx__PerlTestAbstractObject_CLONE); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__PerlTestAbstractObject_CLONE)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "CLASS");
    {
	char *	CLASS = (char *)SvPV_nolen(ST(0))
;
    wxPli_thread_sv_clone( aTHX_ CLASS, (wxPliCloneSV)wxPli_detach_object );
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__PerlTestAbstractObject_DESTROY); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__PerlTestAbstractObject_DESTROY)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxPerlTestAbstractObject *    THIS = (wxPerlTestAbstractObject *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::PerlTestAbstractObject" )
;
      wxPli_thread_sv_unregister( aTHX_ wxPli_get_class( aTHX_ ST(0) ), THIS, ST(0) );
                 delete THIS;
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__PerlTestAbstractObject_GetMoniker); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__PerlTestAbstractObject_GetMoniker)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxPerlTestAbstractObject *    THIS = (wxPerlTestAbstractObject *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::PerlTestAbstractObject" )
;
	wxString	RETVAL;
    try {
      RETVAL = THIS->GetMoniker();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    WXSTRING_OUTPUT( RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__PerlTestAbstractObject_GetMessage); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__PerlTestAbstractObject_GetMessage)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxPerlTestAbstractObject *    THIS = (wxPerlTestAbstractObject *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::PerlTestAbstractObject" )
;
	wxString	RETVAL;
    try {
      RETVAL = THIS->GetMessage();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    WXSTRING_OUTPUT( RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__PerlTestAbstractObject_DoGetMessage); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__PerlTestAbstractObject_DoGetMessage)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxPerlTestAbstractObject *    THIS = (wxPerlTestAbstractObject *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::PerlTestAbstractObject" )
;
	wxString	RETVAL;
    try {
      RETVAL = THIS->DoGetMessage();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    WXSTRING_OUTPUT( RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__PerlTestAbstractObject_EchoClassName); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__PerlTestAbstractObject_EchoClassName)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxPerlTestAbstractObject *    THIS = (wxPerlTestAbstractObject *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::PerlTestAbstractObject" )
;
	wxString	RETVAL;
    try {
      RETVAL = THIS->EchoClassName();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    WXSTRING_OUTPUT( RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__PerlTestAbstractObject_OnlyInBase); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__PerlTestAbstractObject_OnlyInBase)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxPerlTestAbstractObject *    THIS = (wxPerlTestAbstractObject *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::PerlTestAbstractObject" )
;
	wxString	RETVAL;
    try {
      RETVAL = THIS->OnlyInBase();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    WXSTRING_OUTPUT( RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}

#include "xspp/wxplperltestobject.h"

XS_EUPXS(XS_Wx__PerlTestObject_CLONE); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__PerlTestObject_CLONE)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "CLASS");
    {
	char *	CLASS = (char *)SvPV_nolen(ST(0))
;
    wxPli_thread_sv_clone( aTHX_ CLASS, (wxPliCloneSV)wxPli_detach_object );
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__PerlTestObject_DESTROY); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__PerlTestObject_DESTROY)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxPerlTestObject *    THIS = (wxPerlTestObject *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::PerlTestObject" )
;
      wxPli_thread_sv_unregister( aTHX_ wxPli_get_class( aTHX_ ST(0) ), THIS, ST(0) );
                 delete THIS;
    }
    XSRETURN_EMPTY;
}

#undef  xsp_constructor_class
#define xsp_constructor_class(c) (CLASS)

XS_EUPXS(XS_Wx__PerlTestObject_new); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__PerlTestObject_new)
{
    dVAR; dXSARGS;
    if (items < 1 || items > 2)
       croak_xs_usage(cv,  "CLASS, moniker= wxT(\"Object\")");
    {
	char *	CLASS = (char *)SvPV_nolen(ST(0))
;
	wxPerlTestObject *	RETVAL;
	wxString	moniker;

	if (items < 2)
	    moniker = wxT("Object");
	else {
    WXSTRING_INPUT( moniker, wxString, ST(1) )
;
	}
    RETVAL = new wxPlPerlTestObject( CLASS , moniker );
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_object_2_sv( aTHX_ RETVALSV, RETVAL );
    wxPli_thread_sv_register( aTHX_ "Wx::PerlTestObject", RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}

#undef  xsp_constructor_class
#define xsp_constructor_class(c) (c)
#if 1
#undef  xsp_constructor_class
#define xsp_constructor_class(c) (CLASS)
#define XSubPPtmpAAAA 1


XS_EUPXS(XS_Wx__PlPerlTestAbstractNonObject_new); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__PlPerlTestAbstractNonObject_new)
{
    dVAR; dXSARGS;
    if (items < 1 || items > 2)
       croak_xs_usage(cv,  "CLASS, moniker= wxT(\"AbstractNonObject\")");
    {
	char *	CLASS = (char *)SvPV_nolen(ST(0))
;
	wxPlPerlTestAbstractNonObject *	RETVAL;
	wxString	moniker;

	if (items < 2)
	    moniker = wxT("AbstractNonObject");
	else {
    WXSTRING_INPUT( moniker, wxString, ST(1) )
;
	}
    RETVAL = new wxPlPerlTestAbstractNonObject( CLASS , moniker );
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    if( RETVAL == 0 )
    {
       RETVALSV = &PL_sv_undef;
    } else {
       SvSetSV_nosteal( RETVALSV, RETVAL->GetSelf() );
       wxPli_thread_sv_register( aTHX_ "Wx::PlPerlTestAbstractNonObject", RETVAL, RETVALSV );
    }
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}

#undef  xsp_constructor_class
#define xsp_constructor_class(c) (c)
#if 1
#define XSubPPtmpAAAB 1


XS_EUPXS(XS_Wx__PlPerlTestAbstractNonObject_EchoClassName); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__PlPerlTestAbstractNonObject_EchoClassName)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxPlPerlTestAbstractNonObject *    THIS = (wxPlPerlTestAbstractNonObject *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::PlPerlTestAbstractNonObject" )
;
    try {
      THIS->base_EchoClassName();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}

#endif // 1
#if 1
#define XSubPPtmpAAAC 1


XS_EUPXS(XS_Wx__PlPerlTestAbstractNonObject_OnlyInBase); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__PlPerlTestAbstractNonObject_OnlyInBase)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxPlPerlTestAbstractNonObject *    THIS = (wxPlPerlTestAbstractNonObject *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::PlPerlTestAbstractNonObject" )
;
    try {
      THIS->base_OnlyInBase();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}

#endif // 1

XS_EUPXS(XS_Wx__PlPerlTestAbstractNonObject_DESTROY); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__PlPerlTestAbstractNonObject_DESTROY)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxPlPerlTestAbstractNonObject *    THIS = (wxPlPerlTestAbstractNonObject *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::PlPerlTestAbstractNonObject" )
;
      wxPli_thread_sv_unregister( aTHX_ wxPli_get_class( aTHX_ ST(0) ), THIS, ST(0) );
                 delete THIS;
    }
    XSRETURN_EMPTY;
}

#endif // 1
#if 1
#undef  xsp_constructor_class
#define xsp_constructor_class(c) (CLASS)
#define XSubPPtmpAAAD 1


XS_EUPXS(XS_Wx__PlPerlTestNonObject_new); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__PlPerlTestNonObject_new)
{
    dVAR; dXSARGS;
    if (items < 1 || items > 2)
       croak_xs_usage(cv,  "CLASS, moniker= wxT(\"NonObject\")");
    {
	char *	CLASS = (char *)SvPV_nolen(ST(0))
;
	wxPlPerlTestNonObject *	RETVAL;
	wxString	moniker;

	if (items < 2)
	    moniker = wxT("NonObject");
	else {
    WXSTRING_INPUT( moniker, wxString, ST(1) )
;
	}
    RETVAL = new wxPlPerlTestNonObject( CLASS , moniker );
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    if( RETVAL == 0 )
    {
       RETVALSV = &PL_sv_undef;
    } else {
       SvSetSV_nosteal( RETVALSV, RETVAL->GetSelf() );
       wxPli_thread_sv_register( aTHX_ "Wx::PlPerlTestNonObject", RETVAL, RETVALSV );
    }
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}

#undef  xsp_constructor_class
#define xsp_constructor_class(c) (c)
#if 1
#define XSubPPtmpAAAE 1


XS_EUPXS(XS_Wx__PlPerlTestNonObject_DoGetMessage); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__PlPerlTestNonObject_DoGetMessage)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxPlPerlTestNonObject *    THIS = (wxPlPerlTestNonObject *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::PlPerlTestNonObject" )
;
    try {
      THIS->base_DoGetMessage();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}

#endif // 1
#if 1
#define XSubPPtmpAAAF 1


XS_EUPXS(XS_Wx__PlPerlTestNonObject_EchoClassName); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__PlPerlTestNonObject_EchoClassName)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxPlPerlTestNonObject *    THIS = (wxPlPerlTestNonObject *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::PlPerlTestNonObject" )
;
    try {
      THIS->base_EchoClassName();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}

#endif // 1

XS_EUPXS(XS_Wx__PlPerlTestNonObject_DESTROY); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__PlPerlTestNonObject_DESTROY)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxPlPerlTestNonObject *    THIS = (wxPlPerlTestNonObject *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::PlPerlTestNonObject" )
;
      wxPli_thread_sv_unregister( aTHX_ wxPli_get_class( aTHX_ ST(0) ), THIS, ST(0) );
                delete THIS;
    }
    XSRETURN_EMPTY;
}

#endif // 1
#if 1
#undef  xsp_constructor_class
#define xsp_constructor_class(c) (CLASS)
#define XSubPPtmpAAAG 1


XS_EUPXS(XS_Wx__PlPerlTestAbstractObject_new); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__PlPerlTestAbstractObject_new)
{
    dVAR; dXSARGS;
    if (items < 1 || items > 2)
       croak_xs_usage(cv,  "CLASS, moniker= wxT(\"AbstractObject\")");
    {
	char *	CLASS = (char *)SvPV_nolen(ST(0))
;
	wxPlPerlTestAbstractObject *	RETVAL;
	wxString	moniker;

	if (items < 2)
	    moniker = wxT("AbstractObject");
	else {
    WXSTRING_INPUT( moniker, wxString, ST(1) )
;
	}
    RETVAL = new wxPlPerlTestAbstractObject( CLASS , moniker );
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_object_2_sv( aTHX_ RETVALSV, RETVAL );
    wxPli_thread_sv_register( aTHX_ "Wx::PlPerlTestAbstractObject", RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}

#undef  xsp_constructor_class
#define xsp_constructor_class(c) (c)
#if 1
#define XSubPPtmpAAAH 1


XS_EUPXS(XS_Wx__PlPerlTestAbstractObject_EchoClassName); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__PlPerlTestAbstractObject_EchoClassName)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxPlPerlTestAbstractObject *    THIS = (wxPlPerlTestAbstractObject *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::PlPerlTestAbstractObject" )
;
    try {
      THIS->base_EchoClassName();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}

#endif // 1
#if 1
#define XSubPPtmpAAAI 1


XS_EUPXS(XS_Wx__PlPerlTestAbstractObject_OnlyInBase); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__PlPerlTestAbstractObject_OnlyInBase)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxPlPerlTestAbstractObject *    THIS = (wxPlPerlTestAbstractObject *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::PlPerlTestAbstractObject" )
;
    try {
      THIS->base_OnlyInBase();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}

#endif // 1
#endif // 1
#if 1
#if 1
#define XSubPPtmpAAAJ 1


XS_EUPXS(XS_Wx__PerlTestObject_DoGetMessage); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__PerlTestObject_DoGetMessage)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxPlPerlTestObject *    THIS = (wxPlPerlTestObject *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::PlPerlTestObject" )
;
    try {
      THIS->base_DoGetMessage();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}

#endif // 1
#if 1
#define XSubPPtmpAAAK 1


XS_EUPXS(XS_Wx__PerlTestObject_EchoClassName); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__PerlTestObject_EchoClassName)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxPlPerlTestObject *    THIS = (wxPlPerlTestObject *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::PlPerlTestObject" )
;
    try {
      THIS->base_EchoClassName();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}

#endif // 1
#endif // 1

/* INCLUDE: Returning to 'PerlTest.xs' from '/usr/bin/perl -I../.. -MExtUtils::XSpp::Cmd -e xspp -- -t typemap.xsp -t ../../typemap.xsp XS/PerlTest.xsp' */

#ifdef __cplusplus
extern "C"
#endif
XS_EXTERNAL(boot_Wx__PerlTest); /* prototype to pass -Wmissing-prototypes */
XS_EXTERNAL(boot_Wx__PerlTest)
{
#if PERL_VERSION_LE(5, 21, 5)
    dVAR; dXSARGS;
#else
    dVAR; dXSBOOTARGSXSAPIVERCHK;
#endif
#if PERL_VERSION_LE(5, 8, 999) /* PERL_VERSION_LT is 5.33+ */
    char* file = __FILE__;
#else
    const char* file = __FILE__;
#endif

    PERL_UNUSED_VAR(file);

    PERL_UNUSED_VAR(cv); /* -W */
    PERL_UNUSED_VAR(items); /* -W */
#if PERL_VERSION_LE(5, 21, 5)
    XS_VERSION_BOOTCHECK;
#  ifdef XS_APIVERSION_BOOTCHECK
    XS_APIVERSION_BOOTCHECK;
#  endif
#endif

        newXS_deffile("Wx::PerlTestAbstractNonObject::CLONE", XS_Wx__PerlTestAbstractNonObject_CLONE);
        newXS_deffile("Wx::PerlTestAbstractNonObject::GetMoniker", XS_Wx__PerlTestAbstractNonObject_GetMoniker);
        newXS_deffile("Wx::PerlTestAbstractNonObject::GetMessage", XS_Wx__PerlTestAbstractNonObject_GetMessage);
        newXS_deffile("Wx::PerlTestAbstractNonObject::DoGetMessage", XS_Wx__PerlTestAbstractNonObject_DoGetMessage);
        newXS_deffile("Wx::PerlTestAbstractNonObject::EchoClassName", XS_Wx__PerlTestAbstractNonObject_EchoClassName);
        newXS_deffile("Wx::PerlTestAbstractNonObject::OnlyInBase", XS_Wx__PerlTestAbstractNonObject_OnlyInBase);
        newXS_deffile("Wx::PerlTestNonObject::CLONE", XS_Wx__PerlTestNonObject_CLONE);
        newXS_deffile("Wx::PerlTestNonObject::DoGetMessage", XS_Wx__PerlTestNonObject_DoGetMessage);
        newXS_deffile("Wx::PerlTestNonObject::EchoClassName", XS_Wx__PerlTestNonObject_EchoClassName);
        newXS_deffile("Wx::PerlTestAbstractObject::CLONE", XS_Wx__PerlTestAbstractObject_CLONE);
        newXS_deffile("Wx::PerlTestAbstractObject::DESTROY", XS_Wx__PerlTestAbstractObject_DESTROY);
        newXS_deffile("Wx::PerlTestAbstractObject::GetMoniker", XS_Wx__PerlTestAbstractObject_GetMoniker);
        newXS_deffile("Wx::PerlTestAbstractObject::GetMessage", XS_Wx__PerlTestAbstractObject_GetMessage);
        newXS_deffile("Wx::PerlTestAbstractObject::DoGetMessage", XS_Wx__PerlTestAbstractObject_DoGetMessage);
        newXS_deffile("Wx::PerlTestAbstractObject::EchoClassName", XS_Wx__PerlTestAbstractObject_EchoClassName);
        newXS_deffile("Wx::PerlTestAbstractObject::OnlyInBase", XS_Wx__PerlTestAbstractObject_OnlyInBase);
        newXS_deffile("Wx::PerlTestObject::CLONE", XS_Wx__PerlTestObject_CLONE);
        newXS_deffile("Wx::PerlTestObject::DESTROY", XS_Wx__PerlTestObject_DESTROY);
        newXS_deffile("Wx::PerlTestObject::new", XS_Wx__PerlTestObject_new);
#if XSubPPtmpAAAA
        newXS_deffile("Wx::PlPerlTestAbstractNonObject::new", XS_Wx__PlPerlTestAbstractNonObject_new);
#if XSubPPtmpAAAB
        newXS_deffile("Wx::PlPerlTestAbstractNonObject::EchoClassName", XS_Wx__PlPerlTestAbstractNonObject_EchoClassName);
#endif
#if XSubPPtmpAAAC
        newXS_deffile("Wx::PlPerlTestAbstractNonObject::OnlyInBase", XS_Wx__PlPerlTestAbstractNonObject_OnlyInBase);
#endif
        newXS_deffile("Wx::PlPerlTestAbstractNonObject::DESTROY", XS_Wx__PlPerlTestAbstractNonObject_DESTROY);
#endif
#if XSubPPtmpAAAD
        newXS_deffile("Wx::PlPerlTestNonObject::new", XS_Wx__PlPerlTestNonObject_new);
#if XSubPPtmpAAAE
        newXS_deffile("Wx::PlPerlTestNonObject::DoGetMessage", XS_Wx__PlPerlTestNonObject_DoGetMessage);
#endif
#if XSubPPtmpAAAF
        newXS_deffile("Wx::PlPerlTestNonObject::EchoClassName", XS_Wx__PlPerlTestNonObject_EchoClassName);
#endif
        newXS_deffile("Wx::PlPerlTestNonObject::DESTROY", XS_Wx__PlPerlTestNonObject_DESTROY);
#endif
#if XSubPPtmpAAAG
        newXS_deffile("Wx::PlPerlTestAbstractObject::new", XS_Wx__PlPerlTestAbstractObject_new);
#if XSubPPtmpAAAH
        newXS_deffile("Wx::PlPerlTestAbstractObject::EchoClassName", XS_Wx__PlPerlTestAbstractObject_EchoClassName);
#endif
#if XSubPPtmpAAAI
        newXS_deffile("Wx::PlPerlTestAbstractObject::OnlyInBase", XS_Wx__PlPerlTestAbstractObject_OnlyInBase);
#endif
#endif
#if XSubPPtmpAAAJ
        newXS_deffile("Wx::PerlTestObject::DoGetMessage", XS_Wx__PerlTestObject_DoGetMessage);
#endif
#if XSubPPtmpAAAK
        newXS_deffile("Wx::PerlTestObject::EchoClassName", XS_Wx__PerlTestObject_EchoClassName);
#endif

    /* Initialisation Section */

  INIT_PLI_HELPERS( wx_pli_helpers );

    {
        AV* isa = get_av( "Wx::PerlTestNonObject::ISA", 1 );
        av_store( isa, 0, newSVpv( "Wx::PerlTestAbstractNonObject", 0 ) );
    } // blank line here is important

    {
        AV* isa = get_av( "Wx::PerlTestAbstractObject::ISA", 1 );
        av_store( isa, 0, newSVpv( "Wx::Object", 0 ) );
    } // blank line here is important

    {
        AV* isa = get_av( "Wx::PerlTestObject::ISA", 1 );
        av_store( isa, 0, newSVpv( "Wx::PerlTestAbstractObject", 0 ) );
    } // blank line here is important

#if XSubPPtmpAAAA
#if XSubPPtmpAAAB
#endif
#if XSubPPtmpAAAC
#endif
    {
        AV* isa = get_av( "Wx::PlPerlTestAbstractNonObject::ISA", 1 );
        av_store( isa, 0, newSVpv( "Wx::PerlTestAbstractNonObject", 0 ) );
    } // blank line here is important

#endif
#if XSubPPtmpAAAD
#if XSubPPtmpAAAE
#endif
#if XSubPPtmpAAAF
#endif
    {
        AV* isa = get_av( "Wx::PlPerlTestNonObject::ISA", 1 );
        av_store( isa, 0, newSVpv( "Wx::PerlTestNonObject", 0 ) );
    } // blank line here is important

#endif
#if XSubPPtmpAAAG
#if XSubPPtmpAAAH
#endif
#if XSubPPtmpAAAI
#endif
    {
        AV* isa = get_av( "Wx::PlPerlTestAbstractObject::ISA", 1 );
        av_store( isa, 0, newSVpv( "Wx::PerlTestAbstractObject", 0 ) );
    } // blank line here is important

#endif
#if XSubPPtmpAAAJ
#endif
#if XSubPPtmpAAAK
#endif

    /* End of Initialisation Section */

#if PERL_VERSION_LE(5, 21, 5)
#  if PERL_VERSION_GE(5, 9, 0)
    if (PL_unitcheckav)
        call_list(PL_scopestack_ix, PL_unitcheckav);
#  endif
    XSRETURN_YES;
#else
    Perl_xs_boot_epilog(aTHX_ ax);
#endif
}

