/*
 * This file was generated automatically by ExtUtils::ParseXS version 3.44 from the
 * contents of Help.xs. Do not edit this file, edit Help.xs instead.
 *
 *    ANY CHANGES MADE HERE WILL BE LOST!
 *
 */

/////////////////////////////////////////////////////////////////////////////
// Name:        ext/help/Help.xs
// Purpose:     XS for Wx::HelpController*
// Author:      Mattia Barbon
// Modified by:
// Created:     18/03/2001
// RCS-ID:      $Id: Help.xs 2057 2007-06-18 23:03:00Z mbarbon $
// Copyright:   (c) 2001-2002, 2006 Mattia Barbon
// Licence:     This program is free software; you can redistribute it and/or
//              modify it under the same terms as Perl itself
/////////////////////////////////////////////////////////////////////////////

#define PERL_NO_GET_CONTEXT

#include "cpp/wxapi.h"

#undef THIS

#ifndef PERL_UNUSED_VAR
#  define PERL_UNUSED_VAR(var) if (0) var = var
#endif

#ifndef dVAR
#  define dVAR		dNOOP
#endif


/* This stuff is not part of the API! You have been warned. */
#ifndef PERL_VERSION_DECIMAL
#  define PERL_VERSION_DECIMAL(r,v,s) (r*1000000 + v*1000 + s)
#endif
#ifndef PERL_DECIMAL_VERSION
#  define PERL_DECIMAL_VERSION \
	  PERL_VERSION_DECIMAL(PERL_REVISION,PERL_VERSION,PERL_SUBVERSION)
#endif
#ifndef PERL_VERSION_GE
#  define PERL_VERSION_GE(r,v,s) \
	  (PERL_DECIMAL_VERSION >= PERL_VERSION_DECIMAL(r,v,s))
#endif
#ifndef PERL_VERSION_LE
#  define PERL_VERSION_LE(r,v,s) \
	  (PERL_DECIMAL_VERSION <= PERL_VERSION_DECIMAL(r,v,s))
#endif

/* XS_INTERNAL is the explicit static-linkage variant of the default
 * XS macro.
 *
 * XS_EXTERNAL is the same as XS_INTERNAL except it does not include
 * "STATIC", ie. it exports XSUB symbols. You probably don't want that
 * for anything but the BOOT XSUB.
 *
 * See XSUB.h in core!
 */


/* TODO: This might be compatible further back than 5.10.0. */
#if PERL_VERSION_GE(5, 10, 0) && PERL_VERSION_LE(5, 15, 1)
#  undef XS_EXTERNAL
#  undef XS_INTERNAL
#  if defined(__CYGWIN__) && defined(USE_DYNAMIC_LOADING)
#    define XS_EXTERNAL(name) __declspec(dllexport) XSPROTO(name)
#    define XS_INTERNAL(name) STATIC XSPROTO(name)
#  endif
#  if defined(__SYMBIAN32__)
#    define XS_EXTERNAL(name) EXPORT_C XSPROTO(name)
#    define XS_INTERNAL(name) EXPORT_C STATIC XSPROTO(name)
#  endif
#  ifndef XS_EXTERNAL
#    if defined(HASATTRIBUTE_UNUSED) && !defined(__cplusplus)
#      define XS_EXTERNAL(name) void name(pTHX_ CV* cv __attribute__unused__)
#      define XS_INTERNAL(name) STATIC void name(pTHX_ CV* cv __attribute__unused__)
#    else
#      ifdef __cplusplus
#        define XS_EXTERNAL(name) extern "C" XSPROTO(name)
#        define XS_INTERNAL(name) static XSPROTO(name)
#      else
#        define XS_EXTERNAL(name) XSPROTO(name)
#        define XS_INTERNAL(name) STATIC XSPROTO(name)
#      endif
#    endif
#  endif
#endif

/* perl >= 5.10.0 && perl <= 5.15.1 */


/* The XS_EXTERNAL macro is used for functions that must not be static
 * like the boot XSUB of a module. If perl didn't have an XS_EXTERNAL
 * macro defined, the best we can do is assume XS is the same.
 * Dito for XS_INTERNAL.
 */
#ifndef XS_EXTERNAL
#  define XS_EXTERNAL(name) XS(name)
#endif
#ifndef XS_INTERNAL
#  define XS_INTERNAL(name) XS(name)
#endif

/* Now, finally, after all this mess, we want an ExtUtils::ParseXS
 * internal macro that we're free to redefine for varying linkage due
 * to the EXPORT_XSUB_SYMBOLS XS keyword. This is internal, use
 * XS_EXTERNAL(name) or XS_INTERNAL(name) in your code if you need to!
 */

#undef XS_EUPXS
#if defined(PERL_EUPXS_ALWAYS_EXPORT)
#  define XS_EUPXS(name) XS_EXTERNAL(name)
#else
   /* default to internal */
#  define XS_EUPXS(name) XS_INTERNAL(name)
#endif

#ifndef PERL_ARGS_ASSERT_CROAK_XS_USAGE
#define PERL_ARGS_ASSERT_CROAK_XS_USAGE assert(cv); assert(params)

/* prototype to pass -Wmissing-prototypes */
STATIC void
S_croak_xs_usage(const CV *const cv, const char *const params);

STATIC void
S_croak_xs_usage(const CV *const cv, const char *const params)
{
    const GV *const gv = CvGV(cv);

    PERL_ARGS_ASSERT_CROAK_XS_USAGE;

    if (gv) {
        const char *const gvname = GvNAME(gv);
        const HV *const stash = GvSTASH(gv);
        const char *const hvname = stash ? HvNAME(stash) : NULL;

        if (hvname)
	    Perl_croak_nocontext("Usage: %s::%s(%s)", hvname, gvname, params);
        else
	    Perl_croak_nocontext("Usage: %s(%s)", gvname, params);
    } else {
        /* Pants. I don't think that it should be possible to get here. */
	Perl_croak_nocontext("Usage: CODE(0x%" UVxf ")(%s)", PTR2UV(cv), params);
    }
}
#undef  PERL_ARGS_ASSERT_CROAK_XS_USAGE

#define croak_xs_usage        S_croak_xs_usage

#endif

/* NOTE: the prototype of newXSproto() is different in versions of perls,
 * so we define a portable version of newXSproto()
 */
#ifdef newXS_flags
#define newXSproto_portable(name, c_impl, file, proto) newXS_flags(name, c_impl, file, proto, 0)
#else
#define newXSproto_portable(name, c_impl, file, proto) (PL_Sv=(SV*)newXS(name, c_impl, file), sv_setpv(PL_Sv, proto), (CV*)PL_Sv)
#endif /* !defined(newXS_flags) */

#if PERL_VERSION_LE(5, 21, 5)
#  define newXS_deffile(a,b) Perl_newXS(aTHX_ a,b,file)
#else
#  define newXS_deffile(a,b) Perl_newXS_deffile(aTHX_ a,b)
#endif


/* INCLUDE:  Including 'XS/HelpController.xs' from 'Help.xs' */


/* INCLUDE:  Including 'XS/HelpProvider.xs' from 'XS/HelpController.xs' */


/* INCLUDE:  Including 'XS/ContextHelp.xs' from 'XS/HelpProvider.xs' */

#include <wx/cshelp.h>
#undef THIS

XS_EUPXS(XS_Wx__ContextHelp_new); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ContextHelp_new)
{
    dVAR; dXSARGS;
    if (items < 1 || items > 3)
       croak_xs_usage(cv,  "CLASS, window = NULL, beginHelp = true");
    {
	wxWindow*	window;
	bool	beginHelp;
	char *	CLASS = (char *)SvPV_nolen(ST(0))
;
	wxContextHelp *	RETVAL;

	if (items < 2)
	    window = NULL;
	else {
    window = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::Window" )
;
	}

	if (items < 3)
	    beginHelp = true;
	else {
	    beginHelp = (bool)SvTRUE(ST(2))
;
	}

	RETVAL = new wxContextHelp(window, beginHelp);
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_object_2_sv( aTHX_ RETVALSV, RETVAL );
    wxPli_thread_sv_register( aTHX_ "Wx::ContextHelp", RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__ContextHelp_CLONE); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ContextHelp_CLONE)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "CLASS");
    {
	char *	CLASS = (char *)SvPV_nolen(ST(0))
;
    wxPli_thread_sv_clone( aTHX_ CLASS, (wxPliCloneSV)wxPli_detach_object );
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__ContextHelp_DESTROY); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ContextHelp_DESTROY)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxContextHelp *    THIS = (wxContextHelp *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::ContextHelp" )
;
    wxPli_thread_sv_unregister( aTHX_ "Wx::ContextHelp", THIS, ST(0) );
    delete THIS;
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__ContextHelp_BeginContextHelp); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ContextHelp_BeginContextHelp)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, window");
    {
	wxWindow*    window = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::Window" )
;
	wxContextHelp *    THIS = (wxContextHelp *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::ContextHelp" )
;
	bool	RETVAL;

	RETVAL = THIS->BeginContextHelp(window);
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__ContextHelp_EndContextHelp); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ContextHelp_EndContextHelp)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxContextHelp *    THIS = (wxContextHelp *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::ContextHelp" )
;
	bool	RETVAL;

	RETVAL = THIS->EndContextHelp();
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__ContextHelp_SetStatus); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ContextHelp_SetStatus)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, status");
    {
	bool	status = (bool)SvTRUE(ST(1))
;
	wxContextHelp *    THIS = (wxContextHelp *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::ContextHelp" )
;

	THIS->SetStatus(status);
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__ContextHelpButton_new); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ContextHelpButton_new)
{
    dVAR; dXSARGS;
    if (items < 2 || items > 6)
       croak_xs_usage(cv,  "CLASS, parent, id = wxID_CONTEXT_HELP, pos = wxDefaultPosition, size = wxDefaultSize, style = wxBU_AUTODRAW");
    {
	wxWindow*    parent = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::Window" )
;
	wxWindowID	id;
	wxPoint	pos;
	wxSize	size;
	long	style;
	char *	CLASS = (char *)SvPV_nolen(ST(0))
;
	wxContextHelpButton *	RETVAL;

	if (items < 3)
	    id = wxID_CONTEXT_HELP;
	else {
    id = wxPli_get_wxwindowid( aTHX_ ST(2) )
;
	}

	if (items < 4)
	    pos = wxDefaultPosition;
	else {
    pos = wxPli_sv_2_wxpoint( aTHX_ ST(3) )
;
	}

	if (items < 5)
	    size = wxDefaultSize;
	else {
    size = wxPli_sv_2_wxsize( aTHX_ ST(4) )
;
	}

	if (items < 6)
	    style = wxBU_AUTODRAW;
	else {
	    style = (long)SvIV(ST(5))
;
	}
    RETVAL = new wxContextHelpButton( parent, id, pos, size, style );
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_object_2_sv( aTHX_ RETVALSV, RETVAL );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


/* INCLUDE: Returning to 'XS/HelpProvider.xs' from 'XS/ContextHelp.xs' */

#include <wx/cshelp.h>

XS_EUPXS(XS_Wx_ContextId); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx_ContextId)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "id");
    {
	int	id = (int)SvIV(ST(0))
;
	wxString	RETVAL;

	RETVAL = wxContextId(id);
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    WXSTRING_OUTPUT( RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__HelpProvider_Destroy); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__HelpProvider_Destroy)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxHelpProvider *    THIS = (wxHelpProvider *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::HelpProvider" )
;
    delete THIS;
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__HelpProvider_Get); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__HelpProvider_Get)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxHelpProvider *    THIS = (wxHelpProvider *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::HelpProvider" )
;
	wxHelpProvider *	RETVAL;
    RETVAL = wxHelpProvider::Get();
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_non_object_2_sv( aTHX_ RETVALSV, RETVAL, "Wx::HelpProvider" );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__HelpProvider_GetHelp); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__HelpProvider_GetHelp)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, window");
    {
	wxWindow*    window = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::Window" )
;
	wxHelpProvider *    THIS = (wxHelpProvider *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::HelpProvider" )
;
	wxString	RETVAL;

	RETVAL = THIS->GetHelp(window);
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    WXSTRING_OUTPUT( RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__HelpProvider_ShowHelp); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__HelpProvider_ShowHelp)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, window");
    {
	wxWindow*    window = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::Window" )
;
	wxHelpProvider *    THIS = (wxHelpProvider *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::HelpProvider" )
;
	bool	RETVAL;

	RETVAL = THIS->ShowHelp(window);
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__HelpProvider_AddHelp); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__HelpProvider_AddHelp)
{
    dVAR; dXSARGS;
    if (items != 3)
       croak_xs_usage(cv,  "THIS, window, text");
    {
	wxWindow*    window = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::Window" )
;
	wxString	text;
	wxHelpProvider *    THIS = (wxHelpProvider *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::HelpProvider" )
;

    WXSTRING_INPUT( text, wxString, ST(2) )
;

	THIS->AddHelp(window, text);
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__HelpProvider_AddHelpById); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__HelpProvider_AddHelpById)
{
    dVAR; dXSARGS;
    if (items != 3)
       croak_xs_usage(cv,  "THIS, id, text");
    {
	wxWindowID    id = wxPli_get_wxwindowid( aTHX_ ST(1) )
;
	wxString	text;
	wxHelpProvider *    THIS = (wxHelpProvider *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::HelpProvider" )
;

    WXSTRING_INPUT( text, wxString, ST(2) )
;
    THIS->AddHelp( id, text );
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__HelpProvider_Set); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__HelpProvider_Set)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "helpProvider");
    {
	wxHelpProvider*    helpProvider = (wxHelpProvider *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::HelpProvider" )
;
	wxHelpProvider *	RETVAL;
    RETVAL = wxHelpProvider::Set( helpProvider );
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_non_object_2_sv( aTHX_ RETVALSV, RETVAL, "Wx::HelpProvider" );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__SimpleHelpProvider_new); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__SimpleHelpProvider_new)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "CLASS");
    {
	char *	CLASS = (char *)SvPV_nolen(ST(0))
;
	wxSimpleHelpProvider *	RETVAL;
    RETVAL = new wxSimpleHelpProvider();
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_non_object_2_sv( aTHX_ RETVALSV, RETVAL, "Wx::SimpleHelpProvider" );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__HelpControllerHelpProvider_new); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__HelpControllerHelpProvider_new)
{
    dVAR; dXSARGS;
    if (items < 1 || items > 2)
       croak_xs_usage(cv,  "CLASS, hc = 0");
    {
	wxHelpControllerBase*	hc;
	char *	CLASS = (char *)SvPV_nolen(ST(0))
;
	wxHelpControllerHelpProvider *	RETVAL;

	if (items < 2)
	    hc = 0;
	else {
    hc = (wxHelpControllerBase *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::HelpControllerBase" )
;
	}
    RETVAL = new wxHelpControllerHelpProvider( hc );
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_non_object_2_sv( aTHX_ RETVALSV, RETVAL, "Wx::HelpControllerHelpProvider" );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__HelpControllerHelpProvider_SetHelpController); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__HelpControllerHelpProvider_SetHelpController)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, hc");
    {
	wxHelpControllerBase*    hc = (wxHelpControllerBase *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::HelpControllerBase" )
;
	wxHelpControllerHelpProvider *    THIS = (wxHelpControllerHelpProvider *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::HelpControllerHelpProvider" )
;

	THIS->SetHelpController(hc);
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__HelpControllerHelpProvider_GetHelpController); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__HelpControllerHelpProvider_GetHelpController)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxHelpControllerHelpProvider *    THIS = (wxHelpControllerHelpProvider *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::HelpControllerHelpProvider" )
;
	wxHelpControllerBase *	RETVAL;

	RETVAL = THIS->GetHelpController();
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_object_2_sv( aTHX_ RETVALSV, RETVAL );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


/* INCLUDE: Returning to 'XS/HelpController.xs' from 'XS/HelpProvider.xs' */

#include <wx/helpbase.h>

XS_EUPXS(XS_Wx__HelpControllerBase_Destroy); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__HelpControllerBase_Destroy)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxHelpControllerBase *    THIS = (wxHelpControllerBase *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::HelpControllerBase" )
;
    delete THIS;
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__HelpControllerBase_Initialize); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__HelpControllerBase_Initialize)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, file");
    {
	wxString	file;
	wxHelpControllerBase *    THIS = (wxHelpControllerBase *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::HelpControllerBase" )
;

    WXSTRING_INPUT( file, wxString, ST(1) )
;

	THIS->Initialize(file);
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__HelpControllerBase_DisplayBlock); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__HelpControllerBase_DisplayBlock)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, block");
    {
	long	block = (long)SvIV(ST(1))
;
	wxHelpControllerBase *    THIS = (wxHelpControllerBase *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::HelpControllerBase" )
;
	bool	RETVAL;

	RETVAL = THIS->DisplayBlock(block);
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__HelpControllerBase_DisplayContents); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__HelpControllerBase_DisplayContents)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxHelpControllerBase *    THIS = (wxHelpControllerBase *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::HelpControllerBase" )
;
	bool	RETVAL;

	RETVAL = THIS->DisplayContents();
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__HelpControllerBase_DisplayContextPopup); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__HelpControllerBase_DisplayContextPopup)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, id");
    {
	int	id = (int)SvIV(ST(1))
;
	wxHelpControllerBase *    THIS = (wxHelpControllerBase *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::HelpControllerBase" )
;
	bool	RETVAL;

	RETVAL = THIS->DisplayContextPopup(id);
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__HelpControllerBase_DisplayTextPopup); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__HelpControllerBase_DisplayTextPopup)
{
    dVAR; dXSARGS;
    if (items != 3)
       croak_xs_usage(cv,  "THIS, text, pos");
    {
	wxString	text;
	wxPoint    pos = wxPli_sv_2_wxpoint( aTHX_ ST(2) )
;
	wxHelpControllerBase *    THIS = (wxHelpControllerBase *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::HelpControllerBase" )
;
	bool	RETVAL;

    WXSTRING_INPUT( text, wxString, ST(1) )
;

	RETVAL = THIS->DisplayTextPopup(text, pos);
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__HelpControllerBase_DisplaySection); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__HelpControllerBase_DisplaySection)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, section");
    {
	wxString	section;
	wxHelpControllerBase *    THIS = (wxHelpControllerBase *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::HelpControllerBase" )
;
	bool	RETVAL;

    WXSTRING_INPUT( section, wxString, ST(1) )
;

	RETVAL = THIS->DisplaySection(section);
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__HelpControllerBase_DisplaySectionId); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__HelpControllerBase_DisplaySectionId)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, section");
    {
	long	section = (long)SvIV(ST(1))
;
	wxHelpControllerBase *    THIS = (wxHelpControllerBase *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::HelpControllerBase" )
;
	bool	RETVAL;
    RETVAL = THIS->DisplaySection( section );
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__HelpControllerBase_KeywordSearch); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__HelpControllerBase_KeywordSearch)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, keyword");
    {
	wxString	keyword;
	wxHelpControllerBase *    THIS = (wxHelpControllerBase *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::HelpControllerBase" )
;
	bool	RETVAL;

    WXSTRING_INPUT( keyword, wxString, ST(1) )
;

	RETVAL = THIS->KeywordSearch(keyword);
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__HelpControllerBase_LoadFile); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__HelpControllerBase_LoadFile)
{
    dVAR; dXSARGS;
    if (items < 1 || items > 2)
       croak_xs_usage(cv,  "THIS, file = wxEmptyString");
    {
	wxString	file;
	wxHelpControllerBase *    THIS = (wxHelpControllerBase *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::HelpControllerBase" )
;
	bool	RETVAL;

	if (items < 2)
	    file = wxEmptyString;
	else {
    WXSTRING_INPUT( file, wxString, ST(1) )
;
	}

	RETVAL = THIS->LoadFile(file);
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__HelpControllerBase_SetViewer); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__HelpControllerBase_SetViewer)
{
    dVAR; dXSARGS;
    if (items != 3)
       croak_xs_usage(cv,  "THIS, viewer, flags");
    {
	wxString	viewer;
	long	flags = (long)SvIV(ST(2))
;
	wxHelpControllerBase *    THIS = (wxHelpControllerBase *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::HelpControllerBase" )
;

    WXSTRING_INPUT( viewer, wxString, ST(1) )
;

	THIS->SetViewer(viewer, flags);
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__HelpControllerBase_Quit); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__HelpControllerBase_Quit)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxHelpControllerBase *    THIS = (wxHelpControllerBase *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::HelpControllerBase" )
;
	bool	RETVAL;

	RETVAL = THIS->Quit();
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}

#if WXPERL_W_VERSION_GE( 2, 6, 3 )
#define XSubPPtmpAAAA 1


XS_EUPXS(XS_Wx__HelpControllerBase_GetParentWindow); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__HelpControllerBase_GetParentWindow)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxHelpControllerBase *    THIS = (wxHelpControllerBase *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::HelpControllerBase" )
;
	wxWindow *	RETVAL;

	RETVAL = THIS->GetParentWindow();
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_object_2_sv( aTHX_ RETVALSV, RETVAL );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__HelpControllerBase_SetParentWindow); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__HelpControllerBase_SetParentWindow)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, parent");
    {
	wxWindow*    parent = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::Window" )
;
	wxHelpControllerBase *    THIS = (wxHelpControllerBase *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::HelpControllerBase" )
;

	THIS->SetParentWindow(parent);
    }
    XSRETURN_EMPTY;
}

#endif
#if defined( __WXMSW__ )
#include <wx/msw/helpwin.h>
#if WXPERL_W_VERSION_GE( 2, 7, 2 )
#define XSubPPtmpAAAB 1


XS_EUPXS(XS_Wx__WinHelpController_new); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__WinHelpController_new)
{
    dVAR; dXSARGS;
    if (items < 1 || items > 2)
       croak_xs_usage(cv,  "CLASS, parent = NULL");
    {
	wxWindow*	parent;
	char *	CLASS = (char *)SvPV_nolen(ST(0))
;
	wxWinHelpController *	RETVAL;

	if (items < 2)
	    parent = NULL;
	else {
    parent = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::Window" )
;
	}

	RETVAL = new wxWinHelpController(parent);
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_object_2_sv( aTHX_ RETVALSV, RETVAL );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}

#else
#define XSubPPtmpAAAC 1


XS_EUPXS(XS_Wx__WinHelpController_new); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__WinHelpController_new)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "CLASS");
    {
	char *	CLASS = (char *)SvPV_nolen(ST(0))
;
	wxWinHelpController *	RETVAL;

	RETVAL = new wxWinHelpController();
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_object_2_sv( aTHX_ RETVALSV, RETVAL );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}

#endif
#endif
#if wxUSE_MS_HTML_HELP
#include <wx/msw/helpchm.h>
#if WXPERL_W_VERSION_GE( 2, 7, 2 )
#define XSubPPtmpAAAD 1


XS_EUPXS(XS_Wx__CHMHelpController_new); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__CHMHelpController_new)
{
    dVAR; dXSARGS;
    if (items < 1 || items > 2)
       croak_xs_usage(cv,  "CLASS, parent = NULL");
    {
	wxWindow*	parent;
	char *	CLASS = (char *)SvPV_nolen(ST(0))
;
	wxCHMHelpController *	RETVAL;

	if (items < 2)
	    parent = NULL;
	else {
    parent = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::Window" )
;
	}

	RETVAL = new wxCHMHelpController(parent);
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_object_2_sv( aTHX_ RETVALSV, RETVAL );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}

#else
#define XSubPPtmpAAAE 1


XS_EUPXS(XS_Wx__CHMHelpController_new); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__CHMHelpController_new)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "CLASS");
    {
	char *	CLASS = (char *)SvPV_nolen(ST(0))
;
	wxCHMHelpController *	RETVAL;

	RETVAL = new wxCHMHelpController();
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_object_2_sv( aTHX_ RETVALSV, RETVAL );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}

#endif
#endif

/* INCLUDE: Returning to 'Help.xs' from 'XS/HelpController.xs' */

#if defined(__WXMSW__)
#undef XS
#define XS( name ) WXXS( name )
#endif
#ifdef __cplusplus
extern "C"
#endif
XS_EXTERNAL(boot_Wx__Help); /* prototype to pass -Wmissing-prototypes */
XS_EXTERNAL(boot_Wx__Help)
{
#if PERL_VERSION_LE(5, 21, 5)
    dVAR; dXSARGS;
#else
    dVAR; dXSBOOTARGSXSAPIVERCHK;
#endif
#if PERL_VERSION_LE(5, 8, 999) /* PERL_VERSION_LT is 5.33+ */
    char* file = __FILE__;
#else
    const char* file = __FILE__;
#endif

    PERL_UNUSED_VAR(file);

    PERL_UNUSED_VAR(cv); /* -W */
    PERL_UNUSED_VAR(items); /* -W */
#if PERL_VERSION_LE(5, 21, 5)
    XS_VERSION_BOOTCHECK;
#  ifdef XS_APIVERSION_BOOTCHECK
    XS_APIVERSION_BOOTCHECK;
#  endif
#endif

        newXS_deffile("Wx::ContextHelp::new", XS_Wx__ContextHelp_new);
        newXS_deffile("Wx::ContextHelp::CLONE", XS_Wx__ContextHelp_CLONE);
        newXS_deffile("Wx::ContextHelp::DESTROY", XS_Wx__ContextHelp_DESTROY);
        newXS_deffile("Wx::ContextHelp::BeginContextHelp", XS_Wx__ContextHelp_BeginContextHelp);
        newXS_deffile("Wx::ContextHelp::EndContextHelp", XS_Wx__ContextHelp_EndContextHelp);
        newXS_deffile("Wx::ContextHelp::SetStatus", XS_Wx__ContextHelp_SetStatus);
        newXS_deffile("Wx::ContextHelpButton::new", XS_Wx__ContextHelpButton_new);
        newXS_deffile("Wx::ContextId", XS_Wx_ContextId);
        newXS_deffile("Wx::HelpProvider::Destroy", XS_Wx__HelpProvider_Destroy);
        newXS_deffile("Wx::HelpProvider::Get", XS_Wx__HelpProvider_Get);
        newXS_deffile("Wx::HelpProvider::GetHelp", XS_Wx__HelpProvider_GetHelp);
        newXS_deffile("Wx::HelpProvider::ShowHelp", XS_Wx__HelpProvider_ShowHelp);
        newXS_deffile("Wx::HelpProvider::AddHelp", XS_Wx__HelpProvider_AddHelp);
        newXS_deffile("Wx::HelpProvider::AddHelpById", XS_Wx__HelpProvider_AddHelpById);
        newXS_deffile("Wx::HelpProvider::Set", XS_Wx__HelpProvider_Set);
        newXS_deffile("Wx::SimpleHelpProvider::new", XS_Wx__SimpleHelpProvider_new);
        newXS_deffile("Wx::HelpControllerHelpProvider::new", XS_Wx__HelpControllerHelpProvider_new);
        newXS_deffile("Wx::HelpControllerHelpProvider::SetHelpController", XS_Wx__HelpControllerHelpProvider_SetHelpController);
        newXS_deffile("Wx::HelpControllerHelpProvider::GetHelpController", XS_Wx__HelpControllerHelpProvider_GetHelpController);
        newXS_deffile("Wx::HelpControllerBase::Destroy", XS_Wx__HelpControllerBase_Destroy);
        newXS_deffile("Wx::HelpControllerBase::Initialize", XS_Wx__HelpControllerBase_Initialize);
        newXS_deffile("Wx::HelpControllerBase::DisplayBlock", XS_Wx__HelpControllerBase_DisplayBlock);
        newXS_deffile("Wx::HelpControllerBase::DisplayContents", XS_Wx__HelpControllerBase_DisplayContents);
        newXS_deffile("Wx::HelpControllerBase::DisplayContextPopup", XS_Wx__HelpControllerBase_DisplayContextPopup);
        newXS_deffile("Wx::HelpControllerBase::DisplayTextPopup", XS_Wx__HelpControllerBase_DisplayTextPopup);
        newXS_deffile("Wx::HelpControllerBase::DisplaySection", XS_Wx__HelpControllerBase_DisplaySection);
        newXS_deffile("Wx::HelpControllerBase::DisplaySectionId", XS_Wx__HelpControllerBase_DisplaySectionId);
        newXS_deffile("Wx::HelpControllerBase::KeywordSearch", XS_Wx__HelpControllerBase_KeywordSearch);
        newXS_deffile("Wx::HelpControllerBase::LoadFile", XS_Wx__HelpControllerBase_LoadFile);
        newXS_deffile("Wx::HelpControllerBase::SetViewer", XS_Wx__HelpControllerBase_SetViewer);
        newXS_deffile("Wx::HelpControllerBase::Quit", XS_Wx__HelpControllerBase_Quit);
#if XSubPPtmpAAAA
        newXS_deffile("Wx::HelpControllerBase::GetParentWindow", XS_Wx__HelpControllerBase_GetParentWindow);
        newXS_deffile("Wx::HelpControllerBase::SetParentWindow", XS_Wx__HelpControllerBase_SetParentWindow);
#endif
#if XSubPPtmpAAAB
        newXS_deffile("Wx::WinHelpController::new", XS_Wx__WinHelpController_new);
#endif
#if XSubPPtmpAAAC
        newXS_deffile("Wx::WinHelpController::new", XS_Wx__WinHelpController_new);
#endif
#if XSubPPtmpAAAD
        newXS_deffile("Wx::CHMHelpController::new", XS_Wx__CHMHelpController_new);
#endif
#if XSubPPtmpAAAE
        newXS_deffile("Wx::CHMHelpController::new", XS_Wx__CHMHelpController_new);
#endif

    /* Initialisation Section */

  INIT_PLI_HELPERS( wx_pli_helpers );

#if XSubPPtmpAAAA
#endif
#if XSubPPtmpAAAB
#endif
#if XSubPPtmpAAAC
#endif
#if XSubPPtmpAAAD
#endif
#if XSubPPtmpAAAE
#endif

    /* End of Initialisation Section */

#if PERL_VERSION_LE(5, 21, 5)
#  if PERL_VERSION_GE(5, 9, 0)
    if (PL_unitcheckav)
        call_list(PL_scopestack_ix, PL_unitcheckav);
#  endif
    XSRETURN_YES;
#else
    Perl_xs_boot_epilog(aTHX_ ax);
#endif
}

