// GENERATED FILE, DO NOT EDIT

#include "cpp/overload.h"

extern void wxPli_set_ovl_constant( const char* name,
                                    const wxPliPrototype* value );

#ifndef WXPL_EXT

void SetOvlConstants()
{
    dTHX;
    wxPli_set_ovl_constant( "arr", &wxPliOvl_arr );
    wxPli_set_ovl_constant( "arr_arr", &wxPliOvl_arr_arr );
    wxPli_set_ovl_constant( "arr_n", &wxPliOvl_arr_n );
    wxPli_set_ovl_constant( "arr_n_arr", &wxPliOvl_arr_n_arr );
    wxPli_set_ovl_constant( "b", &wxPliOvl_b );
    wxPli_set_ovl_constant( "n", &wxPliOvl_n );
    wxPli_set_ovl_constant( "n_b", &wxPliOvl_n_b );
    wxPli_set_ovl_constant( "n_n", &wxPliOvl_n_n );
    wxPli_set_ovl_constant( "n_n_n", &wxPliOvl_n_n_n );
    wxPli_set_ovl_constant( "n_n_n_n", &wxPliOvl_n_n_n_n );
    wxPli_set_ovl_constant( "n_n_n_n_b", &wxPliOvl_n_n_n_n_b );
    wxPli_set_ovl_constant( "n_n_n_n_b_s_n", &wxPliOvl_n_n_n_n_b_s_n );
    wxPli_set_ovl_constant( "n_n_n_n_n", &wxPliOvl_n_n_n_n_n );
    wxPli_set_ovl_constant( "n_n_n_s_n", &wxPliOvl_n_n_n_s_n );
    wxPli_set_ovl_constant( "n_n_s", &wxPliOvl_n_n_s );
    wxPli_set_ovl_constant( "n_n_s_n", &wxPliOvl_n_n_s_n );
    wxPli_set_ovl_constant( "n_n_s_s", &wxPliOvl_n_n_s_s );
    wxPli_set_ovl_constant( "n_n_s_wbmp_wbmp_b_s_s_s", &wxPliOvl_n_n_s_wbmp_wbmp_b_s_s_s );
    wxPli_set_ovl_constant( "n_n_s_wmen", &wxPliOvl_n_n_s_wmen );
    wxPli_set_ovl_constant( "n_n_wbmp_wbmp_b_s_s_s", &wxPliOvl_n_n_wbmp_wbmp_b_s_s_s );
    wxPli_set_ovl_constant( "n_n_wgbp_wgbs_n_n_s", &wxPliOvl_n_n_wgbp_wgbs_n_n_s );
    wxPli_set_ovl_constant( "n_n_wtae", &wxPliOvl_n_n_wtae );
    wxPli_set_ovl_constant( "n_n_wtat", &wxPliOvl_n_n_wtat );
    wxPli_set_ovl_constant( "n_s", &wxPliOvl_n_s );
    wxPli_set_ovl_constant( "n_s_n_n", &wxPliOvl_n_s_n_n );
    wxPli_set_ovl_constant( "n_s_wbmp_s_n", &wxPliOvl_n_s_wbmp_s_n );
    wxPli_set_ovl_constant( "n_s_wbmp_wbmp_n_s_s_s", &wxPliOvl_n_s_wbmp_wbmp_n_s_s_s );
    wxPli_set_ovl_constant( "n_s_wmen", &wxPliOvl_n_s_wmen );
    wxPli_set_ovl_constant( "n_wbmp_s_s", &wxPliOvl_n_wbmp_s_s );
    wxPli_set_ovl_constant( "n_wbmp_wbmp", &wxPliOvl_n_wbmp_wbmp );
    wxPli_set_ovl_constant( "n_wbmp_wbmp_b_s_s_s", &wxPliOvl_n_wbmp_wbmp_b_s_s_s );
    wxPli_set_ovl_constant( "n_wgbp", &wxPliOvl_n_wgbp );
    wxPli_set_ovl_constant( "n_wgbs", &wxPliOvl_n_wgbs );
    wxPli_set_ovl_constant( "n_wico", &wxPliOvl_n_wico );
    wxPli_set_ovl_constant( "n_wlci", &wxPliOvl_n_wlci );
    wxPli_set_ovl_constant( "n_wmit", &wxPliOvl_n_wmit );
    wxPli_set_ovl_constant( "s", &wxPliOvl_s );
    wxPli_set_ovl_constant( "s_arr", &wxPliOvl_s_arr );
    wxPli_set_ovl_constant( "s_b", &wxPliOvl_s_b );
    wxPli_set_ovl_constant( "s_n", &wxPliOvl_s_n );
    wxPli_set_ovl_constant( "s_n_n", &wxPliOvl_s_n_n );
    wxPli_set_ovl_constant( "s_n_n_n", &wxPliOvl_s_n_n_n );
    wxPli_set_ovl_constant( "s_n_s", &wxPliOvl_s_n_s );
    wxPli_set_ovl_constant( "s_s", &wxPliOvl_s_s );
    wxPli_set_ovl_constant( "s_s_arr", &wxPliOvl_s_s_arr );
    wxPli_set_ovl_constant( "s_s_arr_arr", &wxPliOvl_s_s_arr_arr );
    wxPli_set_ovl_constant( "s_s_arr_arr_n", &wxPliOvl_s_s_arr_arr_n );
    wxPli_set_ovl_constant( "s_s_arr_arr_s", &wxPliOvl_s_s_arr_arr_s );
    wxPli_set_ovl_constant( "s_s_n", &wxPliOvl_s_s_n );
    wxPli_set_ovl_constant( "s_s_s_b_b", &wxPliOvl_s_s_s_b_b );
    wxPli_set_ovl_constant( "s_s_wpgc_arr", &wxPliOvl_s_s_wpgc_arr );
    wxPli_set_ovl_constant( "s_s_wpgc_n", &wxPliOvl_s_s_wpgc_n );
    wxPli_set_ovl_constant( "s_s_wpgc_s", &wxPliOvl_s_s_wpgc_s );
    wxPli_set_ovl_constant( "s_wbmp", &wxPliOvl_s_wbmp );
    wxPli_set_ovl_constant( "s_wbmp_n", &wxPliOvl_s_wbmp_n );
    wxPli_set_ovl_constant( "s_wbmp_n_s", &wxPliOvl_s_wbmp_n_s );
    wxPli_set_ovl_constant( "s_wbmp_s", &wxPliOvl_s_wbmp_s );
    wxPli_set_ovl_constant( "s_wbmp_wrec_n_n_wrec", &wxPliOvl_s_wbmp_wrec_n_n_wrec );
    wxPli_set_ovl_constant( "s_wdtm", &wxPliOvl_s_wdtm );
    wxPli_set_ovl_constant( "s_wdvr_n_n_n_n", &wxPliOvl_s_wdvr_n_n_n_n );
    wxPli_set_ovl_constant( "s_wobj", &wxPliOvl_s_wobj );
    wxPli_set_ovl_constant( "s_wrec_n_n", &wxPliOvl_s_wrec_n_n );
    wxPli_set_ovl_constant( "s_wvar", &wxPliOvl_s_wvar );
    wxPli_set_ovl_constant( "wbmp", &wxPliOvl_wbmp );
    wxPli_set_ovl_constant( "wbmp_n", &wxPliOvl_wbmp_n );
    wxPli_set_ovl_constant( "wbmp_n_n_n", &wxPliOvl_wbmp_n_n_n );
    wxPli_set_ovl_constant( "wbmp_wbmp", &wxPliOvl_wbmp_wbmp );
    wxPli_set_ovl_constant( "wbmp_wcol", &wxPliOvl_wbmp_wcol );
    wxPli_set_ovl_constant( "wbmp_wcol_n", &wxPliOvl_wbmp_wcol_n );
    wxPli_set_ovl_constant( "wbmp_wdvr_n_n_n_n", &wxPliOvl_wbmp_wdvr_n_n_n_n );
    wxPli_set_ovl_constant( "wbru", &wxPliOvl_wbru );
    wxPli_set_ovl_constant( "wcol", &wxPliOvl_wcol );
    wxPli_set_ovl_constant( "wcol_n_n", &wxPliOvl_wcol_n_n );
    wxPli_set_ovl_constant( "wcol_wcol_n", &wxPliOvl_wcol_wcol_n );
    wxPli_set_ovl_constant( "wdat_wwin_wcur_wcur_wcur", &wxPliOvl_wdat_wwin_wcur_wcur_wcur );
    wxPli_set_ovl_constant( "wdat_wwin_wico_wico_wico", &wxPliOvl_wdat_wwin_wico_wico_wico );
    wxPli_set_ovl_constant( "wdc_n", &wxPliOvl_wdc_n );
    wxPli_set_ovl_constant( "wdc_n_n_n_n", &wxPliOvl_wdc_n_n_n_n );
    wxPli_set_ovl_constant( "wdc_wbmp_n", &wxPliOvl_wdc_wbmp_n );
    wxPli_set_ovl_constant( "wdc_wrec", &wxPliOvl_wdc_wrec );
    wxPli_set_ovl_constant( "wdc_wreg", &wxPliOvl_wdc_wreg );
    wxPli_set_ovl_constant( "wdc_wsiz_n", &wxPliOvl_wdc_wsiz_n );
    wxPli_set_ovl_constant( "wehd_n", &wxPliOvl_wehd_n );
    wxPli_set_ovl_constant( "wfon", &wxPliOvl_wfon );
    wxPli_set_ovl_constant( "wfon_wcol", &wxPliOvl_wfon_wcol );
    wxPli_set_ovl_constant( "wfrm_wwin_s", &wxPliOvl_wfrm_wwin_s );
    wxPli_set_ovl_constant( "wgbi", &wxPliOvl_wgbi );
    wxPli_set_ovl_constant( "wgbi_wgbi", &wxPliOvl_wgbi_wgbi );
    wxPli_set_ovl_constant( "wgbp_wgbs", &wxPliOvl_wgbp_wgbs );
    wxPli_set_ovl_constant( "wgbp_wgbs_wgbi", &wxPliOvl_wgbp_wgbs_wgbi );
    wxPli_set_ovl_constant( "wgbr", &wxPliOvl_wgbr );
    wxPli_set_ovl_constant( "wgco", &wxPliOvl_wgco );
    wxPli_set_ovl_constant( "wgco_s", &wxPliOvl_wgco_s );
    wxPli_set_ovl_constant( "wgco_wgco_b", &wxPliOvl_wgco_wgco_b );
    wxPli_set_ovl_constant( "wgfo", &wxPliOvl_wgfo );
    wxPli_set_ovl_constant( "wgpe", &wxPliOvl_wgpe );
    wxPli_set_ovl_constant( "wico", &wxPliOvl_wico );
    wxPli_set_ovl_constant( "wilo", &wxPliOvl_wilo );
    wxPli_set_ovl_constant( "wimg", &wxPliOvl_wimg );
    wxPli_set_ovl_constant( "wimg_n", &wxPliOvl_wimg_n );
    wxPli_set_ovl_constant( "wist_n", &wxPliOvl_wist_n );
    wxPli_set_ovl_constant( "wist_s", &wxPliOvl_wist_s );
    wxPli_set_ovl_constant( "wlci", &wxPliOvl_wlci );
    wxPli_set_ovl_constant( "wlog", &wxPliOvl_wlog );
    wxPli_set_ovl_constant( "wlog_n", &wxPliOvl_wlog_n );
    wxPli_set_ovl_constant( "wmdc", &wxPliOvl_wmdc );
    wxPli_set_ovl_constant( "wmen_n_n", &wxPliOvl_wmen_n_n );
    wxPli_set_ovl_constant( "wmen_wpoi", &wxPliOvl_wmen_wpoi );
    wxPli_set_ovl_constant( "wmit", &wxPliOvl_wmit );
    wxPli_set_ovl_constant( "woly_wdc", &wxPliOvl_woly_wdc );
    wxPli_set_ovl_constant( "woly_wdc_n_n_n_n", &wxPliOvl_woly_wdc_n_n_n_n );
    wxPli_set_ovl_constant( "wost_n", &wxPliOvl_wost_n );
    wxPli_set_ovl_constant( "wost_s", &wxPliOvl_wost_s );
    wxPli_set_ovl_constant( "wpdc", &wxPliOvl_wpdc );
    wxPli_set_ovl_constant( "wpen", &wxPliOvl_wpen );
    wxPli_set_ovl_constant( "wpgp_arr", &wxPliOvl_wpgp_arr );
    wxPli_set_ovl_constant( "wpgp_n", &wxPliOvl_wpgp_n );
    wxPli_set_ovl_constant( "wpgp_s", &wxPliOvl_wpgp_s );
    wxPli_set_ovl_constant( "wpgp_wdtm", &wxPliOvl_wpgp_wdtm );
    wxPli_set_ovl_constant( "wpgp_wobj", &wxPliOvl_wpgp_wobj );
    wxPli_set_ovl_constant( "wpgp_wvar", &wxPliOvl_wpgp_wvar );
    wxPli_set_ovl_constant( "wpoi", &wxPliOvl_wpoi );
    wxPli_set_ovl_constant( "wpoi_wpoi", &wxPliOvl_wpoi_wpoi );
    wxPli_set_ovl_constant( "wpoi_wsiz", &wxPliOvl_wpoi_wsiz );
    wxPli_set_ovl_constant( "wpos", &wxPliOvl_wpos );
    wxPli_set_ovl_constant( "wpos_wpos", &wxPliOvl_wpos_wpos );
    wxPli_set_ovl_constant( "wrec", &wxPliOvl_wrec );
    wxPli_set_ovl_constant( "wrec_n_n_n", &wxPliOvl_wrec_n_n_n );
    wxPli_set_ovl_constant( "wrec_wcol_wcol", &wxPliOvl_wrec_wcol_wcol );
    wxPli_set_ovl_constant( "wrec_wcol_wcol_wpoi", &wxPliOvl_wrec_wcol_wcol_wpoi );
    wxPli_set_ovl_constant( "wreg", &wxPliOvl_wreg );
    wxPli_set_ovl_constant( "writ", &wxPliOvl_writ );
    wxPli_set_ovl_constant( "wrta", &wxPliOvl_wrta );
    wxPli_set_ovl_constant( "wrth", &wxPliOvl_wrth );
    wxPli_set_ovl_constant( "wrtr", &wxPliOvl_wrtr );
    wxPli_set_ovl_constant( "wrtr_wrta", &wxPliOvl_wrtr_wrta );
    wxPli_set_ovl_constant( "wrtr_wrta_n", &wxPliOvl_wrtr_wrta_n );
    wxPli_set_ovl_constant( "wrtr_wtae", &wxPliOvl_wrtr_wtae );
    wxPli_set_ovl_constant( "wrtr_wtae_n", &wxPliOvl_wrtr_wtae_n );
    wxPli_set_ovl_constant( "wsiz", &wxPliOvl_wsiz );
    wxPli_set_ovl_constant( "wsiz_n_n_n_b_s_n", &wxPliOvl_wsiz_n_n_n_b_s_n );
    wxPli_set_ovl_constant( "wsiz_n_n_s_n", &wxPliOvl_wsiz_n_n_s_n );
    wxPli_set_ovl_constant( "wszr", &wxPliOvl_wszr );
    wxPli_set_ovl_constant( "wszr_wgbp", &wxPliOvl_wszr_wgbp );
    wxPli_set_ovl_constant( "wszr_wgbp_wgbs_n_n_s", &wxPliOvl_wszr_wgbp_wgbs_n_n_s );
    wxPli_set_ovl_constant( "wszr_wgbs", &wxPliOvl_wszr_wgbs );
    wxPli_set_ovl_constant( "wtae", &wxPliOvl_wtae );
    wxPli_set_ovl_constant( "wtat", &wxPliOvl_wtat );
    wxPli_set_ovl_constant( "wtid", &wxPliOvl_wtid );
    wxPli_set_ovl_constant( "wtid_n_s_n_n", &wxPliOvl_wtid_n_s_n_n );
    wxPli_set_ovl_constant( "wtid_wtid_s_n_n", &wxPliOvl_wtid_wtid_s_n_n );
    wxPli_set_ovl_constant( "wtip", &wxPliOvl_wtip );
    wxPli_set_ovl_constant( "wwdc", &wxPliOvl_wwdc );
    wxPli_set_ovl_constant( "wwin", &wxPliOvl_wwin );
    wxPli_set_ovl_constant( "wwin_n_n", &wxPliOvl_wwin_n_n );
    wxPli_set_ovl_constant( "wwin_n_s", &wxPliOvl_wwin_n_s );
    wxPli_set_ovl_constant( "wwin_n_wbmp", &wxPliOvl_wwin_n_wbmp );
    wxPli_set_ovl_constant( "wwin_n_wico", &wxPliOvl_wwin_n_wico );
    wxPli_set_ovl_constant( "wwin_s", &wxPliOvl_wwin_s );
    wxPli_set_ovl_constant( "wwin_wapi", &wxPliOvl_wwin_wapi );
    wxPli_set_ovl_constant( "wwin_wapi_wpoi", &wxPliOvl_wwin_wapi_wpoi );
    wxPli_set_ovl_constant( "wwin_wcur_wcur_wcur", &wxPliOvl_wwin_wcur_wcur_wcur );
    wxPli_set_ovl_constant( "wwin_wgbp", &wxPliOvl_wwin_wgbp );
    wxPli_set_ovl_constant( "wwin_wgbp_wgbs_n_n_s", &wxPliOvl_wwin_wgbp_wgbs_n_n_s );
    wxPli_set_ovl_constant( "wwin_wgbs", &wxPliOvl_wwin_wgbs );
    wxPli_set_ovl_constant( "wwin_wico_wico_wico", &wxPliOvl_wwin_wico_wico_wico );
    wxPli_set_ovl_constant( "wwin_wsiz", &wxPliOvl_wwin_wsiz );
}

#endif // WXPL_EXT

#define wxPliOvlwpgp "Wx::PGProperty"
#define wxPliOvlwehd "Wx::EvtHandler"
#define wxPliOvlwimg "Wx::Image"
#define wxPliOvlwtae "Wx::TextAttrEx"
#define wxPliOvlwrth "Wx::RichTextHeaderFooterData"
#define wxPliOvlwmen "Wx::Menu"
#define wxPliOvlwlci "Wx::ListItem"
#define wxPliOvlwdvr "Wx::DataViewRenderer"
#define wxPliOvlwbmp "Wx::Bitmap"
#define wxPliOvlwpge "Wx::PGEditor"
#define wxPliOvlwgbr "Wx::GraphicsBrush"
#define wxPliOvlwrit "Wx::RegionIterator"
#define wxPliOvlwgbs "Wx::GBSpan"
#define wxPliOvlwgbp "Wx::GBPosition"
#define wxPliOvlwfon "Wx::Font"
#define wxPliOvlwapi "Wx::AuiPaneInfo"
#define wxPliOvlwico "Wx::Icon"
#define wxPliOvlwtip "Wx::ToolTip"
#define wxPliOvlwcol "Wx::Colour"
#define wxPliOvlwgpe "Wx::GraphicsPen"
#define wxPliOvlwrta "Wx::RichTextAttr"
#define wxPliOvlwlog "Wx::Log"
#define wxPliOvlwmdc "Wx::MemoryDC"
#define wxPliOvlwwin "Wx::Window"
#define wxPliOvlwvar "Wx::Variant"
#define wxPliOvlwoly "Wx::Overlay"
#define wxPliOvlwcur "Wx::Cursor"
#define wxPliOvlwreg "Wx::Region"
#define wxPliOvlwobj "Wx::Object"
#define wxPliOvlwgco "Wx::GridCellCoords"
#define wxPliOvlwbru "Wx::Brush"
#define wxPliOvlwrtr "Wx::RichTextRange"
#define wxPliOvlwdat "Wx::DataObject"
#define wxPliOvlwtat "Wx::TextAttr"
#define wxPliOvlwfrm "Wx::Frame"
#define wxPliOvlwtid "Wx::TreeItemId"
#define wxPliOvlwpen "Wx::Pen"
#define wxPliOvlwdc "Wx::DC"
#define wxPliOvlwwdc "Wx::WindowDC"
#define wxPliOvlwdtm "Wx::DateTime"
#define wxPliOvlwszr "Wx::Sizer"
#define wxPliOvlwgfo "Wx::GraphicsFont"
#define wxPliOvlwgbi "Wx::GBSizerItem"
#define wxPliOvlwpdc "Wx::PrinterDC"
#define wxPliOvlwilo "Wx::IconLocation"
#define wxPliOvlwmit "Wx::MenuItem"
#define wxPliOvlwrec "Wx::Rect"
#define wxPliOvlwpgc "Wx::PGChoices"
const char* wxPliOvl_arr_datadef[] = { wxPliOvlarr };
const wxPliPrototype wxPliOvl_arr
    ( wxPliOvl_arr_datadef, 1 );
const char* wxPliOvl_arr_arr_datadef[] = { wxPliOvlarr, wxPliOvlarr };
const wxPliPrototype wxPliOvl_arr_arr
    ( wxPliOvl_arr_arr_datadef, 2 );
const char* wxPliOvl_arr_n_datadef[] = { wxPliOvlarr, wxPliOvlnum };
const wxPliPrototype wxPliOvl_arr_n
    ( wxPliOvl_arr_n_datadef, 2 );
const char* wxPliOvl_arr_n_arr_datadef[] = { wxPliOvlarr, wxPliOvlnum, wxPliOvlarr };
const wxPliPrototype wxPliOvl_arr_n_arr
    ( wxPliOvl_arr_n_arr_datadef, 3 );
const char* wxPliOvl_b_datadef[] = { wxPliOvlbool };
const wxPliPrototype wxPliOvl_b
    ( wxPliOvl_b_datadef, 1 );
const char* wxPliOvl_n_datadef[] = { wxPliOvlnum };
const wxPliPrototype wxPliOvl_n
    ( wxPliOvl_n_datadef, 1 );
const char* wxPliOvl_n_b_datadef[] = { wxPliOvlnum, wxPliOvlbool };
const wxPliPrototype wxPliOvl_n_b
    ( wxPliOvl_n_b_datadef, 2 );
const char* wxPliOvl_n_n_datadef[] = { wxPliOvlnum, wxPliOvlnum };
const wxPliPrototype wxPliOvl_n_n
    ( wxPliOvl_n_n_datadef, 2 );
const char* wxPliOvl_n_n_n_datadef[] = { wxPliOvlnum, wxPliOvlnum, wxPliOvlnum };
const wxPliPrototype wxPliOvl_n_n_n
    ( wxPliOvl_n_n_n_datadef, 3 );
const char* wxPliOvl_n_n_n_n_datadef[] = { wxPliOvlnum, wxPliOvlnum, wxPliOvlnum, wxPliOvlnum };
const wxPliPrototype wxPliOvl_n_n_n_n
    ( wxPliOvl_n_n_n_n_datadef, 4 );
const char* wxPliOvl_n_n_n_n_b_datadef[] = { wxPliOvlnum, wxPliOvlnum, wxPliOvlnum, wxPliOvlnum, wxPliOvlbool };
const wxPliPrototype wxPliOvl_n_n_n_n_b
    ( wxPliOvl_n_n_n_n_b_datadef, 5 );
const char* wxPliOvl_n_n_n_n_b_s_n_datadef[] = { wxPliOvlnum, wxPliOvlnum, wxPliOvlnum, wxPliOvlnum, wxPliOvlbool, wxPliOvlstr, wxPliOvlnum };
const wxPliPrototype wxPliOvl_n_n_n_n_b_s_n
    ( wxPliOvl_n_n_n_n_b_s_n_datadef, 7 );
const char* wxPliOvl_n_n_n_n_n_datadef[] = { wxPliOvlnum, wxPliOvlnum, wxPliOvlnum, wxPliOvlnum, wxPliOvlnum };
const wxPliPrototype wxPliOvl_n_n_n_n_n
    ( wxPliOvl_n_n_n_n_n_datadef, 5 );
const char* wxPliOvl_n_n_n_s_n_datadef[] = { wxPliOvlnum, wxPliOvlnum, wxPliOvlnum, wxPliOvlstr, wxPliOvlnum };
const wxPliPrototype wxPliOvl_n_n_n_s_n
    ( wxPliOvl_n_n_n_s_n_datadef, 5 );
const char* wxPliOvl_n_n_s_datadef[] = { wxPliOvlnum, wxPliOvlnum, wxPliOvlstr };
const wxPliPrototype wxPliOvl_n_n_s
    ( wxPliOvl_n_n_s_datadef, 3 );
const char* wxPliOvl_n_n_s_n_datadef[] = { wxPliOvlnum, wxPliOvlnum, wxPliOvlstr, wxPliOvlnum };
const wxPliPrototype wxPliOvl_n_n_s_n
    ( wxPliOvl_n_n_s_n_datadef, 4 );
const char* wxPliOvl_n_n_s_s_datadef[] = { wxPliOvlnum, wxPliOvlnum, wxPliOvlstr, wxPliOvlstr };
const wxPliPrototype wxPliOvl_n_n_s_s
    ( wxPliOvl_n_n_s_s_datadef, 4 );
const char* wxPliOvl_n_n_s_wbmp_wbmp_b_s_s_s_datadef[] = { wxPliOvlnum, wxPliOvlnum, wxPliOvlstr, wxPliOvlwbmp, wxPliOvlwbmp, wxPliOvlbool, wxPliOvlstr, wxPliOvlstr, wxPliOvlstr };
const wxPliPrototype wxPliOvl_n_n_s_wbmp_wbmp_b_s_s_s
    ( wxPliOvl_n_n_s_wbmp_wbmp_b_s_s_s_datadef, 9 );
const char* wxPliOvl_n_n_s_wmen_datadef[] = { wxPliOvlnum, wxPliOvlnum, wxPliOvlstr, wxPliOvlwmen };
const wxPliPrototype wxPliOvl_n_n_s_wmen
    ( wxPliOvl_n_n_s_wmen_datadef, 4 );
const char* wxPliOvl_n_n_wbmp_wbmp_b_s_s_s_datadef[] = { wxPliOvlnum, wxPliOvlnum, wxPliOvlwbmp, wxPliOvlwbmp, wxPliOvlbool, wxPliOvlstr, wxPliOvlstr, wxPliOvlstr };
const wxPliPrototype wxPliOvl_n_n_wbmp_wbmp_b_s_s_s
    ( wxPliOvl_n_n_wbmp_wbmp_b_s_s_s_datadef, 8 );
const char* wxPliOvl_n_n_wgbp_wgbs_n_n_s_datadef[] = { wxPliOvlnum, wxPliOvlnum, wxPliOvlwgbp, wxPliOvlwgbs, wxPliOvlnum, wxPliOvlnum, wxPliOvlstr };
const wxPliPrototype wxPliOvl_n_n_wgbp_wgbs_n_n_s
    ( wxPliOvl_n_n_wgbp_wgbs_n_n_s_datadef, 7 );
const char* wxPliOvl_n_n_wtae_datadef[] = { wxPliOvlnum, wxPliOvlnum, wxPliOvlwtae };
const wxPliPrototype wxPliOvl_n_n_wtae
    ( wxPliOvl_n_n_wtae_datadef, 3 );
const char* wxPliOvl_n_n_wtat_datadef[] = { wxPliOvlnum, wxPliOvlnum, wxPliOvlwtat };
const wxPliPrototype wxPliOvl_n_n_wtat
    ( wxPliOvl_n_n_wtat_datadef, 3 );
const char* wxPliOvl_n_s_datadef[] = { wxPliOvlnum, wxPliOvlstr };
const wxPliPrototype wxPliOvl_n_s
    ( wxPliOvl_n_s_datadef, 2 );
const char* wxPliOvl_n_s_n_n_datadef[] = { wxPliOvlnum, wxPliOvlstr, wxPliOvlnum, wxPliOvlnum };
const wxPliPrototype wxPliOvl_n_s_n_n
    ( wxPliOvl_n_s_n_n_datadef, 4 );
const char* wxPliOvl_n_s_wbmp_s_n_datadef[] = { wxPliOvlnum, wxPliOvlstr, wxPliOvlwbmp, wxPliOvlstr, wxPliOvlnum };
const wxPliPrototype wxPliOvl_n_s_wbmp_s_n
    ( wxPliOvl_n_s_wbmp_s_n_datadef, 5 );
const char* wxPliOvl_n_s_wbmp_wbmp_n_s_s_s_datadef[] = { wxPliOvlnum, wxPliOvlstr, wxPliOvlwbmp, wxPliOvlwbmp, wxPliOvlnum, wxPliOvlstr, wxPliOvlstr, wxPliOvlstr };
const wxPliPrototype wxPliOvl_n_s_wbmp_wbmp_n_s_s_s
    ( wxPliOvl_n_s_wbmp_wbmp_n_s_s_s_datadef, 8 );
const char* wxPliOvl_n_s_wmen_datadef[] = { wxPliOvlnum, wxPliOvlstr, wxPliOvlwmen };
const wxPliPrototype wxPliOvl_n_s_wmen
    ( wxPliOvl_n_s_wmen_datadef, 3 );
const char* wxPliOvl_n_wbmp_s_s_datadef[] = { wxPliOvlnum, wxPliOvlwbmp, wxPliOvlstr, wxPliOvlstr };
const wxPliPrototype wxPliOvl_n_wbmp_s_s
    ( wxPliOvl_n_wbmp_s_s_datadef, 4 );
const char* wxPliOvl_n_wbmp_wbmp_datadef[] = { wxPliOvlnum, wxPliOvlwbmp, wxPliOvlwbmp };
const wxPliPrototype wxPliOvl_n_wbmp_wbmp
    ( wxPliOvl_n_wbmp_wbmp_datadef, 3 );
const char* wxPliOvl_n_wbmp_wbmp_b_s_s_s_datadef[] = { wxPliOvlnum, wxPliOvlwbmp, wxPliOvlwbmp, wxPliOvlbool, wxPliOvlstr, wxPliOvlstr, wxPliOvlstr };
const wxPliPrototype wxPliOvl_n_wbmp_wbmp_b_s_s_s
    ( wxPliOvl_n_wbmp_wbmp_b_s_s_s_datadef, 7 );
const char* wxPliOvl_n_wgbp_datadef[] = { wxPliOvlnum, wxPliOvlwgbp };
const wxPliPrototype wxPliOvl_n_wgbp
    ( wxPliOvl_n_wgbp_datadef, 2 );
const char* wxPliOvl_n_wgbs_datadef[] = { wxPliOvlnum, wxPliOvlwgbs };
const wxPliPrototype wxPliOvl_n_wgbs
    ( wxPliOvl_n_wgbs_datadef, 2 );
const char* wxPliOvl_n_wico_datadef[] = { wxPliOvlnum, wxPliOvlwico };
const wxPliPrototype wxPliOvl_n_wico
    ( wxPliOvl_n_wico_datadef, 2 );
const char* wxPliOvl_n_wlci_datadef[] = { wxPliOvlnum, wxPliOvlwlci };
const wxPliPrototype wxPliOvl_n_wlci
    ( wxPliOvl_n_wlci_datadef, 2 );
const char* wxPliOvl_n_wmit_datadef[] = { wxPliOvlnum, wxPliOvlwmit };
const wxPliPrototype wxPliOvl_n_wmit
    ( wxPliOvl_n_wmit_datadef, 2 );
const char* wxPliOvl_s_datadef[] = { wxPliOvlstr };
const wxPliPrototype wxPliOvl_s
    ( wxPliOvl_s_datadef, 1 );
const char* wxPliOvl_s_arr_datadef[] = { wxPliOvlstr, wxPliOvlarr };
const wxPliPrototype wxPliOvl_s_arr
    ( wxPliOvl_s_arr_datadef, 2 );
const char* wxPliOvl_s_b_datadef[] = { wxPliOvlstr, wxPliOvlbool };
const wxPliPrototype wxPliOvl_s_b
    ( wxPliOvl_s_b_datadef, 2 );
const char* wxPliOvl_s_n_datadef[] = { wxPliOvlstr, wxPliOvlnum };
const wxPliPrototype wxPliOvl_s_n
    ( wxPliOvl_s_n_datadef, 2 );
const char* wxPliOvl_s_n_n_datadef[] = { wxPliOvlstr, wxPliOvlnum, wxPliOvlnum };
const wxPliPrototype wxPliOvl_s_n_n
    ( wxPliOvl_s_n_n_datadef, 3 );
const char* wxPliOvl_s_n_n_n_datadef[] = { wxPliOvlstr, wxPliOvlnum, wxPliOvlnum, wxPliOvlnum };
const wxPliPrototype wxPliOvl_s_n_n_n
    ( wxPliOvl_s_n_n_n_datadef, 4 );
const char* wxPliOvl_s_n_s_datadef[] = { wxPliOvlstr, wxPliOvlnum, wxPliOvlstr };
const wxPliPrototype wxPliOvl_s_n_s
    ( wxPliOvl_s_n_s_datadef, 3 );
const char* wxPliOvl_s_s_datadef[] = { wxPliOvlstr, wxPliOvlstr };
const wxPliPrototype wxPliOvl_s_s
    ( wxPliOvl_s_s_datadef, 2 );
const char* wxPliOvl_s_s_arr_datadef[] = { wxPliOvlstr, wxPliOvlstr, wxPliOvlarr };
const wxPliPrototype wxPliOvl_s_s_arr
    ( wxPliOvl_s_s_arr_datadef, 3 );
const char* wxPliOvl_s_s_arr_arr_datadef[] = { wxPliOvlstr, wxPliOvlstr, wxPliOvlarr, wxPliOvlarr };
const wxPliPrototype wxPliOvl_s_s_arr_arr
    ( wxPliOvl_s_s_arr_arr_datadef, 4 );
const char* wxPliOvl_s_s_arr_arr_n_datadef[] = { wxPliOvlstr, wxPliOvlstr, wxPliOvlarr, wxPliOvlarr, wxPliOvlnum };
const wxPliPrototype wxPliOvl_s_s_arr_arr_n
    ( wxPliOvl_s_s_arr_arr_n_datadef, 5 );
const char* wxPliOvl_s_s_arr_arr_s_datadef[] = { wxPliOvlstr, wxPliOvlstr, wxPliOvlarr, wxPliOvlarr, wxPliOvlstr };
const wxPliPrototype wxPliOvl_s_s_arr_arr_s
    ( wxPliOvl_s_s_arr_arr_s_datadef, 5 );
const char* wxPliOvl_s_s_n_datadef[] = { wxPliOvlstr, wxPliOvlstr, wxPliOvlnum };
const wxPliPrototype wxPliOvl_s_s_n
    ( wxPliOvl_s_s_n_datadef, 3 );
const char* wxPliOvl_s_s_s_b_b_datadef[] = { wxPliOvlstr, wxPliOvlstr, wxPliOvlstr, wxPliOvlbool, wxPliOvlbool };
const wxPliPrototype wxPliOvl_s_s_s_b_b
    ( wxPliOvl_s_s_s_b_b_datadef, 5 );
const char* wxPliOvl_s_s_wpgc_arr_datadef[] = { wxPliOvlstr, wxPliOvlstr, wxPliOvlwpgc, wxPliOvlarr };
const wxPliPrototype wxPliOvl_s_s_wpgc_arr
    ( wxPliOvl_s_s_wpgc_arr_datadef, 4 );
const char* wxPliOvl_s_s_wpgc_n_datadef[] = { wxPliOvlstr, wxPliOvlstr, wxPliOvlwpgc, wxPliOvlnum };
const wxPliPrototype wxPliOvl_s_s_wpgc_n
    ( wxPliOvl_s_s_wpgc_n_datadef, 4 );
const char* wxPliOvl_s_s_wpgc_s_datadef[] = { wxPliOvlstr, wxPliOvlstr, wxPliOvlwpgc, wxPliOvlstr };
const wxPliPrototype wxPliOvl_s_s_wpgc_s
    ( wxPliOvl_s_s_wpgc_s_datadef, 4 );
const char* wxPliOvl_s_wbmp_datadef[] = { wxPliOvlstr, wxPliOvlwbmp };
const wxPliPrototype wxPliOvl_s_wbmp
    ( wxPliOvl_s_wbmp_datadef, 2 );
const char* wxPliOvl_s_wbmp_n_datadef[] = { wxPliOvlstr, wxPliOvlwbmp, wxPliOvlnum };
const wxPliPrototype wxPliOvl_s_wbmp_n
    ( wxPliOvl_s_wbmp_n_datadef, 3 );
const char* wxPliOvl_s_wbmp_n_s_datadef[] = { wxPliOvlstr, wxPliOvlwbmp, wxPliOvlnum, wxPliOvlstr };
const wxPliPrototype wxPliOvl_s_wbmp_n_s
    ( wxPliOvl_s_wbmp_n_s_datadef, 4 );
const char* wxPliOvl_s_wbmp_s_datadef[] = { wxPliOvlstr, wxPliOvlwbmp, wxPliOvlstr };
const wxPliPrototype wxPliOvl_s_wbmp_s
    ( wxPliOvl_s_wbmp_s_datadef, 3 );
const char* wxPliOvl_s_wbmp_wrec_n_n_wrec_datadef[] = { wxPliOvlstr, wxPliOvlwbmp, wxPliOvlwrec, wxPliOvlnum, wxPliOvlnum, wxPliOvlwrec };
const wxPliPrototype wxPliOvl_s_wbmp_wrec_n_n_wrec
    ( wxPliOvl_s_wbmp_wrec_n_n_wrec_datadef, 6 );
const char* wxPliOvl_s_wdtm_datadef[] = { wxPliOvlstr, wxPliOvlwdtm };
const wxPliPrototype wxPliOvl_s_wdtm
    ( wxPliOvl_s_wdtm_datadef, 2 );
const char* wxPliOvl_s_wdvr_n_n_n_n_datadef[] = { wxPliOvlstr, wxPliOvlwdvr, wxPliOvlnum, wxPliOvlnum, wxPliOvlnum, wxPliOvlnum };
const wxPliPrototype wxPliOvl_s_wdvr_n_n_n_n
    ( wxPliOvl_s_wdvr_n_n_n_n_datadef, 6 );
const char* wxPliOvl_s_wobj_datadef[] = { wxPliOvlstr, wxPliOvlwobj };
const wxPliPrototype wxPliOvl_s_wobj
    ( wxPliOvl_s_wobj_datadef, 2 );
const char* wxPliOvl_s_wrec_n_n_datadef[] = { wxPliOvlstr, wxPliOvlwrec, wxPliOvlnum, wxPliOvlnum };
const wxPliPrototype wxPliOvl_s_wrec_n_n
    ( wxPliOvl_s_wrec_n_n_datadef, 4 );
const char* wxPliOvl_s_wvar_datadef[] = { wxPliOvlstr, wxPliOvlwvar };
const wxPliPrototype wxPliOvl_s_wvar
    ( wxPliOvl_s_wvar_datadef, 2 );
const char* wxPliOvl_wbmp_datadef[] = { wxPliOvlwbmp };
const wxPliPrototype wxPliOvl_wbmp
    ( wxPliOvl_wbmp_datadef, 1 );
const char* wxPliOvl_wbmp_n_datadef[] = { wxPliOvlwbmp, wxPliOvlnum };
const wxPliPrototype wxPliOvl_wbmp_n
    ( wxPliOvl_wbmp_n_datadef, 2 );
const char* wxPliOvl_wbmp_n_n_n_datadef[] = { wxPliOvlwbmp, wxPliOvlnum, wxPliOvlnum, wxPliOvlnum };
const wxPliPrototype wxPliOvl_wbmp_n_n_n
    ( wxPliOvl_wbmp_n_n_n_datadef, 4 );
const char* wxPliOvl_wbmp_wbmp_datadef[] = { wxPliOvlwbmp, wxPliOvlwbmp };
const wxPliPrototype wxPliOvl_wbmp_wbmp
    ( wxPliOvl_wbmp_wbmp_datadef, 2 );
const char* wxPliOvl_wbmp_wcol_datadef[] = { wxPliOvlwbmp, wxPliOvlwcol };
const wxPliPrototype wxPliOvl_wbmp_wcol
    ( wxPliOvl_wbmp_wcol_datadef, 2 );
const char* wxPliOvl_wbmp_wcol_n_datadef[] = { wxPliOvlwbmp, wxPliOvlwcol, wxPliOvlnum };
const wxPliPrototype wxPliOvl_wbmp_wcol_n
    ( wxPliOvl_wbmp_wcol_n_datadef, 3 );
const char* wxPliOvl_wbmp_wdvr_n_n_n_n_datadef[] = { wxPliOvlwbmp, wxPliOvlwdvr, wxPliOvlnum, wxPliOvlnum, wxPliOvlnum, wxPliOvlnum };
const wxPliPrototype wxPliOvl_wbmp_wdvr_n_n_n_n
    ( wxPliOvl_wbmp_wdvr_n_n_n_n_datadef, 6 );
const char* wxPliOvl_wbru_datadef[] = { wxPliOvlwbru };
const wxPliPrototype wxPliOvl_wbru
    ( wxPliOvl_wbru_datadef, 1 );
const char* wxPliOvl_wcol_datadef[] = { wxPliOvlwcol };
const wxPliPrototype wxPliOvl_wcol
    ( wxPliOvl_wcol_datadef, 1 );
const char* wxPliOvl_wcol_n_n_datadef[] = { wxPliOvlwcol, wxPliOvlnum, wxPliOvlnum };
const wxPliPrototype wxPliOvl_wcol_n_n
    ( wxPliOvl_wcol_n_n_datadef, 3 );
const char* wxPliOvl_wcol_wcol_n_datadef[] = { wxPliOvlwcol, wxPliOvlwcol, wxPliOvlnum };
const wxPliPrototype wxPliOvl_wcol_wcol_n
    ( wxPliOvl_wcol_wcol_n_datadef, 3 );
const char* wxPliOvl_wdat_wwin_wcur_wcur_wcur_datadef[] = { wxPliOvlwdat, wxPliOvlwwin, wxPliOvlwcur, wxPliOvlwcur, wxPliOvlwcur };
const wxPliPrototype wxPliOvl_wdat_wwin_wcur_wcur_wcur
    ( wxPliOvl_wdat_wwin_wcur_wcur_wcur_datadef, 5 );
const char* wxPliOvl_wdat_wwin_wico_wico_wico_datadef[] = { wxPliOvlwdat, wxPliOvlwwin, wxPliOvlwico, wxPliOvlwico, wxPliOvlwico };
const wxPliPrototype wxPliOvl_wdat_wwin_wico_wico_wico
    ( wxPliOvl_wdat_wwin_wico_wico_wico_datadef, 5 );
const char* wxPliOvl_wdc_n_datadef[] = { wxPliOvlwdc, wxPliOvlnum };
const wxPliPrototype wxPliOvl_wdc_n
    ( wxPliOvl_wdc_n_datadef, 2 );
const char* wxPliOvl_wdc_n_n_n_n_datadef[] = { wxPliOvlwdc, wxPliOvlnum, wxPliOvlnum, wxPliOvlnum, wxPliOvlnum };
const wxPliPrototype wxPliOvl_wdc_n_n_n_n
    ( wxPliOvl_wdc_n_n_n_n_datadef, 5 );
const char* wxPliOvl_wdc_wbmp_n_datadef[] = { wxPliOvlwdc, wxPliOvlwbmp, wxPliOvlnum };
const wxPliPrototype wxPliOvl_wdc_wbmp_n
    ( wxPliOvl_wdc_wbmp_n_datadef, 3 );
const char* wxPliOvl_wdc_wrec_datadef[] = { wxPliOvlwdc, wxPliOvlwrec };
const wxPliPrototype wxPliOvl_wdc_wrec
    ( wxPliOvl_wdc_wrec_datadef, 2 );
const char* wxPliOvl_wdc_wreg_datadef[] = { wxPliOvlwdc, wxPliOvlwreg };
const wxPliPrototype wxPliOvl_wdc_wreg
    ( wxPliOvl_wdc_wreg_datadef, 2 );
const char* wxPliOvl_wdc_wsiz_n_datadef[] = { wxPliOvlwdc, wxPliOvlwsiz, wxPliOvlnum };
const wxPliPrototype wxPliOvl_wdc_wsiz_n
    ( wxPliOvl_wdc_wsiz_n_datadef, 3 );
const char* wxPliOvl_wehd_n_datadef[] = { wxPliOvlwehd, wxPliOvlnum };
const wxPliPrototype wxPliOvl_wehd_n
    ( wxPliOvl_wehd_n_datadef, 2 );
const char* wxPliOvl_wfon_datadef[] = { wxPliOvlwfon };
const wxPliPrototype wxPliOvl_wfon
    ( wxPliOvl_wfon_datadef, 1 );
const char* wxPliOvl_wfon_wcol_datadef[] = { wxPliOvlwfon, wxPliOvlwcol };
const wxPliPrototype wxPliOvl_wfon_wcol
    ( wxPliOvl_wfon_wcol_datadef, 2 );
const char* wxPliOvl_wfrm_wwin_s_datadef[] = { wxPliOvlwfrm, wxPliOvlwwin, wxPliOvlstr };
const wxPliPrototype wxPliOvl_wfrm_wwin_s
    ( wxPliOvl_wfrm_wwin_s_datadef, 3 );
const char* wxPliOvl_wgbi_datadef[] = { wxPliOvlwgbi };
const wxPliPrototype wxPliOvl_wgbi
    ( wxPliOvl_wgbi_datadef, 1 );
const char* wxPliOvl_wgbi_wgbi_datadef[] = { wxPliOvlwgbi, wxPliOvlwgbi };
const wxPliPrototype wxPliOvl_wgbi_wgbi
    ( wxPliOvl_wgbi_wgbi_datadef, 2 );
const char* wxPliOvl_wgbp_wgbs_datadef[] = { wxPliOvlwgbp, wxPliOvlwgbs };
const wxPliPrototype wxPliOvl_wgbp_wgbs
    ( wxPliOvl_wgbp_wgbs_datadef, 2 );
const char* wxPliOvl_wgbp_wgbs_wgbi_datadef[] = { wxPliOvlwgbp, wxPliOvlwgbs, wxPliOvlwgbi };
const wxPliPrototype wxPliOvl_wgbp_wgbs_wgbi
    ( wxPliOvl_wgbp_wgbs_wgbi_datadef, 3 );
const char* wxPliOvl_wgbr_datadef[] = { wxPliOvlwgbr };
const wxPliPrototype wxPliOvl_wgbr
    ( wxPliOvl_wgbr_datadef, 1 );
const char* wxPliOvl_wgco_datadef[] = { wxPliOvlwgco };
const wxPliPrototype wxPliOvl_wgco
    ( wxPliOvl_wgco_datadef, 1 );
const char* wxPliOvl_wgco_s_datadef[] = { wxPliOvlwgco, wxPliOvlstr };
const wxPliPrototype wxPliOvl_wgco_s
    ( wxPliOvl_wgco_s_datadef, 2 );
const char* wxPliOvl_wgco_wgco_b_datadef[] = { wxPliOvlwgco, wxPliOvlwgco, wxPliOvlbool };
const wxPliPrototype wxPliOvl_wgco_wgco_b
    ( wxPliOvl_wgco_wgco_b_datadef, 3 );
const char* wxPliOvl_wgfo_datadef[] = { wxPliOvlwgfo };
const wxPliPrototype wxPliOvl_wgfo
    ( wxPliOvl_wgfo_datadef, 1 );
const char* wxPliOvl_wgpe_datadef[] = { wxPliOvlwgpe };
const wxPliPrototype wxPliOvl_wgpe
    ( wxPliOvl_wgpe_datadef, 1 );
const char* wxPliOvl_wico_datadef[] = { wxPliOvlwico };
const wxPliPrototype wxPliOvl_wico
    ( wxPliOvl_wico_datadef, 1 );
const char* wxPliOvl_wilo_datadef[] = { wxPliOvlwilo };
const wxPliPrototype wxPliOvl_wilo
    ( wxPliOvl_wilo_datadef, 1 );
const char* wxPliOvl_wimg_datadef[] = { wxPliOvlwimg };
const wxPliPrototype wxPliOvl_wimg
    ( wxPliOvl_wimg_datadef, 1 );
const char* wxPliOvl_wimg_n_datadef[] = { wxPliOvlwimg, wxPliOvlnum };
const wxPliPrototype wxPliOvl_wimg_n
    ( wxPliOvl_wimg_n_datadef, 2 );
const char* wxPliOvl_wist_n_datadef[] = { wxPliOvlwist, wxPliOvlnum };
const wxPliPrototype wxPliOvl_wist_n
    ( wxPliOvl_wist_n_datadef, 2 );
const char* wxPliOvl_wist_s_datadef[] = { wxPliOvlwist, wxPliOvlstr };
const wxPliPrototype wxPliOvl_wist_s
    ( wxPliOvl_wist_s_datadef, 2 );
const char* wxPliOvl_wlci_datadef[] = { wxPliOvlwlci };
const wxPliPrototype wxPliOvl_wlci
    ( wxPliOvl_wlci_datadef, 1 );
const char* wxPliOvl_wlog_datadef[] = { wxPliOvlwlog };
const wxPliPrototype wxPliOvl_wlog
    ( wxPliOvl_wlog_datadef, 1 );
const char* wxPliOvl_wlog_n_datadef[] = { wxPliOvlwlog, wxPliOvlnum };
const wxPliPrototype wxPliOvl_wlog_n
    ( wxPliOvl_wlog_n_datadef, 2 );
const char* wxPliOvl_wmdc_datadef[] = { wxPliOvlwmdc };
const wxPliPrototype wxPliOvl_wmdc
    ( wxPliOvl_wmdc_datadef, 1 );
const char* wxPliOvl_wmen_n_n_datadef[] = { wxPliOvlwmen, wxPliOvlnum, wxPliOvlnum };
const wxPliPrototype wxPliOvl_wmen_n_n
    ( wxPliOvl_wmen_n_n_datadef, 3 );
const char* wxPliOvl_wmen_wpoi_datadef[] = { wxPliOvlwmen, wxPliOvlwpoi };
const wxPliPrototype wxPliOvl_wmen_wpoi
    ( wxPliOvl_wmen_wpoi_datadef, 2 );
const char* wxPliOvl_wmit_datadef[] = { wxPliOvlwmit };
const wxPliPrototype wxPliOvl_wmit
    ( wxPliOvl_wmit_datadef, 1 );
const char* wxPliOvl_woly_wdc_datadef[] = { wxPliOvlwoly, wxPliOvlwdc };
const wxPliPrototype wxPliOvl_woly_wdc
    ( wxPliOvl_woly_wdc_datadef, 2 );
const char* wxPliOvl_woly_wdc_n_n_n_n_datadef[] = { wxPliOvlwoly, wxPliOvlwdc, wxPliOvlnum, wxPliOvlnum, wxPliOvlnum, wxPliOvlnum };
const wxPliPrototype wxPliOvl_woly_wdc_n_n_n_n
    ( wxPliOvl_woly_wdc_n_n_n_n_datadef, 6 );
const char* wxPliOvl_wost_n_datadef[] = { wxPliOvlwost, wxPliOvlnum };
const wxPliPrototype wxPliOvl_wost_n
    ( wxPliOvl_wost_n_datadef, 2 );
const char* wxPliOvl_wost_s_datadef[] = { wxPliOvlwost, wxPliOvlstr };
const wxPliPrototype wxPliOvl_wost_s
    ( wxPliOvl_wost_s_datadef, 2 );
const char* wxPliOvl_wpdc_datadef[] = { wxPliOvlwpdc };
const wxPliPrototype wxPliOvl_wpdc
    ( wxPliOvl_wpdc_datadef, 1 );
const char* wxPliOvl_wpen_datadef[] = { wxPliOvlwpen };
const wxPliPrototype wxPliOvl_wpen
    ( wxPliOvl_wpen_datadef, 1 );
const char* wxPliOvl_wpgp_arr_datadef[] = { wxPliOvlwpgp, wxPliOvlarr };
const wxPliPrototype wxPliOvl_wpgp_arr
    ( wxPliOvl_wpgp_arr_datadef, 2 );
const char* wxPliOvl_wpgp_n_datadef[] = { wxPliOvlwpgp, wxPliOvlnum };
const wxPliPrototype wxPliOvl_wpgp_n
    ( wxPliOvl_wpgp_n_datadef, 2 );
const char* wxPliOvl_wpgp_s_datadef[] = { wxPliOvlwpgp, wxPliOvlstr };
const wxPliPrototype wxPliOvl_wpgp_s
    ( wxPliOvl_wpgp_s_datadef, 2 );
const char* wxPliOvl_wpgp_wdtm_datadef[] = { wxPliOvlwpgp, wxPliOvlwdtm };
const wxPliPrototype wxPliOvl_wpgp_wdtm
    ( wxPliOvl_wpgp_wdtm_datadef, 2 );
const char* wxPliOvl_wpgp_wobj_datadef[] = { wxPliOvlwpgp, wxPliOvlwobj };
const wxPliPrototype wxPliOvl_wpgp_wobj
    ( wxPliOvl_wpgp_wobj_datadef, 2 );
const char* wxPliOvl_wpgp_wvar_datadef[] = { wxPliOvlwpgp, wxPliOvlwvar };
const wxPliPrototype wxPliOvl_wpgp_wvar
    ( wxPliOvl_wpgp_wvar_datadef, 2 );
const char* wxPliOvl_wpoi_datadef[] = { wxPliOvlwpoi };
const wxPliPrototype wxPliOvl_wpoi
    ( wxPliOvl_wpoi_datadef, 1 );
const char* wxPliOvl_wpoi_wpoi_datadef[] = { wxPliOvlwpoi, wxPliOvlwpoi };
const wxPliPrototype wxPliOvl_wpoi_wpoi
    ( wxPliOvl_wpoi_wpoi_datadef, 2 );
const char* wxPliOvl_wpoi_wsiz_datadef[] = { wxPliOvlwpoi, wxPliOvlwsiz };
const wxPliPrototype wxPliOvl_wpoi_wsiz
    ( wxPliOvl_wpoi_wsiz_datadef, 2 );
const char* wxPliOvl_wpos_datadef[] = { wxPliOvlwpos };
const wxPliPrototype wxPliOvl_wpos
    ( wxPliOvl_wpos_datadef, 1 );
const char* wxPliOvl_wpos_wpos_datadef[] = { wxPliOvlwpos, wxPliOvlwpos };
const wxPliPrototype wxPliOvl_wpos_wpos
    ( wxPliOvl_wpos_wpos_datadef, 2 );
const char* wxPliOvl_wrec_datadef[] = { wxPliOvlwrec };
const wxPliPrototype wxPliOvl_wrec
    ( wxPliOvl_wrec_datadef, 1 );
const char* wxPliOvl_wrec_n_n_n_datadef[] = { wxPliOvlwrec, wxPliOvlnum, wxPliOvlnum, wxPliOvlnum };
const wxPliPrototype wxPliOvl_wrec_n_n_n
    ( wxPliOvl_wrec_n_n_n_datadef, 4 );
const char* wxPliOvl_wrec_wcol_wcol_datadef[] = { wxPliOvlwrec, wxPliOvlwcol, wxPliOvlwcol };
const wxPliPrototype wxPliOvl_wrec_wcol_wcol
    ( wxPliOvl_wrec_wcol_wcol_datadef, 3 );
const char* wxPliOvl_wrec_wcol_wcol_wpoi_datadef[] = { wxPliOvlwrec, wxPliOvlwcol, wxPliOvlwcol, wxPliOvlwpoi };
const wxPliPrototype wxPliOvl_wrec_wcol_wcol_wpoi
    ( wxPliOvl_wrec_wcol_wcol_wpoi_datadef, 4 );
const char* wxPliOvl_wreg_datadef[] = { wxPliOvlwreg };
const wxPliPrototype wxPliOvl_wreg
    ( wxPliOvl_wreg_datadef, 1 );
const char* wxPliOvl_writ_datadef[] = { wxPliOvlwrit };
const wxPliPrototype wxPliOvl_writ
    ( wxPliOvl_writ_datadef, 1 );
const char* wxPliOvl_wrta_datadef[] = { wxPliOvlwrta };
const wxPliPrototype wxPliOvl_wrta
    ( wxPliOvl_wrta_datadef, 1 );
const char* wxPliOvl_wrth_datadef[] = { wxPliOvlwrth };
const wxPliPrototype wxPliOvl_wrth
    ( wxPliOvl_wrth_datadef, 1 );
const char* wxPliOvl_wrtr_datadef[] = { wxPliOvlwrtr };
const wxPliPrototype wxPliOvl_wrtr
    ( wxPliOvl_wrtr_datadef, 1 );
const char* wxPliOvl_wrtr_wrta_datadef[] = { wxPliOvlwrtr, wxPliOvlwrta };
const wxPliPrototype wxPliOvl_wrtr_wrta
    ( wxPliOvl_wrtr_wrta_datadef, 2 );
const char* wxPliOvl_wrtr_wrta_n_datadef[] = { wxPliOvlwrtr, wxPliOvlwrta, wxPliOvlnum };
const wxPliPrototype wxPliOvl_wrtr_wrta_n
    ( wxPliOvl_wrtr_wrta_n_datadef, 3 );
const char* wxPliOvl_wrtr_wtae_datadef[] = { wxPliOvlwrtr, wxPliOvlwtae };
const wxPliPrototype wxPliOvl_wrtr_wtae
    ( wxPliOvl_wrtr_wtae_datadef, 2 );
const char* wxPliOvl_wrtr_wtae_n_datadef[] = { wxPliOvlwrtr, wxPliOvlwtae, wxPliOvlnum };
const wxPliPrototype wxPliOvl_wrtr_wtae_n
    ( wxPliOvl_wrtr_wtae_n_datadef, 3 );
const char* wxPliOvl_wsiz_datadef[] = { wxPliOvlwsiz };
const wxPliPrototype wxPliOvl_wsiz
    ( wxPliOvl_wsiz_datadef, 1 );
const char* wxPliOvl_wsiz_n_n_n_b_s_n_datadef[] = { wxPliOvlwsiz, wxPliOvlnum, wxPliOvlnum, wxPliOvlnum, wxPliOvlbool, wxPliOvlstr, wxPliOvlnum };
const wxPliPrototype wxPliOvl_wsiz_n_n_n_b_s_n
    ( wxPliOvl_wsiz_n_n_n_b_s_n_datadef, 7 );
const char* wxPliOvl_wsiz_n_n_s_n_datadef[] = { wxPliOvlwsiz, wxPliOvlnum, wxPliOvlnum, wxPliOvlstr, wxPliOvlnum };
const wxPliPrototype wxPliOvl_wsiz_n_n_s_n
    ( wxPliOvl_wsiz_n_n_s_n_datadef, 5 );
const char* wxPliOvl_wszr_datadef[] = { wxPliOvlwszr };
const wxPliPrototype wxPliOvl_wszr
    ( wxPliOvl_wszr_datadef, 1 );
const char* wxPliOvl_wszr_wgbp_datadef[] = { wxPliOvlwszr, wxPliOvlwgbp };
const wxPliPrototype wxPliOvl_wszr_wgbp
    ( wxPliOvl_wszr_wgbp_datadef, 2 );
const char* wxPliOvl_wszr_wgbp_wgbs_n_n_s_datadef[] = { wxPliOvlwszr, wxPliOvlwgbp, wxPliOvlwgbs, wxPliOvlnum, wxPliOvlnum, wxPliOvlstr };
const wxPliPrototype wxPliOvl_wszr_wgbp_wgbs_n_n_s
    ( wxPliOvl_wszr_wgbp_wgbs_n_n_s_datadef, 6 );
const char* wxPliOvl_wszr_wgbs_datadef[] = { wxPliOvlwszr, wxPliOvlwgbs };
const wxPliPrototype wxPliOvl_wszr_wgbs
    ( wxPliOvl_wszr_wgbs_datadef, 2 );
const char* wxPliOvl_wtae_datadef[] = { wxPliOvlwtae };
const wxPliPrototype wxPliOvl_wtae
    ( wxPliOvl_wtae_datadef, 1 );
const char* wxPliOvl_wtat_datadef[] = { wxPliOvlwtat };
const wxPliPrototype wxPliOvl_wtat
    ( wxPliOvl_wtat_datadef, 1 );
const char* wxPliOvl_wtid_datadef[] = { wxPliOvlwtid };
const wxPliPrototype wxPliOvl_wtid
    ( wxPliOvl_wtid_datadef, 1 );
const char* wxPliOvl_wtid_n_s_n_n_datadef[] = { wxPliOvlwtid, wxPliOvlnum, wxPliOvlstr, wxPliOvlnum, wxPliOvlnum };
const wxPliPrototype wxPliOvl_wtid_n_s_n_n
    ( wxPliOvl_wtid_n_s_n_n_datadef, 5 );
const char* wxPliOvl_wtid_wtid_s_n_n_datadef[] = { wxPliOvlwtid, wxPliOvlwtid, wxPliOvlstr, wxPliOvlnum, wxPliOvlnum };
const wxPliPrototype wxPliOvl_wtid_wtid_s_n_n
    ( wxPliOvl_wtid_wtid_s_n_n_datadef, 5 );
const char* wxPliOvl_wtip_datadef[] = { wxPliOvlwtip };
const wxPliPrototype wxPliOvl_wtip
    ( wxPliOvl_wtip_datadef, 1 );
const char* wxPliOvl_wwdc_datadef[] = { wxPliOvlwwdc };
const wxPliPrototype wxPliOvl_wwdc
    ( wxPliOvl_wwdc_datadef, 1 );
const char* wxPliOvl_wwin_datadef[] = { wxPliOvlwwin };
const wxPliPrototype wxPliOvl_wwin
    ( wxPliOvl_wwin_datadef, 1 );
const char* wxPliOvl_wwin_n_n_datadef[] = { wxPliOvlwwin, wxPliOvlnum, wxPliOvlnum };
const wxPliPrototype wxPliOvl_wwin_n_n
    ( wxPliOvl_wwin_n_n_datadef, 3 );
const char* wxPliOvl_wwin_n_s_datadef[] = { wxPliOvlwwin, wxPliOvlnum, wxPliOvlstr };
const wxPliPrototype wxPliOvl_wwin_n_s
    ( wxPliOvl_wwin_n_s_datadef, 3 );
const char* wxPliOvl_wwin_n_wbmp_datadef[] = { wxPliOvlwwin, wxPliOvlnum, wxPliOvlwbmp };
const wxPliPrototype wxPliOvl_wwin_n_wbmp
    ( wxPliOvl_wwin_n_wbmp_datadef, 3 );
const char* wxPliOvl_wwin_n_wico_datadef[] = { wxPliOvlwwin, wxPliOvlnum, wxPliOvlwico };
const wxPliPrototype wxPliOvl_wwin_n_wico
    ( wxPliOvl_wwin_n_wico_datadef, 3 );
const char* wxPliOvl_wwin_s_datadef[] = { wxPliOvlwwin, wxPliOvlstr };
const wxPliPrototype wxPliOvl_wwin_s
    ( wxPliOvl_wwin_s_datadef, 2 );
const char* wxPliOvl_wwin_wapi_datadef[] = { wxPliOvlwwin, wxPliOvlwapi };
const wxPliPrototype wxPliOvl_wwin_wapi
    ( wxPliOvl_wwin_wapi_datadef, 2 );
const char* wxPliOvl_wwin_wapi_wpoi_datadef[] = { wxPliOvlwwin, wxPliOvlwapi, wxPliOvlwpoi };
const wxPliPrototype wxPliOvl_wwin_wapi_wpoi
    ( wxPliOvl_wwin_wapi_wpoi_datadef, 3 );
const char* wxPliOvl_wwin_wcur_wcur_wcur_datadef[] = { wxPliOvlwwin, wxPliOvlwcur, wxPliOvlwcur, wxPliOvlwcur };
const wxPliPrototype wxPliOvl_wwin_wcur_wcur_wcur
    ( wxPliOvl_wwin_wcur_wcur_wcur_datadef, 4 );
const char* wxPliOvl_wwin_wgbp_datadef[] = { wxPliOvlwwin, wxPliOvlwgbp };
const wxPliPrototype wxPliOvl_wwin_wgbp
    ( wxPliOvl_wwin_wgbp_datadef, 2 );
const char* wxPliOvl_wwin_wgbp_wgbs_n_n_s_datadef[] = { wxPliOvlwwin, wxPliOvlwgbp, wxPliOvlwgbs, wxPliOvlnum, wxPliOvlnum, wxPliOvlstr };
const wxPliPrototype wxPliOvl_wwin_wgbp_wgbs_n_n_s
    ( wxPliOvl_wwin_wgbp_wgbs_n_n_s_datadef, 6 );
const char* wxPliOvl_wwin_wgbs_datadef[] = { wxPliOvlwwin, wxPliOvlwgbs };
const wxPliPrototype wxPliOvl_wwin_wgbs
    ( wxPliOvl_wwin_wgbs_datadef, 2 );
const char* wxPliOvl_wwin_wico_wico_wico_datadef[] = { wxPliOvlwwin, wxPliOvlwico, wxPliOvlwico, wxPliOvlwico };
const wxPliPrototype wxPliOvl_wwin_wico_wico_wico
    ( wxPliOvl_wwin_wico_wico_wico_datadef, 4 );
const char* wxPliOvl_wwin_wsiz_datadef[] = { wxPliOvlwwin, wxPliOvlwsiz };
const wxPliPrototype wxPliOvl_wwin_wsiz
    ( wxPliOvl_wwin_wsiz_datadef, 2 );
