/*
 * This file was generated automatically by ExtUtils::ParseXS version 3.44 from the
 * contents of MDI.xs. Do not edit this file, edit MDI.xs instead.
 *
 *    ANY CHANGES MADE HERE WILL BE LOST!
 *
 */

/////////////////////////////////////////////////////////////////////////////
// Name:        ext/mdi/MDI.xs
// Purpose:     XS for MDI
// Author:      Mattia Barbon
// Modified by:
// Created:     06/09/2001
// RCS-ID:      $Id: MDI.xs 2057 2007-06-18 23:03:00Z mbarbon $
// Copyright:   (c) 2001-2002, 2004 Mattia Barbon
// Licence:     This program is free software; you can redistribute it and/or
//              modify it under the same terms as Perl itself
/////////////////////////////////////////////////////////////////////////////

#define PERL_NO_GET_CONTEXT

#include "cpp/wxapi.h"

#undef THIS

#ifndef PERL_UNUSED_VAR
#  define PERL_UNUSED_VAR(var) if (0) var = var
#endif

#ifndef dVAR
#  define dVAR		dNOOP
#endif


/* This stuff is not part of the API! You have been warned. */
#ifndef PERL_VERSION_DECIMAL
#  define PERL_VERSION_DECIMAL(r,v,s) (r*1000000 + v*1000 + s)
#endif
#ifndef PERL_DECIMAL_VERSION
#  define PERL_DECIMAL_VERSION \
	  PERL_VERSION_DECIMAL(PERL_REVISION,PERL_VERSION,PERL_SUBVERSION)
#endif
#ifndef PERL_VERSION_GE
#  define PERL_VERSION_GE(r,v,s) \
	  (PERL_DECIMAL_VERSION >= PERL_VERSION_DECIMAL(r,v,s))
#endif
#ifndef PERL_VERSION_LE
#  define PERL_VERSION_LE(r,v,s) \
	  (PERL_DECIMAL_VERSION <= PERL_VERSION_DECIMAL(r,v,s))
#endif

/* XS_INTERNAL is the explicit static-linkage variant of the default
 * XS macro.
 *
 * XS_EXTERNAL is the same as XS_INTERNAL except it does not include
 * "STATIC", ie. it exports XSUB symbols. You probably don't want that
 * for anything but the BOOT XSUB.
 *
 * See XSUB.h in core!
 */


/* TODO: This might be compatible further back than 5.10.0. */
#if PERL_VERSION_GE(5, 10, 0) && PERL_VERSION_LE(5, 15, 1)
#  undef XS_EXTERNAL
#  undef XS_INTERNAL
#  if defined(__CYGWIN__) && defined(USE_DYNAMIC_LOADING)
#    define XS_EXTERNAL(name) __declspec(dllexport) XSPROTO(name)
#    define XS_INTERNAL(name) STATIC XSPROTO(name)
#  endif
#  if defined(__SYMBIAN32__)
#    define XS_EXTERNAL(name) EXPORT_C XSPROTO(name)
#    define XS_INTERNAL(name) EXPORT_C STATIC XSPROTO(name)
#  endif
#  ifndef XS_EXTERNAL
#    if defined(HASATTRIBUTE_UNUSED) && !defined(__cplusplus)
#      define XS_EXTERNAL(name) void name(pTHX_ CV* cv __attribute__unused__)
#      define XS_INTERNAL(name) STATIC void name(pTHX_ CV* cv __attribute__unused__)
#    else
#      ifdef __cplusplus
#        define XS_EXTERNAL(name) extern "C" XSPROTO(name)
#        define XS_INTERNAL(name) static XSPROTO(name)
#      else
#        define XS_EXTERNAL(name) XSPROTO(name)
#        define XS_INTERNAL(name) STATIC XSPROTO(name)
#      endif
#    endif
#  endif
#endif

/* perl >= 5.10.0 && perl <= 5.15.1 */


/* The XS_EXTERNAL macro is used for functions that must not be static
 * like the boot XSUB of a module. If perl didn't have an XS_EXTERNAL
 * macro defined, the best we can do is assume XS is the same.
 * Dito for XS_INTERNAL.
 */
#ifndef XS_EXTERNAL
#  define XS_EXTERNAL(name) XS(name)
#endif
#ifndef XS_INTERNAL
#  define XS_INTERNAL(name) XS(name)
#endif

/* Now, finally, after all this mess, we want an ExtUtils::ParseXS
 * internal macro that we're free to redefine for varying linkage due
 * to the EXPORT_XSUB_SYMBOLS XS keyword. This is internal, use
 * XS_EXTERNAL(name) or XS_INTERNAL(name) in your code if you need to!
 */

#undef XS_EUPXS
#if defined(PERL_EUPXS_ALWAYS_EXPORT)
#  define XS_EUPXS(name) XS_EXTERNAL(name)
#else
   /* default to internal */
#  define XS_EUPXS(name) XS_INTERNAL(name)
#endif

#ifndef PERL_ARGS_ASSERT_CROAK_XS_USAGE
#define PERL_ARGS_ASSERT_CROAK_XS_USAGE assert(cv); assert(params)

/* prototype to pass -Wmissing-prototypes */
STATIC void
S_croak_xs_usage(const CV *const cv, const char *const params);

STATIC void
S_croak_xs_usage(const CV *const cv, const char *const params)
{
    const GV *const gv = CvGV(cv);

    PERL_ARGS_ASSERT_CROAK_XS_USAGE;

    if (gv) {
        const char *const gvname = GvNAME(gv);
        const HV *const stash = GvSTASH(gv);
        const char *const hvname = stash ? HvNAME(stash) : NULL;

        if (hvname)
	    Perl_croak_nocontext("Usage: %s::%s(%s)", hvname, gvname, params);
        else
	    Perl_croak_nocontext("Usage: %s(%s)", gvname, params);
    } else {
        /* Pants. I don't think that it should be possible to get here. */
	Perl_croak_nocontext("Usage: CODE(0x%" UVxf ")(%s)", PTR2UV(cv), params);
    }
}
#undef  PERL_ARGS_ASSERT_CROAK_XS_USAGE

#define croak_xs_usage        S_croak_xs_usage

#endif

/* NOTE: the prototype of newXSproto() is different in versions of perls,
 * so we define a portable version of newXSproto()
 */
#ifdef newXS_flags
#define newXSproto_portable(name, c_impl, file, proto) newXS_flags(name, c_impl, file, proto, 0)
#else
#define newXSproto_portable(name, c_impl, file, proto) (PL_Sv=(SV*)newXS(name, c_impl, file), sv_setpv(PL_Sv, proto), (CV*)PL_Sv)
#endif /* !defined(newXS_flags) */

#if PERL_VERSION_LE(5, 21, 5)
#  define newXS_deffile(a,b) Perl_newXS(aTHX_ a,b,file)
#else
#  define newXS_deffile(a,b) Perl_newXS_deffile(aTHX_ a,b)
#endif


/* INCLUDE:  Including 'XS/MDIChildFrame.xs' from 'MDI.xs' */


/* INCLUDE:  Including 'XS/MDIParentFrame.xs' from 'XS/MDIChildFrame.xs' */

#if wxPERL_USE_MDI_ARCHITECTURE
#include <wx/menu.h>
#include "cpp/mdi.h"
#include "cpp/overload.h"
#define XSubPPtmpAAAA 1


XS_EUPXS(XS_Wx__MDIParentFrame_new); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__MDIParentFrame_new)
{
    dVAR; dXSARGS;
    PERL_UNUSED_VAR(cv); /* -W */
    PERL_UNUSED_VAR(items); /* -W */
    PERL_UNUSED_VAR(ax); /* -Wall */
    SP -= items;
    {
    BEGIN_OVERLOAD()
        MATCH_VOIDM_REDISP( newDefault )
        MATCH_ANY_REDISP( newFull )
    END_OVERLOAD( "Wx::MDIParentFrame::new" )
	PUTBACK;
	return;
    }
}


XS_EUPXS(XS_Wx__MDIParentFrame_newDefault); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__MDIParentFrame_newDefault)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "CLASS");
    {
	PlClassName    CLASS = wxPli_get_class( aTHX_ ST(0) )
;
	wxMDIParentFrame *	RETVAL;
    RETVAL = new wxPliMDIParentFrame( CLASS );
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_object_2_sv( aTHX_ RETVALSV, RETVAL );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__MDIParentFrame_newFull); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__MDIParentFrame_newFull)
{
    dVAR; dXSARGS;
    if (items < 4 || items > 8)
       croak_xs_usage(cv,  "CLASS, parent, id, title, pos = wxDefaultPosition, size = wxDefaultSize, style = wxDEFAULT_FRAME_STYLE|wxVSCROLL|wxHSCROLL, name = wxFrameNameStr");
    {
	PlClassName    CLASS = wxPli_get_class( aTHX_ ST(0) )
;
	wxWindow*    parent = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::Window" )
;
	wxWindowID    id = wxPli_get_wxwindowid( aTHX_ ST(2) )
;
	wxString	title;
	wxPoint	pos;
	wxSize	size;
	long	style;
	wxString	name;
	wxMDIParentFrame *	RETVAL;

    WXSTRING_INPUT( title, wxString, ST(3) )
;

	if (items < 5)
	    pos = wxDefaultPosition;
	else {
    pos = wxPli_sv_2_wxpoint( aTHX_ ST(4) )
;
	}

	if (items < 6)
	    size = wxDefaultSize;
	else {
    size = wxPli_sv_2_wxsize( aTHX_ ST(5) )
;
	}

	if (items < 7)
	    style = wxDEFAULT_FRAME_STYLE|wxVSCROLL|wxHSCROLL;
	else {
	    style = (long)SvIV(ST(6))
;
	}

	if (items < 8)
	    name = wxFrameNameStr;
	else {
    WXSTRING_INPUT( name, wxString, ST(7) )
;
	}
    RETVAL = new wxPliMDIParentFrame( CLASS );
    RETVAL->Create( parent, id, title, pos, size, style, name );
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_object_2_sv( aTHX_ RETVALSV, RETVAL );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__MDIParentFrame_Create); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__MDIParentFrame_Create)
{
    dVAR; dXSARGS;
    if (items < 4 || items > 8)
       croak_xs_usage(cv,  "THIS, parent, id, title, pos = wxDefaultPosition, size = wxDefaultSize, style = wxDEFAULT_FRAME_STYLE|wxVSCROLL|wxHSCROLL, name = wxFrameNameStr");
    {
	wxWindow*    parent = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::Window" )
;
	wxWindowID    id = wxPli_get_wxwindowid( aTHX_ ST(2) )
;
	wxString	title;
	wxPoint	pos;
	wxSize	size;
	long	style;
	wxString	name;
	wxMDIParentFrame *    THIS = (wxMDIParentFrame *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::MDIParentFrame" )
;
	bool	RETVAL;

    WXSTRING_INPUT( title, wxString, ST(3) )
;

	if (items < 5)
	    pos = wxDefaultPosition;
	else {
    pos = wxPli_sv_2_wxpoint( aTHX_ ST(4) )
;
	}

	if (items < 6)
	    size = wxDefaultSize;
	else {
    size = wxPli_sv_2_wxsize( aTHX_ ST(5) )
;
	}

	if (items < 7)
	    style = wxDEFAULT_FRAME_STYLE|wxVSCROLL|wxHSCROLL;
	else {
	    style = (long)SvIV(ST(6))
;
	}

	if (items < 8)
	    name = wxFrameNameStr;
	else {
    WXSTRING_INPUT( name, wxString, ST(7) )
;
	}

	RETVAL = THIS->Create(parent, id, title, pos, size, style, name);
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__MDIParentFrame_ActivateNext); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__MDIParentFrame_ActivateNext)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxMDIParentFrame *    THIS = (wxMDIParentFrame *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::MDIParentFrame" )
;

	THIS->ActivateNext();
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__MDIParentFrame_ActivatePrevious); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__MDIParentFrame_ActivatePrevious)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxMDIParentFrame *    THIS = (wxMDIParentFrame *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::MDIParentFrame" )
;

	THIS->ActivatePrevious();
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__MDIParentFrame_ArrangeIcons); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__MDIParentFrame_ArrangeIcons)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxMDIParentFrame *    THIS = (wxMDIParentFrame *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::MDIParentFrame" )
;

	THIS->ArrangeIcons();
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__MDIParentFrame_Cascade); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__MDIParentFrame_Cascade)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxMDIParentFrame *    THIS = (wxMDIParentFrame *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::MDIParentFrame" )
;

	THIS->Cascade();
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__MDIParentFrame_GetActiveChild); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__MDIParentFrame_GetActiveChild)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxMDIParentFrame *    THIS = (wxMDIParentFrame *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::MDIParentFrame" )
;
	wxMDIChildFrame *	RETVAL;

	RETVAL = THIS->GetActiveChild();
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_object_2_sv( aTHX_ RETVALSV, RETVAL );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}

#ifdef __WXUNIVERSAL__
#define XSubPPtmpAAAB 1


XS_EUPXS(XS_Wx__MDIParentFrame_GetClientWindow); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__MDIParentFrame_GetClientWindow)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxMDIParentFrame *    THIS = (wxMDIParentFrame *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::MDIParentFrame" )
;
	wxGenericMDIClientWindow *	RETVAL;

	RETVAL = THIS->GetClientWindow();
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_object_2_sv( aTHX_ RETVALSV, RETVAL );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}

#else
#if WXPERL_W_VERSION_GE( 2, 9, 0 )
#define XSubPPtmpAAAC 1


XS_EUPXS(XS_Wx__MDIParentFrame_GetClientWindow); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__MDIParentFrame_GetClientWindow)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxMDIParentFrame *    THIS = (wxMDIParentFrame *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::MDIParentFrame" )
;
	wxMDIClientWindowBase *	RETVAL;

	RETVAL = THIS->GetClientWindow();
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_object_2_sv( aTHX_ RETVALSV, RETVAL );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}

#else
#define XSubPPtmpAAAD 1


XS_EUPXS(XS_Wx__MDIParentFrame_GetClientWindow); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__MDIParentFrame_GetClientWindow)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxMDIParentFrame *    THIS = (wxMDIParentFrame *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::MDIParentFrame" )
;
	wxMDIClientWindow *	RETVAL;

	RETVAL = THIS->GetClientWindow();
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_object_2_sv( aTHX_ RETVALSV, RETVAL );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}

#endif
#endif
#if ( !defined(__WXGTK__) && !defined(__WXMAC__) && !defined(__WXMOTIF__) ) \
    || defined(__WXPERL_FORCE__)
#define XSubPPtmpAAAE 1


XS_EUPXS(XS_Wx__MDIParentFrame_GetWindowMenu); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__MDIParentFrame_GetWindowMenu)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxMDIParentFrame *    THIS = (wxMDIParentFrame *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::MDIParentFrame" )
;
	wxMenu *	RETVAL;

	RETVAL = THIS->GetWindowMenu();
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_object_2_sv( aTHX_ RETVALSV, RETVAL );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__MDIParentFrame_SetWindowMenu); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__MDIParentFrame_SetWindowMenu)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, menu");
    {
	wxMenu*    menu = (wxMenu *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::Menu" )
;
	wxMDIParentFrame *    THIS = (wxMDIParentFrame *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::MDIParentFrame" )
;

	THIS->SetWindowMenu(menu);
    }
    XSRETURN_EMPTY;
}

#endif
#if WXPERL_W_VERSION_GE( 2, 5, 4 )
#define XSubPPtmpAAAF 1


XS_EUPXS(XS_Wx__MDIParentFrame_Tile); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__MDIParentFrame_Tile)
{
    dVAR; dXSARGS;
    if (items < 1 || items > 2)
       croak_xs_usage(cv,  "THIS, orient = wxHORIZONTAL");
    {
	wxOrientation	orient;
	wxMDIParentFrame *    THIS = (wxMDIParentFrame *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::MDIParentFrame" )
;

	if (items < 2)
	    orient = wxHORIZONTAL;
	else {
	    orient = (wxOrientation)SvIV(ST(1))
;
	}

	THIS->Tile(orient);
    }
    XSRETURN_EMPTY;
}

#else
#define XSubPPtmpAAAG 1


XS_EUPXS(XS_Wx__MDIParentFrame_Tile); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__MDIParentFrame_Tile)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxMDIParentFrame *    THIS = (wxMDIParentFrame *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::MDIParentFrame" )
;

	THIS->Tile();
    }
    XSRETURN_EMPTY;
}

#endif
#endif

/* INCLUDE: Returning to 'XS/MDIChildFrame.xs' from 'XS/MDIParentFrame.xs' */

#if wxPERL_USE_MDI_ARCHITECTURE
#include "cpp/mdi.h"
#define XSubPPtmpAAAH 1


XS_EUPXS(XS_Wx__MDIChildFrame_new); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__MDIChildFrame_new)
{
    dVAR; dXSARGS;
    if (items < 4 || items > 8)
       croak_xs_usage(cv,  "CLASS, parent, id, title, pos = wxDefaultPosition, size = wxDefaultSize, style = wxDEFAULT_FRAME_STYLE, name = wxFrameNameStr");
    {
	wxMDIParentFrame*    parent = (wxMDIParentFrame *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::MDIParentFrame" )
;
	wxWindowID    id = wxPli_get_wxwindowid( aTHX_ ST(2) )
;
	wxString	title;
	wxPoint	pos;
	wxSize	size;
	long	style;
	wxString	name;
	char *	CLASS = (char *)SvPV_nolen(ST(0))
;
	wxMDIChildFrame *	RETVAL;

    WXSTRING_INPUT( title, wxString, ST(3) )
;

	if (items < 5)
	    pos = wxDefaultPosition;
	else {
    pos = wxPli_sv_2_wxpoint( aTHX_ ST(4) )
;
	}

	if (items < 6)
	    size = wxDefaultSize;
	else {
    size = wxPli_sv_2_wxsize( aTHX_ ST(5) )
;
	}

	if (items < 7)
	    style = wxDEFAULT_FRAME_STYLE;
	else {
	    style = (long)SvIV(ST(6))
;
	}

	if (items < 8)
	    name = wxFrameNameStr;
	else {
    WXSTRING_INPUT( name, wxString, ST(7) )
;
	}
    RETVAL = new wxPliMDIChildFrame( CLASS, parent, id, title, pos, size,
        style, name );
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_object_2_sv( aTHX_ RETVALSV, RETVAL );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__MDIChildFrame_Activate); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__MDIChildFrame_Activate)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxMDIChildFrame *    THIS = (wxMDIChildFrame *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::MDIChildFrame" )
;

	THIS->Activate();
    }
    XSRETURN_EMPTY;
}

#if !defined(__WXGTK__) || defined(__WXPERL_FORCE__)
#define XSubPPtmpAAAI 1


XS_EUPXS(XS_Wx__MDIChildFrame_Maximize); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__MDIChildFrame_Maximize)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxMDIChildFrame *    THIS = (wxMDIChildFrame *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::MDIChildFrame" )
;

	THIS->Maximize();
    }
    XSRETURN_EMPTY;
}

#endif

XS_EUPXS(XS_Wx__MDIChildFrame_Restore); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__MDIChildFrame_Restore)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxMDIChildFrame *    THIS = (wxMDIChildFrame *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::MDIChildFrame" )
;

	THIS->Restore();
    }
    XSRETURN_EMPTY;
}

#endif

/* INCLUDE: Returning to 'MDI.xs' from 'XS/MDIChildFrame.xs' */

#if defined(__WXMSW__)
#undef XS
#define XS( name ) WXXS( name )
#endif
#ifdef __cplusplus
extern "C"
#endif
XS_EXTERNAL(boot_Wx__MDI); /* prototype to pass -Wmissing-prototypes */
XS_EXTERNAL(boot_Wx__MDI)
{
#if PERL_VERSION_LE(5, 21, 5)
    dVAR; dXSARGS;
#else
    dVAR; dXSBOOTARGSXSAPIVERCHK;
#endif
#if PERL_VERSION_LE(5, 8, 999) /* PERL_VERSION_LT is 5.33+ */
    char* file = __FILE__;
#else
    const char* file = __FILE__;
#endif

    PERL_UNUSED_VAR(file);

    PERL_UNUSED_VAR(cv); /* -W */
    PERL_UNUSED_VAR(items); /* -W */
#if PERL_VERSION_LE(5, 21, 5)
    XS_VERSION_BOOTCHECK;
#  ifdef XS_APIVERSION_BOOTCHECK
    XS_APIVERSION_BOOTCHECK;
#  endif
#endif

#if XSubPPtmpAAAA
        newXS_deffile("Wx::MDIParentFrame::new", XS_Wx__MDIParentFrame_new);
        newXS_deffile("Wx::MDIParentFrame::newDefault", XS_Wx__MDIParentFrame_newDefault);
        newXS_deffile("Wx::MDIParentFrame::newFull", XS_Wx__MDIParentFrame_newFull);
        newXS_deffile("Wx::MDIParentFrame::Create", XS_Wx__MDIParentFrame_Create);
        newXS_deffile("Wx::MDIParentFrame::ActivateNext", XS_Wx__MDIParentFrame_ActivateNext);
        newXS_deffile("Wx::MDIParentFrame::ActivatePrevious", XS_Wx__MDIParentFrame_ActivatePrevious);
        newXS_deffile("Wx::MDIParentFrame::ArrangeIcons", XS_Wx__MDIParentFrame_ArrangeIcons);
        newXS_deffile("Wx::MDIParentFrame::Cascade", XS_Wx__MDIParentFrame_Cascade);
        newXS_deffile("Wx::MDIParentFrame::GetActiveChild", XS_Wx__MDIParentFrame_GetActiveChild);
#if XSubPPtmpAAAB
        newXS_deffile("Wx::MDIParentFrame::GetClientWindow", XS_Wx__MDIParentFrame_GetClientWindow);
#endif
#if XSubPPtmpAAAC
        newXS_deffile("Wx::MDIParentFrame::GetClientWindow", XS_Wx__MDIParentFrame_GetClientWindow);
#endif
#if XSubPPtmpAAAD
        newXS_deffile("Wx::MDIParentFrame::GetClientWindow", XS_Wx__MDIParentFrame_GetClientWindow);
#endif
#if XSubPPtmpAAAE
        newXS_deffile("Wx::MDIParentFrame::GetWindowMenu", XS_Wx__MDIParentFrame_GetWindowMenu);
        newXS_deffile("Wx::MDIParentFrame::SetWindowMenu", XS_Wx__MDIParentFrame_SetWindowMenu);
#endif
#if XSubPPtmpAAAF
        newXS_deffile("Wx::MDIParentFrame::Tile", XS_Wx__MDIParentFrame_Tile);
#endif
#if XSubPPtmpAAAG
        newXS_deffile("Wx::MDIParentFrame::Tile", XS_Wx__MDIParentFrame_Tile);
#endif
#endif
#if XSubPPtmpAAAH
        newXS_deffile("Wx::MDIChildFrame::new", XS_Wx__MDIChildFrame_new);
        newXS_deffile("Wx::MDIChildFrame::Activate", XS_Wx__MDIChildFrame_Activate);
#if XSubPPtmpAAAI
        newXS_deffile("Wx::MDIChildFrame::Maximize", XS_Wx__MDIChildFrame_Maximize);
#endif
        newXS_deffile("Wx::MDIChildFrame::Restore", XS_Wx__MDIChildFrame_Restore);
#endif

    /* Initialisation Section */

  INIT_PLI_HELPERS( wx_pli_helpers );

#if XSubPPtmpAAAA
#if XSubPPtmpAAAB
#endif
#if XSubPPtmpAAAC
#endif
#if XSubPPtmpAAAD
#endif
#if XSubPPtmpAAAE
#endif
#if XSubPPtmpAAAF
#endif
#if XSubPPtmpAAAG
#endif
#endif
#if XSubPPtmpAAAH
#if XSubPPtmpAAAI
#endif
#endif

    /* End of Initialisation Section */

#if PERL_VERSION_LE(5, 21, 5)
#  if PERL_VERSION_GE(5, 9, 0)
    if (PL_unitcheckav)
        call_list(PL_scopestack_ix, PL_unitcheckav);
#  endif
    XSRETURN_YES;
#else
    Perl_xs_boot_epilog(aTHX_ ax);
#endif
}

