/*
 * This file was generated automatically by ExtUtils::ParseXS version 3.44 from the
 * contents of Controls.xs. Do not edit this file, edit Controls.xs instead.
 *
 *    ANY CHANGES MADE HERE WILL BE LOST!
 *
 */

/////////////////////////////////////////////////////////////////////////////
// Name:        Controls.xs
// Purpose:     XS for Wx::Control and derived classes
// Author:      Mattia Barbon
// Modified by:
// Created:     29/10/2000
// RCS-ID:      $Id: Controls.xs 3478 2013-04-16 10:31:53Z mdootson $
// Copyright:   (c) 2000-2013 Mattia Barbon
// Licence:     This program is free software; you can redistribute it and/or
//              modify it under the same terms as Perl itself
/////////////////////////////////////////////////////////////////////////////

#define PERL_NO_GET_CONTEXT

#include "cpp/wxapi.h"

#include <wx/defs.h>

#include <wx/imaglist.h>
#include <wx/event.h>
#include <wx/colour.h>
#include <wx/listctrl.h>
#include <wx/treectrl.h>
#include <wx/ctrlsub.h>

// re-include for client data
#include "cpp/helpers.h"

#define wxDefaultValidatorPtr (wxValidator*)&wxDefaultValidator
#define wxBLACKPtr (wxColour*)wxBLACK
#define wxNORMAL_FONTPtr (wxFont*)wxNORMAL_FONT
#define wxNullBitmapPtr (wxBitmap*) &wxNullBitmap
#define wxNullAnimationPtr (wxAnimation*) &wxNullAnimation
#define wxNullColourPtr (wxColour*)&wxNullColour

#undef THIS

#include "cpp/v_cback.h"

#include "cpp/controls.h"
#include "cpp/controls.cpp"
#include "cpp/overload.h"

WXPLI_BOOT_ONCE(Wx_Ctrl);
#define boot_Wx_Ctrl wxPli_boot_Wx_Ctrl

#ifndef PERL_UNUSED_VAR
#  define PERL_UNUSED_VAR(var) if (0) var = var
#endif

#ifndef dVAR
#  define dVAR		dNOOP
#endif


/* This stuff is not part of the API! You have been warned. */
#ifndef PERL_VERSION_DECIMAL
#  define PERL_VERSION_DECIMAL(r,v,s) (r*1000000 + v*1000 + s)
#endif
#ifndef PERL_DECIMAL_VERSION
#  define PERL_DECIMAL_VERSION \
	  PERL_VERSION_DECIMAL(PERL_REVISION,PERL_VERSION,PERL_SUBVERSION)
#endif
#ifndef PERL_VERSION_GE
#  define PERL_VERSION_GE(r,v,s) \
	  (PERL_DECIMAL_VERSION >= PERL_VERSION_DECIMAL(r,v,s))
#endif
#ifndef PERL_VERSION_LE
#  define PERL_VERSION_LE(r,v,s) \
	  (PERL_DECIMAL_VERSION <= PERL_VERSION_DECIMAL(r,v,s))
#endif

/* XS_INTERNAL is the explicit static-linkage variant of the default
 * XS macro.
 *
 * XS_EXTERNAL is the same as XS_INTERNAL except it does not include
 * "STATIC", ie. it exports XSUB symbols. You probably don't want that
 * for anything but the BOOT XSUB.
 *
 * See XSUB.h in core!
 */


/* TODO: This might be compatible further back than 5.10.0. */
#if PERL_VERSION_GE(5, 10, 0) && PERL_VERSION_LE(5, 15, 1)
#  undef XS_EXTERNAL
#  undef XS_INTERNAL
#  if defined(__CYGWIN__) && defined(USE_DYNAMIC_LOADING)
#    define XS_EXTERNAL(name) __declspec(dllexport) XSPROTO(name)
#    define XS_INTERNAL(name) STATIC XSPROTO(name)
#  endif
#  if defined(__SYMBIAN32__)
#    define XS_EXTERNAL(name) EXPORT_C XSPROTO(name)
#    define XS_INTERNAL(name) EXPORT_C STATIC XSPROTO(name)
#  endif
#  ifndef XS_EXTERNAL
#    if defined(HASATTRIBUTE_UNUSED) && !defined(__cplusplus)
#      define XS_EXTERNAL(name) void name(pTHX_ CV* cv __attribute__unused__)
#      define XS_INTERNAL(name) STATIC void name(pTHX_ CV* cv __attribute__unused__)
#    else
#      ifdef __cplusplus
#        define XS_EXTERNAL(name) extern "C" XSPROTO(name)
#        define XS_INTERNAL(name) static XSPROTO(name)
#      else
#        define XS_EXTERNAL(name) XSPROTO(name)
#        define XS_INTERNAL(name) STATIC XSPROTO(name)
#      endif
#    endif
#  endif
#endif

/* perl >= 5.10.0 && perl <= 5.15.1 */


/* The XS_EXTERNAL macro is used for functions that must not be static
 * like the boot XSUB of a module. If perl didn't have an XS_EXTERNAL
 * macro defined, the best we can do is assume XS is the same.
 * Dito for XS_INTERNAL.
 */
#ifndef XS_EXTERNAL
#  define XS_EXTERNAL(name) XS(name)
#endif
#ifndef XS_INTERNAL
#  define XS_INTERNAL(name) XS(name)
#endif

/* Now, finally, after all this mess, we want an ExtUtils::ParseXS
 * internal macro that we're free to redefine for varying linkage due
 * to the EXPORT_XSUB_SYMBOLS XS keyword. This is internal, use
 * XS_EXTERNAL(name) or XS_INTERNAL(name) in your code if you need to!
 */

#undef XS_EUPXS
#if defined(PERL_EUPXS_ALWAYS_EXPORT)
#  define XS_EUPXS(name) XS_EXTERNAL(name)
#else
   /* default to internal */
#  define XS_EUPXS(name) XS_INTERNAL(name)
#endif

#ifndef PERL_ARGS_ASSERT_CROAK_XS_USAGE
#define PERL_ARGS_ASSERT_CROAK_XS_USAGE assert(cv); assert(params)

/* prototype to pass -Wmissing-prototypes */
STATIC void
S_croak_xs_usage(const CV *const cv, const char *const params);

STATIC void
S_croak_xs_usage(const CV *const cv, const char *const params)
{
    const GV *const gv = CvGV(cv);

    PERL_ARGS_ASSERT_CROAK_XS_USAGE;

    if (gv) {
        const char *const gvname = GvNAME(gv);
        const HV *const stash = GvSTASH(gv);
        const char *const hvname = stash ? HvNAME(stash) : NULL;

        if (hvname)
	    Perl_croak_nocontext("Usage: %s::%s(%s)", hvname, gvname, params);
        else
	    Perl_croak_nocontext("Usage: %s(%s)", gvname, params);
    } else {
        /* Pants. I don't think that it should be possible to get here. */
	Perl_croak_nocontext("Usage: CODE(0x%" UVxf ")(%s)", PTR2UV(cv), params);
    }
}
#undef  PERL_ARGS_ASSERT_CROAK_XS_USAGE

#define croak_xs_usage        S_croak_xs_usage

#endif

/* NOTE: the prototype of newXSproto() is different in versions of perls,
 * so we define a portable version of newXSproto()
 */
#ifdef newXS_flags
#define newXSproto_portable(name, c_impl, file, proto) newXS_flags(name, c_impl, file, proto, 0)
#else
#define newXSproto_portable(name, c_impl, file, proto) (PL_Sv=(SV*)newXS(name, c_impl, file), sv_setpv(PL_Sv, proto), (CV*)PL_Sv)
#endif /* !defined(newXS_flags) */

#if PERL_VERSION_LE(5, 21, 5)
#  define newXS_deffile(a,b) Perl_newXS(aTHX_ a,b,file)
#else
#  define newXS_deffile(a,b) Perl_newXS_deffile(aTHX_ a,b)
#endif


XS_EUPXS(XS_Wx__Control_Command); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Control_Command)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, event");
    {
	wxCommandEvent*    event = (wxCommandEvent *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::CommandEvent" )
;
	wxControl *    THIS = (wxControl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Control" )
;
    THIS->Command( *event );
    }
    XSRETURN_EMPTY;
}

#if WXPERL_W_VERSION_GE( 2, 7, 2 )
#define XSubPPtmpAAAA 1


XS_EUPXS(XS_Wx__Control_GetLabelText); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Control_GetLabelText)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxControl *    THIS = (wxControl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Control" )
;
	wxString	RETVAL;

	RETVAL = THIS->GetLabelText();
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    WXSTRING_OUTPUT( RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}

#endif

/* INCLUDE_COMMAND:  Including output of '/usr/bin/perl -I./ -MExtUtils::XSpp::Cmd -e xspp -- -t typemap.xsp XS/ControlWithItems.xsp' from 'Controls.xs' */

#include <exception>

#undef  xsp_constructor_class
#define xsp_constructor_class(c) (c)

/* INCLUDE_COMMAND:  Including output of '/usr/bin/perl -pe "s/ItemContainerImmutable/ControlWithItems/g" XS/ItemContainerImmutable.xs' from '/usr/bin/perl -I./ -MExtUtils::XSpp::Cmd -e xspp -- -t typemap.xsp XS/ControlWithItems.xsp' */

#include <exception>

#undef  xsp_constructor_class
#define xsp_constructor_class(c) (c)

XS_EUPXS(XS_Wx__ControlWithItems_GetCount); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ControlWithItems_GetCount)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxControlWithItems *    THIS = (wxControlWithItems *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::ControlWithItems" )
;
	unsigned int	RETVAL;
	dXSTARG;
    try {
      RETVAL = THIS->GetCount();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	XSprePUSH;
	PUSHu((UV)RETVAL );
    }
    XSRETURN(1);
}

#if !defined(WXPERL_IN_COMBOBOX) || WXPERL_W_VERSION_LE( 2, 9, 2 )
#define XSpp_f9ce292b_043796
#define XSubPPtmpAAAB 1


XS_EUPXS(XS_Wx__ControlWithItems_IsEmpty); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ControlWithItems_IsEmpty)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxControlWithItems *    THIS = (wxControlWithItems *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::ControlWithItems" )
;
	bool	RETVAL;
    try {
      RETVAL = THIS->IsEmpty();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}

#endif

XS_EUPXS(XS_Wx__ControlWithItems_GetString); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ControlWithItems_GetString)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, n");
    {
	wxControlWithItems *    THIS = (wxControlWithItems *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::ControlWithItems" )
;
	wxString	RETVAL;
	unsigned int    n = (unsigned int)SvUV( ST(1) )
;
    try {
      RETVAL = THIS->GetString( n );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    WXSTRING_OUTPUT( RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__ControlWithItems_GetStrings); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ControlWithItems_GetStrings)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    PERL_UNUSED_VAR(ax); /* -Wall */
    SP -= items;
    {
	wxControlWithItems *    THIS = (wxControlWithItems *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::ControlWithItems" )
;
    PUTBACK;
    wxPli_stringarray_push( aTHX_ THIS->GetStrings() );
    SPAGAIN;
	PUTBACK;
	return;
    }
}


XS_EUPXS(XS_Wx__ControlWithItems_SetString); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ControlWithItems_SetString)
{
    dVAR; dXSARGS;
    if (items != 3)
       croak_xs_usage(cv,  "THIS, n, s");
    {
	wxControlWithItems *    THIS = (wxControlWithItems *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::ControlWithItems" )
;
	unsigned int    n = (unsigned int)SvUV( ST(1) )
;
	wxString	s;

    WXSTRING_INPUT( s, wxString, ST(2) )
;
    try {
      THIS->SetString( n, s );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__ControlWithItems_FindString); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ControlWithItems_FindString)
{
    dVAR; dXSARGS;
    if (items < 1)
       croak_xs_usage(cv,  "THIS, ...");
    PERL_UNUSED_VAR(ax); /* -Wall */
    SP -= items;
    {
	wxControlWithItems *    THIS = (wxControlWithItems *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::ControlWithItems" )
;
	int	RETVAL;
	dXSTARG;
    BEGIN_OVERLOAD()
#if WXPERL_W_VERSION_GE( 2, 7, 2 )
        MATCH_REDISP( wxPliOvl_s_b, FindStringCase )
#endif
        MATCH_REDISP( wxPliOvl_s, FindStringNoCase )
    END_OVERLOAD( Wx::ControlWithItems::FindString )
	PUTBACK;
	return;
    }
}


XS_EUPXS(XS_Wx__ControlWithItems_FindStringNoCase); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ControlWithItems_FindStringNoCase)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, s");
    {
	wxControlWithItems *    THIS = (wxControlWithItems *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::ControlWithItems" )
;
	int	RETVAL;
	dXSTARG;
	wxString	s;

    WXSTRING_INPUT( s, wxString, ST(1) )
;
    try {
      RETVAL = THIS->FindString( s );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}

#if WXPERL_W_VERSION_GE( 2, 7, 2 )
#define XSpp_f9ce292b_037748
#define XSubPPtmpAAAC 1


XS_EUPXS(XS_Wx__ControlWithItems_FindStringCase); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ControlWithItems_FindStringCase)
{
    dVAR; dXSARGS;
    if (items < 2 || items > 3)
       croak_xs_usage(cv,  "THIS, s, bCase= false");
    {
	wxControlWithItems *    THIS = (wxControlWithItems *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::ControlWithItems" )
;
	int	RETVAL;
	dXSTARG;
	wxString	s;
	bool	bCase;

    WXSTRING_INPUT( s, wxString, ST(1) )
;

	if (items < 3)
	    bCase = false;
	else {
	    bCase = (bool)SvTRUE(ST(2))
;
	}
    try {
      RETVAL = THIS->FindString( s, bCase );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}

#endif
#if !defined(WXPERL_IN_COMBOBOX)
#define XSpp_f9ce292b_078389
#define XSubPPtmpAAAD 1


XS_EUPXS(XS_Wx__ControlWithItems_SetSelection); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ControlWithItems_SetSelection)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, n");
    {
	wxControlWithItems *    THIS = (wxControlWithItems *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::ControlWithItems" )
;
	int	n = (int)SvIV(ST(1))
;
    try {
      THIS->SetSelection( n );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__ControlWithItems_GetSelection); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ControlWithItems_GetSelection)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxControlWithItems *    THIS = (wxControlWithItems *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::ControlWithItems" )
;
	int	RETVAL;
	dXSTARG;
    try {
      RETVAL = THIS->GetSelection();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}

#endif

XS_EUPXS(XS_Wx__ControlWithItems_SetStringSelection); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ControlWithItems_SetStringSelection)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, s");
    {
	wxControlWithItems *    THIS = (wxControlWithItems *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::ControlWithItems" )
;
	bool	RETVAL;
	wxString	s;

    WXSTRING_INPUT( s, wxString, ST(1) )
;
    try {
      RETVAL = THIS->SetStringSelection( s );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__ControlWithItems_GetStringSelection); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ControlWithItems_GetStringSelection)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxControlWithItems *    THIS = (wxControlWithItems *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::ControlWithItems" )
;
	wxString	RETVAL;
    try {
      RETVAL = THIS->GetStringSelection();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    WXSTRING_OUTPUT( RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__ControlWithItems_Select); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ControlWithItems_Select)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, n");
    {
	wxControlWithItems *    THIS = (wxControlWithItems *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::ControlWithItems" )
;
	int	n = (int)SvIV(ST(1))
;
    try {
      THIS->Select( n );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


/* INCLUDE: Returning to '/usr/bin/perl -I./ -MExtUtils::XSpp::Cmd -e xspp -- -t typemap.xsp XS/ControlWithItems.xsp' from '/usr/bin/perl -pe "s/ItemContainerImmutable/ControlWithItems/g" XS/ItemContainerImmutable.xs' */


/* INCLUDE_COMMAND:  Including output of '/usr/bin/perl -pe "s/ItemContainer/ControlWithItems/g" XS/ItemContainer.xs' from '/usr/bin/perl -I./ -MExtUtils::XSpp::Cmd -e xspp -- -t typemap.xsp XS/ControlWithItems.xsp' */

#include <exception>

#undef  xsp_constructor_class
#define xsp_constructor_class(c) (c)

XS_EUPXS(XS_Wx__ControlWithItems_Append); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ControlWithItems_Append)
{
    dVAR; dXSARGS;
    if (items < 1)
       croak_xs_usage(cv,  "THIS, ...");
    PERL_UNUSED_VAR(ax); /* -Wall */
    SP -= items;
    {
	wxControlWithItems *    THIS = (wxControlWithItems *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::ControlWithItems" )
;
    BEGIN_OVERLOAD()
        MATCH_REDISP( wxPliOvl_arr_arr, AppendItemsData )
        MATCH_REDISP( wxPliOvl_arr, AppendItems )
        MATCH_REDISP( wxPliOvl_s_s, AppendData )
        MATCH_REDISP( wxPliOvl_s, AppendString )
    END_OVERLOAD( Wx::ControlWithItems::Append )
	PUTBACK;
	return;
    }
}


XS_EUPXS(XS_Wx__ControlWithItems_AppendString); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ControlWithItems_AppendString)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, item");
    {
	wxControlWithItems *    THIS = (wxControlWithItems *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::ControlWithItems" )
;
	wxString	item;

    WXSTRING_INPUT( item, wxString, ST(1) )
;
    try {
      THIS->Append( item );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__ControlWithItems_AppendData); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ControlWithItems_AppendData)
{
    dVAR; dXSARGS;
    if (items != 3)
       croak_xs_usage(cv,  "THIS, item, data");
    {
	wxControlWithItems *    THIS = (wxControlWithItems *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::ControlWithItems" )
;
	wxString	item;
	wxPliUserDataCD*	data;

    WXSTRING_INPUT( item, wxString, ST(1) )
;

    if( SvOK( ST(2) ) )
    {
        data = new wxPliUserDataCD( ST(2) );
    }
    else
        data = 0
;
    try {
      THIS->Append( item, data );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__ControlWithItems_AppendItems); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ControlWithItems_AppendItems)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, items");
    {
	wxControlWithItems *    THIS = (wxControlWithItems *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::ControlWithItems" )
;
	wxArrayString	items;

    wxPli_av_2_arraystring( aTHX_ ST(1), & items )
;
    try {
      THIS->Append( items );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}

#if WXPERL_W_VERSION_GE( 2, 9, 0 )
#define XSpp_a2ea7434_096891
#define XSubPPtmpAAAE 1


XS_EUPXS(XS_Wx__ControlWithItems_AppendItemsData); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ControlWithItems_AppendItemsData)
{
    dVAR; dXSARGS;
    if (items != 3)
       croak_xs_usage(cv,  "THIS, items, data");
    {
	wxControlWithItems *    THIS = (wxControlWithItems *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::ControlWithItems" )
;
	wxArrayString	items;
	wxPliUserDataCD**	data;

    wxPli_av_2_arraystring( aTHX_ ST(1), & items )
;

    wxPli_av_2_userdatacdarray( aTHX_ ST(2), & data );
    wxPliArrayGuard<wxPliUserDataCD*> guard_data = data
;
     THIS->Append( items, (wxClientData**)data ); 
    }
    XSRETURN_EMPTY;
}

#endif

XS_EUPXS(XS_Wx__ControlWithItems_Insert); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ControlWithItems_Insert)
{
    dVAR; dXSARGS;
    if (items < 1)
       croak_xs_usage(cv,  "THIS, ...");
    PERL_UNUSED_VAR(ax); /* -Wall */
    SP -= items;
    {
	wxControlWithItems *    THIS = (wxControlWithItems *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::ControlWithItems" )
;
    BEGIN_OVERLOAD()
        MATCH_REDISP( wxPliOvl_arr_n_arr, InsertItemsData )
        MATCH_REDISP( wxPliOvl_arr_n, InsertItems )
        MATCH_REDISP( wxPliOvl_s_n_s, InsertData )
        MATCH_REDISP( wxPliOvl_s_n, InsertString )
    END_OVERLOAD( Wx::ControlWithItems::Insert )
	PUTBACK;
	return;
    }
}


XS_EUPXS(XS_Wx__ControlWithItems_InsertString); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ControlWithItems_InsertString)
{
    dVAR; dXSARGS;
    if (items != 3)
       croak_xs_usage(cv,  "THIS, item, pos");
    {
	wxControlWithItems *    THIS = (wxControlWithItems *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::ControlWithItems" )
;
	wxString	item;
	unsigned int    pos = (unsigned int)SvUV( ST(2) )
;

    WXSTRING_INPUT( item, wxString, ST(1) )
;
    try {
      THIS->Insert( item, pos );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__ControlWithItems_InsertData); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ControlWithItems_InsertData)
{
    dVAR; dXSARGS;
    if (items != 4)
       croak_xs_usage(cv,  "THIS, item, pos, data");
    {
	wxControlWithItems *    THIS = (wxControlWithItems *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::ControlWithItems" )
;
	wxString	item;
	unsigned int    pos = (unsigned int)SvUV( ST(2) )
;
	wxPliUserDataCD*	data;

    WXSTRING_INPUT( item, wxString, ST(1) )
;

    if( SvOK( ST(3) ) )
    {
        data = new wxPliUserDataCD( ST(3) );
    }
    else
        data = 0
;
    try {
      THIS->Insert( item, pos, data );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}

#if WXPERL_W_VERSION_GE( 2, 9, 0 )
#define XSpp_a2ea7434_055796
#define XSubPPtmpAAAF 1


XS_EUPXS(XS_Wx__ControlWithItems_InsertItems); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ControlWithItems_InsertItems)
{
    dVAR; dXSARGS;
    if (items != 3)
       croak_xs_usage(cv,  "THIS, items, pos");
    {
	wxControlWithItems *    THIS = (wxControlWithItems *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::ControlWithItems" )
;
	wxArrayString	items;
	unsigned int    pos = (unsigned int)SvUV( ST(2) )
;

    wxPli_av_2_arraystring( aTHX_ ST(1), & items )
;
    try {
      THIS->Insert( items, pos );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__ControlWithItems_InsertItemsData); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ControlWithItems_InsertItemsData)
{
    dVAR; dXSARGS;
    if (items != 4)
       croak_xs_usage(cv,  "THIS, items, pos, data");
    {
	wxControlWithItems *    THIS = (wxControlWithItems *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::ControlWithItems" )
;
	wxArrayString	items;
	unsigned int    pos = (unsigned int)SvUV( ST(2) )
;
	wxPliUserDataCD**	data;

    wxPli_av_2_arraystring( aTHX_ ST(1), & items )
;

    wxPli_av_2_userdatacdarray( aTHX_ ST(3), & data );
    wxPliArrayGuard<wxPliUserDataCD*> guard_data = data
;
     THIS->Insert( items, pos, (wxClientData**)data ); 
    }
    XSRETURN_EMPTY;
}

#endif
#if WXPERL_W_VERSION_GE( 2, 9, 0 )
#define XSpp_a2ea7434_019830
#define XSubPPtmpAAAG 1


XS_EUPXS(XS_Wx__ControlWithItems_Set); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ControlWithItems_Set)
{
    dVAR; dXSARGS;
    if (items < 1)
       croak_xs_usage(cv,  "THIS, ...");
    PERL_UNUSED_VAR(ax); /* -Wall */
    SP -= items;
    {
	wxControlWithItems *    THIS = (wxControlWithItems *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::ControlWithItems" )
;
    BEGIN_OVERLOAD()
        MATCH_REDISP( wxPliOvl_arr_arr, SetItemsData )
        MATCH_REDISP( wxPliOvl_arr, SetItems )
    END_OVERLOAD( Wx::ControlWithItems::Set )
	PUTBACK;
	return;
    }
}


XS_EUPXS(XS_Wx__ControlWithItems_SetItems); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ControlWithItems_SetItems)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, items");
    {
	wxControlWithItems *    THIS = (wxControlWithItems *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::ControlWithItems" )
;
	wxArrayString	items;

    wxPli_av_2_arraystring( aTHX_ ST(1), & items )
;
    try {
      THIS->Set( items );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__ControlWithItems_SetItemsData); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ControlWithItems_SetItemsData)
{
    dVAR; dXSARGS;
    if (items != 3)
       croak_xs_usage(cv,  "THIS, items, data");
    {
	wxControlWithItems *    THIS = (wxControlWithItems *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::ControlWithItems" )
;
	wxArrayString	items;
	wxPliUserDataCD**	data;

    wxPli_av_2_arraystring( aTHX_ ST(1), & items )
;

    wxPli_av_2_userdatacdarray( aTHX_ ST(2), & data );
    wxPliArrayGuard<wxPliUserDataCD*> guard_data = data
;
     THIS->Set( items, (wxClientData**)data ); 
    }
    XSRETURN_EMPTY;
}

#endif

XS_EUPXS(XS_Wx__ControlWithItems_Clear); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ControlWithItems_Clear)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxControlWithItems *    THIS = (wxControlWithItems *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::ControlWithItems" )
;
    try {
      THIS->Clear();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__ControlWithItems_Delete); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ControlWithItems_Delete)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, n");
    {
	wxControlWithItems *    THIS = (wxControlWithItems *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::ControlWithItems" )
;
	int	n = (int)SvIV(ST(1))
;
    try {
      THIS->Delete( n );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__ControlWithItems_GetClientData); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ControlWithItems_GetClientData)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, n");
    {
	wxControlWithItems *    THIS = (wxControlWithItems *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::ControlWithItems" )
;
	wxPliUserDataCD *	RETVAL;
	int	n = (int)SvIV(ST(1))
;
     RETVAL = (wxPliUserDataCD*) THIS->GetClientObject( n ); 
	{
	    SV * RETVALSV;
    RETVALSV = ( RETVAL == 0 ) ? &PL_sv_undef : RETVAL->GetData();
    SvREFCNT_inc( RETVALSV ); // xsubpp mortalizes it...
	    RETVALSV = sv_2mortal(RETVALSV);
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__ControlWithItems_SetClientData); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ControlWithItems_SetClientData)
{
    dVAR; dXSARGS;
    if (items != 3)
       croak_xs_usage(cv,  "THIS, n, data");
    {
	wxControlWithItems *    THIS = (wxControlWithItems *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::ControlWithItems" )
;
	int	n = (int)SvIV(ST(1))
;
	wxPliUserDataCD*	data;

    if( SvOK( ST(2) ) )
    {
        data = new wxPliUserDataCD( ST(2) );
    }
    else
        data = 0
;
    try {
      THIS->SetClientObject( n, data );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}

#if WXPERL_W_VERSION_GE( 2, 9, 0 )
#define XSpp_a2ea7434_093657
#endif

/* INCLUDE: Returning to '/usr/bin/perl -I./ -MExtUtils::XSpp::Cmd -e xspp -- -t typemap.xsp XS/ControlWithItems.xsp' from '/usr/bin/perl -pe "s/ItemContainer/ControlWithItems/g" XS/ItemContainer.xs' */


/* INCLUDE: Returning to 'Controls.xs' from '/usr/bin/perl -I./ -MExtUtils::XSpp::Cmd -e xspp -- -t typemap.xsp XS/ControlWithItems.xsp' */


/* INCLUDE_COMMAND:  Including output of '/usr/bin/perl -I./ -MExtUtils::XSpp::Cmd -e xspp -- -t typemap.xsp interface/wx/bmpbuttn.h' from 'Controls.xs' */


/* INCLUDE_COMMAND:  Including output of '/usr/bin/perl -I./ -MExtUtils::XSpp::Cmd -e xspp -- -t typemap.xsp XS/AnimationCtrl.xsp' from '/usr/bin/perl -I./ -MExtUtils::XSpp::Cmd -e xspp -- -t typemap.xsp interface/wx/bmpbuttn.h' */

#include <exception>

#undef  xsp_constructor_class
#define xsp_constructor_class(c) (c)
#if WXPERL_W_VERSION_GE( 2, 7, 2 )
#define XSpp_29145de4_084734
#include <wx/animate.h>
#undef  xsp_constructor_class
#define xsp_constructor_class(c) (CLASS)
#define XSubPPtmpAAAH 1


XS_EUPXS(XS_Wx__AnimationCtrl_newDefault); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__AnimationCtrl_newDefault)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "CLASS");
    {
	char *	CLASS = (char *)SvPV_nolen(ST(0))
;
	wxAnimationCtrl *	RETVAL;
     RETVAL = new wxAnimationCtrl();
                wxPli_create_evthandler( aTHX_ RETVAL, CLASS );
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_evthandler_2_sv( aTHX_ RETVALSV, RETVAL );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}

#undef  xsp_constructor_class
#define xsp_constructor_class(c) (c)
#undef  xsp_constructor_class
#define xsp_constructor_class(c) (CLASS)

XS_EUPXS(XS_Wx__AnimationCtrl_new); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__AnimationCtrl_new)
{
    dVAR; dXSARGS;
    if (items < 3 || items > 8)
       croak_xs_usage(cv,  "CLASS, parent, id, anim= wxNullAnimationPtr, pos= wxDefaultPosition, size= wxDefaultSize, style= wxAC_DEFAULT_STYLE, name= wxAnimationCtrlNameStr");
    {
	char *	CLASS = (char *)SvPV_nolen(ST(0))
;
	wxAnimationCtrl *	RETVAL;
	wxWindow*    parent = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::Window" )
;
	wxWindowID    id = wxPli_get_wxwindowid( aTHX_ ST(2) )
;
	wxAnimation*	anim;
	wxPoint	pos;
	wxSize	size;
	long	style;
	wxString	name;

	if (items < 4)
	    anim = wxNullAnimationPtr;
	else {
    anim = (wxAnimation *) wxPli_sv_2_object( aTHX_ ST(3), "Wx::Animation" )
;
	}

	if (items < 5)
	    pos = wxDefaultPosition;
	else {
    pos = wxPli_sv_2_wxpoint( aTHX_ ST(4) )
;
	}

	if (items < 6)
	    size = wxDefaultSize;
	else {
    size = wxPli_sv_2_wxsize( aTHX_ ST(5) )
;
	}

	if (items < 7)
	    style = wxAC_DEFAULT_STYLE;
	else {
	    style = (long)SvIV(ST(6))
;
	}

	if (items < 8)
	    name = wxAnimationCtrlNameStr;
	else {
    WXSTRING_INPUT( name, wxString, ST(7) )
;
	}
     RETVAL = new wxAnimationCtrl( parent, id, *anim, pos, size,
                                              style, name );
                wxPli_create_evthandler( aTHX_ RETVAL, CLASS );
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_evthandler_2_sv( aTHX_ RETVALSV, RETVAL );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}

#undef  xsp_constructor_class
#define xsp_constructor_class(c) (c)

XS_EUPXS(XS_Wx__AnimationCtrl_Create); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__AnimationCtrl_Create)
{
    dVAR; dXSARGS;
    if (items < 3 || items > 8)
       croak_xs_usage(cv,  "THIS, parent, id, anim= wxNullAnimationPtr, pos= wxDefaultPosition, size= wxDefaultSize, style= wxAC_DEFAULT_STYLE, name= wxAnimationCtrlNameStr");
    {
	wxAnimationCtrl *    THIS = (wxAnimationCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::AnimationCtrl" )
;
	bool	RETVAL;
	wxWindow*    parent = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::Window" )
;
	wxWindowID    id = wxPli_get_wxwindowid( aTHX_ ST(2) )
;
	wxAnimation*	anim;
	wxPoint	pos;
	wxSize	size;
	long	style;
	wxString	name;

	if (items < 4)
	    anim = wxNullAnimationPtr;
	else {
    anim = (wxAnimation *) wxPli_sv_2_object( aTHX_ ST(3), "Wx::Animation" )
;
	}

	if (items < 5)
	    pos = wxDefaultPosition;
	else {
    pos = wxPli_sv_2_wxpoint( aTHX_ ST(4) )
;
	}

	if (items < 6)
	    size = wxDefaultSize;
	else {
    size = wxPli_sv_2_wxsize( aTHX_ ST(5) )
;
	}

	if (items < 7)
	    style = wxAC_DEFAULT_STYLE;
	else {
	    style = (long)SvIV(ST(6))
;
	}

	if (items < 8)
	    name = wxAnimationCtrlNameStr;
	else {
    WXSTRING_INPUT( name, wxString, ST(7) )
;
	}
    try {
      RETVAL = THIS->Create( parent, id, *( anim ), pos, size, style, name );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__AnimationCtrl_LoadFile); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__AnimationCtrl_LoadFile)
{
    dVAR; dXSARGS;
    if (items < 2 || items > 3)
       croak_xs_usage(cv,  "THIS, filename, type= wxANIMATION_TYPE_ANY");
    {
	wxAnimationCtrl *    THIS = (wxAnimationCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::AnimationCtrl" )
;
	bool	RETVAL;
	wxString	filename;
	wxAnimationType	type;

    WXSTRING_INPUT( filename, wxString, ST(1) )
;

	if (items < 3)
	    type = wxANIMATION_TYPE_ANY;
	else {
	    type = (wxAnimationType)SvIV(ST(2))
;
	}
    try {
      RETVAL = THIS->LoadFile( filename, type );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__AnimationCtrl_SetAnimation); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__AnimationCtrl_SetAnimation)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, anim");
    {
	wxAnimationCtrl *    THIS = (wxAnimationCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::AnimationCtrl" )
;
	wxAnimation*    anim = (wxAnimation *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::Animation" )
;
    try {
      THIS->SetAnimation( *( anim ) );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__AnimationCtrl_GetAnimation); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__AnimationCtrl_GetAnimation)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxAnimationCtrl *    THIS = (wxAnimationCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::AnimationCtrl" )
;
	wxAnimation *	RETVAL;
    try {
      RETVAL = new wxAnimation( THIS->GetAnimation() );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_object_2_sv( aTHX_ RETVALSV, RETVAL );
    wxPli_thread_sv_register( aTHX_ "Wx::Animation", RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__AnimationCtrl_Play); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__AnimationCtrl_Play)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxAnimationCtrl *    THIS = (wxAnimationCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::AnimationCtrl" )
;
	bool	RETVAL;
    try {
      RETVAL = THIS->Play();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__AnimationCtrl_Stop); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__AnimationCtrl_Stop)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxAnimationCtrl *    THIS = (wxAnimationCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::AnimationCtrl" )
;
    try {
      THIS->Stop();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__AnimationCtrl_IsPlaying); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__AnimationCtrl_IsPlaying)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxAnimationCtrl *    THIS = (wxAnimationCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::AnimationCtrl" )
;
	bool	RETVAL;
    try {
      RETVAL = THIS->IsPlaying();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__AnimationCtrl_SetInactiveBitmap); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__AnimationCtrl_SetInactiveBitmap)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, bmp");
    {
	wxAnimationCtrl *    THIS = (wxAnimationCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::AnimationCtrl" )
;
	wxBitmap*    bmp = (wxBitmap *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::Bitmap" )
;
    try {
      THIS->SetInactiveBitmap( *( bmp ) );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__AnimationCtrl_GetInactiveBitmap); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__AnimationCtrl_GetInactiveBitmap)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxAnimationCtrl *    THIS = (wxAnimationCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::AnimationCtrl" )
;
	wxBitmap *	RETVAL;
    try {
      RETVAL = new wxBitmap( THIS->GetInactiveBitmap() );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_object_2_sv( aTHX_ RETVALSV, RETVAL );
    wxPli_thread_sv_register( aTHX_ "Wx::Bitmap", RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}

#endif

/* INCLUDE: Returning to '/usr/bin/perl -I./ -MExtUtils::XSpp::Cmd -e xspp -- -t typemap.xsp interface/wx/bmpbuttn.h' from '/usr/bin/perl -I./ -MExtUtils::XSpp::Cmd -e xspp -- -t typemap.xsp XS/AnimationCtrl.xsp' */

#include <exception>

#undef  xsp_constructor_class
#define xsp_constructor_class(c) (c)
#include <wx/bmpbuttn.h>
#if WXPERL_W_VERSION_GE( 2, 9, 5 )
#define XSpp_359dd586_041084
#define XSubPPtmpAAAI 1


XS_EUPXS(XS_Wx__BitmapButton_NewCloseButton); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__BitmapButton_NewCloseButton)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "parent, winid");
    {
	wxBitmapButton *	RETVAL;
	wxWindow*    parent = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Window" )
;
	wxWindowID    winid = wxPli_get_wxwindowid( aTHX_ ST(1) )
;
    try {
      RETVAL = wxBitmapButton::NewCloseButton( parent, winid );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_evthandler_2_sv( aTHX_ RETVALSV, RETVAL );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}

#endif    
#undef  xsp_constructor_class
#define xsp_constructor_class(c) (CLASS)

XS_EUPXS(XS_Wx__BitmapButton_newDefault); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__BitmapButton_newDefault)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "CLASS");
    {
	char *	CLASS = (char *)SvPV_nolen(ST(0))
;
	wxBitmapButton *	RETVAL;
    try {
      RETVAL = new wxBitmapButton();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
     wxPli_create_evthandler( aTHX_ RETVAL, CLASS ); 
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_evthandler_2_sv( aTHX_ RETVALSV, RETVAL );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}

#undef  xsp_constructor_class
#define xsp_constructor_class(c) (c)
#undef  xsp_constructor_class
#define xsp_constructor_class(c) (CLASS)

XS_EUPXS(XS_Wx__BitmapButton_newFull); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__BitmapButton_newFull)
{
    dVAR; dXSARGS;
    if (items < 4 || items > 9)
       croak_xs_usage(cv,  "CLASS, parent, id, bitmap, pos= wxDefaultPosition, size= wxDefaultSize, style= wxBU_AUTODRAW, validator= wxDefaultValidatorPtr, name= wxButtonNameStr");
    {
	char *	CLASS = (char *)SvPV_nolen(ST(0))
;
	wxBitmapButton *	RETVAL;
	wxWindow*    parent = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::Window" )
;
	wxWindowID    id = wxPli_get_wxwindowid( aTHX_ ST(2) )
;
	wxBitmap*    bitmap = (wxBitmap *) wxPli_sv_2_object( aTHX_ ST(3), "Wx::Bitmap" )
;
	wxPoint	pos;
	wxSize	size;
	long	style;
	wxValidator*	validator;
	wxString	name;

	if (items < 5)
	    pos = wxDefaultPosition;
	else {
    pos = wxPli_sv_2_wxpoint( aTHX_ ST(4) )
;
	}

	if (items < 6)
	    size = wxDefaultSize;
	else {
    size = wxPli_sv_2_wxsize( aTHX_ ST(5) )
;
	}

	if (items < 7)
	    style = wxBU_AUTODRAW;
	else {
	    style = (long)SvIV(ST(6))
;
	}

	if (items < 8)
	    validator = wxDefaultValidatorPtr;
	else {
    validator = (wxValidator *) wxPli_sv_2_object( aTHX_ ST(7), "Wx::Validator" )
;
	}

	if (items < 9)
	    name = wxButtonNameStr;
	else {
    WXSTRING_INPUT( name, wxString, ST(8) )
;
	}
    try {
      RETVAL = new wxBitmapButton( parent, id, *( bitmap ), pos, size, style, *( validator ), name );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
     wxPli_create_evthandler( aTHX_ RETVAL, CLASS ); 
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_evthandler_2_sv( aTHX_ RETVALSV, RETVAL );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}

#undef  xsp_constructor_class
#define xsp_constructor_class(c) (c)

XS_EUPXS(XS_Wx__BitmapButton_Create); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__BitmapButton_Create)
{
    dVAR; dXSARGS;
    if (items < 4 || items > 9)
       croak_xs_usage(cv,  "THIS, parent, id, bitmap, pos= wxDefaultPosition, size= wxDefaultSize, style= wxBU_AUTODRAW, validator= wxDefaultValidatorPtr, name= wxButtonNameStr");
    {
	wxBitmapButton *    THIS = (wxBitmapButton *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::BitmapButton" )
;
	bool	RETVAL;
	wxWindow*    parent = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::Window" )
;
	wxWindowID    id = wxPli_get_wxwindowid( aTHX_ ST(2) )
;
	wxBitmap*    bitmap = (wxBitmap *) wxPli_sv_2_object( aTHX_ ST(3), "Wx::Bitmap" )
;
	wxPoint	pos;
	wxSize	size;
	long	style;
	wxValidator*	validator;
	wxString	name;

	if (items < 5)
	    pos = wxDefaultPosition;
	else {
    pos = wxPli_sv_2_wxpoint( aTHX_ ST(4) )
;
	}

	if (items < 6)
	    size = wxDefaultSize;
	else {
    size = wxPli_sv_2_wxsize( aTHX_ ST(5) )
;
	}

	if (items < 7)
	    style = wxBU_AUTODRAW;
	else {
	    style = (long)SvIV(ST(6))
;
	}

	if (items < 8)
	    validator = wxDefaultValidatorPtr;
	else {
    validator = (wxValidator *) wxPli_sv_2_object( aTHX_ ST(7), "Wx::Validator" )
;
	}

	if (items < 9)
	    name = wxButtonNameStr;
	else {
    WXSTRING_INPUT( name, wxString, ST(8) )
;
	}
    try {
      RETVAL = THIS->Create( parent, id, *( bitmap ), pos, size, style, *( validator ), name );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__BitmapButton_GetBitmapDisabled); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__BitmapButton_GetBitmapDisabled)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxBitmapButton *    THIS = (wxBitmapButton *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::BitmapButton" )
;
	wxBitmap *	RETVAL;
    try {
      RETVAL = new wxBitmap( THIS->GetBitmapDisabled() );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_object_2_sv( aTHX_ RETVALSV, RETVAL );
    wxPli_thread_sv_register( aTHX_ "Wx::Bitmap", RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__BitmapButton_GetBitmapFocus); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__BitmapButton_GetBitmapFocus)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxBitmapButton *    THIS = (wxBitmapButton *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::BitmapButton" )
;
	wxBitmap *	RETVAL;
    try {
      RETVAL = new wxBitmap( THIS->GetBitmapFocus() );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_object_2_sv( aTHX_ RETVALSV, RETVAL );
    wxPli_thread_sv_register( aTHX_ "Wx::Bitmap", RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}

#if WXPERL_W_VERSION_GE( 2, 7, 0 )
#define XSpp_359dd586_051592
#define XSubPPtmpAAAJ 1


XS_EUPXS(XS_Wx__BitmapButton_GetBitmapHover); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__BitmapButton_GetBitmapHover)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxBitmapButton *    THIS = (wxBitmapButton *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::BitmapButton" )
;
	wxBitmap *	RETVAL;
    try {
      RETVAL = new wxBitmap( THIS->GetBitmapHover() );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_object_2_sv( aTHX_ RETVALSV, RETVAL );
    wxPli_thread_sv_register( aTHX_ "Wx::Bitmap", RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}

#endif

XS_EUPXS(XS_Wx__BitmapButton_GetBitmapLabel); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__BitmapButton_GetBitmapLabel)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxBitmapButton *    THIS = (wxBitmapButton *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::BitmapButton" )
;
	wxBitmap *	RETVAL;
    try {
      RETVAL = new wxBitmap( THIS->GetBitmapLabel() );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_object_2_sv( aTHX_ RETVALSV, RETVAL );
    wxPli_thread_sv_register( aTHX_ "Wx::Bitmap", RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__BitmapButton_GetBitmapSelected); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__BitmapButton_GetBitmapSelected)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxBitmapButton *    THIS = (wxBitmapButton *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::BitmapButton" )
;
	wxBitmap *	RETVAL;
    try {
      RETVAL = new wxBitmap( THIS->GetBitmapSelected() );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_object_2_sv( aTHX_ RETVALSV, RETVAL );
    wxPli_thread_sv_register( aTHX_ "Wx::Bitmap", RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__BitmapButton_SetBitmapDisabled); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__BitmapButton_SetBitmapDisabled)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, bitmap");
    {
	wxBitmapButton *    THIS = (wxBitmapButton *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::BitmapButton" )
;
	wxBitmap*    bitmap = (wxBitmap *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::Bitmap" )
;
    try {
      THIS->SetBitmapDisabled( *( bitmap ) );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__BitmapButton_SetBitmapFocus); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__BitmapButton_SetBitmapFocus)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, bitmap");
    {
	wxBitmapButton *    THIS = (wxBitmapButton *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::BitmapButton" )
;
	wxBitmap*    bitmap = (wxBitmap *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::Bitmap" )
;
    try {
      THIS->SetBitmapFocus( *( bitmap ) );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}

#if WXPERL_W_VERSION_GE( 2, 7, 0 )
#define XSpp_359dd586_012287
#define XSubPPtmpAAAK 1


XS_EUPXS(XS_Wx__BitmapButton_SetBitmapHover); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__BitmapButton_SetBitmapHover)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, bitmap");
    {
	wxBitmapButton *    THIS = (wxBitmapButton *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::BitmapButton" )
;
	wxBitmap*    bitmap = (wxBitmap *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::Bitmap" )
;
    try {
      THIS->SetBitmapHover( *( bitmap ) );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}

#endif

XS_EUPXS(XS_Wx__BitmapButton_SetBitmapLabel); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__BitmapButton_SetBitmapLabel)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, bitmap");
    {
	wxBitmapButton *    THIS = (wxBitmapButton *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::BitmapButton" )
;
	wxBitmap*    bitmap = (wxBitmap *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::Bitmap" )
;
    try {
      THIS->SetBitmapLabel( *( bitmap ) );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__BitmapButton_SetBitmapSelected); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__BitmapButton_SetBitmapSelected)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, bitmap");
    {
	wxBitmapButton *    THIS = (wxBitmapButton *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::BitmapButton" )
;
	wxBitmap*    bitmap = (wxBitmap *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::Bitmap" )
;
    try {
      THIS->SetBitmapSelected( *( bitmap ) );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}

#include "cpp/overload.h"
#if 1
#define XSubPPtmpAAAL 1


XS_EUPXS(XS_Wx__BitmapButton_new); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__BitmapButton_new)
{
    dVAR; dXSARGS;
    if (items < 1)
       croak_xs_usage(cv,  "CLASS, ...");
    PERL_UNUSED_VAR(ax); /* -Wall */
    SP -= items;
    {
	char *	CLASS = (char *)SvPV_nolen(ST(0))
;
#if 1
    static wxPliPrototype void_proto( NULL, 0 );
#endif // 1
    static wxPliPrototype *wxPliOvl_all_prototypes[] = {
#if 1
        &void_proto,
#endif // 1
        NULL };
    BEGIN_OVERLOAD()
#if 1
        MATCH_VOIDM_REDISP( newDefault )
#endif // 1
#if 1
        MATCH_ANY_REDISP( newFull )
#endif // 1
    END_OVERLOAD_MESSAGE( Wx::BitmapButton::new, wxPliOvl_all_prototypes )
	PUTBACK;
	return;
    }
}

#endif // 1

/* INCLUDE: Returning to 'Controls.xs' from '/usr/bin/perl -I./ -MExtUtils::XSpp::Cmd -e xspp -- -t typemap.xsp interface/wx/bmpbuttn.h' */


/* INCLUDE_COMMAND:  Including output of '/usr/bin/perl -I./ -MExtUtils::XSpp::Cmd -e xspp -- -t typemap.xsp XS/EditableListBox.xsp' from 'Controls.xs' */

#include <exception>

#undef  xsp_constructor_class
#define xsp_constructor_class(c) (c)
#if WXPERL_W_VERSION_GE( 2, 9, 0 )
#define XSpp_03826871_073258
#include <wx/editlbox.h>
#define XSubPPtmpAAAM 1


XS_EUPXS(XS_Wx__EditableListBox_new); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__EditableListBox_new)
{
    dVAR; dXSARGS;
    PERL_UNUSED_VAR(cv); /* -W */
    PERL_UNUSED_VAR(items); /* -W */
    PERL_UNUSED_VAR(ax); /* -Wall */
    SP -= items;
    {
    BEGIN_OVERLOAD()
        MATCH_VOIDM_REDISP( newDefault )
        MATCH_ANY_REDISP( newFull )
    END_OVERLOAD( "Wx::EditableListBox::new" )
	PUTBACK;
	return;
    }
}

#undef  xsp_constructor_class
#define xsp_constructor_class(c) (CLASS)

XS_EUPXS(XS_Wx__EditableListBox_newDefault); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__EditableListBox_newDefault)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "CLASS");
    {
	char *	CLASS = (char *)SvPV_nolen(ST(0))
;
	wxEditableListBox *	RETVAL;
     RETVAL = new wxEditableListBox();
                wxPli_create_evthandler( aTHX_ RETVAL, CLASS );
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_object_2_sv( aTHX_ RETVALSV, RETVAL );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}

#undef  xsp_constructor_class
#define xsp_constructor_class(c) (c)
#undef  xsp_constructor_class
#define xsp_constructor_class(c) (CLASS)

XS_EUPXS(XS_Wx__EditableListBox_newFull); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__EditableListBox_newFull)
{
    dVAR; dXSARGS;
    if (items < 4 || items > 8)
       croak_xs_usage(cv,  "CLASS, parent, id, label, pos= wxDefaultPosition, size= wxDefaultSize, style= wxEL_DEFAULT_STYLE, name= wxEditableListBoxNameStr");
    {
	char *	CLASS = (char *)SvPV_nolen(ST(0))
;
	wxEditableListBox *	RETVAL;
	wxWindow*    parent = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::Window" )
;
	wxWindowID    id = wxPli_get_wxwindowid( aTHX_ ST(2) )
;
	wxString	label;
	wxPoint	pos;
	wxSize	size;
	long	style;
	wxString	name;

    WXSTRING_INPUT( label, wxString, ST(3) )
;

	if (items < 5)
	    pos = wxDefaultPosition;
	else {
    pos = wxPli_sv_2_wxpoint( aTHX_ ST(4) )
;
	}

	if (items < 6)
	    size = wxDefaultSize;
	else {
    size = wxPli_sv_2_wxsize( aTHX_ ST(5) )
;
	}

	if (items < 7)
	    style = wxEL_DEFAULT_STYLE;
	else {
	    style = (long)SvIV(ST(6))
;
	}

	if (items < 8)
	    name = wxEditableListBoxNameStr;
	else {
    WXSTRING_INPUT( name, wxString, ST(7) )
;
	}
     RETVAL = new wxEditableListBox( parent, id, label, pos, size,
                                                style, name );
                wxPli_create_evthandler( aTHX_ RETVAL, CLASS );
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_object_2_sv( aTHX_ RETVALSV, RETVAL );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}

#undef  xsp_constructor_class
#define xsp_constructor_class(c) (c)

XS_EUPXS(XS_Wx__EditableListBox_Create); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__EditableListBox_Create)
{
    dVAR; dXSARGS;
    if (items < 4 || items > 8)
       croak_xs_usage(cv,  "THIS, parent, id, label, pos= wxDefaultPosition, size= wxDefaultSize, style= wxEL_DEFAULT_STYLE, name= wxEditableListBoxNameStr");
    {
	wxEditableListBox *    THIS = (wxEditableListBox *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::EditableListBox" )
;
	bool	RETVAL;
	wxWindow*    parent = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::Window" )
;
	wxWindowID    id = wxPli_get_wxwindowid( aTHX_ ST(2) )
;
	wxString	label;
	wxPoint	pos;
	wxSize	size;
	long	style;
	wxString	name;

    WXSTRING_INPUT( label, wxString, ST(3) )
;

	if (items < 5)
	    pos = wxDefaultPosition;
	else {
    pos = wxPli_sv_2_wxpoint( aTHX_ ST(4) )
;
	}

	if (items < 6)
	    size = wxDefaultSize;
	else {
    size = wxPli_sv_2_wxsize( aTHX_ ST(5) )
;
	}

	if (items < 7)
	    style = wxEL_DEFAULT_STYLE;
	else {
	    style = (long)SvIV(ST(6))
;
	}

	if (items < 8)
	    name = wxEditableListBoxNameStr;
	else {
    WXSTRING_INPUT( name, wxString, ST(7) )
;
	}
    try {
      RETVAL = THIS->Create( parent, id, label, pos, size, style, name );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__EditableListBox_SetStrings); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__EditableListBox_SetStrings)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, strings");
    {
	wxEditableListBox *    THIS = (wxEditableListBox *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::EditableListBox" )
;
	wxArrayString	strings;

    wxPli_av_2_arraystring( aTHX_ ST(1), & strings )
;
    try {
      THIS->SetStrings( strings );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__EditableListBox_GetStrings); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__EditableListBox_GetStrings)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    PERL_UNUSED_VAR(ax); /* -Wall */
    SP -= items;
    {
	wxEditableListBox *    THIS = (wxEditableListBox *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::EditableListBox" )
;
    wxArrayString strings;
    THIS->GetStrings( strings );
    PUTBACK;
    wxPli_stringarray_push( aTHX_ strings );
    SPAGAIN;
	PUTBACK;
	return;
    }
}


XS_EUPXS(XS_Wx__EditableListBox_GetListCtrl); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__EditableListBox_GetListCtrl)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxEditableListBox *    THIS = (wxEditableListBox *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::EditableListBox" )
;
	wxListCtrl *	RETVAL;
    try {
      RETVAL = THIS->GetListCtrl();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_object_2_sv( aTHX_ RETVALSV, RETVAL );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__EditableListBox_GetDelButton); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__EditableListBox_GetDelButton)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxEditableListBox *    THIS = (wxEditableListBox *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::EditableListBox" )
;
	wxBitmapButton *	RETVAL;
    try {
      RETVAL = THIS->GetDelButton();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_evthandler_2_sv( aTHX_ RETVALSV, RETVAL );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__EditableListBox_GetNewButton); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__EditableListBox_GetNewButton)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxEditableListBox *    THIS = (wxEditableListBox *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::EditableListBox" )
;
	wxBitmapButton *	RETVAL;
    try {
      RETVAL = THIS->GetNewButton();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_evthandler_2_sv( aTHX_ RETVALSV, RETVAL );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__EditableListBox_GetUpButton); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__EditableListBox_GetUpButton)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxEditableListBox *    THIS = (wxEditableListBox *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::EditableListBox" )
;
	wxBitmapButton *	RETVAL;
    try {
      RETVAL = THIS->GetUpButton();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_evthandler_2_sv( aTHX_ RETVALSV, RETVAL );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__EditableListBox_GetDownButton); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__EditableListBox_GetDownButton)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxEditableListBox *    THIS = (wxEditableListBox *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::EditableListBox" )
;
	wxBitmapButton *	RETVAL;
    try {
      RETVAL = THIS->GetDownButton();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_evthandler_2_sv( aTHX_ RETVALSV, RETVAL );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__EditableListBox_GetEditButton); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__EditableListBox_GetEditButton)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxEditableListBox *    THIS = (wxEditableListBox *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::EditableListBox" )
;
	wxBitmapButton *	RETVAL;
    try {
      RETVAL = THIS->GetEditButton();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_evthandler_2_sv( aTHX_ RETVALSV, RETVAL );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}

#endif

/* INCLUDE: Returning to 'Controls.xs' from '/usr/bin/perl -I./ -MExtUtils::XSpp::Cmd -e xspp -- -t typemap.xsp XS/EditableListBox.xsp' */


/* INCLUDE_COMMAND:  Including output of '/usr/bin/perl -I./ -MExtUtils::XSpp::Cmd -e xspp -- -t typemap.xsp XS/BookCtrl.xsp' from 'Controls.xs' */

#include <exception>

#undef  xsp_constructor_class
#define xsp_constructor_class(c) (c)
#if WXPERL_W_VERSION_GE( 2, 5, 1 )
#include <wx/bookctrl.h>
#include <wx/sizer.h>
#define XSubPPtmpAAAN 1


XS_EUPXS(XS_Wx__BookCtrl_GetPageCount); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__BookCtrl_GetPageCount)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxBookCtrl *    THIS = (wxBookCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::BookCtrl" )
;
	size_t	RETVAL;
	dXSTARG;
    try {
      RETVAL = THIS->GetPageCount();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	XSprePUSH;
	PUSHu((UV)RETVAL );
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__BookCtrl_GetPage); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__BookCtrl_GetPage)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, n");
    {
	wxBookCtrl *    THIS = (wxBookCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::BookCtrl" )
;
	wxWindow *	RETVAL;
	size_t    n = (size_t)SvUV( ST(1) )
;
    try {
      RETVAL = THIS->GetPage( n );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_object_2_sv( aTHX_ RETVALSV, RETVAL );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__BookCtrl_GetSelection); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__BookCtrl_GetSelection)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxBookCtrl *    THIS = (wxBookCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::BookCtrl" )
;
	int	RETVAL;
	dXSTARG;
    try {
      RETVAL = THIS->GetSelection();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__BookCtrl_SetPageText); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__BookCtrl_SetPageText)
{
    dVAR; dXSARGS;
    if (items != 3)
       croak_xs_usage(cv,  "THIS, n, strText");
    {
	wxBookCtrl *    THIS = (wxBookCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::BookCtrl" )
;
	bool	RETVAL;
	size_t    n = (size_t)SvUV( ST(1) )
;
	wxString	strText;

    WXSTRING_INPUT( strText, wxString, ST(2) )
;
    try {
      RETVAL = THIS->SetPageText( n, strText );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__BookCtrl_GetPageText); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__BookCtrl_GetPageText)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, n");
    {
	wxBookCtrl *    THIS = (wxBookCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::BookCtrl" )
;
	wxString	RETVAL;
	size_t    n = (size_t)SvUV( ST(1) )
;
    try {
      RETVAL = THIS->GetPageText( n );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    WXSTRING_OUTPUT( RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__BookCtrl_SetImageList); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__BookCtrl_SetImageList)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, imageList");
    {
	wxBookCtrl *    THIS = (wxBookCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::BookCtrl" )
;
	wxImageList*    imageList = (wxImageList *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::ImageList" )
;
    try {
      THIS->SetImageList( imageList );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__BookCtrl_GetPageImage); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__BookCtrl_GetPageImage)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, n");
    {
	wxBookCtrl *    THIS = (wxBookCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::BookCtrl" )
;
	int	RETVAL;
	dXSTARG;
	size_t    n = (size_t)SvUV( ST(1) )
;
    try {
      RETVAL = THIS->GetPageImage( n );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__BookCtrl_SetPageImage); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__BookCtrl_SetPageImage)
{
    dVAR; dXSARGS;
    if (items != 3)
       croak_xs_usage(cv,  "THIS, n, imageId");
    {
	wxBookCtrl *    THIS = (wxBookCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::BookCtrl" )
;
	bool	RETVAL;
	size_t    n = (size_t)SvUV( ST(1) )
;
	int	imageId = (int)SvIV(ST(2))
;
    try {
      RETVAL = THIS->SetPageImage( n, imageId );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__BookCtrl_SetPageSize); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__BookCtrl_SetPageSize)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, size");
    {
	wxBookCtrl *    THIS = (wxBookCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::BookCtrl" )
;
	wxSize    size = wxPli_sv_2_wxsize( aTHX_ ST(1) )
;
    try {
      THIS->SetPageSize( size );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__BookCtrl_CalcSizeFromPage); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__BookCtrl_CalcSizeFromPage)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, sizePage");
    {
	wxBookCtrl *    THIS = (wxBookCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::BookCtrl" )
;
	wxSize	RETVAL;
	wxSize    sizePage = wxPli_sv_2_wxsize( aTHX_ ST(1) )
;
    try {
      RETVAL = THIS->CalcSizeFromPage( sizePage );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_non_object_2_sv( aTHX_ RETVALSV, new wxSize(RETVAL), "Wx::Size" );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}

#if WXPERL_W_VERSION_GE( 2, 7, 0 )
#define XSpp_8f34ba62_003430
#define XSubPPtmpAAAO 1


XS_EUPXS(XS_Wx__BookCtrl_GetInternalBorder); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__BookCtrl_GetInternalBorder)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxBookCtrl *    THIS = (wxBookCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::BookCtrl" )
;
	unsigned int	RETVAL;
	dXSTARG;
    try {
      RETVAL = THIS->GetInternalBorder();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	XSprePUSH;
	PUSHu((UV)RETVAL );
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__BookCtrl_SetInternalBorder); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__BookCtrl_SetInternalBorder)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, border");
    {
	wxBookCtrl *    THIS = (wxBookCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::BookCtrl" )
;
	unsigned int    border = (unsigned int)SvUV( ST(1) )
;
    try {
      THIS->SetInternalBorder( border );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__BookCtrl_IsVertical); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__BookCtrl_IsVertical)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxBookCtrl *    THIS = (wxBookCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::BookCtrl" )
;
	bool	RETVAL;
    try {
      RETVAL = THIS->IsVertical();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__BookCtrl_SetFitToCurrentPage); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__BookCtrl_SetFitToCurrentPage)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, fit");
    {
	wxBookCtrl *    THIS = (wxBookCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::BookCtrl" )
;
	bool	fit = (bool)SvTRUE(ST(1))
;
    try {
      THIS->SetFitToCurrentPage( fit );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__BookCtrl_GetFitToCurrentPage); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__BookCtrl_GetFitToCurrentPage)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxBookCtrl *    THIS = (wxBookCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::BookCtrl" )
;
	bool	RETVAL;
    try {
      RETVAL = THIS->GetFitToCurrentPage();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__BookCtrl_GetControlSizer); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__BookCtrl_GetControlSizer)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxBookCtrl *    THIS = (wxBookCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::BookCtrl" )
;
	wxSizer *	RETVAL;
    try {
      RETVAL = THIS->GetControlSizer();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_object_2_sv( aTHX_ RETVALSV, RETVAL );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}

#endif

XS_EUPXS(XS_Wx__BookCtrl_DeletePage); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__BookCtrl_DeletePage)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, n");
    {
	wxBookCtrl *    THIS = (wxBookCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::BookCtrl" )
;
	bool	RETVAL;
	size_t    n = (size_t)SvUV( ST(1) )
;
    try {
      RETVAL = THIS->DeletePage( n );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__BookCtrl_RemovePage); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__BookCtrl_RemovePage)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, n");
    {
	wxBookCtrl *    THIS = (wxBookCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::BookCtrl" )
;
	bool	RETVAL;
	size_t    n = (size_t)SvUV( ST(1) )
;
    try {
      RETVAL = THIS->RemovePage( n );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__BookCtrl_DeleteAllPages); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__BookCtrl_DeleteAllPages)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxBookCtrl *    THIS = (wxBookCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::BookCtrl" )
;
	bool	RETVAL;
    try {
      RETVAL = THIS->DeleteAllPages();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__BookCtrl_AddPage); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__BookCtrl_AddPage)
{
    dVAR; dXSARGS;
    if (items < 3 || items > 5)
       croak_xs_usage(cv,  "THIS, page, text, bSelect= false, imageId= -1");
    {
	wxBookCtrl *    THIS = (wxBookCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::BookCtrl" )
;
	bool	RETVAL;
	wxWindow*    page = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::Window" )
;
	wxString	text;
	bool	bSelect;
	int	imageId;

    WXSTRING_INPUT( text, wxString, ST(2) )
;

	if (items < 4)
	    bSelect = false;
	else {
	    bSelect = (bool)SvTRUE(ST(3))
;
	}

	if (items < 5)
	    imageId = -1;
	else {
	    imageId = (int)SvIV(ST(4))
;
	}
    try {
      RETVAL = THIS->AddPage( page, text, bSelect, imageId );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__BookCtrl_InsertPage); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__BookCtrl_InsertPage)
{
    dVAR; dXSARGS;
    if (items < 4 || items > 6)
       croak_xs_usage(cv,  "THIS, n, page, text, bSelect= false, imageId= -1");
    {
	wxBookCtrl *    THIS = (wxBookCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::BookCtrl" )
;
	bool	RETVAL;
	size_t    n = (size_t)SvUV( ST(1) )
;
	wxWindow*    page = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(2), "Wx::Window" )
;
	wxString	text;
	bool	bSelect;
	int	imageId;

    WXSTRING_INPUT( text, wxString, ST(3) )
;

	if (items < 5)
	    bSelect = false;
	else {
	    bSelect = (bool)SvTRUE(ST(4))
;
	}

	if (items < 6)
	    imageId = -1;
	else {
	    imageId = (int)SvIV(ST(5))
;
	}
    try {
      RETVAL = THIS->InsertPage( n, page, text, bSelect, imageId );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__BookCtrl_SetSelection); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__BookCtrl_SetSelection)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, n");
    {
	wxBookCtrl *    THIS = (wxBookCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::BookCtrl" )
;
	int	RETVAL;
	dXSTARG;
	size_t    n = (size_t)SvUV( ST(1) )
;
    try {
      RETVAL = THIS->SetSelection( n );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__BookCtrl_AdvanceSelection); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__BookCtrl_AdvanceSelection)
{
    dVAR; dXSARGS;
    if (items < 1 || items > 2)
       croak_xs_usage(cv,  "THIS, forward= true");
    {
	wxBookCtrl *    THIS = (wxBookCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::BookCtrl" )
;
	bool	forward;

	if (items < 2)
	    forward = true;
	else {
	    forward = (bool)SvTRUE(ST(1))
;
	}
    try {
      THIS->AdvanceSelection( forward );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}

#if WXPERL_W_VERSION_GE( 2, 7, 2 )
#define XSpp_8f34ba62_077686
#define XSubPPtmpAAAP 1


XS_EUPXS(XS_Wx__BookCtrl_ChangeSelection); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__BookCtrl_ChangeSelection)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, n");
    {
	wxBookCtrl *    THIS = (wxBookCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::BookCtrl" )
;
	int	RETVAL;
	dXSTARG;
	size_t    n = (size_t)SvUV( ST(1) )
;
    try {
      RETVAL = THIS->ChangeSelection( n );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}

#endif
#if WXPERL_W_VERSION_GE( 2, 6, 0 )
#define XSpp_8f34ba62_030936
#define XSubPPtmpAAAQ 1


XS_EUPXS(XS_Wx__BookCtrl_GetCurrentPage); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__BookCtrl_GetCurrentPage)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxBookCtrl *    THIS = (wxBookCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::BookCtrl" )
;
	wxWindow *	RETVAL;
    try {
      RETVAL = THIS->GetCurrentPage();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_object_2_sv( aTHX_ RETVALSV, RETVAL );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}

#endif

XS_EUPXS(XS_Wx__BookCtrl_AssignImageList); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__BookCtrl_AssignImageList)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, imagelist");
    {
	wxImageList*    imagelist = (wxImageList *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::ImageList" )
;
	wxBookCtrl *    THIS = (wxBookCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::BookCtrl" )
;
    wxPli_object_set_deleteable( aTHX_ ST(1), false );
    THIS->AssignImageList( imagelist );
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__BookCtrl_GetImageList); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__BookCtrl_GetImageList)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxBookCtrl *    THIS = (wxBookCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::BookCtrl" )
;
	wxImageList *	RETVAL;

	RETVAL = THIS->GetImageList();
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_object_2_sv( aTHX_ RETVALSV, RETVAL );
    wxPli_thread_sv_register( aTHX_ "Wx::ImageList", RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    wxPli_object_set_deleteable( aTHX_ ST(0), false );
    }
    XSRETURN(1);
}

#if WXPERL_W_VERSION_GE( 2, 7, 0 )
#define XSubPPtmpAAAR 1


XS_EUPXS(XS_Wx__BookCtrl_HitTest); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__BookCtrl_HitTest)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, point");
    PERL_UNUSED_VAR(ax); /* -Wall */
    SP -= items;
    {
	wxPoint    point = wxPli_sv_2_wxpoint( aTHX_ ST(1) )
;
    long flags;
    int item;
	wxBookCtrl *    THIS = (wxBookCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::BookCtrl" )
;
    item = THIS->HitTest( point, &flags );
    EXTEND( SP, 2 );
    PUSHs( sv_2mortal( newSViv( item ) ) );
    PUSHs( sv_2mortal( newSViv( flags ) ) );
	PUTBACK;
	return;
    }
}

#endif

XS_EUPXS(XS_Wx__BookCtrlEvent_GetSelection); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__BookCtrlEvent_GetSelection)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxBookCtrlEvent *    THIS = (wxBookCtrlEvent *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::BookCtrlEvent" )
;
	int	RETVAL;
	dXSTARG;
    try {
      RETVAL = THIS->GetSelection();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__BookCtrlEvent_SetSelection); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__BookCtrlEvent_SetSelection)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, nSel");
    {
	wxBookCtrlEvent *    THIS = (wxBookCtrlEvent *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::BookCtrlEvent" )
;
	int	nSel = (int)SvIV(ST(1))
;
    try {
      THIS->SetSelection( nSel );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__BookCtrlEvent_GetOldSelection); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__BookCtrlEvent_GetOldSelection)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxBookCtrlEvent *    THIS = (wxBookCtrlEvent *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::BookCtrlEvent" )
;
	int	RETVAL;
	dXSTARG;
    try {
      RETVAL = THIS->GetOldSelection();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__BookCtrlEvent_SetOldSelection); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__BookCtrlEvent_SetOldSelection)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, nOldSel");
    {
	wxBookCtrlEvent *    THIS = (wxBookCtrlEvent *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::BookCtrlEvent" )
;
	int	nOldSel = (int)SvIV(ST(1))
;
    try {
      THIS->SetOldSelection( nOldSel );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}

#endif

/* INCLUDE: Returning to 'Controls.xs' from '/usr/bin/perl -I./ -MExtUtils::XSpp::Cmd -e xspp -- -t typemap.xsp XS/BookCtrl.xsp' */


/* INCLUDE_COMMAND:  Including output of '/usr/bin/perl -I./ -MExtUtils::XSpp::Cmd -e xspp -- -t typemap.xsp XS/Listbook.xsp' from 'Controls.xs' */

#include <exception>

#undef  xsp_constructor_class
#define xsp_constructor_class(c) (c)
#if WXPERL_W_VERSION_GE( 2, 5, 1 )
#include <wx/listbook.h>
#undef  xsp_constructor_class
#define xsp_constructor_class(c) (CLASS)
#define XSubPPtmpAAAS 1


XS_EUPXS(XS_Wx__Listbook_newDefault); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Listbook_newDefault)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "CLASS");
    {
	char *	CLASS = (char *)SvPV_nolen(ST(0))
;
	wxListbook *	RETVAL;
     RETVAL = new wxListbook();
                wxPli_create_evthandler( aTHX_ RETVAL, CLASS );
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_evthandler_2_sv( aTHX_ RETVALSV, RETVAL );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}

#undef  xsp_constructor_class
#define xsp_constructor_class(c) (c)
#undef  xsp_constructor_class
#define xsp_constructor_class(c) (CLASS)

XS_EUPXS(XS_Wx__Listbook_newFull); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Listbook_newFull)
{
    dVAR; dXSARGS;
    if (items < 2 || items > 7)
       croak_xs_usage(cv,  "CLASS, parent, id= wxID_ANY, pos= wxDefaultPosition, size= wxDefaultSize, style= 0, name= wxEmptyString");
    {
	char *	CLASS = (char *)SvPV_nolen(ST(0))
;
	wxListbook *	RETVAL;
	wxWindow*    parent = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::Window" )
;
	wxWindowID	id;
	wxPoint	pos;
	wxSize	size;
	long	style;
	wxString	name;

	if (items < 3)
	    id = wxID_ANY;
	else {
    id = wxPli_get_wxwindowid( aTHX_ ST(2) )
;
	}

	if (items < 4)
	    pos = wxDefaultPosition;
	else {
    pos = wxPli_sv_2_wxpoint( aTHX_ ST(3) )
;
	}

	if (items < 5)
	    size = wxDefaultSize;
	else {
    size = wxPli_sv_2_wxsize( aTHX_ ST(4) )
;
	}

	if (items < 6)
	    style = 0;
	else {
	    style = (long)SvIV(ST(5))
;
	}

	if (items < 7)
	    name = wxEmptyString;
	else {
    WXSTRING_INPUT( name, wxString, ST(6) )
;
	}
     RETVAL = new wxListbook( parent, id, pos, size, style, name );
                wxPli_create_evthandler( aTHX_ RETVAL, CLASS );
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_evthandler_2_sv( aTHX_ RETVALSV, RETVAL );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}

#undef  xsp_constructor_class
#define xsp_constructor_class(c) (c)

XS_EUPXS(XS_Wx__Listbook_Create); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Listbook_Create)
{
    dVAR; dXSARGS;
    if (items < 2 || items > 7)
       croak_xs_usage(cv,  "THIS, parent, id= wxID_ANY, pos= wxDefaultPosition, size= wxDefaultSize, style= 0, name= wxEmptyString");
    {
	wxListbook *    THIS = (wxListbook *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Listbook" )
;
	bool	RETVAL;
	wxWindow*    parent = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::Window" )
;
	wxWindowID	id;
	wxPoint	pos;
	wxSize	size;
	long	style;
	wxString	name;

	if (items < 3)
	    id = wxID_ANY;
	else {
    id = wxPli_get_wxwindowid( aTHX_ ST(2) )
;
	}

	if (items < 4)
	    pos = wxDefaultPosition;
	else {
    pos = wxPli_sv_2_wxpoint( aTHX_ ST(3) )
;
	}

	if (items < 5)
	    size = wxDefaultSize;
	else {
    size = wxPli_sv_2_wxsize( aTHX_ ST(4) )
;
	}

	if (items < 6)
	    style = 0;
	else {
	    style = (long)SvIV(ST(5))
;
	}

	if (items < 7)
	    name = wxEmptyString;
	else {
    WXSTRING_INPUT( name, wxString, ST(6) )
;
	}
    try {
      RETVAL = THIS->Create( parent, id, pos, size, style, name );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}

#if WXPERL_W_VERSION_GE( 2, 5, 3 )
#define XSpp_1a1a5341_073174
#define XSubPPtmpAAAT 1


XS_EUPXS(XS_Wx__Listbook_GetListView); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Listbook_GetListView)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxListbook *    THIS = (wxListbook *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Listbook" )
;
	wxListView *	RETVAL;
    try {
      RETVAL = THIS->GetListView();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_evthandler_2_sv( aTHX_ RETVALSV, RETVAL );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}

#endif

XS_EUPXS(XS_Wx__Listbook_new); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Listbook_new)
{
    dVAR; dXSARGS;
    PERL_UNUSED_VAR(cv); /* -W */
    PERL_UNUSED_VAR(items); /* -W */
    PERL_UNUSED_VAR(ax); /* -Wall */
    SP -= items;
    {
    BEGIN_OVERLOAD()
        MATCH_VOIDM_REDISP( newDefault )
        MATCH_ANY_REDISP( newFull )
    END_OVERLOAD( "Wx::Listbook::new" )
	PUTBACK;
	return;
    }
}

#endif

/* INCLUDE: Returning to 'Controls.xs' from '/usr/bin/perl -I./ -MExtUtils::XSpp::Cmd -e xspp -- -t typemap.xsp XS/Listbook.xsp' */


/* INCLUDE_COMMAND:  Including output of '/usr/bin/perl -I./ -MExtUtils::XSpp::Cmd -e xspp -- -t typemap.xsp XS/Choicebook.xsp' from 'Controls.xs' */

#include <exception>

#undef  xsp_constructor_class
#define xsp_constructor_class(c) (c)
#if WXPERL_W_VERSION_GE( 2, 5, 3 )
#include <wx/choice.h>
#include <wx/choicebk.h>
#undef  xsp_constructor_class
#define xsp_constructor_class(c) (CLASS)
#define XSubPPtmpAAAU 1


XS_EUPXS(XS_Wx__Choicebook_newDefault); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Choicebook_newDefault)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "CLASS");
    {
	char *	CLASS = (char *)SvPV_nolen(ST(0))
;
	wxChoicebook *	RETVAL;
     RETVAL = new wxChoicebook();
                wxPli_create_evthandler( aTHX_ RETVAL, CLASS );
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_evthandler_2_sv( aTHX_ RETVALSV, RETVAL );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}

#undef  xsp_constructor_class
#define xsp_constructor_class(c) (c)
#undef  xsp_constructor_class
#define xsp_constructor_class(c) (CLASS)

XS_EUPXS(XS_Wx__Choicebook_newFull); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Choicebook_newFull)
{
    dVAR; dXSARGS;
    if (items < 3 || items > 7)
       croak_xs_usage(cv,  "CLASS, parent, id, pos= wxDefaultPosition, size= wxDefaultSize, style= 0, name= wxEmptyString");
    {
	char *	CLASS = (char *)SvPV_nolen(ST(0))
;
	wxChoicebook *	RETVAL;
	wxWindow*    parent = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::Window" )
;
	wxWindowID    id = wxPli_get_wxwindowid( aTHX_ ST(2) )
;
	wxPoint	pos;
	wxSize	size;
	long	style;
	wxString	name;

	if (items < 4)
	    pos = wxDefaultPosition;
	else {
    pos = wxPli_sv_2_wxpoint( aTHX_ ST(3) )
;
	}

	if (items < 5)
	    size = wxDefaultSize;
	else {
    size = wxPli_sv_2_wxsize( aTHX_ ST(4) )
;
	}

	if (items < 6)
	    style = 0;
	else {
	    style = (long)SvIV(ST(5))
;
	}

	if (items < 7)
	    name = wxEmptyString;
	else {
    WXSTRING_INPUT( name, wxString, ST(6) )
;
	}
     RETVAL = new wxChoicebook( parent, id, pos, size, style, name );
                wxPli_create_evthandler( aTHX_ RETVAL, CLASS );
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_evthandler_2_sv( aTHX_ RETVALSV, RETVAL );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}

#undef  xsp_constructor_class
#define xsp_constructor_class(c) (c)

XS_EUPXS(XS_Wx__Choicebook_Create); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Choicebook_Create)
{
    dVAR; dXSARGS;
    if (items < 3 || items > 7)
       croak_xs_usage(cv,  "THIS, parent, id, pos= wxDefaultPosition, size= wxDefaultSize, style= 0, name= wxEmptyString");
    {
	wxChoicebook *    THIS = (wxChoicebook *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Choicebook" )
;
	bool	RETVAL;
	wxWindow*    parent = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::Window" )
;
	wxWindowID    id = wxPli_get_wxwindowid( aTHX_ ST(2) )
;
	wxPoint	pos;
	wxSize	size;
	long	style;
	wxString	name;

	if (items < 4)
	    pos = wxDefaultPosition;
	else {
    pos = wxPli_sv_2_wxpoint( aTHX_ ST(3) )
;
	}

	if (items < 5)
	    size = wxDefaultSize;
	else {
    size = wxPli_sv_2_wxsize( aTHX_ ST(4) )
;
	}

	if (items < 6)
	    style = 0;
	else {
	    style = (long)SvIV(ST(5))
;
	}

	if (items < 7)
	    name = wxEmptyString;
	else {
    WXSTRING_INPUT( name, wxString, ST(6) )
;
	}
    try {
      RETVAL = THIS->Create( parent, id, pos, size, style, name );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__Choicebook_IsVertical); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Choicebook_IsVertical)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxChoicebook *    THIS = (wxChoicebook *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Choicebook" )
;
	bool	RETVAL;
    try {
      RETVAL = THIS->IsVertical();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}

#if WXPERL_W_VERSION_GE( 2, 6, 0 )
#define XSpp_a863ef1b_008579
#define XSubPPtmpAAAV 1


XS_EUPXS(XS_Wx__Choicebook_GetChoiceCtrl); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Choicebook_GetChoiceCtrl)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxChoicebook *    THIS = (wxChoicebook *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Choicebook" )
;
	wxChoice *	RETVAL;
    try {
      RETVAL = THIS->GetChoiceCtrl();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_evthandler_2_sv( aTHX_ RETVALSV, RETVAL );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}

#endif

XS_EUPXS(XS_Wx__Choicebook_new); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Choicebook_new)
{
    dVAR; dXSARGS;
    PERL_UNUSED_VAR(cv); /* -W */
    PERL_UNUSED_VAR(items); /* -W */
    PERL_UNUSED_VAR(ax); /* -Wall */
    SP -= items;
    {
    BEGIN_OVERLOAD()
        MATCH_VOIDM_REDISP( newDefault )
        MATCH_ANY_REDISP( newFull )
    END_OVERLOAD( "Wx::Choicebook::new" )
	PUTBACK;
	return;
    }
}

#endif

/* INCLUDE: Returning to 'Controls.xs' from '/usr/bin/perl -I./ -MExtUtils::XSpp::Cmd -e xspp -- -t typemap.xsp XS/Choicebook.xsp' */


/* INCLUDE_COMMAND:  Including output of '/usr/bin/perl -I./ -MExtUtils::XSpp::Cmd -e xspp -- -t typemap.xsp XS/Toolbook.xsp' from 'Controls.xs' */

#include <exception>

#undef  xsp_constructor_class
#define xsp_constructor_class(c) (c)
#if WXPERL_W_VERSION_GE( 2, 7, 0 )
#include <wx/toolbar.h>
#include <wx/toolbook.h>
#undef  xsp_constructor_class
#define xsp_constructor_class(c) (CLASS)
#define XSubPPtmpAAAW 1


XS_EUPXS(XS_Wx__Toolbook_newDefault); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Toolbook_newDefault)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "CLASS");
    {
	char *	CLASS = (char *)SvPV_nolen(ST(0))
;
	wxToolbook *	RETVAL;
     RETVAL = new wxToolbook();
                wxPli_create_evthandler( aTHX_ RETVAL, CLASS );
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_evthandler_2_sv( aTHX_ RETVALSV, RETVAL );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}

#undef  xsp_constructor_class
#define xsp_constructor_class(c) (c)
#undef  xsp_constructor_class
#define xsp_constructor_class(c) (CLASS)

XS_EUPXS(XS_Wx__Toolbook_newFull); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Toolbook_newFull)
{
    dVAR; dXSARGS;
    if (items < 2 || items > 7)
       croak_xs_usage(cv,  "CLASS, parent, id= wxID_ANY, pos= wxDefaultPosition, size= wxDefaultSize, style= 0, name= wxEmptyString");
    {
	char *	CLASS = (char *)SvPV_nolen(ST(0))
;
	wxToolbook *	RETVAL;
	wxWindow*    parent = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::Window" )
;
	wxWindowID	id;
	wxPoint	pos;
	wxSize	size;
	long	style;
	wxString	name;

	if (items < 3)
	    id = wxID_ANY;
	else {
    id = wxPli_get_wxwindowid( aTHX_ ST(2) )
;
	}

	if (items < 4)
	    pos = wxDefaultPosition;
	else {
    pos = wxPli_sv_2_wxpoint( aTHX_ ST(3) )
;
	}

	if (items < 5)
	    size = wxDefaultSize;
	else {
    size = wxPli_sv_2_wxsize( aTHX_ ST(4) )
;
	}

	if (items < 6)
	    style = 0;
	else {
	    style = (long)SvIV(ST(5))
;
	}

	if (items < 7)
	    name = wxEmptyString;
	else {
    WXSTRING_INPUT( name, wxString, ST(6) )
;
	}
     RETVAL = new wxToolbook( parent, id, pos, size, style, name );
                wxPli_create_evthandler( aTHX_ RETVAL, CLASS );
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_evthandler_2_sv( aTHX_ RETVALSV, RETVAL );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}

#undef  xsp_constructor_class
#define xsp_constructor_class(c) (c)

XS_EUPXS(XS_Wx__Toolbook_Create); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Toolbook_Create)
{
    dVAR; dXSARGS;
    if (items < 2 || items > 7)
       croak_xs_usage(cv,  "THIS, parent, id= wxID_ANY, pos= wxDefaultPosition, size= wxDefaultSize, style= 0, name= wxEmptyString");
    {
	wxToolbook *    THIS = (wxToolbook *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Toolbook" )
;
	bool	RETVAL;
	wxWindow*    parent = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::Window" )
;
	wxWindowID	id;
	wxPoint	pos;
	wxSize	size;
	long	style;
	wxString	name;

	if (items < 3)
	    id = wxID_ANY;
	else {
    id = wxPli_get_wxwindowid( aTHX_ ST(2) )
;
	}

	if (items < 4)
	    pos = wxDefaultPosition;
	else {
    pos = wxPli_sv_2_wxpoint( aTHX_ ST(3) )
;
	}

	if (items < 5)
	    size = wxDefaultSize;
	else {
    size = wxPli_sv_2_wxsize( aTHX_ ST(4) )
;
	}

	if (items < 6)
	    style = 0;
	else {
	    style = (long)SvIV(ST(5))
;
	}

	if (items < 7)
	    name = wxEmptyString;
	else {
    WXSTRING_INPUT( name, wxString, ST(6) )
;
	}
    try {
      RETVAL = THIS->Create( parent, id, pos, size, style, name );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__Toolbook_GetToolBar); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Toolbook_GetToolBar)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxToolbook *    THIS = (wxToolbook *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Toolbook" )
;
	wxToolBarBase *	RETVAL;
    try {
      RETVAL = THIS->GetToolBar();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_evthandler_2_sv( aTHX_ RETVALSV, RETVAL );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__Toolbook_Realize); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Toolbook_Realize)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxToolbook *    THIS = (wxToolbook *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Toolbook" )
;
    try {
      THIS->Realize();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__Toolbook_new); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Toolbook_new)
{
    dVAR; dXSARGS;
    PERL_UNUSED_VAR(cv); /* -W */
    PERL_UNUSED_VAR(items); /* -W */
    PERL_UNUSED_VAR(ax); /* -Wall */
    SP -= items;
    {
    BEGIN_OVERLOAD()
        MATCH_VOIDM_REDISP( newDefault )
        MATCH_ANY_REDISP( newFull )
    END_OVERLOAD( "Wx::Toolbook::new" )
	PUTBACK;
	return;
    }
}

#endif

/* INCLUDE: Returning to 'Controls.xs' from '/usr/bin/perl -I./ -MExtUtils::XSpp::Cmd -e xspp -- -t typemap.xsp XS/Toolbook.xsp' */


/* INCLUDE_COMMAND:  Including output of '/usr/bin/perl -I./ -MExtUtils::XSpp::Cmd -e xspp -- -t typemap.xsp XS/Treebook.xsp' from 'Controls.xs' */

#include <exception>

#undef  xsp_constructor_class
#define xsp_constructor_class(c) (c)
#if WXPERL_W_VERSION_GE( 2, 7, 0 )
#define XSpp_c46ff287_047787
#include <wx/treebook.h>
#undef  xsp_constructor_class
#define xsp_constructor_class(c) (CLASS)
#define XSubPPtmpAAAX 1


XS_EUPXS(XS_Wx__TreebookEvent_new); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__TreebookEvent_new)
{
    dVAR; dXSARGS;
    if (items < 1 || items > 5)
       croak_xs_usage(cv,  "CLASS, commandType= wxEVT_NULL, id= 0, nSel= wxNOT_FOUND, nOldSel= wxNOT_FOUND");
    {
	char *	CLASS = (char *)SvPV_nolen(ST(0))
;
	wxTreebookEvent *	RETVAL;
	wxEventType	commandType;
	int	id;
	int	nSel;
	int	nOldSel;

	if (items < 2)
	    commandType = wxEVT_NULL;
	else {
	    commandType = (wxEventType)SvIV(ST(1))
;
	}

	if (items < 3)
	    id = 0;
	else {
	    id = (int)SvIV(ST(2))
;
	}

	if (items < 4)
	    nSel = wxNOT_FOUND;
	else {
	    nSel = (int)SvIV(ST(3))
;
	}

	if (items < 5)
	    nOldSel = wxNOT_FOUND;
	else {
	    nOldSel = (int)SvIV(ST(4))
;
	}
    try {
      RETVAL = new wxTreebookEvent( commandType, id, nSel, nOldSel );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_object_2_sv( aTHX_ RETVALSV, RETVAL );
    wxPli_thread_sv_register( aTHX_ "Wx::TreebookEvent", RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}

#undef  xsp_constructor_class
#define xsp_constructor_class(c) (c)

XS_EUPXS(XS_Wx__TreebookEvent_GetOldSelection); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__TreebookEvent_GetOldSelection)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxTreebookEvent *    THIS = (wxTreebookEvent *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::TreebookEvent" )
;
	int	RETVAL;
	dXSTARG;
    try {
      RETVAL = THIS->GetOldSelection();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__TreebookEvent_GetSelection); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__TreebookEvent_GetSelection)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxTreebookEvent *    THIS = (wxTreebookEvent *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::TreebookEvent" )
;
	int	RETVAL;
	dXSTARG;
    try {
      RETVAL = THIS->GetSelection();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}

#undef  xsp_constructor_class
#define xsp_constructor_class(c) (CLASS)

XS_EUPXS(XS_Wx__Treebook_newDefault); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Treebook_newDefault)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "CLASS");
    {
	char *	CLASS = (char *)SvPV_nolen(ST(0))
;
	wxTreebook *	RETVAL;
     RETVAL = new wxTreebook();
                wxPli_create_evthandler( aTHX_ RETVAL, CLASS );
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_evthandler_2_sv( aTHX_ RETVALSV, RETVAL );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}

#undef  xsp_constructor_class
#define xsp_constructor_class(c) (c)
#undef  xsp_constructor_class
#define xsp_constructor_class(c) (CLASS)

XS_EUPXS(XS_Wx__Treebook_newFull); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Treebook_newFull)
{
    dVAR; dXSARGS;
    if (items < 2 || items > 7)
       croak_xs_usage(cv,  "CLASS, parent, id= wxID_ANY, pos= wxDefaultPosition, size= wxDefaultSize, style= 0, name= wxEmptyString");
    {
	char *	CLASS = (char *)SvPV_nolen(ST(0))
;
	wxTreebook *	RETVAL;
	wxWindow*    parent = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::Window" )
;
	wxWindowID	id;
	wxPoint	pos;
	wxSize	size;
	long	style;
	wxString	name;

	if (items < 3)
	    id = wxID_ANY;
	else {
    id = wxPli_get_wxwindowid( aTHX_ ST(2) )
;
	}

	if (items < 4)
	    pos = wxDefaultPosition;
	else {
    pos = wxPli_sv_2_wxpoint( aTHX_ ST(3) )
;
	}

	if (items < 5)
	    size = wxDefaultSize;
	else {
    size = wxPli_sv_2_wxsize( aTHX_ ST(4) )
;
	}

	if (items < 6)
	    style = 0;
	else {
	    style = (long)SvIV(ST(5))
;
	}

	if (items < 7)
	    name = wxEmptyString;
	else {
    WXSTRING_INPUT( name, wxString, ST(6) )
;
	}
     RETVAL = new wxTreebook( parent, id, pos, size, style, name );
                wxPli_create_evthandler( aTHX_ RETVAL, CLASS );
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_evthandler_2_sv( aTHX_ RETVALSV, RETVAL );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}

#undef  xsp_constructor_class
#define xsp_constructor_class(c) (c)

XS_EUPXS(XS_Wx__Treebook_Create); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Treebook_Create)
{
    dVAR; dXSARGS;
    if (items < 2 || items > 7)
       croak_xs_usage(cv,  "THIS, parent, id= wxID_ANY, pos= wxDefaultPosition, size= wxDefaultSize, style= 0, name= wxEmptyString");
    {
	wxTreebook *    THIS = (wxTreebook *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Treebook" )
;
	bool	RETVAL;
	wxWindow*    parent = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::Window" )
;
	wxWindowID	id;
	wxPoint	pos;
	wxSize	size;
	long	style;
	wxString	name;

	if (items < 3)
	    id = wxID_ANY;
	else {
    id = wxPli_get_wxwindowid( aTHX_ ST(2) )
;
	}

	if (items < 4)
	    pos = wxDefaultPosition;
	else {
    pos = wxPli_sv_2_wxpoint( aTHX_ ST(3) )
;
	}

	if (items < 5)
	    size = wxDefaultSize;
	else {
    size = wxPli_sv_2_wxsize( aTHX_ ST(4) )
;
	}

	if (items < 6)
	    style = 0;
	else {
	    style = (long)SvIV(ST(5))
;
	}

	if (items < 7)
	    name = wxEmptyString;
	else {
    WXSTRING_INPUT( name, wxString, ST(6) )
;
	}
    try {
      RETVAL = THIS->Create( parent, id, pos, size, style, name );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__Treebook_InsertSubPage); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Treebook_InsertSubPage)
{
    dVAR; dXSARGS;
    if (items < 4 || items > 6)
       croak_xs_usage(cv,  "THIS, pos, page, text, bSelect= false, imageId= wxNOT_FOUND");
    {
	wxTreebook *    THIS = (wxTreebook *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Treebook" )
;
	bool	RETVAL;
	size_t    pos = (size_t)SvUV( ST(1) )
;
	wxWindow*    page = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(2), "Wx::Window" )
;
	wxString	text;
	bool	bSelect;
	int	imageId;

    WXSTRING_INPUT( text, wxString, ST(3) )
;

	if (items < 5)
	    bSelect = false;
	else {
	    bSelect = (bool)SvTRUE(ST(4))
;
	}

	if (items < 6)
	    imageId = wxNOT_FOUND;
	else {
	    imageId = (int)SvIV(ST(5))
;
	}
    try {
      RETVAL = THIS->InsertSubPage( pos, page, text, bSelect, imageId );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__Treebook_AddSubPage); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Treebook_AddSubPage)
{
    dVAR; dXSARGS;
    if (items < 3 || items > 5)
       croak_xs_usage(cv,  "THIS, page, text, bSelect= false, imageId= wxNOT_FOUND");
    {
	wxTreebook *    THIS = (wxTreebook *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Treebook" )
;
	bool	RETVAL;
	wxWindow*    page = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::Window" )
;
	wxString	text;
	bool	bSelect;
	int	imageId;

    WXSTRING_INPUT( text, wxString, ST(2) )
;

	if (items < 4)
	    bSelect = false;
	else {
	    bSelect = (bool)SvTRUE(ST(3))
;
	}

	if (items < 5)
	    imageId = wxNOT_FOUND;
	else {
	    imageId = (int)SvIV(ST(4))
;
	}
    try {
      RETVAL = THIS->AddSubPage( page, text, bSelect, imageId );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__Treebook_IsNodeExpanded); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Treebook_IsNodeExpanded)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, pos");
    {
	wxTreebook *    THIS = (wxTreebook *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Treebook" )
;
	bool	RETVAL;
	size_t    pos = (size_t)SvUV( ST(1) )
;
    try {
      RETVAL = THIS->IsNodeExpanded( pos );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__Treebook_ExpandNode); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Treebook_ExpandNode)
{
    dVAR; dXSARGS;
    if (items < 2 || items > 3)
       croak_xs_usage(cv,  "THIS, pos, expand= true");
    {
	wxTreebook *    THIS = (wxTreebook *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Treebook" )
;
	bool	RETVAL;
	size_t    pos = (size_t)SvUV( ST(1) )
;
	bool	expand;

	if (items < 3)
	    expand = true;
	else {
	    expand = (bool)SvTRUE(ST(2))
;
	}
    try {
      RETVAL = THIS->ExpandNode( pos, expand );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__Treebook_CollapseNode); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Treebook_CollapseNode)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, pos");
    {
	wxTreebook *    THIS = (wxTreebook *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Treebook" )
;
	bool	RETVAL;
	size_t    pos = (size_t)SvUV( ST(1) )
;
    try {
      RETVAL = THIS->CollapseNode( pos );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__Treebook_GetPageParent); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Treebook_GetPageParent)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, pos");
    {
	wxTreebook *    THIS = (wxTreebook *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Treebook" )
;
	int	RETVAL;
	dXSTARG;
	size_t    pos = (size_t)SvUV( ST(1) )
;
    try {
      RETVAL = THIS->GetPageParent( pos );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__Treebook_GetTreeCtrl); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Treebook_GetTreeCtrl)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxTreebook *    THIS = (wxTreebook *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Treebook" )
;
	wxTreeCtrl *	RETVAL;
    try {
      RETVAL = THIS->GetTreeCtrl();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_object_2_sv( aTHX_ RETVALSV, RETVAL );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__Treebook_new); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Treebook_new)
{
    dVAR; dXSARGS;
    PERL_UNUSED_VAR(cv); /* -W */
    PERL_UNUSED_VAR(items); /* -W */
    PERL_UNUSED_VAR(ax); /* -Wall */
    SP -= items;
    {
    BEGIN_OVERLOAD()
        MATCH_VOIDM_REDISP( newDefault )
        MATCH_ANY_REDISP( newFull )
    END_OVERLOAD( "Wx::Treebook::new" )
	PUTBACK;
	return;
    }
}

#endif

/* INCLUDE: Returning to 'Controls.xs' from '/usr/bin/perl -I./ -MExtUtils::XSpp::Cmd -e xspp -- -t typemap.xsp XS/Treebook.xsp' */


/* INCLUDE_COMMAND:  Including output of '/usr/bin/perl -I./ -MExtUtils::XSpp::Cmd -e xspp -- -t typemap.xsp XS/HyperlinkCtrl.xsp' from 'Controls.xs' */

#include <exception>

#undef  xsp_constructor_class
#define xsp_constructor_class(c) (c)
#if WXPERL_W_VERSION_GE( 2, 7, 0 )
#include <wx/hyperlink.h>
#undef  xsp_constructor_class
#define xsp_constructor_class(c) (CLASS)
#define XSubPPtmpAAAY 1


XS_EUPXS(XS_Wx__HyperlinkCtrl_newDefault); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__HyperlinkCtrl_newDefault)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "CLASS");
    {
	char *	CLASS = (char *)SvPV_nolen(ST(0))
;
	wxHyperlinkCtrl *	RETVAL;
     RETVAL = new wxHyperlinkCtrl();
                wxPli_create_evthandler( aTHX_ RETVAL, CLASS );
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_evthandler_2_sv( aTHX_ RETVALSV, RETVAL );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}

#undef  xsp_constructor_class
#define xsp_constructor_class(c) (c)
#undef  xsp_constructor_class
#define xsp_constructor_class(c) (CLASS)

XS_EUPXS(XS_Wx__HyperlinkCtrl_newFull); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__HyperlinkCtrl_newFull)
{
    dVAR; dXSARGS;
    if (items < 5 || items > 9)
       croak_xs_usage(cv,  "CLASS, parent, id, label, url, pos= wxDefaultPosition, size= wxDefaultSize, style= 0, name= wxHyperlinkCtrlNameStr");
    {
	char *	CLASS = (char *)SvPV_nolen(ST(0))
;
	wxHyperlinkCtrl *	RETVAL;
	wxWindow*    parent = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::Window" )
;
	wxWindowID    id = wxPli_get_wxwindowid( aTHX_ ST(2) )
;
	wxString	label;
	wxString	url;
	wxPoint	pos;
	wxSize	size;
	long	style;
	wxString	name;

    WXSTRING_INPUT( label, wxString, ST(3) )
;

    WXSTRING_INPUT( url, wxString, ST(4) )
;

	if (items < 6)
	    pos = wxDefaultPosition;
	else {
    pos = wxPli_sv_2_wxpoint( aTHX_ ST(5) )
;
	}

	if (items < 7)
	    size = wxDefaultSize;
	else {
    size = wxPli_sv_2_wxsize( aTHX_ ST(6) )
;
	}

	if (items < 8)
	    style = 0;
	else {
	    style = (long)SvIV(ST(7))
;
	}

	if (items < 9)
	    name = wxHyperlinkCtrlNameStr;
	else {
    WXSTRING_INPUT( name, wxString, ST(8) )
;
	}
     RETVAL = new wxHyperlinkCtrl( parent, id, label, url,
                                              pos, size, style, name );
                wxPli_create_evthandler( aTHX_ RETVAL, CLASS );
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_evthandler_2_sv( aTHX_ RETVALSV, RETVAL );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}

#undef  xsp_constructor_class
#define xsp_constructor_class(c) (c)

XS_EUPXS(XS_Wx__HyperlinkCtrl_Create); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__HyperlinkCtrl_Create)
{
    dVAR; dXSARGS;
    if (items < 5 || items > 9)
       croak_xs_usage(cv,  "THIS, parent, id, label, url, pos= wxDefaultPosition, size= wxDefaultSize, style= 0, name= wxHyperlinkCtrlNameStr");
    {
	wxHyperlinkCtrl *    THIS = (wxHyperlinkCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::HyperlinkCtrl" )
;
	bool	RETVAL;
	wxWindow*    parent = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::Window" )
;
	wxWindowID    id = wxPli_get_wxwindowid( aTHX_ ST(2) )
;
	wxString	label;
	wxString	url;
	wxPoint	pos;
	wxSize	size;
	long	style;
	wxString	name;

    WXSTRING_INPUT( label, wxString, ST(3) )
;

    WXSTRING_INPUT( url, wxString, ST(4) )
;

	if (items < 6)
	    pos = wxDefaultPosition;
	else {
    pos = wxPli_sv_2_wxpoint( aTHX_ ST(5) )
;
	}

	if (items < 7)
	    size = wxDefaultSize;
	else {
    size = wxPli_sv_2_wxsize( aTHX_ ST(6) )
;
	}

	if (items < 8)
	    style = 0;
	else {
	    style = (long)SvIV(ST(7))
;
	}

	if (items < 9)
	    name = wxHyperlinkCtrlNameStr;
	else {
    WXSTRING_INPUT( name, wxString, ST(8) )
;
	}
    try {
      RETVAL = THIS->Create( parent, id, label, url, pos, size, style, name );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__HyperlinkCtrl_GetHoverColour); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__HyperlinkCtrl_GetHoverColour)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxHyperlinkCtrl *    THIS = (wxHyperlinkCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::HyperlinkCtrl" )
;
	wxColour *	RETVAL;
    try {
      RETVAL = new wxColour( THIS->GetHoverColour() );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_non_object_2_sv( aTHX_ RETVALSV, RETVAL, "Wx::Colour" );
    wxPli_thread_sv_register( aTHX_ "Wx::Colour", RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__HyperlinkCtrl_SetHoverColour); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__HyperlinkCtrl_SetHoverColour)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, colour");
    {
	wxHyperlinkCtrl *    THIS = (wxHyperlinkCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::HyperlinkCtrl" )
;
	wxColour*    colour = (wxColour *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::Colour" )
;
    try {
      THIS->SetHoverColour( *( colour ) );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__HyperlinkCtrl_GetNormalColour); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__HyperlinkCtrl_GetNormalColour)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxHyperlinkCtrl *    THIS = (wxHyperlinkCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::HyperlinkCtrl" )
;
	wxColour *	RETVAL;
    try {
      RETVAL = new wxColour( THIS->GetNormalColour() );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_non_object_2_sv( aTHX_ RETVALSV, RETVAL, "Wx::Colour" );
    wxPli_thread_sv_register( aTHX_ "Wx::Colour", RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__HyperlinkCtrl_SetNormalColour); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__HyperlinkCtrl_SetNormalColour)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, colour");
    {
	wxHyperlinkCtrl *    THIS = (wxHyperlinkCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::HyperlinkCtrl" )
;
	wxColour*    colour = (wxColour *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::Colour" )
;
    try {
      THIS->SetNormalColour( *( colour ) );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__HyperlinkCtrl_GetVisitedColour); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__HyperlinkCtrl_GetVisitedColour)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxHyperlinkCtrl *    THIS = (wxHyperlinkCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::HyperlinkCtrl" )
;
	wxColour *	RETVAL;
    try {
      RETVAL = new wxColour( THIS->GetVisitedColour() );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_non_object_2_sv( aTHX_ RETVALSV, RETVAL, "Wx::Colour" );
    wxPli_thread_sv_register( aTHX_ "Wx::Colour", RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__HyperlinkCtrl_SetVisitedColour); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__HyperlinkCtrl_SetVisitedColour)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, colour");
    {
	wxHyperlinkCtrl *    THIS = (wxHyperlinkCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::HyperlinkCtrl" )
;
	wxColour*    colour = (wxColour *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::Colour" )
;
    try {
      THIS->SetVisitedColour( *( colour ) );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__HyperlinkCtrl_GetURL); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__HyperlinkCtrl_GetURL)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxHyperlinkCtrl *    THIS = (wxHyperlinkCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::HyperlinkCtrl" )
;
	wxString	RETVAL;
    try {
      RETVAL = THIS->GetURL();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    WXSTRING_OUTPUT( RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__HyperlinkCtrl_SetURL); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__HyperlinkCtrl_SetURL)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, url");
    {
	wxHyperlinkCtrl *    THIS = (wxHyperlinkCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::HyperlinkCtrl" )
;
	wxString	url;

    WXSTRING_INPUT( url, wxString, ST(1) )
;
    try {
      THIS->SetURL( url );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__HyperlinkCtrl_SetVisited); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__HyperlinkCtrl_SetVisited)
{
    dVAR; dXSARGS;
    if (items < 1 || items > 2)
       croak_xs_usage(cv,  "THIS, visited= true");
    {
	wxHyperlinkCtrl *    THIS = (wxHyperlinkCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::HyperlinkCtrl" )
;
	bool	visited;

	if (items < 2)
	    visited = true;
	else {
	    visited = (bool)SvTRUE(ST(1))
;
	}
    try {
      THIS->SetVisited( visited );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__HyperlinkCtrl_GetVisited); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__HyperlinkCtrl_GetVisited)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxHyperlinkCtrl *    THIS = (wxHyperlinkCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::HyperlinkCtrl" )
;
	bool	RETVAL;
    try {
      RETVAL = THIS->GetVisited();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__HyperlinkEvent_GetURL); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__HyperlinkEvent_GetURL)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxHyperlinkEvent *    THIS = (wxHyperlinkEvent *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::HyperlinkEvent" )
;
	wxString	RETVAL;
    try {
      RETVAL = THIS->GetURL();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    WXSTRING_OUTPUT( RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__HyperlinkEvent_SetURL); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__HyperlinkEvent_SetURL)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, url");
    {
	wxHyperlinkEvent *    THIS = (wxHyperlinkEvent *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::HyperlinkEvent" )
;
	wxString	url;

    WXSTRING_INPUT( url, wxString, ST(1) )
;
    try {
      THIS->SetURL( url );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__HyperlinkEvent_new); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__HyperlinkEvent_new)
{
    dVAR; dXSARGS;
    PERL_UNUSED_VAR(cv); /* -W */
    PERL_UNUSED_VAR(items); /* -W */
    PERL_UNUSED_VAR(ax); /* -Wall */
    SP -= items;
    {
    BEGIN_OVERLOAD()
        MATCH_VOIDM_REDISP( newDefault )
        MATCH_ANY_REDISP( newFull )
    END_OVERLOAD( "Wx::HyperlinkCtrl::new" )
	PUTBACK;
	return;
    }
}

#endif

/* INCLUDE: Returning to 'Controls.xs' from '/usr/bin/perl -I./ -MExtUtils::XSpp::Cmd -e xspp -- -t typemap.xsp XS/HyperlinkCtrl.xsp' */


/* INCLUDE_COMMAND:  Including output of '/usr/bin/perl -I./ -MExtUtils::XSpp::Cmd -e xspp -- -t typemap.xsp XS/VListBox.xsp' from 'Controls.xs' */

#include <exception>

#undef  xsp_constructor_class
#define xsp_constructor_class(c) (c)
#if WXPERL_W_VERSION_GE( 2, 5, 0 )
#define XSpp_88ac6f59_086112
#include <wx/vlbox.h>
#define XSubPPtmpAAAZ 1


XS_EUPXS(XS_Wx__VListBox_Create); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__VListBox_Create)
{
    dVAR; dXSARGS;
    if (items < 2 || items > 7)
       croak_xs_usage(cv,  "THIS, parent, id= wxID_ANY, pos= wxDefaultPosition, size= wxDefaultSize, style= 0, name= wxVListBoxNameStr");
    {
	wxVListBox *    THIS = (wxVListBox *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::VListBox" )
;
	bool	RETVAL;
	wxWindow*    parent = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::Window" )
;
	wxWindowID	id;
	wxPoint	pos;
	wxSize	size;
	long	style;
	wxString	name;

	if (items < 3)
	    id = wxID_ANY;
	else {
    id = wxPli_get_wxwindowid( aTHX_ ST(2) )
;
	}

	if (items < 4)
	    pos = wxDefaultPosition;
	else {
    pos = wxPli_sv_2_wxpoint( aTHX_ ST(3) )
;
	}

	if (items < 5)
	    size = wxDefaultSize;
	else {
    size = wxPli_sv_2_wxsize( aTHX_ ST(4) )
;
	}

	if (items < 6)
	    style = 0;
	else {
	    style = (long)SvIV(ST(5))
;
	}

	if (items < 7)
	    name = wxVListBoxNameStr;
	else {
    WXSTRING_INPUT( name, wxString, ST(6) )
;
	}
    try {
      RETVAL = THIS->Create( parent, id, pos, size, style, name );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__VListBox_GetItemCount); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__VListBox_GetItemCount)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxVListBox *    THIS = (wxVListBox *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::VListBox" )
;
	size_t	RETVAL;
	dXSTARG;
    try {
      RETVAL = THIS->GetItemCount();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	XSprePUSH;
	PUSHu((UV)RETVAL );
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__VListBox_HasMultipleSelection); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__VListBox_HasMultipleSelection)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxVListBox *    THIS = (wxVListBox *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::VListBox" )
;
	bool	RETVAL;
    try {
      RETVAL = THIS->HasMultipleSelection();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__VListBox_IsCurrent); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__VListBox_IsCurrent)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, item");
    {
	wxVListBox *    THIS = (wxVListBox *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::VListBox" )
;
	bool	RETVAL;
	size_t    item = (size_t)SvUV( ST(1) )
;
    try {
      RETVAL = THIS->IsCurrent( item );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__VListBox_IsSelected); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__VListBox_IsSelected)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, item");
    {
	wxVListBox *    THIS = (wxVListBox *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::VListBox" )
;
	bool	RETVAL;
	size_t    item = (size_t)SvUV( ST(1) )
;
    try {
      RETVAL = THIS->IsSelected( item );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__VListBox_GetSelectedCount); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__VListBox_GetSelectedCount)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxVListBox *    THIS = (wxVListBox *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::VListBox" )
;
	size_t	RETVAL;
	dXSTARG;
    try {
      RETVAL = THIS->GetSelectedCount();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	XSprePUSH;
	PUSHu((UV)RETVAL );
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__VListBox_GetMargins); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__VListBox_GetMargins)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxVListBox *    THIS = (wxVListBox *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::VListBox" )
;
	wxPoint	RETVAL;
    try {
      RETVAL = THIS->GetMargins();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_non_object_2_sv( aTHX_ RETVALSV, new wxPoint(RETVAL), "Wx::Point" );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__VListBox_GetSelectionBackground); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__VListBox_GetSelectionBackground)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxVListBox *    THIS = (wxVListBox *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::VListBox" )
;
	wxColour *	RETVAL;
    try {
      RETVAL = new wxColour( THIS->GetSelectionBackground() );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_non_object_2_sv( aTHX_ RETVALSV, RETVAL, "Wx::Colour" );
    wxPli_thread_sv_register( aTHX_ "Wx::Colour", RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__VListBox_SetItemCount); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__VListBox_SetItemCount)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, count");
    {
	wxVListBox *    THIS = (wxVListBox *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::VListBox" )
;
	size_t    count = (size_t)SvUV( ST(1) )
;
    try {
      THIS->SetItemCount( count );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__VListBox_Clear); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__VListBox_Clear)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxVListBox *    THIS = (wxVListBox *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::VListBox" )
;
    try {
      THIS->Clear();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__VListBox_GetSelection); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__VListBox_GetSelection)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxVListBox *    THIS = (wxVListBox *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::VListBox" )
;
	int	RETVAL;
	dXSTARG;
    try {
      RETVAL = THIS->GetSelection();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__VListBox_SetSelection); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__VListBox_SetSelection)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, selection");
    {
	wxVListBox *    THIS = (wxVListBox *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::VListBox" )
;
	int	selection = (int)SvIV(ST(1))
;
    try {
      THIS->SetSelection( selection );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__VListBox_Select); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__VListBox_Select)
{
    dVAR; dXSARGS;
    if (items < 2 || items > 3)
       croak_xs_usage(cv,  "THIS, item, select= true");
    {
	wxVListBox *    THIS = (wxVListBox *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::VListBox" )
;
	bool	RETVAL;
	size_t    item = (size_t)SvUV( ST(1) )
;
	bool	select;

	if (items < 3)
	    select = true;
	else {
	    select = (bool)SvTRUE(ST(2))
;
	}
    try {
      RETVAL = THIS->Select( item, select );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__VListBox_SelectRange); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__VListBox_SelectRange)
{
    dVAR; dXSARGS;
    if (items != 3)
       croak_xs_usage(cv,  "THIS, from, to");
    {
	wxVListBox *    THIS = (wxVListBox *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::VListBox" )
;
	bool	RETVAL;
	size_t    from = (size_t)SvUV( ST(1) )
;
	size_t    to = (size_t)SvUV( ST(2) )
;
    try {
      RETVAL = THIS->SelectRange( from, to );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__VListBox_Toggle); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__VListBox_Toggle)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, item");
    {
	wxVListBox *    THIS = (wxVListBox *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::VListBox" )
;
	size_t    item = (size_t)SvUV( ST(1) )
;
    try {
      THIS->Toggle( item );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__VListBox_SelectAll); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__VListBox_SelectAll)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxVListBox *    THIS = (wxVListBox *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::VListBox" )
;
	bool	RETVAL;
    try {
      RETVAL = THIS->SelectAll();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__VListBox_DeselectAll); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__VListBox_DeselectAll)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxVListBox *    THIS = (wxVListBox *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::VListBox" )
;
	bool	RETVAL;
    try {
      RETVAL = THIS->DeselectAll();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__VListBox_SetMargins); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__VListBox_SetMargins)
{
    dVAR; dXSARGS;
    if (items != 3)
       croak_xs_usage(cv,  "THIS, x, y");
    {
	wxVListBox *    THIS = (wxVListBox *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::VListBox" )
;
	wxCoord	x = (wxCoord)SvIV(ST(1))
;
	wxCoord	y = (wxCoord)SvIV(ST(2))
;
    try {
      THIS->SetMargins( x, y );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__VListBox_SetSelectionBackground); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__VListBox_SetSelectionBackground)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, col");
    {
	wxVListBox *    THIS = (wxVListBox *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::VListBox" )
;
	wxColour*    col = (wxColour *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::Colour" )
;
    try {
      THIS->SetSelectionBackground( *( col ) );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__VListBox_GetFirstSelected); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__VListBox_GetFirstSelected)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    PERL_UNUSED_VAR(ax); /* -Wall */
    SP -= items;
    {
	wxVListBox *    THIS = (wxVListBox *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::VListBox" )
;
    unsigned long cookie;
    int ret = THIS->GetFirstSelected( cookie );
    EXTEND( SP, 2 );
    PUSHs( sv_2mortal( newSViv( ret ) ) );
    PUSHs( sv_2mortal( newSViv( cookie ) ) );
	PUTBACK;
	return;
    }
}


XS_EUPXS(XS_Wx__VListBox_GetNextSelected); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__VListBox_GetNextSelected)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, cookie");
    PERL_UNUSED_VAR(ax); /* -Wall */
    SP -= items;
    {
	wxVListBox *    THIS = (wxVListBox *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::VListBox" )
;
	unsigned long    cookie = (unsigned long)SvUV( ST(1) )
;
    int ret = THIS->GetNextSelected( cookie );
    EXTEND( SP, 2 );
    PUSHs( sv_2mortal( newSViv( ret ) ) );
    PUSHs( sv_2mortal( newSViv( cookie ) ) );
	PUTBACK;
	return;
    }
}

#include "cpp/overload.h"
#include "xspp/vlbox.h"

XS_EUPXS(XS_Wx__PlVListBox_new); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__PlVListBox_new)
{
    dVAR; dXSARGS;
    PERL_UNUSED_VAR(cv); /* -W */
    PERL_UNUSED_VAR(items); /* -W */
    PERL_UNUSED_VAR(ax); /* -Wall */
    SP -= items;
    {
    BEGIN_OVERLOAD()
        MATCH_VOIDM_REDISP( newDefault )
        MATCH_ANY_REDISP( newFull )
    END_OVERLOAD( "Wx::PlVListBox::new" )
	PUTBACK;
	return;
    }
}

#undef  xsp_constructor_class
#define xsp_constructor_class(c) (CLASS)

XS_EUPXS(XS_Wx__PlVListBox_newDefault); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__PlVListBox_newDefault)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "CLASS");
    {
	char *	CLASS = (char *)SvPV_nolen(ST(0))
;
	wxPlVListBox *	RETVAL;
     RETVAL = new wxPlVListBox( CLASS ); 
                wxPli_create_evthandler( aTHX_ RETVAL, CLASS );
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_evthandler_2_sv( aTHX_ RETVALSV, RETVAL );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}

#undef  xsp_constructor_class
#define xsp_constructor_class(c) (c)
#undef  xsp_constructor_class
#define xsp_constructor_class(c) (CLASS)

XS_EUPXS(XS_Wx__PlVListBox_newFull); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__PlVListBox_newFull)
{
    dVAR; dXSARGS;
    if (items < 2 || items > 7)
       croak_xs_usage(cv,  "CLASS, parent, id= wxID_ANY, pos= wxDefaultPosition, size= wxDefaultSize, style= 0, name= wxVListBoxNameStr");
    {
	char *	CLASS = (char *)SvPV_nolen(ST(0))
;
	wxPlVListBox *	RETVAL;
	wxWindow*    parent = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::Window" )
;
	wxWindowID	id;
	wxPoint	pos;
	wxSize	size;
	long	style;
	wxString	name;

	if (items < 3)
	    id = wxID_ANY;
	else {
    id = wxPli_get_wxwindowid( aTHX_ ST(2) )
;
	}

	if (items < 4)
	    pos = wxDefaultPosition;
	else {
    pos = wxPli_sv_2_wxpoint( aTHX_ ST(3) )
;
	}

	if (items < 5)
	    size = wxDefaultSize;
	else {
    size = wxPli_sv_2_wxsize( aTHX_ ST(4) )
;
	}

	if (items < 6)
	    style = 0;
	else {
	    style = (long)SvIV(ST(5))
;
	}

	if (items < 7)
	    name = wxVListBoxNameStr;
	else {
    WXSTRING_INPUT( name, wxString, ST(6) )
;
	}
     RETVAL = new wxPlVListBox( CLASS, parent, id, pos, size,
                                           style, name );
                wxPli_create_evthandler( aTHX_ RETVAL, CLASS );
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_evthandler_2_sv( aTHX_ RETVALSV, RETVAL );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}

#undef  xsp_constructor_class
#define xsp_constructor_class(c) (c)
#endif

/* INCLUDE: Returning to 'Controls.xs' from '/usr/bin/perl -I./ -MExtUtils::XSpp::Cmd -e xspp -- -t typemap.xsp XS/VListBox.xsp' */


/* INCLUDE_COMMAND:  Including output of '/usr/bin/perl -I./ -MExtUtils::XSpp::Cmd -e xspp -- -t typemap.xsp XS/SearchCtrl.xsp' from 'Controls.xs' */

#include <exception>

#undef  xsp_constructor_class
#define xsp_constructor_class(c) (c)
#if WXPERL_W_VERSION_GE( 2, 8, 3 )
#define XSpp_61b6cb38_044136
#include <wx/srchctrl.h>
#include <wx/menu.h>
#define XSubPPtmpAABA 1


XS_EUPXS(XS_Wx__SearchCtrl_new); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__SearchCtrl_new)
{
    dVAR; dXSARGS;
    PERL_UNUSED_VAR(cv); /* -W */
    PERL_UNUSED_VAR(items); /* -W */
    PERL_UNUSED_VAR(ax); /* -Wall */
    SP -= items;
    {
    BEGIN_OVERLOAD()
        MATCH_VOIDM_REDISP( newDefault )
        MATCH_ANY_REDISP( newFull )
    END_OVERLOAD( "Wx::SearchCtrl::new" )
	PUTBACK;
	return;
    }
}

#undef  xsp_constructor_class
#define xsp_constructor_class(c) (CLASS)

XS_EUPXS(XS_Wx__SearchCtrl_newDefault); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__SearchCtrl_newDefault)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "CLASS");
    {
	char *	CLASS = (char *)SvPV_nolen(ST(0))
;
	wxSearchCtrl *	RETVAL;
     RETVAL = new wxSearchCtrl();
                wxPli_create_evthandler( aTHX_ RETVAL, CLASS );
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_evthandler_2_sv( aTHX_ RETVALSV, RETVAL );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}

#undef  xsp_constructor_class
#define xsp_constructor_class(c) (c)
#undef  xsp_constructor_class
#define xsp_constructor_class(c) (CLASS)

XS_EUPXS(XS_Wx__SearchCtrl_newFull); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__SearchCtrl_newFull)
{
    dVAR; dXSARGS;
    if (items < 3 || items > 9)
       croak_xs_usage(cv,  "CLASS, parent, id, label= wxEmptyString, pos= wxDefaultPosition, size= wxDefaultSize, style= 0, validator= wxDefaultValidatorPtr, name= wxSearchCtrlNameStr");
    {
	char *	CLASS = (char *)SvPV_nolen(ST(0))
;
	wxSearchCtrl *	RETVAL;
	wxWindow*    parent = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::Window" )
;
	wxWindowID    id = wxPli_get_wxwindowid( aTHX_ ST(2) )
;
	wxString	label;
	wxPoint	pos;
	wxSize	size;
	long	style;
	wxValidator*	validator;
	wxString	name;

	if (items < 4)
	    label = wxEmptyString;
	else {
    WXSTRING_INPUT( label, wxString, ST(3) )
;
	}

	if (items < 5)
	    pos = wxDefaultPosition;
	else {
    pos = wxPli_sv_2_wxpoint( aTHX_ ST(4) )
;
	}

	if (items < 6)
	    size = wxDefaultSize;
	else {
    size = wxPli_sv_2_wxsize( aTHX_ ST(5) )
;
	}

	if (items < 7)
	    style = 0;
	else {
	    style = (long)SvIV(ST(6))
;
	}

	if (items < 8)
	    validator = wxDefaultValidatorPtr;
	else {
    validator = (wxValidator *) wxPli_sv_2_object( aTHX_ ST(7), "Wx::Validator" )
;
	}

	if (items < 9)
	    name = wxSearchCtrlNameStr;
	else {
    WXSTRING_INPUT( name, wxString, ST(8) )
;
	}
     RETVAL = new wxSearchCtrl( parent, id, label, pos, size,
                                                style, *validator, name );
                wxPli_create_evthandler( aTHX_ RETVAL, CLASS );
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_evthandler_2_sv( aTHX_ RETVALSV, RETVAL );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}

#undef  xsp_constructor_class
#define xsp_constructor_class(c) (c)

XS_EUPXS(XS_Wx__SearchCtrl_Create); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__SearchCtrl_Create)
{
    dVAR; dXSARGS;
    if (items < 3 || items > 9)
       croak_xs_usage(cv,  "THIS, parent, id, value= wxEmptyString, pos= wxDefaultPosition, size= wxDefaultSize, style= 0, validator= wxDefaultValidatorPtr, name= wxSearchCtrlNameStr");
    {
	wxSearchCtrl *    THIS = (wxSearchCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::SearchCtrl" )
;
	bool	RETVAL;
	wxWindow*    parent = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::Window" )
;
	wxWindowID    id = wxPli_get_wxwindowid( aTHX_ ST(2) )
;
	wxString	value;
	wxPoint	pos;
	wxSize	size;
	long	style;
	wxValidator*	validator;
	wxString	name;

	if (items < 4)
	    value = wxEmptyString;
	else {
    WXSTRING_INPUT( value, wxString, ST(3) )
;
	}

	if (items < 5)
	    pos = wxDefaultPosition;
	else {
    pos = wxPli_sv_2_wxpoint( aTHX_ ST(4) )
;
	}

	if (items < 6)
	    size = wxDefaultSize;
	else {
    size = wxPli_sv_2_wxsize( aTHX_ ST(5) )
;
	}

	if (items < 7)
	    style = 0;
	else {
	    style = (long)SvIV(ST(6))
;
	}

	if (items < 8)
	    validator = wxDefaultValidatorPtr;
	else {
    validator = (wxValidator *) wxPli_sv_2_object( aTHX_ ST(7), "Wx::Validator" )
;
	}

	if (items < 9)
	    name = wxSearchCtrlNameStr;
	else {
    WXSTRING_INPUT( name, wxString, ST(8) )
;
	}
    try {
      RETVAL = THIS->Create( parent, id, value, pos, size, style, *( validator ), name );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__SearchCtrl_SetMenu); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__SearchCtrl_SetMenu)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, menu");
    {
	wxSearchCtrl *    THIS = (wxSearchCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::SearchCtrl" )
;
	wxMenu*    menu = (wxMenu *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::Menu" )
;
    try {
      THIS->SetMenu( menu );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__SearchCtrl_GetMenu); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__SearchCtrl_GetMenu)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxSearchCtrl *    THIS = (wxSearchCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::SearchCtrl" )
;
	wxMenu *	RETVAL;
    try {
      RETVAL = THIS->GetMenu();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_object_2_sv( aTHX_ RETVALSV, RETVAL );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__SearchCtrl_ShowSearchButton); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__SearchCtrl_ShowSearchButton)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, show");
    {
	wxSearchCtrl *    THIS = (wxSearchCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::SearchCtrl" )
;
	bool	show = (bool)SvTRUE(ST(1))
;
    try {
      THIS->ShowSearchButton( show );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__SearchCtrl_IsSearchButtonVisible); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__SearchCtrl_IsSearchButtonVisible)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxSearchCtrl *    THIS = (wxSearchCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::SearchCtrl" )
;
	bool	RETVAL;
    try {
      RETVAL = THIS->IsSearchButtonVisible();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__SearchCtrl_ShowCancelButton); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__SearchCtrl_ShowCancelButton)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, show");
    {
	wxSearchCtrl *    THIS = (wxSearchCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::SearchCtrl" )
;
	bool	show = (bool)SvTRUE(ST(1))
;
    try {
      THIS->ShowCancelButton( show );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__SearchCtrl_IsCancelButtonVisible); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__SearchCtrl_IsCancelButtonVisible)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxSearchCtrl *    THIS = (wxSearchCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::SearchCtrl" )
;
	bool	RETVAL;
    try {
      RETVAL = THIS->IsCancelButtonVisible();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__SearchCtrl_SetDescriptiveText); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__SearchCtrl_SetDescriptiveText)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, text");
    {
	wxSearchCtrl *    THIS = (wxSearchCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::SearchCtrl" )
;
	wxString	text;

    WXSTRING_INPUT( text, wxString, ST(1) )
;
    try {
      THIS->SetDescriptiveText( text );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__SearchCtrl_GetDescriptiveText); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__SearchCtrl_GetDescriptiveText)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxSearchCtrl *    THIS = (wxSearchCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::SearchCtrl" )
;
	wxString	RETVAL;
    try {
      RETVAL = THIS->GetDescriptiveText();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    WXSTRING_OUTPUT( RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}

#if WXPERL_W_VERSION_GE( 2, 9, 2 ) && !defined(__WXMAC__)
#define XSpp_61b6cb38_003493
#define WXPERL_IN_SEARCHCTRL
#define XSubPPtmpAABB 1


/* INCLUDE_COMMAND:  Including output of '/usr/bin/perl -MExtUtils::XSpp::Cmd -e xspp -- -t typemap.xsp XS/TextCtrlIface.xsp' from '/usr/bin/perl -I./ -MExtUtils::XSpp::Cmd -e xspp -- -t typemap.xsp XS/SearchCtrl.xsp' */

#include <exception>

#undef  xsp_constructor_class
#define xsp_constructor_class(c) (c)

/* INCLUDE: Returning to '/usr/bin/perl -I./ -MExtUtils::XSpp::Cmd -e xspp -- -t typemap.xsp XS/SearchCtrl.xsp' from '/usr/bin/perl -MExtUtils::XSpp::Cmd -e xspp -- -t typemap.xsp XS/TextCtrlIface.xsp' */


/* INCLUDE_COMMAND:  Including output of '/usr/bin/perl -pe "s/TextCtrlIface/SearchCtrl/g" xspp/TextCtrlIface.h' from '/usr/bin/perl -I./ -MExtUtils::XSpp::Cmd -e xspp -- -t typemap.xsp XS/SearchCtrl.xsp' */

#include <exception>

#undef  xsp_constructor_class
#define xsp_constructor_class(c) (c)
#if WXPERL_W_VERSION_GE( 2, 9, 2 )
#define XSpp_9c486bef_000236
#define XSubPPtmpAABC 1


XS_EUPXS(XS_Wx__SearchCtrl_GetValue); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__SearchCtrl_GetValue)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxSearchCtrl *    THIS = (wxSearchCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::SearchCtrl" )
;
	wxString	RETVAL;
    try {
      RETVAL = THIS->GetValue();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    WXSTRING_OUTPUT( RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__SearchCtrl_SetValue); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__SearchCtrl_SetValue)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, value");
    {
	wxSearchCtrl *    THIS = (wxSearchCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::SearchCtrl" )
;
	wxString	value;

    WXSTRING_INPUT( value, wxString, ST(1) )
;
    try {
      THIS->SetValue( value );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__SearchCtrl_ChangeValue); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__SearchCtrl_ChangeValue)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, value");
    {
	wxSearchCtrl *    THIS = (wxSearchCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::SearchCtrl" )
;
	wxString	value;

    WXSTRING_INPUT( value, wxString, ST(1) )
;
    try {
      THIS->ChangeValue( value );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__SearchCtrl_GetRange); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__SearchCtrl_GetRange)
{
    dVAR; dXSARGS;
    if (items != 3)
       croak_xs_usage(cv,  "THIS, from, to");
    {
	wxSearchCtrl *    THIS = (wxSearchCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::SearchCtrl" )
;
	wxString	RETVAL;
	long	from = (long)SvIV(ST(1))
;
	long	to = (long)SvIV(ST(2))
;
    try {
      RETVAL = THIS->GetRange( from, to );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    WXSTRING_OUTPUT( RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__SearchCtrl_WriteText); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__SearchCtrl_WriteText)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, text");
    {
	wxSearchCtrl *    THIS = (wxSearchCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::SearchCtrl" )
;
	wxString	text;

    WXSTRING_INPUT( text, wxString, ST(1) )
;
    try {
      THIS->WriteText( text );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__SearchCtrl_AppendText); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__SearchCtrl_AppendText)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, text");
    {
	wxSearchCtrl *    THIS = (wxSearchCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::SearchCtrl" )
;
	wxString	text;

    WXSTRING_INPUT( text, wxString, ST(1) )
;
    try {
      THIS->AppendText( text );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__SearchCtrl_IsEmpty); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__SearchCtrl_IsEmpty)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxSearchCtrl *    THIS = (wxSearchCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::SearchCtrl" )
;
	bool	RETVAL;
    try {
      RETVAL = THIS->IsEmpty();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__SearchCtrl_Clear); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__SearchCtrl_Clear)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxSearchCtrl *    THIS = (wxSearchCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::SearchCtrl" )
;
    try {
      THIS->Clear();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__SearchCtrl_Replace); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__SearchCtrl_Replace)
{
    dVAR; dXSARGS;
    if (items != 4)
       croak_xs_usage(cv,  "THIS, from, to, value");
    {
	wxSearchCtrl *    THIS = (wxSearchCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::SearchCtrl" )
;
	long	from = (long)SvIV(ST(1))
;
	long	to = (long)SvIV(ST(2))
;
	wxString	value;

    WXSTRING_INPUT( value, wxString, ST(3) )
;
    try {
      THIS->Replace( from, to, value );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__SearchCtrl_Remove); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__SearchCtrl_Remove)
{
    dVAR; dXSARGS;
    if (items != 3)
       croak_xs_usage(cv,  "THIS, from, to");
    {
	wxSearchCtrl *    THIS = (wxSearchCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::SearchCtrl" )
;
	long	from = (long)SvIV(ST(1))
;
	long	to = (long)SvIV(ST(2))
;
    try {
      THIS->Remove( from, to );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__SearchCtrl_RemoveSelection); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__SearchCtrl_RemoveSelection)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxSearchCtrl *    THIS = (wxSearchCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::SearchCtrl" )
;
    try {
      THIS->RemoveSelection();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__SearchCtrl_Copy); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__SearchCtrl_Copy)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxSearchCtrl *    THIS = (wxSearchCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::SearchCtrl" )
;
    try {
      THIS->Copy();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__SearchCtrl_Cut); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__SearchCtrl_Cut)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxSearchCtrl *    THIS = (wxSearchCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::SearchCtrl" )
;
    try {
      THIS->Cut();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__SearchCtrl_Paste); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__SearchCtrl_Paste)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxSearchCtrl *    THIS = (wxSearchCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::SearchCtrl" )
;
    try {
      THIS->Paste();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__SearchCtrl_CanCopy); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__SearchCtrl_CanCopy)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxSearchCtrl *    THIS = (wxSearchCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::SearchCtrl" )
;
	bool	RETVAL;
    try {
      RETVAL = THIS->CanCopy();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__SearchCtrl_CanCut); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__SearchCtrl_CanCut)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxSearchCtrl *    THIS = (wxSearchCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::SearchCtrl" )
;
	bool	RETVAL;
    try {
      RETVAL = THIS->CanCut();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__SearchCtrl_CanPaste); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__SearchCtrl_CanPaste)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxSearchCtrl *    THIS = (wxSearchCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::SearchCtrl" )
;
	bool	RETVAL;
    try {
      RETVAL = THIS->CanPaste();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__SearchCtrl_Undo); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__SearchCtrl_Undo)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxSearchCtrl *    THIS = (wxSearchCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::SearchCtrl" )
;
    try {
      THIS->Undo();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__SearchCtrl_Redo); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__SearchCtrl_Redo)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxSearchCtrl *    THIS = (wxSearchCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::SearchCtrl" )
;
    try {
      THIS->Redo();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__SearchCtrl_CanUndo); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__SearchCtrl_CanUndo)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxSearchCtrl *    THIS = (wxSearchCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::SearchCtrl" )
;
	bool	RETVAL;
    try {
      RETVAL = THIS->CanUndo();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__SearchCtrl_CanRedo); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__SearchCtrl_CanRedo)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxSearchCtrl *    THIS = (wxSearchCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::SearchCtrl" )
;
	bool	RETVAL;
    try {
      RETVAL = THIS->CanRedo();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__SearchCtrl_SetInsertionPoint); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__SearchCtrl_SetInsertionPoint)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, pos");
    {
	wxSearchCtrl *    THIS = (wxSearchCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::SearchCtrl" )
;
	long	pos = (long)SvIV(ST(1))
;
    try {
      THIS->SetInsertionPoint( pos );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__SearchCtrl_SetInsertionPointEnd); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__SearchCtrl_SetInsertionPointEnd)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxSearchCtrl *    THIS = (wxSearchCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::SearchCtrl" )
;
    try {
      THIS->SetInsertionPointEnd();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__SearchCtrl_GetInsertionPoint); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__SearchCtrl_GetInsertionPoint)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxSearchCtrl *    THIS = (wxSearchCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::SearchCtrl" )
;
	long	RETVAL;
	dXSTARG;
    try {
      RETVAL = THIS->GetInsertionPoint();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__SearchCtrl_GetLastPosition); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__SearchCtrl_GetLastPosition)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxSearchCtrl *    THIS = (wxSearchCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::SearchCtrl" )
;
	long	RETVAL;
	dXSTARG;
    try {
      RETVAL = THIS->GetLastPosition();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__SearchCtrl_SetSelection); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__SearchCtrl_SetSelection)
{
    dVAR; dXSARGS;
    if (items != 3)
       croak_xs_usage(cv,  "THIS, from, to");
    {
	wxSearchCtrl *    THIS = (wxSearchCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::SearchCtrl" )
;
	long	from = (long)SvIV(ST(1))
;
	long	to = (long)SvIV(ST(2))
;
    try {
      THIS->SetSelection( from, to );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__SearchCtrl_SelectAll); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__SearchCtrl_SelectAll)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxSearchCtrl *    THIS = (wxSearchCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::SearchCtrl" )
;
    try {
      THIS->SelectAll();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__SearchCtrl_HasSelection); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__SearchCtrl_HasSelection)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxSearchCtrl *    THIS = (wxSearchCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::SearchCtrl" )
;
	bool	RETVAL;
    try {
      RETVAL = THIS->HasSelection();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__SearchCtrl_GetStringSelection); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__SearchCtrl_GetStringSelection)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxSearchCtrl *    THIS = (wxSearchCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::SearchCtrl" )
;
	wxString	RETVAL;
    try {
      RETVAL = THIS->GetStringSelection();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    WXSTRING_OUTPUT( RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__SearchCtrl_AutoCompleteFileNames); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__SearchCtrl_AutoCompleteFileNames)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxSearchCtrl *    THIS = (wxSearchCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::SearchCtrl" )
;
	bool	RETVAL;
    try {
      RETVAL = THIS->AutoCompleteFileNames();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__SearchCtrl_AutoComplete); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__SearchCtrl_AutoComplete)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, choices");
    {
	wxSearchCtrl *    THIS = (wxSearchCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::SearchCtrl" )
;
	bool	RETVAL;
	wxArrayString	choices;

    wxPli_av_2_arraystring( aTHX_ ST(1), & choices )
;
    try {
      RETVAL = THIS->AutoComplete( choices );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__SearchCtrl_IsEditable); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__SearchCtrl_IsEditable)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxSearchCtrl *    THIS = (wxSearchCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::SearchCtrl" )
;
	bool	RETVAL;
    try {
      RETVAL = THIS->IsEditable();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__SearchCtrl_SetEditable); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__SearchCtrl_SetEditable)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, editable");
    {
	wxSearchCtrl *    THIS = (wxSearchCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::SearchCtrl" )
;
	bool	editable = (bool)SvTRUE(ST(1))
;
    try {
      THIS->SetEditable( editable );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__SearchCtrl_SetMaxLength); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__SearchCtrl_SetMaxLength)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, len");
    {
	wxSearchCtrl *    THIS = (wxSearchCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::SearchCtrl" )
;
	unsigned long    len = (unsigned long)SvUV( ST(1) )
;
    try {
      THIS->SetMaxLength( len );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__SearchCtrl_SetHint); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__SearchCtrl_SetHint)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, hint");
    {
	wxSearchCtrl *    THIS = (wxSearchCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::SearchCtrl" )
;
	bool	RETVAL;
	wxString	hint;

    WXSTRING_INPUT( hint, wxString, ST(1) )
;
    try {
      RETVAL = THIS->SetHint( hint );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__SearchCtrl_GetHint); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__SearchCtrl_GetHint)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxSearchCtrl *    THIS = (wxSearchCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::SearchCtrl" )
;
	wxString	RETVAL;
    try {
      RETVAL = THIS->GetHint();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    WXSTRING_OUTPUT( RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__SearchCtrl_SetMargins); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__SearchCtrl_SetMargins)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, pt");
    {
	wxSearchCtrl *    THIS = (wxSearchCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::SearchCtrl" )
;
	bool	RETVAL;
	wxPoint    pt = wxPli_sv_2_wxpoint( aTHX_ ST(1) )
;
    try {
      RETVAL = THIS->SetMargins( pt );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__SearchCtrl_GetMargins); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__SearchCtrl_GetMargins)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxSearchCtrl *    THIS = (wxSearchCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::SearchCtrl" )
;
	wxPoint	RETVAL;
    try {
      RETVAL = THIS->GetMargins();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_non_object_2_sv( aTHX_ RETVALSV, new wxPoint(RETVAL), "Wx::Point" );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__SearchCtrl_GetLineLength); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__SearchCtrl_GetLineLength)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, lineNo");
    {
	wxSearchCtrl *    THIS = (wxSearchCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::SearchCtrl" )
;
	int	RETVAL;
	dXSTARG;
	long	lineNo = (long)SvIV(ST(1))
;
    try {
      RETVAL = THIS->GetLineLength( lineNo );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__SearchCtrl_GetLineText); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__SearchCtrl_GetLineText)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, lineNo");
    {
	wxSearchCtrl *    THIS = (wxSearchCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::SearchCtrl" )
;
	wxString	RETVAL;
	long	lineNo = (long)SvIV(ST(1))
;
    try {
      RETVAL = THIS->GetLineText( lineNo );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    WXSTRING_OUTPUT( RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__SearchCtrl_GetNumberOfLines); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__SearchCtrl_GetNumberOfLines)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxSearchCtrl *    THIS = (wxSearchCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::SearchCtrl" )
;
	int	RETVAL;
	dXSTARG;
    try {
      RETVAL = THIS->GetNumberOfLines();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}

#if defined(WXPERL_IN_RICHTEXTCTRL)
#define XSpp_9c486bef_083003
#define XSubPPtmpAABD 1


XS_EUPXS(XS_Wx__SearchCtrl_LoadFile); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__SearchCtrl_LoadFile)
{
    dVAR; dXSARGS;
    if (items < 2 || items > 3)
       croak_xs_usage(cv,  "THIS, file, fileType= wxTEXT_TYPE_ANY");
    {
	wxSearchCtrl *    THIS = (wxSearchCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::SearchCtrl" )
;
	bool	RETVAL;
	wxString	file;
	int	fileType;

    WXSTRING_INPUT( file, wxString, ST(1) )
;

	if (items < 3)
	    fileType = wxTEXT_TYPE_ANY;
	else {
	    fileType = (int)SvIV(ST(2))
;
	}
    try {
      RETVAL = THIS->LoadFile( file, fileType );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__SearchCtrl_SaveFile); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__SearchCtrl_SaveFile)
{
    dVAR; dXSARGS;
    if (items < 1 || items > 3)
       croak_xs_usage(cv,  "THIS, file= wxEmptyString, fileType= wxTEXT_TYPE_ANY");
    {
	wxSearchCtrl *    THIS = (wxSearchCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::SearchCtrl" )
;
	bool	RETVAL;
	wxString	file;
	int	fileType;

	if (items < 2)
	    file = wxEmptyString;
	else {
    WXSTRING_INPUT( file, wxString, ST(1) )
;
	}

	if (items < 3)
	    fileType = wxTEXT_TYPE_ANY;
	else {
	    fileType = (int)SvIV(ST(2))
;
	}
    try {
      RETVAL = THIS->SaveFile( file, fileType );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}

#endif

XS_EUPXS(XS_Wx__SearchCtrl_IsModified); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__SearchCtrl_IsModified)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxSearchCtrl *    THIS = (wxSearchCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::SearchCtrl" )
;
	bool	RETVAL;
    try {
      RETVAL = THIS->IsModified();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__SearchCtrl_MarkDirty); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__SearchCtrl_MarkDirty)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxSearchCtrl *    THIS = (wxSearchCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::SearchCtrl" )
;
    try {
      THIS->MarkDirty();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__SearchCtrl_DiscardEdits); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__SearchCtrl_DiscardEdits)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxSearchCtrl *    THIS = (wxSearchCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::SearchCtrl" )
;
    try {
      THIS->DiscardEdits();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__SearchCtrl_SetModified); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__SearchCtrl_SetModified)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, modified");
    {
	wxSearchCtrl *    THIS = (wxSearchCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::SearchCtrl" )
;
	bool	modified = (bool)SvTRUE(ST(1))
;
    try {
      THIS->SetModified( modified );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}

#if defined(WXPERL_IN_SEARCHCTRL)
#define XSpp_9c486bef_045237
#define XSubPPtmpAABE 1


XS_EUPXS(XS_Wx__SearchCtrl_SetStyle); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__SearchCtrl_SetStyle)
{
    dVAR; dXSARGS;
    if (items != 4)
       croak_xs_usage(cv,  "THIS, start, end, style");
    {
	wxSearchCtrl *    THIS = (wxSearchCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::SearchCtrl" )
;
	bool	RETVAL;
	long	start = (long)SvIV(ST(1))
;
	long	end = (long)SvIV(ST(2))
;
	wxTextAttr*    style = (wxTextAttr *) wxPli_sv_2_object( aTHX_ ST(3), "Wx::TextAttr" )
;
    try {
      RETVAL = THIS->SetStyle( start, end, *( style ) );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}

#endif
#if !defined(WXPERL_IN_RICHTEXTCTRL)
#define XSpp_9c486bef_047928
#define XSubPPtmpAABF 1


XS_EUPXS(XS_Wx__SearchCtrl_SetDefaultStyle); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__SearchCtrl_SetDefaultStyle)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, style");
    {
	wxSearchCtrl *    THIS = (wxSearchCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::SearchCtrl" )
;
	bool	RETVAL;
	wxTextAttr*    style = (wxTextAttr *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::TextAttr" )
;
    try {
      RETVAL = THIS->SetDefaultStyle( *( style ) );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}

#endif

XS_EUPXS(XS_Wx__SearchCtrl_GetDefaultStyle); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__SearchCtrl_GetDefaultStyle)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxSearchCtrl *    THIS = (wxSearchCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::SearchCtrl" )
;
	wxTextAttr *	RETVAL;
    try {
      RETVAL = new wxTextAttr( THIS->GetDefaultStyle() );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_non_object_2_sv( aTHX_ RETVALSV, RETVAL, "Wx::TextAttr" );
    wxPli_thread_sv_register( aTHX_ "Wx::TextAttr", RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__SearchCtrl_XYToPosition); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__SearchCtrl_XYToPosition)
{
    dVAR; dXSARGS;
    if (items != 3)
       croak_xs_usage(cv,  "THIS, x, y");
    {
	wxSearchCtrl *    THIS = (wxSearchCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::SearchCtrl" )
;
	long	RETVAL;
	dXSTARG;
	long	x = (long)SvIV(ST(1))
;
	long	y = (long)SvIV(ST(2))
;
    try {
      RETVAL = THIS->XYToPosition( x, y );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__SearchCtrl_ShowPosition); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__SearchCtrl_ShowPosition)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, pos");
    {
	wxSearchCtrl *    THIS = (wxSearchCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::SearchCtrl" )
;
	long	pos = (long)SvIV(ST(1))
;
    try {
      THIS->ShowPosition( pos );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__SearchCtrl_GetSelection); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__SearchCtrl_GetSelection)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    PERL_UNUSED_VAR(ax); /* -Wall */
    SP -= items;
    {
    long from;
    long to;
	wxSearchCtrl *    THIS = (wxSearchCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::SearchCtrl" )
;
    THIS->GetSelection( &from, &to );
    EXTEND( SP, 2 );
    PUSHs( sv_2mortal( newSViv( from ) ) );
    PUSHs( sv_2mortal( newSViv( to ) ) );
	PUTBACK;
	return;
    }
}

#if defined(WXPERL_IN_SEARCHCTRL)
#define XSpp_9c486bef_014610
#define XSubPPtmpAABG 1


XS_EUPXS(XS_Wx__SearchCtrl_GetStyle); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__SearchCtrl_GetStyle)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, position");
    PERL_UNUSED_VAR(ax); /* -Wall */
    SP -= items;
    {
	long	position = (long)SvIV(ST(1))
;
	wxSearchCtrl *    THIS = (wxSearchCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::SearchCtrl" )
;
    wxTextAttr attr;
    bool retval = THIS->GetStyle( position, attr );
    EXTEND( SP, 2 );
    PUSHs( newSViv( retval ) );
    PUSHs( retval ? wxPli_non_object_2_sv( aTHX_ sv_newmortal(),
                                           new wxTextAttr( attr ),
                                           "Wx::TextAttr" ) :
                    &PL_sv_undef );
	PUTBACK;
	return;
    }
}

#endif

XS_EUPXS(XS_Wx__SearchCtrl_PositionToXY); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__SearchCtrl_PositionToXY)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, pos");
    PERL_UNUSED_VAR(ax); /* -Wall */
    SP -= items;
    {
	long	pos = (long)SvIV(ST(1))
;
    long x;
    long y;
	wxSearchCtrl *    THIS = (wxSearchCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::SearchCtrl" )
;
    THIS->PositionToXY( pos, &x, &y );
    EXTEND( SP, 2 );
    PUSHs( sv_2mortal( newSViv( x ) ) );
    PUSHs( sv_2mortal( newSViv( y ) ) );
	PUTBACK;
	return;
    }
}


XS_EUPXS(XS_Wx__SearchCtrl_HitTest); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__SearchCtrl_HitTest)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, pt");
    PERL_UNUSED_VAR(ax); /* -Wall */
    SP -= items;
    {
	wxPoint    pt = wxPli_sv_2_wxpoint( aTHX_ ST(1) )
;
	wxSearchCtrl *    THIS = (wxSearchCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::SearchCtrl" )
;
    long col, row;
    wxTextCtrlHitTestResult res = THIS->HitTest( pt, &col, &row );

    EXTEND( SP, 3 );
    PUSHs( sv_2mortal( newSViv( res ) ) );
    PUSHs( sv_2mortal( newSViv( col ) ) );
    PUSHs( sv_2mortal( newSViv( row ) ) );
	PUTBACK;
	return;
    }
}

#endif

/* INCLUDE: Returning to '/usr/bin/perl -I./ -MExtUtils::XSpp::Cmd -e xspp -- -t typemap.xsp XS/SearchCtrl.xsp' from '/usr/bin/perl -pe "s/TextCtrlIface/SearchCtrl/g" xspp/TextCtrlIface.h' */

#undef WXPERL_IN_SEARCHCTRL
#endif
#endif

/* INCLUDE: Returning to 'Controls.xs' from '/usr/bin/perl -I./ -MExtUtils::XSpp::Cmd -e xspp -- -t typemap.xsp XS/SearchCtrl.xsp' */


/* INCLUDE_COMMAND:  Including output of '/usr/bin/perl -I./ -MExtUtils::XSpp::Cmd -e xspp -- -t typemap.xsp XS/ComboPopup.xsp' from 'Controls.xs' */

#include <exception>

#undef  xsp_constructor_class
#define xsp_constructor_class(c) (c)
#if WXPERL_W_VERSION_GE( 2, 7, 2 )
#define XSpp_7608ce22_084050
#include "xspp/combopopup.h"
#undef  xsp_constructor_class
#define xsp_constructor_class(c) (CLASS)
#define XSubPPtmpAABH 1


XS_EUPXS(XS_Wx__ComboPopup_new); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ComboPopup_new)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "CLASS");
    {
	char *	CLASS = (char *)SvPV_nolen(ST(0))
;
	wxPlComboPopup *	RETVAL;
     RETVAL = new wxPlComboPopup( CLASS ); 
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_non_object_2_sv( aTHX_ RETVALSV, RETVAL, "Wx::PlComboPopup" );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}

#undef  xsp_constructor_class
#define xsp_constructor_class(c) (c)

XS_EUPXS(XS_Wx__ComboPopup_OnPopup); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ComboPopup_OnPopup)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxPlComboPopup *    THIS = (wxPlComboPopup *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::PlComboPopup" )
;
    try {
      THIS->base_OnPopup();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__ComboPopup_OnDismiss); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ComboPopup_OnDismiss)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxPlComboPopup *    THIS = (wxPlComboPopup *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::PlComboPopup" )
;
    try {
      THIS->base_OnDismiss();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__ComboPopup_SetStringValue); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ComboPopup_SetStringValue)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, value");
    {
	wxPlComboPopup *    THIS = (wxPlComboPopup *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::PlComboPopup" )
;
	wxString	value;

    WXSTRING_INPUT( value, wxString, ST(1) )
;
    try {
      THIS->base_SetStringValue( value );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__ComboPopup_PaintComboControl); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ComboPopup_PaintComboControl)
{
    dVAR; dXSARGS;
    if (items != 3)
       croak_xs_usage(cv,  "THIS, dc, rect");
    {
	wxPlComboPopup *    THIS = (wxPlComboPopup *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::PlComboPopup" )
;
	wxDC*    dc = (wxDC *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::DC" )
;
	wxRect*    rect = (wxRect *) wxPli_sv_2_object( aTHX_ ST(2), "Wx::Rect" )
;
    try {
      THIS->base_PaintComboControl( *( dc ), *( rect ) );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__ComboPopup_OnComboKeyEvent); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ComboPopup_OnComboKeyEvent)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, event");
    {
	wxPlComboPopup *    THIS = (wxPlComboPopup *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::PlComboPopup" )
;
	wxKeyEvent*    event = (wxKeyEvent *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::KeyEvent" )
;
    try {
      THIS->base_OnComboKeyEvent( *( event ) );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__ComboPopup_OnComboDoubleClick); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ComboPopup_OnComboDoubleClick)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxPlComboPopup *    THIS = (wxPlComboPopup *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::PlComboPopup" )
;
    try {
      THIS->base_OnComboDoubleClick();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__ComboPopup_GetAdjustedSize); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ComboPopup_GetAdjustedSize)
{
    dVAR; dXSARGS;
    if (items != 4)
       croak_xs_usage(cv,  "THIS, minWidth, prefHeight, maxHeight");
    {
	wxPlComboPopup *    THIS = (wxPlComboPopup *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::PlComboPopup" )
;
	wxSize	RETVAL;
	int	minWidth = (int)SvIV(ST(1))
;
	int	prefHeight = (int)SvIV(ST(2))
;
	int	maxHeight = (int)SvIV(ST(3))
;
    try {
      RETVAL = THIS->base_GetAdjustedSize( minWidth, prefHeight, maxHeight );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_non_object_2_sv( aTHX_ RETVALSV, new wxSize(RETVAL), "Wx::Size" );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__ComboPopup_LazyCreate); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ComboPopup_LazyCreate)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxPlComboPopup *    THIS = (wxPlComboPopup *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::PlComboPopup" )
;
	bool	RETVAL;
    try {
      RETVAL = THIS->base_LazyCreate();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__ComboPopup_Dismiss); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ComboPopup_Dismiss)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxPlComboPopup *    THIS = (wxPlComboPopup *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::PlComboPopup" )
;
    try {
      THIS->Dismiss();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__ComboPopup_IsCreated); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ComboPopup_IsCreated)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxPlComboPopup *    THIS = (wxPlComboPopup *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::PlComboPopup" )
;
	bool	RETVAL;
    try {
      RETVAL = THIS->IsCreated();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__ComboPopup_GetComboCtrl); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ComboPopup_GetComboCtrl)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxPlComboPopup *    THIS = (wxPlComboPopup *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::PlComboPopup" )
;
	wxComboCtrlBase *	RETVAL;
    try {
      RETVAL = THIS->GetComboCtrl();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_evthandler_2_sv( aTHX_ RETVALSV, RETVAL );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}

#endif

/* INCLUDE: Returning to 'Controls.xs' from '/usr/bin/perl -I./ -MExtUtils::XSpp::Cmd -e xspp -- -t typemap.xsp XS/ComboPopup.xsp' */


/* INCLUDE_COMMAND:  Including output of '/usr/bin/perl -I./ -MExtUtils::XSpp::Cmd -e xspp -- -t typemap.xsp XS/ComboCtrl.xsp' from 'Controls.xs' */

#include <exception>

#undef  xsp_constructor_class
#define xsp_constructor_class(c) (c)
#if WXPERL_W_VERSION_GE( 2, 7, 2 )
#define XSpp_9e985890_030866
#include <wx/combo.h>
#define XSubPPtmpAABI 1


XS_EUPXS(XS_Wx__ComboCtrl_new); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ComboCtrl_new)
{
    dVAR; dXSARGS;
    PERL_UNUSED_VAR(cv); /* -W */
    PERL_UNUSED_VAR(items); /* -W */
    PERL_UNUSED_VAR(ax); /* -Wall */
    SP -= items;
    {
    BEGIN_OVERLOAD()
        MATCH_VOIDM_REDISP( newDefault )
        MATCH_ANY_REDISP( newFull )
    END_OVERLOAD( "Wx::ComboCtrl::new" )
	PUTBACK;
	return;
    }
}

#undef  xsp_constructor_class
#define xsp_constructor_class(c) (CLASS)

XS_EUPXS(XS_Wx__ComboCtrl_newDefault); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ComboCtrl_newDefault)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "CLASS");
    {
	char *	CLASS = (char *)SvPV_nolen(ST(0))
;
	wxComboCtrl *	RETVAL;
     RETVAL = new wxComboCtrl();
                wxPli_create_evthandler( aTHX_ RETVAL, CLASS );
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_evthandler_2_sv( aTHX_ RETVALSV, RETVAL );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}

#undef  xsp_constructor_class
#define xsp_constructor_class(c) (c)
#undef  xsp_constructor_class
#define xsp_constructor_class(c) (CLASS)

XS_EUPXS(XS_Wx__ComboCtrl_newFull); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ComboCtrl_newFull)
{
    dVAR; dXSARGS;
    if (items < 2 || items > 9)
       croak_xs_usage(cv,  "CLASS, parent, id= wxID_ANY, value= wxEmptyString, pos= wxDefaultPosition, size= wxDefaultSize, style= 0, validator= wxDefaultValidatorPtr, name= wxEmptyString");
    {
	char *	CLASS = (char *)SvPV_nolen(ST(0))
;
	wxComboCtrl *	RETVAL;
	wxWindow*    parent = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::Window" )
;
	wxWindowID	id;
	wxString	value;
	wxPoint	pos;
	wxSize	size;
	long	style;
	wxValidator*	validator;
	wxString	name;

	if (items < 3)
	    id = wxID_ANY;
	else {
    id = wxPli_get_wxwindowid( aTHX_ ST(2) )
;
	}

	if (items < 4)
	    value = wxEmptyString;
	else {
    WXSTRING_INPUT( value, wxString, ST(3) )
;
	}

	if (items < 5)
	    pos = wxDefaultPosition;
	else {
    pos = wxPli_sv_2_wxpoint( aTHX_ ST(4) )
;
	}

	if (items < 6)
	    size = wxDefaultSize;
	else {
    size = wxPli_sv_2_wxsize( aTHX_ ST(5) )
;
	}

	if (items < 7)
	    style = 0;
	else {
	    style = (long)SvIV(ST(6))
;
	}

	if (items < 8)
	    validator = wxDefaultValidatorPtr;
	else {
    validator = (wxValidator *) wxPli_sv_2_object( aTHX_ ST(7), "Wx::Validator" )
;
	}

	if (items < 9)
	    name = wxEmptyString;
	else {
    WXSTRING_INPUT( name, wxString, ST(8) )
;
	}
     RETVAL = new wxComboCtrl( parent, id, value, pos, size,
                                          style, *validator, name );
                wxPli_create_evthandler( aTHX_ RETVAL, CLASS );
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_evthandler_2_sv( aTHX_ RETVALSV, RETVAL );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}

#undef  xsp_constructor_class
#define xsp_constructor_class(c) (c)

XS_EUPXS(XS_Wx__ComboCtrl_Create); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ComboCtrl_Create)
{
    dVAR; dXSARGS;
    if (items < 3 || items > 9)
       croak_xs_usage(cv,  "THIS, parent, id, value= wxEmptyString, pos= wxDefaultPosition, size= wxDefaultSize, style= 0, validator= wxDefaultValidatorPtr, name= wxEmptyString");
    {
	wxComboCtrl *    THIS = (wxComboCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::ComboCtrl" )
;
	bool	RETVAL;
	wxWindow*    parent = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::Window" )
;
	wxWindowID    id = wxPli_get_wxwindowid( aTHX_ ST(2) )
;
	wxString	value;
	wxPoint	pos;
	wxSize	size;
	long	style;
	wxValidator*	validator;
	wxString	name;

	if (items < 4)
	    value = wxEmptyString;
	else {
    WXSTRING_INPUT( value, wxString, ST(3) )
;
	}

	if (items < 5)
	    pos = wxDefaultPosition;
	else {
    pos = wxPli_sv_2_wxpoint( aTHX_ ST(4) )
;
	}

	if (items < 6)
	    size = wxDefaultSize;
	else {
    size = wxPli_sv_2_wxsize( aTHX_ ST(5) )
;
	}

	if (items < 7)
	    style = 0;
	else {
	    style = (long)SvIV(ST(6))
;
	}

	if (items < 8)
	    validator = wxDefaultValidatorPtr;
	else {
    validator = (wxValidator *) wxPli_sv_2_object( aTHX_ ST(7), "Wx::Validator" )
;
	}

	if (items < 9)
	    name = wxEmptyString;
	else {
    WXSTRING_INPUT( name, wxString, ST(8) )
;
	}
    try {
      RETVAL = THIS->Create( parent, id, value, pos, size, style, *( validator ), name );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__ComboCtrl_ShowPopup); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ComboCtrl_ShowPopup)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxComboCtrl *    THIS = (wxComboCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::ComboCtrl" )
;
    try {
      THIS->ShowPopup();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__ComboCtrl_HidePopup); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ComboCtrl_HidePopup)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxComboCtrl *    THIS = (wxComboCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::ComboCtrl" )
;
    try {
      THIS->HidePopup();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__ComboCtrl_IsPopupShown); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ComboCtrl_IsPopupShown)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxComboCtrl *    THIS = (wxComboCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::ComboCtrl" )
;
	bool	RETVAL;
    try {
      RETVAL = THIS->IsPopupShown();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__ComboCtrl_SetPopupControl); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ComboCtrl_SetPopupControl)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, popup");
    {
	wxComboCtrl *    THIS = (wxComboCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::ComboCtrl" )
;
	wxComboPopup*    popup = (wxComboPopup *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::ComboPopup" )
;
    try {
      THIS->SetPopupControl( popup );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__ComboCtrl_GetPopupControl); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ComboCtrl_GetPopupControl)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxComboCtrl *    THIS = (wxComboCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::ComboCtrl" )
;
	wxComboPopup *	RETVAL;
    try {
      RETVAL = THIS->GetPopupControl();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_non_object_2_sv( aTHX_ RETVALSV, RETVAL, "Wx::ComboPopup" );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__ComboCtrl_GetPopupWindow); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ComboCtrl_GetPopupWindow)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxComboCtrl *    THIS = (wxComboCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::ComboCtrl" )
;
	wxWindow *	RETVAL;
    try {
      RETVAL = THIS->GetPopupWindow();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_object_2_sv( aTHX_ RETVALSV, RETVAL );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__ComboCtrl_GetTextCtrl); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ComboCtrl_GetTextCtrl)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxComboCtrl *    THIS = (wxComboCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::ComboCtrl" )
;
	wxTextCtrl *	RETVAL;
    try {
      RETVAL = THIS->GetTextCtrl();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_object_2_sv( aTHX_ RETVALSV, RETVAL );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__ComboCtrl_GetButton); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ComboCtrl_GetButton)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxComboCtrl *    THIS = (wxComboCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::ComboCtrl" )
;
	wxWindow *	RETVAL;
    try {
      RETVAL = THIS->GetButton();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_object_2_sv( aTHX_ RETVALSV, RETVAL );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__ComboCtrl_GetValue); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ComboCtrl_GetValue)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxComboCtrl *    THIS = (wxComboCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::ComboCtrl" )
;
	wxString	RETVAL;
    try {
      RETVAL = THIS->GetValue();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    WXSTRING_OUTPUT( RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__ComboCtrl_SetValue); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ComboCtrl_SetValue)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, value");
    {
	wxComboCtrl *    THIS = (wxComboCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::ComboCtrl" )
;
	wxString	value;

    WXSTRING_INPUT( value, wxString, ST(1) )
;
    try {
      THIS->SetValue( value );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__ComboCtrl_Copy); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ComboCtrl_Copy)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxComboCtrl *    THIS = (wxComboCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::ComboCtrl" )
;
    try {
      THIS->Copy();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__ComboCtrl_Cut); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ComboCtrl_Cut)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxComboCtrl *    THIS = (wxComboCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::ComboCtrl" )
;
    try {
      THIS->Cut();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__ComboCtrl_Paste); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ComboCtrl_Paste)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxComboCtrl *    THIS = (wxComboCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::ComboCtrl" )
;
    try {
      THIS->Paste();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__ComboCtrl_SetInsertionPoint); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ComboCtrl_SetInsertionPoint)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, pos");
    {
	wxComboCtrl *    THIS = (wxComboCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::ComboCtrl" )
;
	long	pos = (long)SvIV(ST(1))
;
    try {
      THIS->SetInsertionPoint( pos );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__ComboCtrl_SetInsertionPointEnd); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ComboCtrl_SetInsertionPointEnd)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxComboCtrl *    THIS = (wxComboCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::ComboCtrl" )
;
    try {
      THIS->SetInsertionPointEnd();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__ComboCtrl_GetInsertionPoint); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ComboCtrl_GetInsertionPoint)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxComboCtrl *    THIS = (wxComboCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::ComboCtrl" )
;
	long	RETVAL;
	dXSTARG;
    try {
      RETVAL = THIS->GetInsertionPoint();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__ComboCtrl_GetLastPosition); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ComboCtrl_GetLastPosition)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxComboCtrl *    THIS = (wxComboCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::ComboCtrl" )
;
	long	RETVAL;
	dXSTARG;
    try {
      RETVAL = THIS->GetLastPosition();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__ComboCtrl_Replace); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ComboCtrl_Replace)
{
    dVAR; dXSARGS;
    if (items != 4)
       croak_xs_usage(cv,  "THIS, from, to, value");
    {
	wxComboCtrl *    THIS = (wxComboCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::ComboCtrl" )
;
	long	from = (long)SvIV(ST(1))
;
	long	to = (long)SvIV(ST(2))
;
	wxString	value;

    WXSTRING_INPUT( value, wxString, ST(3) )
;
    try {
      THIS->Replace( from, to, value );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__ComboCtrl_Remove); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ComboCtrl_Remove)
{
    dVAR; dXSARGS;
    if (items != 3)
       croak_xs_usage(cv,  "THIS, from, to");
    {
	wxComboCtrl *    THIS = (wxComboCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::ComboCtrl" )
;
	long	from = (long)SvIV(ST(1))
;
	long	to = (long)SvIV(ST(2))
;
    try {
      THIS->Remove( from, to );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__ComboCtrl_SetSelection); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ComboCtrl_SetSelection)
{
    dVAR; dXSARGS;
    if (items != 3)
       croak_xs_usage(cv,  "THIS, from, to");
    {
	wxComboCtrl *    THIS = (wxComboCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::ComboCtrl" )
;
	long	from = (long)SvIV(ST(1))
;
	long	to = (long)SvIV(ST(2))
;
    try {
      THIS->SetSelection( from, to );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__ComboCtrl_Undo); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ComboCtrl_Undo)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxComboCtrl *    THIS = (wxComboCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::ComboCtrl" )
;
    try {
      THIS->Undo();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__ComboCtrl_SetText); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ComboCtrl_SetText)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, value");
    {
	wxComboCtrl *    THIS = (wxComboCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::ComboCtrl" )
;
	wxString	value;

    WXSTRING_INPUT( value, wxString, ST(1) )
;
    try {
      THIS->SetText( value );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__ComboCtrl_SetPopupMinWidth); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ComboCtrl_SetPopupMinWidth)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, width");
    {
	wxComboCtrl *    THIS = (wxComboCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::ComboCtrl" )
;
	int	width = (int)SvIV(ST(1))
;
    try {
      THIS->SetPopupMinWidth( width );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__ComboCtrl_SetPopupMaxHeight); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ComboCtrl_SetPopupMaxHeight)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, height");
    {
	wxComboCtrl *    THIS = (wxComboCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::ComboCtrl" )
;
	int	height = (int)SvIV(ST(1))
;
    try {
      THIS->SetPopupMaxHeight( height );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__ComboCtrl_SetPopupExtents); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ComboCtrl_SetPopupExtents)
{
    dVAR; dXSARGS;
    if (items != 3)
       croak_xs_usage(cv,  "THIS, extLeft, extRight");
    {
	wxComboCtrl *    THIS = (wxComboCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::ComboCtrl" )
;
	int	extLeft = (int)SvIV(ST(1))
;
	int	extRight = (int)SvIV(ST(2))
;
    try {
      THIS->SetPopupExtents( extLeft, extRight );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__ComboCtrl_SetCustomPaintWidth); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ComboCtrl_SetCustomPaintWidth)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, width");
    {
	wxComboCtrl *    THIS = (wxComboCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::ComboCtrl" )
;
	int	width = (int)SvIV(ST(1))
;
    try {
      THIS->SetCustomPaintWidth( width );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__ComboCtrl_GetCustomPaintWidth); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ComboCtrl_GetCustomPaintWidth)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxComboCtrl *    THIS = (wxComboCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::ComboCtrl" )
;
	int	RETVAL;
	dXSTARG;
    try {
      RETVAL = THIS->GetCustomPaintWidth();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__ComboCtrl_SetPopupAnchor); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ComboCtrl_SetPopupAnchor)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, anchorSide");
    {
	wxComboCtrl *    THIS = (wxComboCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::ComboCtrl" )
;
	int	anchorSide = (int)SvIV(ST(1))
;
    try {
      THIS->SetPopupAnchor( anchorSide );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__ComboCtrl_SetButtonPosition); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ComboCtrl_SetButtonPosition)
{
    dVAR; dXSARGS;
    if (items < 1 || items > 5)
       croak_xs_usage(cv,  "THIS, width= -1, height= -1, side= wxRIGHT, spacingX= 0");
    {
	wxComboCtrl *    THIS = (wxComboCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::ComboCtrl" )
;
	int	width;
	int	height;
	int	side;
	int	spacingX;

	if (items < 2)
	    width = -1;
	else {
	    width = (int)SvIV(ST(1))
;
	}

	if (items < 3)
	    height = -1;
	else {
	    height = (int)SvIV(ST(2))
;
	}

	if (items < 4)
	    side = wxRIGHT;
	else {
	    side = (int)SvIV(ST(3))
;
	}

	if (items < 5)
	    spacingX = 0;
	else {
	    spacingX = (int)SvIV(ST(4))
;
	}
    try {
      THIS->SetButtonPosition( width, height, side, spacingX );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__ComboCtrl_GetButtonSize); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ComboCtrl_GetButtonSize)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxComboCtrl *    THIS = (wxComboCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::ComboCtrl" )
;
	wxSize	RETVAL;
    try {
      RETVAL = THIS->GetButtonSize();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_non_object_2_sv( aTHX_ RETVALSV, new wxSize(RETVAL), "Wx::Size" );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__ComboCtrl_SetButtonBitmaps); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ComboCtrl_SetButtonBitmaps)
{
    dVAR; dXSARGS;
    if (items < 2 || items > 6)
       croak_xs_usage(cv,  "THIS, bmpNormal, pushButtonBg= false, bmpPressed= wxNullBitmapPtr, bmpHover= wxNullBitmapPtr, bmpDisabled= wxNullBitmapPtr");
    {
	wxComboCtrl *    THIS = (wxComboCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::ComboCtrl" )
;
	wxBitmap*    bmpNormal = (wxBitmap *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::Bitmap" )
;
	bool	pushButtonBg;
	wxBitmap*	bmpPressed;
	wxBitmap*	bmpHover;
	wxBitmap*	bmpDisabled;

	if (items < 3)
	    pushButtonBg = false;
	else {
	    pushButtonBg = (bool)SvTRUE(ST(2))
;
	}

	if (items < 4)
	    bmpPressed = wxNullBitmapPtr;
	else {
    bmpPressed = (wxBitmap *) wxPli_sv_2_object( aTHX_ ST(3), "Wx::Bitmap" )
;
	}

	if (items < 5)
	    bmpHover = wxNullBitmapPtr;
	else {
    bmpHover = (wxBitmap *) wxPli_sv_2_object( aTHX_ ST(4), "Wx::Bitmap" )
;
	}

	if (items < 6)
	    bmpDisabled = wxNullBitmapPtr;
	else {
    bmpDisabled = (wxBitmap *) wxPli_sv_2_object( aTHX_ ST(5), "Wx::Bitmap" )
;
	}
    try {
      THIS->SetButtonBitmaps( *( bmpNormal ), pushButtonBg, *( bmpPressed ), *( bmpHover ), *( bmpDisabled ) );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}

#if WXPERL_W_VERSION_LT( 2, 7, 0 ) || WXWIN_COMPATIBILITY_2_6
#define XSpp_9e985890_076709
#define XSubPPtmpAABJ 1


XS_EUPXS(XS_Wx__ComboCtrl_SetTextIndent); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ComboCtrl_SetTextIndent)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, indent");
    {
	wxComboCtrl *    THIS = (wxComboCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::ComboCtrl" )
;
	int	indent = (int)SvIV(ST(1))
;
    try {
      THIS->SetTextIndent( indent );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__ComboCtrl_GetTextIndent); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ComboCtrl_GetTextIndent)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxComboCtrl *    THIS = (wxComboCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::ComboCtrl" )
;
	wxCoord	RETVAL;
	dXSTARG;
    try {
      RETVAL = THIS->GetTextIndent();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}

#endif

XS_EUPXS(XS_Wx__ComboCtrl_GetTextRect); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ComboCtrl_GetTextRect)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxComboCtrl *    THIS = (wxComboCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::ComboCtrl" )
;
	wxRect *	RETVAL;
    try {
      RETVAL = new wxRect( THIS->GetTextRect() );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_non_object_2_sv( aTHX_ RETVALSV, RETVAL, "Wx::Rect" );
    wxPli_thread_sv_register( aTHX_ "Wx::Rect", RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__ComboCtrl_UseAltPopupWindow); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ComboCtrl_UseAltPopupWindow)
{
    dVAR; dXSARGS;
    if (items < 1 || items > 2)
       croak_xs_usage(cv,  "THIS, enable= true");
    {
	wxComboCtrl *    THIS = (wxComboCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::ComboCtrl" )
;
	bool	enable;

	if (items < 2)
	    enable = true;
	else {
	    enable = (bool)SvTRUE(ST(1))
;
	}
    try {
      THIS->UseAltPopupWindow( enable );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__ComboCtrl_EnablePopupAnimation); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ComboCtrl_EnablePopupAnimation)
{
    dVAR; dXSARGS;
    if (items < 1 || items > 2)
       croak_xs_usage(cv,  "THIS, enable= true");
    {
	wxComboCtrl *    THIS = (wxComboCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::ComboCtrl" )
;
	bool	enable;

	if (items < 2)
	    enable = true;
	else {
	    enable = (bool)SvTRUE(ST(1))
;
	}
    try {
      THIS->EnablePopupAnimation( enable );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__ComboCtrl_GetBitmapNormal); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ComboCtrl_GetBitmapNormal)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxComboCtrl *    THIS = (wxComboCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::ComboCtrl" )
;
	wxBitmap *	RETVAL;
    try {
      RETVAL = new wxBitmap( THIS->GetBitmapNormal() );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_object_2_sv( aTHX_ RETVALSV, RETVAL );
    wxPli_thread_sv_register( aTHX_ "Wx::Bitmap", RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__ComboCtrl_GetBitmapPressed); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ComboCtrl_GetBitmapPressed)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxComboCtrl *    THIS = (wxComboCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::ComboCtrl" )
;
	wxBitmap *	RETVAL;
    try {
      RETVAL = new wxBitmap( THIS->GetBitmapPressed() );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_object_2_sv( aTHX_ RETVALSV, RETVAL );
    wxPli_thread_sv_register( aTHX_ "Wx::Bitmap", RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__ComboCtrl_GetBitmapHover); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ComboCtrl_GetBitmapHover)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxComboCtrl *    THIS = (wxComboCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::ComboCtrl" )
;
	wxBitmap *	RETVAL;
    try {
      RETVAL = new wxBitmap( THIS->GetBitmapHover() );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_object_2_sv( aTHX_ RETVALSV, RETVAL );
    wxPli_thread_sv_register( aTHX_ "Wx::Bitmap", RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__ComboCtrl_GetBitmapDisabled); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ComboCtrl_GetBitmapDisabled)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxComboCtrl *    THIS = (wxComboCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::ComboCtrl" )
;
	wxBitmap *	RETVAL;
    try {
      RETVAL = new wxBitmap( THIS->GetBitmapDisabled() );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_object_2_sv( aTHX_ RETVALSV, RETVAL );
    wxPli_thread_sv_register( aTHX_ "Wx::Bitmap", RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}

#endif

/* INCLUDE: Returning to 'Controls.xs' from '/usr/bin/perl -I./ -MExtUtils::XSpp::Cmd -e xspp -- -t typemap.xsp XS/ComboCtrl.xsp' */


/* INCLUDE_COMMAND:  Including output of '/usr/bin/perl -I./ -MExtUtils::XSpp::Cmd -e xspp -- -t typemap.xsp XS/OwnerDrawnComboBox.xsp' from 'Controls.xs' */

#include <exception>

#undef  xsp_constructor_class
#define xsp_constructor_class(c) (c)
#if WXPERL_W_VERSION_GE( 2, 7, 2 )
#define XSpp_6f06a6f0_003614
#include <wx/odcombo.h>
#define XSubPPtmpAABK 1


XS_EUPXS(XS_Wx__OwnerDrawnComboBox_GetWidestItemWidth); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__OwnerDrawnComboBox_GetWidestItemWidth)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxOwnerDrawnComboBox *    THIS = (wxOwnerDrawnComboBox *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::OwnerDrawnComboBox" )
;
	int	RETVAL;
	dXSTARG;
    try {
      RETVAL = THIS->GetWidestItemWidth();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__OwnerDrawnComboBox_GetWidestItem); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__OwnerDrawnComboBox_GetWidestItem)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxOwnerDrawnComboBox *    THIS = (wxOwnerDrawnComboBox *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::OwnerDrawnComboBox" )
;
	int	RETVAL;
	dXSTARG;
    try {
      RETVAL = THIS->GetWidestItem();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


/* INCLUDE_COMMAND:  Including output of '/usr/bin/perl -pe "s/ItemContainerImmutable/OwnerDrawnComboBox/g;s/->(?=IsEmpty|GetStringSelection)/->wxItemContainerImmutable::/" XS/ItemContainerImmutable.xs' from '/usr/bin/perl -I./ -MExtUtils::XSpp::Cmd -e xspp -- -t typemap.xsp XS/OwnerDrawnComboBox.xsp' */

#include <exception>

#undef  xsp_constructor_class
#define xsp_constructor_class(c) (c)

XS_EUPXS(XS_Wx__OwnerDrawnComboBox_GetCount); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__OwnerDrawnComboBox_GetCount)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxOwnerDrawnComboBox *    THIS = (wxOwnerDrawnComboBox *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::OwnerDrawnComboBox" )
;
	unsigned int	RETVAL;
	dXSTARG;
    try {
      RETVAL = THIS->GetCount();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	XSprePUSH;
	PUSHu((UV)RETVAL );
    }
    XSRETURN(1);
}

#if !defined(WXPERL_IN_COMBOBOX) || WXPERL_W_VERSION_LE( 2, 9, 2 )
#define XSpp_f9ce292b_043796
#define XSubPPtmpAABL 1


XS_EUPXS(XS_Wx__OwnerDrawnComboBox_IsEmpty); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__OwnerDrawnComboBox_IsEmpty)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxOwnerDrawnComboBox *    THIS = (wxOwnerDrawnComboBox *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::OwnerDrawnComboBox" )
;
	bool	RETVAL;
    try {
      RETVAL = THIS->wxItemContainerImmutable::IsEmpty();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}

#endif

XS_EUPXS(XS_Wx__OwnerDrawnComboBox_GetString); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__OwnerDrawnComboBox_GetString)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, n");
    {
	wxOwnerDrawnComboBox *    THIS = (wxOwnerDrawnComboBox *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::OwnerDrawnComboBox" )
;
	wxString	RETVAL;
	unsigned int    n = (unsigned int)SvUV( ST(1) )
;
    try {
      RETVAL = THIS->GetString( n );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    WXSTRING_OUTPUT( RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__OwnerDrawnComboBox_GetStrings); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__OwnerDrawnComboBox_GetStrings)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    PERL_UNUSED_VAR(ax); /* -Wall */
    SP -= items;
    {
	wxOwnerDrawnComboBox *    THIS = (wxOwnerDrawnComboBox *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::OwnerDrawnComboBox" )
;
    PUTBACK;
    wxPli_stringarray_push( aTHX_ THIS->GetStrings() );
    SPAGAIN;
	PUTBACK;
	return;
    }
}


XS_EUPXS(XS_Wx__OwnerDrawnComboBox_SetString); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__OwnerDrawnComboBox_SetString)
{
    dVAR; dXSARGS;
    if (items != 3)
       croak_xs_usage(cv,  "THIS, n, s");
    {
	wxOwnerDrawnComboBox *    THIS = (wxOwnerDrawnComboBox *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::OwnerDrawnComboBox" )
;
	unsigned int    n = (unsigned int)SvUV( ST(1) )
;
	wxString	s;

    WXSTRING_INPUT( s, wxString, ST(2) )
;
    try {
      THIS->SetString( n, s );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__OwnerDrawnComboBox_FindString); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__OwnerDrawnComboBox_FindString)
{
    dVAR; dXSARGS;
    if (items < 1)
       croak_xs_usage(cv,  "THIS, ...");
    PERL_UNUSED_VAR(ax); /* -Wall */
    SP -= items;
    {
	wxOwnerDrawnComboBox *    THIS = (wxOwnerDrawnComboBox *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::OwnerDrawnComboBox" )
;
	int	RETVAL;
	dXSTARG;
    BEGIN_OVERLOAD()
#if WXPERL_W_VERSION_GE( 2, 7, 2 )
        MATCH_REDISP( wxPliOvl_s_b, FindStringCase )
#endif
        MATCH_REDISP( wxPliOvl_s, FindStringNoCase )
    END_OVERLOAD( Wx::OwnerDrawnComboBox::FindString )
	PUTBACK;
	return;
    }
}


XS_EUPXS(XS_Wx__OwnerDrawnComboBox_FindStringNoCase); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__OwnerDrawnComboBox_FindStringNoCase)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, s");
    {
	wxOwnerDrawnComboBox *    THIS = (wxOwnerDrawnComboBox *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::OwnerDrawnComboBox" )
;
	int	RETVAL;
	dXSTARG;
	wxString	s;

    WXSTRING_INPUT( s, wxString, ST(1) )
;
    try {
      RETVAL = THIS->FindString( s );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}

#if WXPERL_W_VERSION_GE( 2, 7, 2 )
#define XSpp_f9ce292b_037748
#define XSubPPtmpAABM 1


XS_EUPXS(XS_Wx__OwnerDrawnComboBox_FindStringCase); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__OwnerDrawnComboBox_FindStringCase)
{
    dVAR; dXSARGS;
    if (items < 2 || items > 3)
       croak_xs_usage(cv,  "THIS, s, bCase= false");
    {
	wxOwnerDrawnComboBox *    THIS = (wxOwnerDrawnComboBox *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::OwnerDrawnComboBox" )
;
	int	RETVAL;
	dXSTARG;
	wxString	s;
	bool	bCase;

    WXSTRING_INPUT( s, wxString, ST(1) )
;

	if (items < 3)
	    bCase = false;
	else {
	    bCase = (bool)SvTRUE(ST(2))
;
	}
    try {
      RETVAL = THIS->FindString( s, bCase );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}

#endif
#if !defined(WXPERL_IN_COMBOBOX)
#define XSpp_f9ce292b_078389
#define XSubPPtmpAABN 1


XS_EUPXS(XS_Wx__OwnerDrawnComboBox_SetSelection); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__OwnerDrawnComboBox_SetSelection)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, n");
    {
	wxOwnerDrawnComboBox *    THIS = (wxOwnerDrawnComboBox *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::OwnerDrawnComboBox" )
;
	int	n = (int)SvIV(ST(1))
;
    try {
      THIS->SetSelection( n );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__OwnerDrawnComboBox_GetSelection); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__OwnerDrawnComboBox_GetSelection)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxOwnerDrawnComboBox *    THIS = (wxOwnerDrawnComboBox *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::OwnerDrawnComboBox" )
;
	int	RETVAL;
	dXSTARG;
    try {
      RETVAL = THIS->GetSelection();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}

#endif

XS_EUPXS(XS_Wx__OwnerDrawnComboBox_SetStringSelection); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__OwnerDrawnComboBox_SetStringSelection)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, s");
    {
	wxOwnerDrawnComboBox *    THIS = (wxOwnerDrawnComboBox *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::OwnerDrawnComboBox" )
;
	bool	RETVAL;
	wxString	s;

    WXSTRING_INPUT( s, wxString, ST(1) )
;
    try {
      RETVAL = THIS->SetStringSelection( s );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__OwnerDrawnComboBox_GetStringSelection); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__OwnerDrawnComboBox_GetStringSelection)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxOwnerDrawnComboBox *    THIS = (wxOwnerDrawnComboBox *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::OwnerDrawnComboBox" )
;
	wxString	RETVAL;
    try {
      RETVAL = THIS->wxItemContainerImmutable::GetStringSelection();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    WXSTRING_OUTPUT( RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__OwnerDrawnComboBox_Select); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__OwnerDrawnComboBox_Select)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, n");
    {
	wxOwnerDrawnComboBox *    THIS = (wxOwnerDrawnComboBox *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::OwnerDrawnComboBox" )
;
	int	n = (int)SvIV(ST(1))
;
    try {
      THIS->Select( n );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


/* INCLUDE: Returning to '/usr/bin/perl -I./ -MExtUtils::XSpp::Cmd -e xspp -- -t typemap.xsp XS/OwnerDrawnComboBox.xsp' from '/usr/bin/perl -pe "s/ItemContainerImmutable/OwnerDrawnComboBox/g;s/->(?=IsEmpty|GetStringSelection)/->wxItemContainerImmutable::/" XS/ItemContainerImmutable.xs' */


/* INCLUDE_COMMAND:  Including output of '/usr/bin/perl -pe "s/ItemContainer/OwnerDrawnComboBox/g" XS/ItemContainer.xs' from '/usr/bin/perl -I./ -MExtUtils::XSpp::Cmd -e xspp -- -t typemap.xsp XS/OwnerDrawnComboBox.xsp' */

#include <exception>

#undef  xsp_constructor_class
#define xsp_constructor_class(c) (c)

XS_EUPXS(XS_Wx__OwnerDrawnComboBox_Append); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__OwnerDrawnComboBox_Append)
{
    dVAR; dXSARGS;
    if (items < 1)
       croak_xs_usage(cv,  "THIS, ...");
    PERL_UNUSED_VAR(ax); /* -Wall */
    SP -= items;
    {
	wxOwnerDrawnComboBox *    THIS = (wxOwnerDrawnComboBox *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::OwnerDrawnComboBox" )
;
    BEGIN_OVERLOAD()
        MATCH_REDISP( wxPliOvl_arr_arr, AppendItemsData )
        MATCH_REDISP( wxPliOvl_arr, AppendItems )
        MATCH_REDISP( wxPliOvl_s_s, AppendData )
        MATCH_REDISP( wxPliOvl_s, AppendString )
    END_OVERLOAD( Wx::OwnerDrawnComboBox::Append )
	PUTBACK;
	return;
    }
}


XS_EUPXS(XS_Wx__OwnerDrawnComboBox_AppendString); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__OwnerDrawnComboBox_AppendString)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, item");
    {
	wxOwnerDrawnComboBox *    THIS = (wxOwnerDrawnComboBox *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::OwnerDrawnComboBox" )
;
	wxString	item;

    WXSTRING_INPUT( item, wxString, ST(1) )
;
    try {
      THIS->Append( item );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__OwnerDrawnComboBox_AppendData); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__OwnerDrawnComboBox_AppendData)
{
    dVAR; dXSARGS;
    if (items != 3)
       croak_xs_usage(cv,  "THIS, item, data");
    {
	wxOwnerDrawnComboBox *    THIS = (wxOwnerDrawnComboBox *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::OwnerDrawnComboBox" )
;
	wxString	item;
	wxPliUserDataCD*	data;

    WXSTRING_INPUT( item, wxString, ST(1) )
;

    if( SvOK( ST(2) ) )
    {
        data = new wxPliUserDataCD( ST(2) );
    }
    else
        data = 0
;
    try {
      THIS->Append( item, data );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__OwnerDrawnComboBox_AppendItems); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__OwnerDrawnComboBox_AppendItems)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, items");
    {
	wxOwnerDrawnComboBox *    THIS = (wxOwnerDrawnComboBox *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::OwnerDrawnComboBox" )
;
	wxArrayString	items;

    wxPli_av_2_arraystring( aTHX_ ST(1), & items )
;
    try {
      THIS->Append( items );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}

#if WXPERL_W_VERSION_GE( 2, 9, 0 )
#define XSpp_a2ea7434_096891
#define XSubPPtmpAABO 1


XS_EUPXS(XS_Wx__OwnerDrawnComboBox_AppendItemsData); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__OwnerDrawnComboBox_AppendItemsData)
{
    dVAR; dXSARGS;
    if (items != 3)
       croak_xs_usage(cv,  "THIS, items, data");
    {
	wxOwnerDrawnComboBox *    THIS = (wxOwnerDrawnComboBox *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::OwnerDrawnComboBox" )
;
	wxArrayString	items;
	wxPliUserDataCD**	data;

    wxPli_av_2_arraystring( aTHX_ ST(1), & items )
;

    wxPli_av_2_userdatacdarray( aTHX_ ST(2), & data );
    wxPliArrayGuard<wxPliUserDataCD*> guard_data = data
;
     THIS->Append( items, (wxClientData**)data ); 
    }
    XSRETURN_EMPTY;
}

#endif

XS_EUPXS(XS_Wx__OwnerDrawnComboBox_Insert); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__OwnerDrawnComboBox_Insert)
{
    dVAR; dXSARGS;
    if (items < 1)
       croak_xs_usage(cv,  "THIS, ...");
    PERL_UNUSED_VAR(ax); /* -Wall */
    SP -= items;
    {
	wxOwnerDrawnComboBox *    THIS = (wxOwnerDrawnComboBox *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::OwnerDrawnComboBox" )
;
    BEGIN_OVERLOAD()
        MATCH_REDISP( wxPliOvl_arr_n_arr, InsertItemsData )
        MATCH_REDISP( wxPliOvl_arr_n, InsertItems )
        MATCH_REDISP( wxPliOvl_s_n_s, InsertData )
        MATCH_REDISP( wxPliOvl_s_n, InsertString )
    END_OVERLOAD( Wx::OwnerDrawnComboBox::Insert )
	PUTBACK;
	return;
    }
}


XS_EUPXS(XS_Wx__OwnerDrawnComboBox_InsertString); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__OwnerDrawnComboBox_InsertString)
{
    dVAR; dXSARGS;
    if (items != 3)
       croak_xs_usage(cv,  "THIS, item, pos");
    {
	wxOwnerDrawnComboBox *    THIS = (wxOwnerDrawnComboBox *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::OwnerDrawnComboBox" )
;
	wxString	item;
	unsigned int    pos = (unsigned int)SvUV( ST(2) )
;

    WXSTRING_INPUT( item, wxString, ST(1) )
;
    try {
      THIS->Insert( item, pos );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__OwnerDrawnComboBox_InsertData); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__OwnerDrawnComboBox_InsertData)
{
    dVAR; dXSARGS;
    if (items != 4)
       croak_xs_usage(cv,  "THIS, item, pos, data");
    {
	wxOwnerDrawnComboBox *    THIS = (wxOwnerDrawnComboBox *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::OwnerDrawnComboBox" )
;
	wxString	item;
	unsigned int    pos = (unsigned int)SvUV( ST(2) )
;
	wxPliUserDataCD*	data;

    WXSTRING_INPUT( item, wxString, ST(1) )
;

    if( SvOK( ST(3) ) )
    {
        data = new wxPliUserDataCD( ST(3) );
    }
    else
        data = 0
;
    try {
      THIS->Insert( item, pos, data );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}

#if WXPERL_W_VERSION_GE( 2, 9, 0 )
#define XSpp_a2ea7434_055796
#define XSubPPtmpAABP 1


XS_EUPXS(XS_Wx__OwnerDrawnComboBox_InsertItems); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__OwnerDrawnComboBox_InsertItems)
{
    dVAR; dXSARGS;
    if (items != 3)
       croak_xs_usage(cv,  "THIS, items, pos");
    {
	wxOwnerDrawnComboBox *    THIS = (wxOwnerDrawnComboBox *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::OwnerDrawnComboBox" )
;
	wxArrayString	items;
	unsigned int    pos = (unsigned int)SvUV( ST(2) )
;

    wxPli_av_2_arraystring( aTHX_ ST(1), & items )
;
    try {
      THIS->Insert( items, pos );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__OwnerDrawnComboBox_InsertItemsData); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__OwnerDrawnComboBox_InsertItemsData)
{
    dVAR; dXSARGS;
    if (items != 4)
       croak_xs_usage(cv,  "THIS, items, pos, data");
    {
	wxOwnerDrawnComboBox *    THIS = (wxOwnerDrawnComboBox *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::OwnerDrawnComboBox" )
;
	wxArrayString	items;
	unsigned int    pos = (unsigned int)SvUV( ST(2) )
;
	wxPliUserDataCD**	data;

    wxPli_av_2_arraystring( aTHX_ ST(1), & items )
;

    wxPli_av_2_userdatacdarray( aTHX_ ST(3), & data );
    wxPliArrayGuard<wxPliUserDataCD*> guard_data = data
;
     THIS->Insert( items, pos, (wxClientData**)data ); 
    }
    XSRETURN_EMPTY;
}

#endif
#if WXPERL_W_VERSION_GE( 2, 9, 0 )
#define XSpp_a2ea7434_019830
#define XSubPPtmpAABQ 1


XS_EUPXS(XS_Wx__OwnerDrawnComboBox_Set); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__OwnerDrawnComboBox_Set)
{
    dVAR; dXSARGS;
    if (items < 1)
       croak_xs_usage(cv,  "THIS, ...");
    PERL_UNUSED_VAR(ax); /* -Wall */
    SP -= items;
    {
	wxOwnerDrawnComboBox *    THIS = (wxOwnerDrawnComboBox *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::OwnerDrawnComboBox" )
;
    BEGIN_OVERLOAD()
        MATCH_REDISP( wxPliOvl_arr_arr, SetItemsData )
        MATCH_REDISP( wxPliOvl_arr, SetItems )
    END_OVERLOAD( Wx::OwnerDrawnComboBox::Set )
	PUTBACK;
	return;
    }
}


XS_EUPXS(XS_Wx__OwnerDrawnComboBox_SetItems); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__OwnerDrawnComboBox_SetItems)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, items");
    {
	wxOwnerDrawnComboBox *    THIS = (wxOwnerDrawnComboBox *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::OwnerDrawnComboBox" )
;
	wxArrayString	items;

    wxPli_av_2_arraystring( aTHX_ ST(1), & items )
;
    try {
      THIS->Set( items );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__OwnerDrawnComboBox_SetItemsData); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__OwnerDrawnComboBox_SetItemsData)
{
    dVAR; dXSARGS;
    if (items != 3)
       croak_xs_usage(cv,  "THIS, items, data");
    {
	wxOwnerDrawnComboBox *    THIS = (wxOwnerDrawnComboBox *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::OwnerDrawnComboBox" )
;
	wxArrayString	items;
	wxPliUserDataCD**	data;

    wxPli_av_2_arraystring( aTHX_ ST(1), & items )
;

    wxPli_av_2_userdatacdarray( aTHX_ ST(2), & data );
    wxPliArrayGuard<wxPliUserDataCD*> guard_data = data
;
     THIS->Set( items, (wxClientData**)data ); 
    }
    XSRETURN_EMPTY;
}

#endif

XS_EUPXS(XS_Wx__OwnerDrawnComboBox_Clear); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__OwnerDrawnComboBox_Clear)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxOwnerDrawnComboBox *    THIS = (wxOwnerDrawnComboBox *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::OwnerDrawnComboBox" )
;
    try {
      THIS->Clear();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__OwnerDrawnComboBox_Delete); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__OwnerDrawnComboBox_Delete)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, n");
    {
	wxOwnerDrawnComboBox *    THIS = (wxOwnerDrawnComboBox *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::OwnerDrawnComboBox" )
;
	int	n = (int)SvIV(ST(1))
;
    try {
      THIS->Delete( n );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__OwnerDrawnComboBox_GetClientData); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__OwnerDrawnComboBox_GetClientData)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, n");
    {
	wxOwnerDrawnComboBox *    THIS = (wxOwnerDrawnComboBox *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::OwnerDrawnComboBox" )
;
	wxPliUserDataCD *	RETVAL;
	int	n = (int)SvIV(ST(1))
;
     RETVAL = (wxPliUserDataCD*) THIS->GetClientObject( n ); 
	{
	    SV * RETVALSV;
    RETVALSV = ( RETVAL == 0 ) ? &PL_sv_undef : RETVAL->GetData();
    SvREFCNT_inc( RETVALSV ); // xsubpp mortalizes it...
	    RETVALSV = sv_2mortal(RETVALSV);
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__OwnerDrawnComboBox_SetClientData); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__OwnerDrawnComboBox_SetClientData)
{
    dVAR; dXSARGS;
    if (items != 3)
       croak_xs_usage(cv,  "THIS, n, data");
    {
	wxOwnerDrawnComboBox *    THIS = (wxOwnerDrawnComboBox *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::OwnerDrawnComboBox" )
;
	int	n = (int)SvIV(ST(1))
;
	wxPliUserDataCD*	data;

    if( SvOK( ST(2) ) )
    {
        data = new wxPliUserDataCD( ST(2) );
    }
    else
        data = 0
;
    try {
      THIS->SetClientObject( n, data );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}

#if WXPERL_W_VERSION_GE( 2, 9, 0 )
#define XSpp_a2ea7434_093657
#endif

/* INCLUDE: Returning to '/usr/bin/perl -I./ -MExtUtils::XSpp::Cmd -e xspp -- -t typemap.xsp XS/OwnerDrawnComboBox.xsp' from '/usr/bin/perl -pe "s/ItemContainer/OwnerDrawnComboBox/g" XS/ItemContainer.xs' */

#include "xspp/odcombo.h"

XS_EUPXS(XS_Wx__PlOwnerDrawnComboBox_new); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__PlOwnerDrawnComboBox_new)
{
    dVAR; dXSARGS;
    PERL_UNUSED_VAR(cv); /* -W */
    PERL_UNUSED_VAR(items); /* -W */
    PERL_UNUSED_VAR(ax); /* -Wall */
    SP -= items;
    {
    BEGIN_OVERLOAD()
        MATCH_VOIDM_REDISP( newDefault )
        MATCH_ANY_REDISP( newFull )
    END_OVERLOAD( "Wx::PlOwnerDrawnComboBox::new" )
	PUTBACK;
	return;
    }
}

#undef  xsp_constructor_class
#define xsp_constructor_class(c) (CLASS)

XS_EUPXS(XS_Wx__PlOwnerDrawnComboBox_newDefault); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__PlOwnerDrawnComboBox_newDefault)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "CLASS");
    {
	char *	CLASS = (char *)SvPV_nolen(ST(0))
;
	wxPlOwnerDrawnComboBox *	RETVAL;
     RETVAL = new wxPlOwnerDrawnComboBox( CLASS );
                wxPli_create_evthandler( aTHX_ RETVAL, CLASS );
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_evthandler_2_sv( aTHX_ RETVALSV, RETVAL );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}

#undef  xsp_constructor_class
#define xsp_constructor_class(c) (c)
#undef  xsp_constructor_class
#define xsp_constructor_class(c) (CLASS)

XS_EUPXS(XS_Wx__PlOwnerDrawnComboBox_newFull); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__PlOwnerDrawnComboBox_newFull)
{
    dVAR; dXSARGS;
    if (items < 7 || items > 10)
       croak_xs_usage(cv,  "CLASS, parent, id, value, pos, size, choices, style= 0, validator= wxDefaultValidatorPtr, name= wxEmptyString");
    {
	char *	CLASS = (char *)SvPV_nolen(ST(0))
;
	wxPlOwnerDrawnComboBox *	RETVAL;
	wxWindow*    parent = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::Window" )
;
	wxWindowID    id = wxPli_get_wxwindowid( aTHX_ ST(2) )
;
	wxString	value;
	wxPoint    pos = wxPli_sv_2_wxpoint( aTHX_ ST(4) )
;
	wxSize    size = wxPli_sv_2_wxsize( aTHX_ ST(5) )
;
	wxArrayString	choices;
	long	style;
	wxValidator*	validator;
	wxString	name;

    WXSTRING_INPUT( value, wxString, ST(3) )
;

    wxPli_av_2_arraystring( aTHX_ ST(6), & choices )
;

	if (items < 8)
	    style = 0;
	else {
	    style = (long)SvIV(ST(7))
;
	}

	if (items < 9)
	    validator = wxDefaultValidatorPtr;
	else {
    validator = (wxValidator *) wxPli_sv_2_object( aTHX_ ST(8), "Wx::Validator" )
;
	}

	if (items < 10)
	    name = wxEmptyString;
	else {
    WXSTRING_INPUT( name, wxString, ST(9) )
;
	}
     RETVAL = new wxPlOwnerDrawnComboBox( CLASS, parent, id, value,
                                                     pos, size, choices, style,
                                                     *validator, name );
                wxPli_create_evthandler( aTHX_ RETVAL, CLASS );
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_evthandler_2_sv( aTHX_ RETVALSV, RETVAL );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}

#undef  xsp_constructor_class
#define xsp_constructor_class(c) (c)

XS_EUPXS(XS_Wx__PlOwnerDrawnComboBox_Create); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__PlOwnerDrawnComboBox_Create)
{
    dVAR; dXSARGS;
    if (items < 4 || items > 10)
       croak_xs_usage(cv,  "THIS, parent, id, value= wxEmptyString, pos= wxDefaultPosition, size= wxDefaultSize, choices, style= 0, validator= wxDefaultValidatorPtr, name= wxEmptyString");
    {
	wxPlOwnerDrawnComboBox *    THIS = (wxPlOwnerDrawnComboBox *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::PlOwnerDrawnComboBox" )
;
	bool	RETVAL;
	wxWindow*    parent = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::Window" )
;
	wxWindowID    id = wxPli_get_wxwindowid( aTHX_ ST(2) )
;
	wxString	value;
	wxPoint	pos;
	wxSize	size;
	wxArrayString	choices;
	long	style;
	wxValidator*	validator;
	wxString	name;

	if (items < 4)
	    value = wxEmptyString;
	else {
    WXSTRING_INPUT( value, wxString, ST(3) )
;
	}

	if (items < 5)
	    pos = wxDefaultPosition;
	else {
    pos = wxPli_sv_2_wxpoint( aTHX_ ST(4) )
;
	}

	if (items < 6)
	    size = wxDefaultSize;
	else {
    size = wxPli_sv_2_wxsize( aTHX_ ST(5) )
;
	}

    wxPli_av_2_arraystring( aTHX_ ST(6), & choices )
;

	if (items < 8)
	    style = 0;
	else {
	    style = (long)SvIV(ST(7))
;
	}

	if (items < 9)
	    validator = wxDefaultValidatorPtr;
	else {
    validator = (wxValidator *) wxPli_sv_2_object( aTHX_ ST(8), "Wx::Validator" )
;
	}

	if (items < 10)
	    name = wxEmptyString;
	else {
    WXSTRING_INPUT( name, wxString, ST(9) )
;
	}
    try {
      RETVAL = THIS->Create( parent, id, value, pos, size, choices, style, *( validator ), name );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}

#endif

/* INCLUDE: Returning to 'Controls.xs' from '/usr/bin/perl -I./ -MExtUtils::XSpp::Cmd -e xspp -- -t typemap.xsp XS/OwnerDrawnComboBox.xsp' */


/* INCLUDE_COMMAND:  Including output of '/usr/bin/perl -I./ -MExtUtils::XSpp::Cmd -e xspp -- -t typemap.xsp XS/CollapsiblePane.xsp' from 'Controls.xs' */

#include <exception>

#undef  xsp_constructor_class
#define xsp_constructor_class(c) (c)
#if WXPERL_W_VERSION_GE( 2, 7, 2 )
#define XSpp_e76ebb63_056445
#include <wx/collpane.h>
#undef  xsp_constructor_class
#define xsp_constructor_class(c) (CLASS)
#define XSubPPtmpAABR 1


XS_EUPXS(XS_Wx__CollapsiblePaneEvent_new); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__CollapsiblePaneEvent_new)
{
    dVAR; dXSARGS;
    if (items != 4)
       croak_xs_usage(cv,  "CLASS, generator, id, collapsed");
    {
	char *	CLASS = (char *)SvPV_nolen(ST(0))
;
	wxCollapsiblePaneEvent *	RETVAL;
	wxObject*    generator = (wxObject *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::Object" )
;
	int	id = (int)SvIV(ST(2))
;
	bool	collapsed = (bool)SvTRUE(ST(3))
;
    try {
      RETVAL = new wxCollapsiblePaneEvent( generator, id, collapsed );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_object_2_sv( aTHX_ RETVALSV, RETVAL );
    wxPli_thread_sv_register( aTHX_ "Wx::CollapsiblePaneEvent", RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}

#undef  xsp_constructor_class
#define xsp_constructor_class(c) (c)

XS_EUPXS(XS_Wx__CollapsiblePaneEvent_GetCollapsed); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__CollapsiblePaneEvent_GetCollapsed)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxCollapsiblePaneEvent *    THIS = (wxCollapsiblePaneEvent *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::CollapsiblePaneEvent" )
;
	bool	RETVAL;
    try {
      RETVAL = THIS->GetCollapsed();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__CollapsiblePaneEvent_SetCollapsed); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__CollapsiblePaneEvent_SetCollapsed)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, c");
    {
	wxCollapsiblePaneEvent *    THIS = (wxCollapsiblePaneEvent *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::CollapsiblePaneEvent" )
;
	bool	c = (bool)SvTRUE(ST(1))
;
    try {
      THIS->SetCollapsed( c );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__CollapsiblePane_new); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__CollapsiblePane_new)
{
    dVAR; dXSARGS;
    PERL_UNUSED_VAR(cv); /* -W */
    PERL_UNUSED_VAR(items); /* -W */
    PERL_UNUSED_VAR(ax); /* -Wall */
    SP -= items;
    {
    BEGIN_OVERLOAD()
        MATCH_VOIDM_REDISP( newDefault )
        MATCH_ANY_REDISP( newFull )
    END_OVERLOAD( "Wx::CollapsiblePane::new" )
	PUTBACK;
	return;
    }
}

#undef  xsp_constructor_class
#define xsp_constructor_class(c) (CLASS)

XS_EUPXS(XS_Wx__CollapsiblePane_newDefault); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__CollapsiblePane_newDefault)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "CLASS");
    {
	char *	CLASS = (char *)SvPV_nolen(ST(0))
;
	wxCollapsiblePane *	RETVAL;
     RETVAL = new wxCollapsiblePane();
                wxPli_create_evthandler( aTHX_ RETVAL, CLASS );
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_evthandler_2_sv( aTHX_ RETVALSV, RETVAL );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}

#undef  xsp_constructor_class
#define xsp_constructor_class(c) (c)
#undef  xsp_constructor_class
#define xsp_constructor_class(c) (CLASS)

XS_EUPXS(XS_Wx__CollapsiblePane_newFull); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__CollapsiblePane_newFull)
{
    dVAR; dXSARGS;
    if (items < 4 || items > 9)
       croak_xs_usage(cv,  "CLASS, parent, id, label, pos= wxDefaultPosition, size= wxDefaultSize, style= wxCP_DEFAULT_STYLE, val= wxDefaultValidatorPtr, name= wxCollapsiblePaneNameStr");
    {
	char *	CLASS = (char *)SvPV_nolen(ST(0))
;
	wxCollapsiblePane *	RETVAL;
	wxWindow*    parent = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::Window" )
;
	wxWindowID    id = wxPli_get_wxwindowid( aTHX_ ST(2) )
;
	wxString	label;
	wxPoint	pos;
	wxSize	size;
	long	style;
	wxValidator*	val;
	wxString	name;

    WXSTRING_INPUT( label, wxString, ST(3) )
;

	if (items < 5)
	    pos = wxDefaultPosition;
	else {
    pos = wxPli_sv_2_wxpoint( aTHX_ ST(4) )
;
	}

	if (items < 6)
	    size = wxDefaultSize;
	else {
    size = wxPli_sv_2_wxsize( aTHX_ ST(5) )
;
	}

	if (items < 7)
	    style = wxCP_DEFAULT_STYLE;
	else {
	    style = (long)SvIV(ST(6))
;
	}

	if (items < 8)
	    val = wxDefaultValidatorPtr;
	else {
    val = (wxValidator *) wxPli_sv_2_object( aTHX_ ST(7), "Wx::Validator" )
;
	}

	if (items < 9)
	    name = wxCollapsiblePaneNameStr;
	else {
    WXSTRING_INPUT( name, wxString, ST(8) )
;
	}
     RETVAL = new wxCollapsiblePane( parent, id, label, pos, size,
                                                style, *val, name );
                wxPli_create_evthandler( aTHX_ RETVAL, CLASS );
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_evthandler_2_sv( aTHX_ RETVALSV, RETVAL );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}

#undef  xsp_constructor_class
#define xsp_constructor_class(c) (c)

XS_EUPXS(XS_Wx__CollapsiblePane_Create); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__CollapsiblePane_Create)
{
    dVAR; dXSARGS;
    if (items < 4 || items > 9)
       croak_xs_usage(cv,  "THIS, parent, id, label, pos= wxDefaultPosition, size= wxDefaultSize, style= wxCP_DEFAULT_STYLE, val= wxDefaultValidatorPtr, name= wxCollapsiblePaneNameStr");
    {
	wxCollapsiblePane *    THIS = (wxCollapsiblePane *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::CollapsiblePane" )
;
	bool	RETVAL;
	wxWindow*    parent = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::Window" )
;
	wxWindowID    id = wxPli_get_wxwindowid( aTHX_ ST(2) )
;
	wxString	label;
	wxPoint	pos;
	wxSize	size;
	long	style;
	wxValidator*	val;
	wxString	name;

    WXSTRING_INPUT( label, wxString, ST(3) )
;

	if (items < 5)
	    pos = wxDefaultPosition;
	else {
    pos = wxPli_sv_2_wxpoint( aTHX_ ST(4) )
;
	}

	if (items < 6)
	    size = wxDefaultSize;
	else {
    size = wxPli_sv_2_wxsize( aTHX_ ST(5) )
;
	}

	if (items < 7)
	    style = wxCP_DEFAULT_STYLE;
	else {
	    style = (long)SvIV(ST(6))
;
	}

	if (items < 8)
	    val = wxDefaultValidatorPtr;
	else {
    val = (wxValidator *) wxPli_sv_2_object( aTHX_ ST(7), "Wx::Validator" )
;
	}

	if (items < 9)
	    name = wxCollapsiblePaneNameStr;
	else {
    WXSTRING_INPUT( name, wxString, ST(8) )
;
	}
    try {
      RETVAL = THIS->Create( parent, id, label, pos, size, style, *( val ), name );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__CollapsiblePane_Collapse); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__CollapsiblePane_Collapse)
{
    dVAR; dXSARGS;
    if (items < 1 || items > 2)
       croak_xs_usage(cv,  "THIS, collapse= true");
    {
	wxCollapsiblePane *    THIS = (wxCollapsiblePane *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::CollapsiblePane" )
;
	bool	collapse;

	if (items < 2)
	    collapse = true;
	else {
	    collapse = (bool)SvTRUE(ST(1))
;
	}
    try {
      THIS->Collapse( collapse );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__CollapsiblePane_Expand); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__CollapsiblePane_Expand)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxCollapsiblePane *    THIS = (wxCollapsiblePane *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::CollapsiblePane" )
;
    try {
      THIS->Expand();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__CollapsiblePane_IsCollapsed); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__CollapsiblePane_IsCollapsed)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxCollapsiblePane *    THIS = (wxCollapsiblePane *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::CollapsiblePane" )
;
	bool	RETVAL;
    try {
      RETVAL = THIS->IsCollapsed();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__CollapsiblePane_IsExpanded); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__CollapsiblePane_IsExpanded)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxCollapsiblePane *    THIS = (wxCollapsiblePane *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::CollapsiblePane" )
;
	bool	RETVAL;
    try {
      RETVAL = THIS->IsExpanded();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__CollapsiblePane_GetPane); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__CollapsiblePane_GetPane)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxCollapsiblePane *    THIS = (wxCollapsiblePane *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::CollapsiblePane" )
;
	wxWindow *	RETVAL;
    try {
      RETVAL = THIS->GetPane();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_object_2_sv( aTHX_ RETVALSV, RETVAL );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}

#endif

/* INCLUDE: Returning to 'Controls.xs' from '/usr/bin/perl -I./ -MExtUtils::XSpp::Cmd -e xspp -- -t typemap.xsp XS/CollapsiblePane.xsp' */


/* INCLUDE_COMMAND:  Including output of '/usr/bin/perl -I./ -MExtUtils::XSpp::Cmd -e xspp -- -t typemap.xsp XS/BitmapComboBox.xsp' from 'Controls.xs' */

#include <exception>

#undef  xsp_constructor_class
#define xsp_constructor_class(c) (c)
#if WXPERL_W_VERSION_GE( 2, 7, 2 )
#define XSpp_b3adac27_096178
#include <wx/bmpcbox.h>
#define XSubPPtmpAABS 1


XS_EUPXS(XS_Wx__BitmapComboBox_new); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__BitmapComboBox_new)
{
    dVAR; dXSARGS;
    PERL_UNUSED_VAR(cv); /* -W */
    PERL_UNUSED_VAR(items); /* -W */
    PERL_UNUSED_VAR(ax); /* -Wall */
    SP -= items;
    {
    BEGIN_OVERLOAD()
        MATCH_VOIDM_REDISP( newDefault )
        MATCH_ANY_REDISP( newFull )
    END_OVERLOAD( "Wx::BitmapComboBox::new" )
	PUTBACK;
	return;
    }
}

#undef  xsp_constructor_class
#define xsp_constructor_class(c) (CLASS)

XS_EUPXS(XS_Wx__BitmapComboBox_newDefault); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__BitmapComboBox_newDefault)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "CLASS");
    {
	char *	CLASS = (char *)SvPV_nolen(ST(0))
;
	wxBitmapComboBox *	RETVAL;
     RETVAL = new wxBitmapComboBox();
                wxPli_create_evthandler( aTHX_ RETVAL, CLASS );
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_evthandler_2_sv( aTHX_ RETVALSV, RETVAL );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}

#undef  xsp_constructor_class
#define xsp_constructor_class(c) (c)
#undef  xsp_constructor_class
#define xsp_constructor_class(c) (CLASS)

XS_EUPXS(XS_Wx__BitmapComboBox_newFull); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__BitmapComboBox_newFull)
{
    dVAR; dXSARGS;
    if (items < 5 || items > 10)
       croak_xs_usage(cv,  "CLASS, parent, id, value, pos= wxDefaultPosition, size= wxDefaultSize, choices, style= 0, val= wxDefaultValidatorPtr, name= wxBitmapComboBoxNameStr");
    {
	char *	CLASS = (char *)SvPV_nolen(ST(0))
;
	wxBitmapComboBox *	RETVAL;
	wxWindow*    parent = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::Window" )
;
	wxWindowID    id = wxPli_get_wxwindowid( aTHX_ ST(2) )
;
	wxString	value;
	wxPoint	pos;
	wxSize	size;
	wxArrayString	choices;
	long	style;
	wxValidator*	val;
	wxString	name;

    WXSTRING_INPUT( value, wxString, ST(3) )
;

	if (items < 5)
	    pos = wxDefaultPosition;
	else {
    pos = wxPli_sv_2_wxpoint( aTHX_ ST(4) )
;
	}

	if (items < 6)
	    size = wxDefaultSize;
	else {
    size = wxPli_sv_2_wxsize( aTHX_ ST(5) )
;
	}

    wxPli_av_2_arraystring( aTHX_ ST(6), & choices )
;

	if (items < 8)
	    style = 0;
	else {
	    style = (long)SvIV(ST(7))
;
	}

	if (items < 9)
	    val = wxDefaultValidatorPtr;
	else {
    val = (wxValidator *) wxPli_sv_2_object( aTHX_ ST(8), "Wx::Validator" )
;
	}

	if (items < 10)
	    name = wxBitmapComboBoxNameStr;
	else {
    WXSTRING_INPUT( name, wxString, ST(9) )
;
	}
     RETVAL = new wxBitmapComboBox( parent, id, value, pos, size,
                                                choices, style, *val, name );
                wxPli_create_evthandler( aTHX_ RETVAL, CLASS );
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_evthandler_2_sv( aTHX_ RETVALSV, RETVAL );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}

#undef  xsp_constructor_class
#define xsp_constructor_class(c) (c)

XS_EUPXS(XS_Wx__BitmapComboBox_Create); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__BitmapComboBox_Create)
{
    dVAR; dXSARGS;
    if (items < 5 || items > 10)
       croak_xs_usage(cv,  "THIS, parent, id, value, pos= wxDefaultPosition, size= wxDefaultSize, choices, style= 0, val= wxDefaultValidatorPtr, name= wxBitmapComboBoxNameStr");
    {
	wxBitmapComboBox *    THIS = (wxBitmapComboBox *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::BitmapComboBox" )
;
	bool	RETVAL;
	wxWindow*    parent = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::Window" )
;
	wxWindowID    id = wxPli_get_wxwindowid( aTHX_ ST(2) )
;
	wxString	value;
	wxPoint	pos;
	wxSize	size;
	wxArrayString	choices;
	long	style;
	wxValidator*	val;
	wxString	name;

    WXSTRING_INPUT( value, wxString, ST(3) )
;

	if (items < 5)
	    pos = wxDefaultPosition;
	else {
    pos = wxPli_sv_2_wxpoint( aTHX_ ST(4) )
;
	}

	if (items < 6)
	    size = wxDefaultSize;
	else {
    size = wxPli_sv_2_wxsize( aTHX_ ST(5) )
;
	}

    wxPli_av_2_arraystring( aTHX_ ST(6), & choices )
;

	if (items < 8)
	    style = 0;
	else {
	    style = (long)SvIV(ST(7))
;
	}

	if (items < 9)
	    val = wxDefaultValidatorPtr;
	else {
    val = (wxValidator *) wxPli_sv_2_object( aTHX_ ST(8), "Wx::Validator" )
;
	}

	if (items < 10)
	    name = wxBitmapComboBoxNameStr;
	else {
    WXSTRING_INPUT( name, wxString, ST(9) )
;
	}
    try {
      RETVAL = THIS->Create( parent, id, value, pos, size, choices, style, *( val ), name );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__BitmapComboBox_Append); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__BitmapComboBox_Append)
{
    dVAR; dXSARGS;
    if (items < 1)
       croak_xs_usage(cv,  "THIS, ...");
    PERL_UNUSED_VAR(ax); /* -Wall */
    SP -= items;
    {
	wxBitmapComboBox *    THIS = (wxBitmapComboBox *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::BitmapComboBox" )
;
    BEGIN_OVERLOAD()
        MATCH_REDISP( wxPliOvl_s_wbmp_s, AppendData )
        MATCH_REDISP( wxPliOvl_s_wbmp, AppendString )
    END_OVERLOAD( Wx::BitmapComboBox::Append )
	PUTBACK;
	return;
    }
}


XS_EUPXS(XS_Wx__BitmapComboBox_AppendString); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__BitmapComboBox_AppendString)
{
    dVAR; dXSARGS;
    if (items < 2 || items > 3)
       croak_xs_usage(cv,  "THIS, item, bitmap= wxNullBitmapPtr");
    {
	wxBitmapComboBox *    THIS = (wxBitmapComboBox *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::BitmapComboBox" )
;
	wxString	item;
	wxBitmap*	bitmap;

    WXSTRING_INPUT( item, wxString, ST(1) )
;

	if (items < 3)
	    bitmap = wxNullBitmapPtr;
	else {
    bitmap = (wxBitmap *) wxPli_sv_2_object( aTHX_ ST(2), "Wx::Bitmap" )
;
	}
    try {
      THIS->Append( item, *( bitmap ) );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__BitmapComboBox_AppendData); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__BitmapComboBox_AppendData)
{
    dVAR; dXSARGS;
    if (items != 4)
       croak_xs_usage(cv,  "THIS, item, bitmap, data");
    {
	wxBitmapComboBox *    THIS = (wxBitmapComboBox *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::BitmapComboBox" )
;
	wxString	item;
	wxBitmap*    bitmap = (wxBitmap *) wxPli_sv_2_object( aTHX_ ST(2), "Wx::Bitmap" )
;
	wxPliUserDataCD*	data;

    WXSTRING_INPUT( item, wxString, ST(1) )
;

    if( SvOK( ST(3) ) )
    {
        data = new wxPliUserDataCD( ST(3) );
    }
    else
        data = 0
;
    try {
      THIS->Append( item, *( bitmap ), data );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__BitmapComboBox_Insert); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__BitmapComboBox_Insert)
{
    dVAR; dXSARGS;
    if (items < 1)
       croak_xs_usage(cv,  "THIS, ...");
    PERL_UNUSED_VAR(ax); /* -Wall */
    SP -= items;
    {
	wxBitmapComboBox *    THIS = (wxBitmapComboBox *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::BitmapComboBox" )
;
    BEGIN_OVERLOAD()
        MATCH_REDISP( wxPliOvl_s_wbmp_n_s, InsertData )
        MATCH_REDISP( wxPliOvl_s_wbmp_n, InsertString )
    END_OVERLOAD( Wx::BitmapComboBox::Insert )
	PUTBACK;
	return;
    }
}


XS_EUPXS(XS_Wx__BitmapComboBox_InsertString); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__BitmapComboBox_InsertString)
{
    dVAR; dXSARGS;
    if (items != 4)
       croak_xs_usage(cv,  "THIS, item, bitmap, pos");
    {
	wxBitmapComboBox *    THIS = (wxBitmapComboBox *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::BitmapComboBox" )
;
	wxString	item;
	wxBitmap*    bitmap = (wxBitmap *) wxPli_sv_2_object( aTHX_ ST(2), "Wx::Bitmap" )
;
	unsigned int    pos = (unsigned int)SvUV( ST(3) )
;

    WXSTRING_INPUT( item, wxString, ST(1) )
;
    try {
      THIS->Insert( item, *( bitmap ), pos );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__BitmapComboBox_InsertData); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__BitmapComboBox_InsertData)
{
    dVAR; dXSARGS;
    if (items != 5)
       croak_xs_usage(cv,  "THIS, item, bitmap, pos, data");
    {
	wxBitmapComboBox *    THIS = (wxBitmapComboBox *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::BitmapComboBox" )
;
	wxString	item;
	wxBitmap*    bitmap = (wxBitmap *) wxPli_sv_2_object( aTHX_ ST(2), "Wx::Bitmap" )
;
	unsigned int    pos = (unsigned int)SvUV( ST(3) )
;
	wxPliUserDataCD*	data;

    WXSTRING_INPUT( item, wxString, ST(1) )
;

    if( SvOK( ST(4) ) )
    {
        data = new wxPliUserDataCD( ST(4) );
    }
    else
        data = 0
;
    try {
      THIS->Insert( item, *( bitmap ), pos, data );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__BitmapComboBox_GetItemBitmap); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__BitmapComboBox_GetItemBitmap)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, n");
    {
	wxBitmapComboBox *    THIS = (wxBitmapComboBox *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::BitmapComboBox" )
;
	wxBitmap *	RETVAL;
	unsigned int    n = (unsigned int)SvUV( ST(1) )
;
    try {
      RETVAL = new wxBitmap( THIS->GetItemBitmap( n ) );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_object_2_sv( aTHX_ RETVALSV, RETVAL );
    wxPli_thread_sv_register( aTHX_ "Wx::Bitmap", RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__BitmapComboBox_SetItemBitmap); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__BitmapComboBox_SetItemBitmap)
{
    dVAR; dXSARGS;
    if (items != 3)
       croak_xs_usage(cv,  "THIS, n, bitmap");
    {
	wxBitmapComboBox *    THIS = (wxBitmapComboBox *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::BitmapComboBox" )
;
	unsigned int    n = (unsigned int)SvUV( ST(1) )
;
	wxBitmap*    bitmap = (wxBitmap *) wxPli_sv_2_object( aTHX_ ST(2), "Wx::Bitmap" )
;
    try {
      THIS->SetItemBitmap( n, *( bitmap ) );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__BitmapComboBox_GetBitmapSize); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__BitmapComboBox_GetBitmapSize)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxBitmapComboBox *    THIS = (wxBitmapComboBox *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::BitmapComboBox" )
;
	wxSize	RETVAL;
    try {
      RETVAL = THIS->GetBitmapSize();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_non_object_2_sv( aTHX_ RETVALSV, new wxSize(RETVAL), "Wx::Size" );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}

#endif

/* INCLUDE: Returning to 'Controls.xs' from '/usr/bin/perl -I./ -MExtUtils::XSpp::Cmd -e xspp -- -t typemap.xsp XS/BitmapComboBox.xsp' */


/* INCLUDE_COMMAND:  Including output of '/usr/bin/perl -I./ -MExtUtils::XSpp::Cmd -e xspp -- -t typemap.xsp XS/DirCtrl.xsp' from 'Controls.xs' */

#include <exception>

#undef  xsp_constructor_class
#define xsp_constructor_class(c) (c)
#include <wx/dirctrl.h>
#define wxPLI_DEFAULT_DIRCTRL_STYLE wxDIRCTRL_3D_INTERNAL|wxSUNKEN_BORDER

XS_EUPXS(XS_Wx__GenericDirCtrl_new); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__GenericDirCtrl_new)
{
    dVAR; dXSARGS;
    PERL_UNUSED_VAR(cv); /* -W */
    PERL_UNUSED_VAR(items); /* -W */
    PERL_UNUSED_VAR(ax); /* -Wall */
    SP -= items;
    {
    BEGIN_OVERLOAD()
        MATCH_VOIDM_REDISP( newDefault )
        MATCH_ANY_REDISP( newFull )
    END_OVERLOAD( "Wx::GenericDirCtrl::new" )
	PUTBACK;
	return;
    }
}

#undef  xsp_constructor_class
#define xsp_constructor_class(c) (CLASS)

XS_EUPXS(XS_Wx__GenericDirCtrl_newDefault); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__GenericDirCtrl_newDefault)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "CLASS");
    {
	char *	CLASS = (char *)SvPV_nolen(ST(0))
;
	wxGenericDirCtrl *	RETVAL;
     RETVAL = new wxGenericDirCtrl();
                wxPli_create_evthandler( aTHX_ RETVAL, CLASS );
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_evthandler_2_sv( aTHX_ RETVALSV, RETVAL );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}

#undef  xsp_constructor_class
#define xsp_constructor_class(c) (c)
#undef  xsp_constructor_class
#define xsp_constructor_class(c) (CLASS)

XS_EUPXS(XS_Wx__GenericDirCtrl_newFull); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__GenericDirCtrl_newFull)
{
    dVAR; dXSARGS;
    if (items < 2 || items > 10)
       croak_xs_usage(cv,  "CLASS, parent, id= wxID_ANY, dir= wxDirDialogDefaultFolderStr, pos= wxDefaultPosition, size= wxDefaultSize, style= wxPLI_DEFAULT_DIRCTRL_STYLE, filter= wxEmptyString, defaultFilter= 0, name= wxTreeCtrlNameStr");
    {
	char *	CLASS = (char *)SvPV_nolen(ST(0))
;
	wxGenericDirCtrl *	RETVAL;
	wxWindow*    parent = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::Window" )
;
	wxWindowID	id;
	wxString	dir;
	wxPoint	pos;
	wxSize	size;
	long	style;
	wxString	filter;
	int	defaultFilter;
	wxString	name;

	if (items < 3)
	    id = wxID_ANY;
	else {
    id = wxPli_get_wxwindowid( aTHX_ ST(2) )
;
	}

	if (items < 4)
	    dir = wxDirDialogDefaultFolderStr;
	else {
    WXSTRING_INPUT( dir, wxString, ST(3) )
;
	}

	if (items < 5)
	    pos = wxDefaultPosition;
	else {
    pos = wxPli_sv_2_wxpoint( aTHX_ ST(4) )
;
	}

	if (items < 6)
	    size = wxDefaultSize;
	else {
    size = wxPli_sv_2_wxsize( aTHX_ ST(5) )
;
	}

	if (items < 7)
	    style = wxPLI_DEFAULT_DIRCTRL_STYLE;
	else {
	    style = (long)SvIV(ST(6))
;
	}

	if (items < 8)
	    filter = wxEmptyString;
	else {
    WXSTRING_INPUT( filter, wxString, ST(7) )
;
	}

	if (items < 9)
	    defaultFilter = 0;
	else {
	    defaultFilter = (int)SvIV(ST(8))
;
	}

	if (items < 10)
	    name = wxTreeCtrlNameStr;
	else {
    WXSTRING_INPUT( name, wxString, ST(9) )
;
	}
     RETVAL = new wxGenericDirCtrl( parent, id, dir, pos, size,
                                               style, filter, defaultFilter,
                                               name );
                wxPli_create_evthandler( aTHX_ RETVAL, CLASS );
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_evthandler_2_sv( aTHX_ RETVALSV, RETVAL );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}

#undef  xsp_constructor_class
#define xsp_constructor_class(c) (c)

XS_EUPXS(XS_Wx__GenericDirCtrl_Create); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__GenericDirCtrl_Create)
{
    dVAR; dXSARGS;
    if (items < 2 || items > 10)
       croak_xs_usage(cv,  "THIS, parent, id= wxID_ANY, dir= wxDirDialogDefaultFolderStr, pos= wxDefaultPosition, size= wxDefaultSize, style= wxPLI_DEFAULT_DIRCTRL_STYLE, filter= wxEmptyString, defaultFilter= 0, name= wxTreeCtrlNameStr");
    {
	wxGenericDirCtrl *    THIS = (wxGenericDirCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::GenericDirCtrl" )
;
	bool	RETVAL;
	wxWindow*    parent = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::Window" )
;
	wxWindowID	id;
	wxString	dir;
	wxPoint	pos;
	wxSize	size;
	long	style;
	wxString	filter;
	int	defaultFilter;
	wxString	name;

	if (items < 3)
	    id = wxID_ANY;
	else {
    id = wxPli_get_wxwindowid( aTHX_ ST(2) )
;
	}

	if (items < 4)
	    dir = wxDirDialogDefaultFolderStr;
	else {
    WXSTRING_INPUT( dir, wxString, ST(3) )
;
	}

	if (items < 5)
	    pos = wxDefaultPosition;
	else {
    pos = wxPli_sv_2_wxpoint( aTHX_ ST(4) )
;
	}

	if (items < 6)
	    size = wxDefaultSize;
	else {
    size = wxPli_sv_2_wxsize( aTHX_ ST(5) )
;
	}

	if (items < 7)
	    style = wxPLI_DEFAULT_DIRCTRL_STYLE;
	else {
	    style = (long)SvIV(ST(6))
;
	}

	if (items < 8)
	    filter = wxEmptyString;
	else {
    WXSTRING_INPUT( filter, wxString, ST(7) )
;
	}

	if (items < 9)
	    defaultFilter = 0;
	else {
	    defaultFilter = (int)SvIV(ST(8))
;
	}

	if (items < 10)
	    name = wxTreeCtrlNameStr;
	else {
    WXSTRING_INPUT( name, wxString, ST(9) )
;
	}
    try {
      RETVAL = THIS->Create( parent, id, dir, pos, size, style, filter, defaultFilter, name );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__GenericDirCtrl_ExpandPath); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__GenericDirCtrl_ExpandPath)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, path");
    {
	wxGenericDirCtrl *    THIS = (wxGenericDirCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::GenericDirCtrl" )
;
	bool	RETVAL;
	wxString	path;

    WXSTRING_INPUT( path, wxString, ST(1) )
;
    try {
      RETVAL = THIS->ExpandPath( path );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}

#if WXPERL_W_VERSION_GE( 2, 9, 0 )
#define XSpp_9e399684_083075
#define XSubPPtmpAABT 1


XS_EUPXS(XS_Wx__GenericDirCtrl_CollapsePath); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__GenericDirCtrl_CollapsePath)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, path");
    {
	wxGenericDirCtrl *    THIS = (wxGenericDirCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::GenericDirCtrl" )
;
	bool	RETVAL;
	wxString	path;

    WXSTRING_INPUT( path, wxString, ST(1) )
;
    try {
      RETVAL = THIS->CollapsePath( path );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}

#endif

XS_EUPXS(XS_Wx__GenericDirCtrl_GetDefaultPath); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__GenericDirCtrl_GetDefaultPath)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxGenericDirCtrl *    THIS = (wxGenericDirCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::GenericDirCtrl" )
;
	wxString	RETVAL;
    try {
      RETVAL = THIS->GetDefaultPath();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    WXSTRING_OUTPUT( RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__GenericDirCtrl_SetDefaultPath); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__GenericDirCtrl_SetDefaultPath)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, path");
    {
	wxGenericDirCtrl *    THIS = (wxGenericDirCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::GenericDirCtrl" )
;
	wxString	path;

    WXSTRING_INPUT( path, wxString, ST(1) )
;
    try {
      THIS->SetDefaultPath( path );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__GenericDirCtrl_GetPath); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__GenericDirCtrl_GetPath)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxGenericDirCtrl *    THIS = (wxGenericDirCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::GenericDirCtrl" )
;
	wxString	RETVAL;
    try {
      RETVAL = THIS->GetPath();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    WXSTRING_OUTPUT( RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__GenericDirCtrl_GetFilePath); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__GenericDirCtrl_GetFilePath)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxGenericDirCtrl *    THIS = (wxGenericDirCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::GenericDirCtrl" )
;
	wxString	RETVAL;
    try {
      RETVAL = THIS->GetFilePath();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    WXSTRING_OUTPUT( RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__GenericDirCtrl_SetPath); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__GenericDirCtrl_SetPath)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, path");
    {
	wxGenericDirCtrl *    THIS = (wxGenericDirCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::GenericDirCtrl" )
;
	wxString	path;

    WXSTRING_INPUT( path, wxString, ST(1) )
;
    try {
      THIS->SetPath( path );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__GenericDirCtrl_ShowHidden); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__GenericDirCtrl_ShowHidden)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, show");
    {
	wxGenericDirCtrl *    THIS = (wxGenericDirCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::GenericDirCtrl" )
;
	bool	show = (bool)SvTRUE(ST(1))
;
    try {
      THIS->ShowHidden( show );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__GenericDirCtrl_GetShowHidden); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__GenericDirCtrl_GetShowHidden)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxGenericDirCtrl *    THIS = (wxGenericDirCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::GenericDirCtrl" )
;
	bool	RETVAL;
    try {
      RETVAL = THIS->GetShowHidden();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__GenericDirCtrl_GetFilter); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__GenericDirCtrl_GetFilter)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxGenericDirCtrl *    THIS = (wxGenericDirCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::GenericDirCtrl" )
;
	wxString	RETVAL;
    try {
      RETVAL = THIS->GetFilter();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    WXSTRING_OUTPUT( RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__GenericDirCtrl_SetFilter); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__GenericDirCtrl_SetFilter)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, filter");
    {
	wxGenericDirCtrl *    THIS = (wxGenericDirCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::GenericDirCtrl" )
;
	wxString	filter;

    WXSTRING_INPUT( filter, wxString, ST(1) )
;
    try {
      THIS->SetFilter( filter );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__GenericDirCtrl_GetFilterIndex); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__GenericDirCtrl_GetFilterIndex)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxGenericDirCtrl *    THIS = (wxGenericDirCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::GenericDirCtrl" )
;
	int	RETVAL;
	dXSTARG;
    try {
      RETVAL = THIS->GetFilterIndex();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__GenericDirCtrl_SetFilterIndex); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__GenericDirCtrl_SetFilterIndex)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, n");
    {
	wxGenericDirCtrl *    THIS = (wxGenericDirCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::GenericDirCtrl" )
;
	int	n = (int)SvIV(ST(1))
;
    try {
      THIS->SetFilterIndex( n );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__GenericDirCtrl_GetRootId); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__GenericDirCtrl_GetRootId)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxGenericDirCtrl *    THIS = (wxGenericDirCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::GenericDirCtrl" )
;
	wxTreeItemId *	RETVAL;
    try {
      RETVAL = new wxTreeItemId( THIS->GetRootId() );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_non_object_2_sv( aTHX_ RETVALSV, RETVAL, "Wx::TreeItemId" );
    wxPli_thread_sv_register( aTHX_ "Wx::TreeItemId", RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__GenericDirCtrl_GetTreeCtrl); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__GenericDirCtrl_GetTreeCtrl)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxGenericDirCtrl *    THIS = (wxGenericDirCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::GenericDirCtrl" )
;
	wxTreeCtrl *	RETVAL;
    try {
      RETVAL = THIS->GetTreeCtrl();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_object_2_sv( aTHX_ RETVALSV, RETVAL );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__GenericDirCtrl_GetFilterListCtrl); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__GenericDirCtrl_GetFilterListCtrl)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxGenericDirCtrl *    THIS = (wxGenericDirCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::GenericDirCtrl" )
;
	wxDirFilterListCtrl *	RETVAL;
    try {
      RETVAL = THIS->GetFilterListCtrl();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_evthandler_2_sv( aTHX_ RETVALSV, RETVAL );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__GenericDirCtrl_ReCreateTree); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__GenericDirCtrl_ReCreateTree)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxGenericDirCtrl *    THIS = (wxGenericDirCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::GenericDirCtrl" )
;
    try {
      THIS->ReCreateTree();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}

#if WXPERL_W_VERSION_GE( 2, 6, 0 )
#define XSpp_9e399684_012025
#define XSubPPtmpAABU 1


XS_EUPXS(XS_Wx__GenericDirCtrl_CollapseTree); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__GenericDirCtrl_CollapseTree)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxGenericDirCtrl *    THIS = (wxGenericDirCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::GenericDirCtrl" )
;
    try {
      THIS->CollapseTree();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}

#endif

/* INCLUDE: Returning to 'Controls.xs' from '/usr/bin/perl -I./ -MExtUtils::XSpp::Cmd -e xspp -- -t typemap.xsp XS/DirCtrl.xsp' */


/* INCLUDE_COMMAND:  Including output of '/usr/bin/perl -I./ -MExtUtils::XSpp::Cmd -e xspp -- -t typemap.xsp XS/FileCtrl.xsp' from 'Controls.xs' */

#include <exception>

#undef  xsp_constructor_class
#define xsp_constructor_class(c) (c)
#if WXPERL_W_VERSION_GE( 2, 9, 0 )
#define XSpp_db4a2361_047514
#include <wx/filectrl.h>
#define XSubPPtmpAABV 1


XS_EUPXS(XS_Wx__FileCtrl_new); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__FileCtrl_new)
{
    dVAR; dXSARGS;
    PERL_UNUSED_VAR(cv); /* -W */
    PERL_UNUSED_VAR(items); /* -W */
    PERL_UNUSED_VAR(ax); /* -Wall */
    SP -= items;
    {
    BEGIN_OVERLOAD()
        MATCH_VOIDM_REDISP( newDefault )
        MATCH_ANY_REDISP( newFull )
    END_OVERLOAD( "Wx::FileCtrl::new" )
	PUTBACK;
	return;
    }
}

#undef  xsp_constructor_class
#define xsp_constructor_class(c) (CLASS)

XS_EUPXS(XS_Wx__FileCtrl_newDefault); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__FileCtrl_newDefault)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "CLASS");
    {
	char *	CLASS = (char *)SvPV_nolen(ST(0))
;
	wxFileCtrl *	RETVAL;
     RETVAL = new wxFileCtrl();
                wxPli_create_evthandler( aTHX_ RETVAL, CLASS );
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_evthandler_2_sv( aTHX_ RETVALSV, RETVAL );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}

#undef  xsp_constructor_class
#define xsp_constructor_class(c) (c)
#undef  xsp_constructor_class
#define xsp_constructor_class(c) (CLASS)

XS_EUPXS(XS_Wx__FileCtrl_newFull); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__FileCtrl_newFull)
{
    dVAR; dXSARGS;
    if (items < 2 || items > 10)
       croak_xs_usage(cv,  "CLASS, parent, id= wxID_ANY, defaultDirectory= wxEmptyString, defaultFilename= wxEmptyString, wildCard= wxFileSelectorDefaultWildcardStr, style= wxFC_DEFAULT_STYLE, pos= wxDefaultPosition, size= wxDefaultSize, name= wxFileCtrlNameStr");
    {
	char *	CLASS = (char *)SvPV_nolen(ST(0))
;
	wxFileCtrl *	RETVAL;
	wxWindow*    parent = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::Window" )
;
	wxWindowID	id;
	wxString	defaultDirectory;
	wxString	defaultFilename;
	wxString	wildCard;
	long	style;
	wxPoint	pos;
	wxSize	size;
	wxString	name;

	if (items < 3)
	    id = wxID_ANY;
	else {
    id = wxPli_get_wxwindowid( aTHX_ ST(2) )
;
	}

	if (items < 4)
	    defaultDirectory = wxEmptyString;
	else {
    WXSTRING_INPUT( defaultDirectory, wxString, ST(3) )
;
	}

	if (items < 5)
	    defaultFilename = wxEmptyString;
	else {
    WXSTRING_INPUT( defaultFilename, wxString, ST(4) )
;
	}

	if (items < 6)
	    wildCard = wxFileSelectorDefaultWildcardStr;
	else {
    WXSTRING_INPUT( wildCard, wxString, ST(5) )
;
	}

	if (items < 7)
	    style = wxFC_DEFAULT_STYLE;
	else {
	    style = (long)SvIV(ST(6))
;
	}

	if (items < 8)
	    pos = wxDefaultPosition;
	else {
    pos = wxPli_sv_2_wxpoint( aTHX_ ST(7) )
;
	}

	if (items < 9)
	    size = wxDefaultSize;
	else {
    size = wxPli_sv_2_wxsize( aTHX_ ST(8) )
;
	}

	if (items < 10)
	    name = wxFileCtrlNameStr;
	else {
    WXSTRING_INPUT( name, wxString, ST(9) )
;
	}
     RETVAL = new wxFileCtrl( parent, id, defaultDirectory,
                                         defaultFilename, wildCard, style,
                                         pos, size, name );
                wxPli_create_evthandler( aTHX_ RETVAL, CLASS );
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_evthandler_2_sv( aTHX_ RETVALSV, RETVAL );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}

#undef  xsp_constructor_class
#define xsp_constructor_class(c) (c)

XS_EUPXS(XS_Wx__FileCtrl_Create); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__FileCtrl_Create)
{
    dVAR; dXSARGS;
    if (items < 2 || items > 10)
       croak_xs_usage(cv,  "THIS, parent, id= wxID_ANY, defaultDirectory= wxEmptyString, defaultFilename= wxEmptyString, wildCard= wxFileSelectorDefaultWildcardStr, style= wxFC_DEFAULT_STYLE, pos= wxDefaultPosition, size= wxDefaultSize, name= wxFileCtrlNameStr");
    {
	wxFileCtrl *    THIS = (wxFileCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::FileCtrl" )
;
	bool	RETVAL;
	wxWindow*    parent = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::Window" )
;
	wxWindowID	id;
	wxString	defaultDirectory;
	wxString	defaultFilename;
	wxString	wildCard;
	long	style;
	wxPoint	pos;
	wxSize	size;
	wxString	name;

	if (items < 3)
	    id = wxID_ANY;
	else {
    id = wxPli_get_wxwindowid( aTHX_ ST(2) )
;
	}

	if (items < 4)
	    defaultDirectory = wxEmptyString;
	else {
    WXSTRING_INPUT( defaultDirectory, wxString, ST(3) )
;
	}

	if (items < 5)
	    defaultFilename = wxEmptyString;
	else {
    WXSTRING_INPUT( defaultFilename, wxString, ST(4) )
;
	}

	if (items < 6)
	    wildCard = wxFileSelectorDefaultWildcardStr;
	else {
    WXSTRING_INPUT( wildCard, wxString, ST(5) )
;
	}

	if (items < 7)
	    style = wxFC_DEFAULT_STYLE;
	else {
	    style = (long)SvIV(ST(6))
;
	}

	if (items < 8)
	    pos = wxDefaultPosition;
	else {
    pos = wxPli_sv_2_wxpoint( aTHX_ ST(7) )
;
	}

	if (items < 9)
	    size = wxDefaultSize;
	else {
    size = wxPli_sv_2_wxsize( aTHX_ ST(8) )
;
	}

	if (items < 10)
	    name = wxFileCtrlNameStr;
	else {
    WXSTRING_INPUT( name, wxString, ST(9) )
;
	}
    try {
      RETVAL = THIS->Create( parent, id, defaultDirectory, defaultFilename, wildCard, style, pos, size, name );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__FileCtrl_SetWildcard); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__FileCtrl_SetWildcard)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, wildCard");
    {
	wxFileCtrl *    THIS = (wxFileCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::FileCtrl" )
;
	wxString	wildCard;

    WXSTRING_INPUT( wildCard, wxString, ST(1) )
;
    try {
      THIS->SetWildcard( wildCard );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__FileCtrl_SetFilterIndex); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__FileCtrl_SetFilterIndex)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, filterindex");
    {
	wxFileCtrl *    THIS = (wxFileCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::FileCtrl" )
;
	int	filterindex = (int)SvIV(ST(1))
;
    try {
      THIS->SetFilterIndex( filterindex );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__FileCtrl_SetDirectory); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__FileCtrl_SetDirectory)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, dir");
    {
	wxFileCtrl *    THIS = (wxFileCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::FileCtrl" )
;
	bool	RETVAL;
	wxString	dir;

    WXSTRING_INPUT( dir, wxString, ST(1) )
;
    try {
      RETVAL = THIS->SetDirectory( dir );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__FileCtrl_SetFilename); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__FileCtrl_SetFilename)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, name");
    {
	wxFileCtrl *    THIS = (wxFileCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::FileCtrl" )
;
	bool	RETVAL;
	wxString	name;

    WXSTRING_INPUT( name, wxString, ST(1) )
;
    try {
      RETVAL = THIS->SetFilename( name );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__FileCtrl_SetPath); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__FileCtrl_SetPath)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, path");
    {
	wxFileCtrl *    THIS = (wxFileCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::FileCtrl" )
;
	bool	RETVAL;
	wxString	path;

    WXSTRING_INPUT( path, wxString, ST(1) )
;
    try {
      RETVAL = THIS->SetPath( path );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__FileCtrl_GetFilename); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__FileCtrl_GetFilename)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxFileCtrl *    THIS = (wxFileCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::FileCtrl" )
;
	wxString	RETVAL;
    try {
      RETVAL = THIS->GetFilename();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    WXSTRING_OUTPUT( RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__FileCtrl_GetDirectory); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__FileCtrl_GetDirectory)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxFileCtrl *    THIS = (wxFileCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::FileCtrl" )
;
	wxString	RETVAL;
    try {
      RETVAL = THIS->GetDirectory();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    WXSTRING_OUTPUT( RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__FileCtrl_GetWildcard); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__FileCtrl_GetWildcard)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxFileCtrl *    THIS = (wxFileCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::FileCtrl" )
;
	wxString	RETVAL;
    try {
      RETVAL = THIS->GetWildcard();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    WXSTRING_OUTPUT( RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__FileCtrl_GetPath); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__FileCtrl_GetPath)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxFileCtrl *    THIS = (wxFileCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::FileCtrl" )
;
	wxString	RETVAL;
    try {
      RETVAL = THIS->GetPath();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    WXSTRING_OUTPUT( RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__FileCtrl_GetPaths); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__FileCtrl_GetPaths)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    PERL_UNUSED_VAR(ax); /* -Wall */
    SP -= items;
    {
	wxFileCtrl *    THIS = (wxFileCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::FileCtrl" )
;
    PUTBACK;
    wxArrayString ret;
    THIS->GetPaths( ret );
    wxPli_stringarray_push( aTHX_ ret );
    SPAGAIN;
	PUTBACK;
	return;
    }
}


XS_EUPXS(XS_Wx__FileCtrl_GetFilenames); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__FileCtrl_GetFilenames)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    PERL_UNUSED_VAR(ax); /* -Wall */
    SP -= items;
    {
	wxFileCtrl *    THIS = (wxFileCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::FileCtrl" )
;
    PUTBACK;
    wxArrayString ret;
    THIS->GetFilenames( ret );
    wxPli_stringarray_push( aTHX_ ret );
    SPAGAIN;
	PUTBACK;
	return;
    }
}


XS_EUPXS(XS_Wx__FileCtrl_GetFilterIndex); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__FileCtrl_GetFilterIndex)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxFileCtrl *    THIS = (wxFileCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::FileCtrl" )
;
	int	RETVAL;
	dXSTARG;
    try {
      RETVAL = THIS->GetFilterIndex();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__FileCtrl_HasMultipleFileSelection); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__FileCtrl_HasMultipleFileSelection)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxFileCtrl *    THIS = (wxFileCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::FileCtrl" )
;
	bool	RETVAL;
    try {
      RETVAL = THIS->HasMultipleFileSelection();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__FileCtrl_ShowHidden); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__FileCtrl_ShowHidden)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, show");
    {
	wxFileCtrl *    THIS = (wxFileCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::FileCtrl" )
;
	bool	show = (bool)SvTRUE(ST(1))
;
    try {
      THIS->ShowHidden( show );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__FileCtrlEvent_SetFiles); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__FileCtrlEvent_SetFiles)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, files");
    {
	wxFileCtrlEvent *    THIS = (wxFileCtrlEvent *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::FileCtrlEvent" )
;
	wxArrayString	files;

    wxPli_av_2_arraystring( aTHX_ ST(1), & files )
;
    try {
      THIS->SetFiles( files );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__FileCtrlEvent_SetDirectory); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__FileCtrlEvent_SetDirectory)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, directory");
    {
	wxFileCtrlEvent *    THIS = (wxFileCtrlEvent *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::FileCtrlEvent" )
;
	wxString	directory;

    WXSTRING_INPUT( directory, wxString, ST(1) )
;
    try {
      THIS->SetDirectory( directory );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__FileCtrlEvent_GetFiles); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__FileCtrlEvent_GetFiles)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    PERL_UNUSED_VAR(ax); /* -Wall */
    SP -= items;
    {
	wxFileCtrlEvent *    THIS = (wxFileCtrlEvent *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::FileCtrlEvent" )
;
    PUTBACK;
    wxPli_stringarray_push( aTHX_ THIS->GetFiles() );
    SPAGAIN;
	PUTBACK;
	return;
    }
}


XS_EUPXS(XS_Wx__FileCtrlEvent_GetDirectory); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__FileCtrlEvent_GetDirectory)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxFileCtrlEvent *    THIS = (wxFileCtrlEvent *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::FileCtrlEvent" )
;
	wxString	RETVAL;
    try {
      RETVAL = THIS->GetDirectory();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    WXSTRING_OUTPUT( RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__FileCtrlEvent_GetFile); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__FileCtrlEvent_GetFile)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxFileCtrlEvent *    THIS = (wxFileCtrlEvent *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::FileCtrlEvent" )
;
	wxString	RETVAL;
    try {
      RETVAL = THIS->GetFile();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    WXSTRING_OUTPUT( RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}

#endif

/* INCLUDE: Returning to 'Controls.xs' from '/usr/bin/perl -I./ -MExtUtils::XSpp::Cmd -e xspp -- -t typemap.xsp XS/FileCtrl.xsp' */


/* INCLUDE_COMMAND:  Including output of '/usr/bin/perl -I./ -MExtUtils::XSpp::Cmd -e xspp -- -t typemap.xsp interface/wx/generic/spinctrg.h' from 'Controls.xs' */

#include <exception>

#undef  xsp_constructor_class
#define xsp_constructor_class(c) (c)
#if WXPERL_W_VERSION_GE( 2, 9, 0 )
#define XSpp_bf682a9f_068242
#include <wx/spinctrl.h>
#undef  xsp_constructor_class
#define xsp_constructor_class(c) (CLASS)
#define XSubPPtmpAABW 1


XS_EUPXS(XS_Wx__SpinCtrlDouble_wxSpinCtrlDouble0); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__SpinCtrlDouble_wxSpinCtrlDouble0)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "CLASS");
    {
	char *	CLASS = (char *)SvPV_nolen(ST(0))
;
	wxSpinCtrlDouble *	RETVAL;
    try {
      RETVAL = new wxSpinCtrlDouble();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
     wxPli_create_evthandler( aTHX_ RETVAL, CLASS ); 
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_evthandler_2_sv( aTHX_ RETVALSV, RETVAL );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}

#undef  xsp_constructor_class
#define xsp_constructor_class(c) (c)
#undef  xsp_constructor_class
#define xsp_constructor_class(c) (CLASS)

XS_EUPXS(XS_Wx__SpinCtrlDouble_wxSpinCtrlDouble1); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__SpinCtrlDouble_wxSpinCtrlDouble1)
{
    dVAR; dXSARGS;
    if (items < 2 || items > 12)
       croak_xs_usage(cv,  "CLASS, parent, id= -1, value= wxEmptyString, pos= wxDefaultPosition, size= wxDefaultSize, style= wxSP_ARROW_KEYS, min= 0, max= 100, initial= 0, inc= 1, name= _T(\"wxSpinCtrlDouble\")");
    {
	char *	CLASS = (char *)SvPV_nolen(ST(0))
;
	wxSpinCtrlDouble *	RETVAL;
	wxWindow*    parent = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::Window" )
;
	wxWindowID	id;
	wxString	value;
	wxPoint	pos;
	wxSize	size;
	long	style;
	double	min;
	double	max;
	double	initial;
	double	inc;
	wxString	name;

	if (items < 3)
	    id = -1;
	else {
    id = wxPli_get_wxwindowid( aTHX_ ST(2) )
;
	}

	if (items < 4)
	    value = wxEmptyString;
	else {
    WXSTRING_INPUT( value, wxString, ST(3) )
;
	}

	if (items < 5)
	    pos = wxDefaultPosition;
	else {
    pos = wxPli_sv_2_wxpoint( aTHX_ ST(4) )
;
	}

	if (items < 6)
	    size = wxDefaultSize;
	else {
    size = wxPli_sv_2_wxsize( aTHX_ ST(5) )
;
	}

	if (items < 7)
	    style = wxSP_ARROW_KEYS;
	else {
	    style = (long)SvIV(ST(6))
;
	}

	if (items < 8)
	    min = 0;
	else {
	    min = (double)SvNV(ST(7))
;
	}

	if (items < 9)
	    max = 100;
	else {
	    max = (double)SvNV(ST(8))
;
	}

	if (items < 10)
	    initial = 0;
	else {
	    initial = (double)SvNV(ST(9))
;
	}

	if (items < 11)
	    inc = 1;
	else {
	    inc = (double)SvNV(ST(10))
;
	}

	if (items < 12)
	    name = _T("wxSpinCtrlDouble");
	else {
    WXSTRING_INPUT( name, wxString, ST(11) )
;
	}
    try {
      RETVAL = new wxSpinCtrlDouble( parent, id, value, pos, size, style, min, max, initial, inc, name );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
     wxPli_create_evthandler( aTHX_ RETVAL, CLASS ); 
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_evthandler_2_sv( aTHX_ RETVALSV, RETVAL );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}

#undef  xsp_constructor_class
#define xsp_constructor_class(c) (c)

XS_EUPXS(XS_Wx__SpinCtrlDouble_Create); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__SpinCtrlDouble_Create)
{
    dVAR; dXSARGS;
    if (items < 2 || items > 12)
       croak_xs_usage(cv,  "THIS, parent, id= wxID_ANY, value= wxEmptyString, pos= wxDefaultPosition, size= wxDefaultSize, style= wxSP_ARROW_KEYS, min= 0, max= 100, initial= 0, inc= 1, name= \"wxSpinCtrlDouble\"");
    {
	wxSpinCtrlDouble *    THIS = (wxSpinCtrlDouble *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::SpinCtrlDouble" )
;
	bool	RETVAL;
	wxWindow*    parent = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::Window" )
;
	wxWindowID	id;
	wxString	value;
	wxPoint	pos;
	wxSize	size;
	long	style;
	double	min;
	double	max;
	double	initial;
	double	inc;
	wxString	name;

	if (items < 3)
	    id = wxID_ANY;
	else {
    id = wxPli_get_wxwindowid( aTHX_ ST(2) )
;
	}

	if (items < 4)
	    value = wxEmptyString;
	else {
    WXSTRING_INPUT( value, wxString, ST(3) )
;
	}

	if (items < 5)
	    pos = wxDefaultPosition;
	else {
    pos = wxPli_sv_2_wxpoint( aTHX_ ST(4) )
;
	}

	if (items < 6)
	    size = wxDefaultSize;
	else {
    size = wxPli_sv_2_wxsize( aTHX_ ST(5) )
;
	}

	if (items < 7)
	    style = wxSP_ARROW_KEYS;
	else {
	    style = (long)SvIV(ST(6))
;
	}

	if (items < 8)
	    min = 0;
	else {
	    min = (double)SvNV(ST(7))
;
	}

	if (items < 9)
	    max = 100;
	else {
	    max = (double)SvNV(ST(8))
;
	}

	if (items < 10)
	    initial = 0;
	else {
	    initial = (double)SvNV(ST(9))
;
	}

	if (items < 11)
	    inc = 1;
	else {
	    inc = (double)SvNV(ST(10))
;
	}

	if (items < 12)
	    name = "wxSpinCtrlDouble";
	else {
    WXSTRING_INPUT( name, wxString, ST(11) )
;
	}
    try {
      RETVAL = THIS->Create( parent, id, value, pos, size, style, min, max, initial, inc, name );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__SpinCtrlDouble_GetDigits); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__SpinCtrlDouble_GetDigits)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxSpinCtrlDouble *    THIS = (wxSpinCtrlDouble *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::SpinCtrlDouble" )
;
	unsigned int	RETVAL;
	dXSTARG;
    try {
      RETVAL = THIS->GetDigits();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	XSprePUSH;
	PUSHu((UV)RETVAL );
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__SpinCtrlDouble_GetIncrement); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__SpinCtrlDouble_GetIncrement)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxSpinCtrlDouble *    THIS = (wxSpinCtrlDouble *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::SpinCtrlDouble" )
;
	double	RETVAL;
	dXSTARG;
    try {
      RETVAL = THIS->GetIncrement();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	XSprePUSH;
	PUSHn((double)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__SpinCtrlDouble_GetMax); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__SpinCtrlDouble_GetMax)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxSpinCtrlDouble *    THIS = (wxSpinCtrlDouble *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::SpinCtrlDouble" )
;
	double	RETVAL;
	dXSTARG;
    try {
      RETVAL = THIS->GetMax();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	XSprePUSH;
	PUSHn((double)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__SpinCtrlDouble_GetMin); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__SpinCtrlDouble_GetMin)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxSpinCtrlDouble *    THIS = (wxSpinCtrlDouble *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::SpinCtrlDouble" )
;
	double	RETVAL;
	dXSTARG;
    try {
      RETVAL = THIS->GetMin();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	XSprePUSH;
	PUSHn((double)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__SpinCtrlDouble_GetValue); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__SpinCtrlDouble_GetValue)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxSpinCtrlDouble *    THIS = (wxSpinCtrlDouble *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::SpinCtrlDouble" )
;
	double	RETVAL;
	dXSTARG;
    try {
      RETVAL = THIS->GetValue();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	XSprePUSH;
	PUSHn((double)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__SpinCtrlDouble_SetDigits); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__SpinCtrlDouble_SetDigits)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, digits");
    {
	wxSpinCtrlDouble *    THIS = (wxSpinCtrlDouble *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::SpinCtrlDouble" )
;
	unsigned int    digits = (unsigned int)SvUV( ST(1) )
;
    try {
      THIS->SetDigits( digits );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__SpinCtrlDouble_SetIncrement); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__SpinCtrlDouble_SetIncrement)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, inc");
    {
	wxSpinCtrlDouble *    THIS = (wxSpinCtrlDouble *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::SpinCtrlDouble" )
;
	double	inc = (double)SvNV(ST(1))
;
    try {
      THIS->SetIncrement( inc );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__SpinCtrlDouble_SetRange); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__SpinCtrlDouble_SetRange)
{
    dVAR; dXSARGS;
    if (items != 3)
       croak_xs_usage(cv,  "THIS, minVal, maxVal");
    {
	wxSpinCtrlDouble *    THIS = (wxSpinCtrlDouble *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::SpinCtrlDouble" )
;
	double	minVal = (double)SvNV(ST(1))
;
	double	maxVal = (double)SvNV(ST(2))
;
    try {
      THIS->SetRange( minVal, maxVal );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__SpinCtrlDouble_SetValue0); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__SpinCtrlDouble_SetValue0)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, text");
    {
	wxSpinCtrlDouble *    THIS = (wxSpinCtrlDouble *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::SpinCtrlDouble" )
;
	wxString	text;

    WXSTRING_INPUT( text, wxString, ST(1) )
;
    try {
      THIS->SetValue( text );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__SpinCtrlDouble_SetValue1); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__SpinCtrlDouble_SetValue1)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, value");
    {
	wxSpinCtrlDouble *    THIS = (wxSpinCtrlDouble *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::SpinCtrlDouble" )
;
	double	value = (double)SvNV(ST(1))
;
    try {
      THIS->SetValue( value );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}

#include "cpp/overload.h"
#if defined( XSpp_bf682a9f_068242 )
#define XSubPPtmpAABX 1


XS_EUPXS(XS_Wx__SpinCtrlDouble_new); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__SpinCtrlDouble_new)
{
    dVAR; dXSARGS;
    if (items < 1)
       croak_xs_usage(cv,  "CLASS, ...");
    PERL_UNUSED_VAR(ax); /* -Wall */
    SP -= items;
    {
	char *	CLASS = (char *)SvPV_nolen(ST(0))
;
#if defined( XSpp_bf682a9f_068242 )
    static wxPliPrototype void_proto( NULL, 0 );
#endif // defined( XSpp_bf682a9f_068242 )
    static wxPliPrototype *wxPliOvl_all_prototypes[] = {
#if defined( XSpp_bf682a9f_068242 )
        &void_proto,
#endif // defined( XSpp_bf682a9f_068242 )
        NULL };
    BEGIN_OVERLOAD()
#if defined( XSpp_bf682a9f_068242 )
        MATCH_VOIDM_REDISP( wxSpinCtrlDouble0 )
#endif // defined( XSpp_bf682a9f_068242 )
#if defined( XSpp_bf682a9f_068242 )
        MATCH_ANY_REDISP( wxSpinCtrlDouble1 )
#endif // defined( XSpp_bf682a9f_068242 )
    END_OVERLOAD_MESSAGE( Wx::SpinCtrlDouble::new, wxPliOvl_all_prototypes )
	PUTBACK;
	return;
    }
}

#endif // defined( XSpp_bf682a9f_068242 )
#if defined( XSpp_bf682a9f_068242 )
#define XSubPPtmpAABY 1


XS_EUPXS(XS_Wx__SpinCtrlDouble_SetValue); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__SpinCtrlDouble_SetValue)
{
    dVAR; dXSARGS;
    if (items < 1)
       croak_xs_usage(cv,  "THIS, ...");
    PERL_UNUSED_VAR(ax); /* -Wall */
    SP -= items;
    {
	wxSpinCtrlDouble *    THIS = (wxSpinCtrlDouble *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::SpinCtrlDouble" )
;
#if defined( XSpp_bf682a9f_068242 )
    static const char *SetValue0_types[] = { wxPliOvlstr };
    static wxPliPrototype SetValue0_proto( SetValue0_types, sizeof( SetValue0_types ) / sizeof( SetValue0_types[0] ) );
#endif // defined( XSpp_bf682a9f_068242 )
#if defined( XSpp_bf682a9f_068242 )
    static const char *SetValue1_types[] = { wxPliOvlnum };
    static wxPliPrototype SetValue1_proto( SetValue1_types, sizeof( SetValue1_types ) / sizeof( SetValue1_types[0] ) );
#endif // defined( XSpp_bf682a9f_068242 )
    static wxPliPrototype *wxPliOvl_all_prototypes[] = {
#if defined( XSpp_bf682a9f_068242 )
        &SetValue0_proto,
#endif // defined( XSpp_bf682a9f_068242 )
#if defined( XSpp_bf682a9f_068242 )
        &SetValue1_proto,
#endif // defined( XSpp_bf682a9f_068242 )
        NULL };
    BEGIN_OVERLOAD()
#if defined( XSpp_bf682a9f_068242 )
        MATCH_REDISP_COUNT( SetValue0_proto, SetValue0, 1 )
#endif // defined( XSpp_bf682a9f_068242 )
#if defined( XSpp_bf682a9f_068242 )
        MATCH_REDISP_COUNT( SetValue1_proto, SetValue1, 1 )
#endif // defined( XSpp_bf682a9f_068242 )
    END_OVERLOAD_MESSAGE( Wx::SpinCtrlDouble::SetValue, wxPliOvl_all_prototypes )
	PUTBACK;
	return;
    }
}

#endif // defined( XSpp_bf682a9f_068242 )
#endif

/* INCLUDE: Returning to 'Controls.xs' from '/usr/bin/perl -I./ -MExtUtils::XSpp::Cmd -e xspp -- -t typemap.xsp interface/wx/generic/spinctrg.h' */


/* INCLUDE_COMMAND:  Including output of '/usr/bin/perl -I./ -MExtUtils::XSpp::Cmd -e xspp -- -t typemap.xsp interface/wx/infobar.h' from 'Controls.xs' */

#include <exception>

#undef  xsp_constructor_class
#define xsp_constructor_class(c) (c)
#if WXPERL_W_VERSION_GE( 2, 9, 1 )
#define XSpp_622a4aee_084652
#include <wx/infobar.h>
#undef  xsp_constructor_class
#define xsp_constructor_class(c) (CLASS)
#define XSubPPtmpAABZ 1


XS_EUPXS(XS_Wx__InfoBar_wxInfoBar0); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__InfoBar_wxInfoBar0)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "CLASS");
    {
	char *	CLASS = (char *)SvPV_nolen(ST(0))
;
	wxInfoBar *	RETVAL;
    try {
      RETVAL = new wxInfoBar();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
     wxPli_create_evthandler( aTHX_ RETVAL, CLASS ); 
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_evthandler_2_sv( aTHX_ RETVALSV, RETVAL );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}

#undef  xsp_constructor_class
#define xsp_constructor_class(c) (c)
#undef  xsp_constructor_class
#define xsp_constructor_class(c) (CLASS)

XS_EUPXS(XS_Wx__InfoBar_wxInfoBar1); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__InfoBar_wxInfoBar1)
{
    dVAR; dXSARGS;
    if (items < 2 || items > 3)
       croak_xs_usage(cv,  "CLASS, parent, winid= wxID_ANY");
    {
	char *	CLASS = (char *)SvPV_nolen(ST(0))
;
	wxInfoBar *	RETVAL;
	wxWindow*    parent = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::Window" )
;
	wxWindowID	winid;

	if (items < 3)
	    winid = wxID_ANY;
	else {
    winid = wxPli_get_wxwindowid( aTHX_ ST(2) )
;
	}
    try {
      RETVAL = new wxInfoBar( parent, winid );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
     wxPli_create_evthandler( aTHX_ RETVAL, CLASS ); 
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_evthandler_2_sv( aTHX_ RETVALSV, RETVAL );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}

#undef  xsp_constructor_class
#define xsp_constructor_class(c) (c)

XS_EUPXS(XS_Wx__InfoBar_Create); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__InfoBar_Create)
{
    dVAR; dXSARGS;
    if (items < 2 || items > 3)
       croak_xs_usage(cv,  "THIS, parent, winid= wxID_ANY");
    {
	wxInfoBar *    THIS = (wxInfoBar *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::InfoBar" )
;
	bool	RETVAL;
	wxWindow*    parent = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::Window" )
;
	wxWindowID	winid;

	if (items < 3)
	    winid = wxID_ANY;
	else {
    winid = wxPli_get_wxwindowid( aTHX_ ST(2) )
;
	}
    try {
      RETVAL = THIS->Create( parent, winid );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__InfoBar_AddButton); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__InfoBar_AddButton)
{
    dVAR; dXSARGS;
    if (items < 2 || items > 3)
       croak_xs_usage(cv,  "THIS, btnid, label= wxString()");
    {
	wxInfoBar *    THIS = (wxInfoBar *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::InfoBar" )
;
	wxWindowID    btnid = wxPli_get_wxwindowid( aTHX_ ST(1) )
;
	wxString	label;

	if (items < 3)
	    label = wxString();
	else {
    WXSTRING_INPUT( label, wxString, ST(2) )
;
	}
    try {
      THIS->AddButton( btnid, label );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__InfoBar_Dismiss); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__InfoBar_Dismiss)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxInfoBar *    THIS = (wxInfoBar *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::InfoBar" )
;
    try {
      THIS->Dismiss();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__InfoBar_RemoveButton); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__InfoBar_RemoveButton)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, btnid");
    {
	wxInfoBar *    THIS = (wxInfoBar *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::InfoBar" )
;
	wxWindowID    btnid = wxPli_get_wxwindowid( aTHX_ ST(1) )
;
    try {
      THIS->RemoveButton( btnid );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__InfoBar_ShowMessage); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__InfoBar_ShowMessage)
{
    dVAR; dXSARGS;
    if (items < 2 || items > 3)
       croak_xs_usage(cv,  "THIS, msg, flags= wxICON_NONE");
    {
	wxInfoBar *    THIS = (wxInfoBar *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::InfoBar" )
;
	wxString	msg;
	int	flags;

    WXSTRING_INPUT( msg, wxString, ST(1) )
;

	if (items < 3)
	    flags = wxICON_NONE;
	else {
	    flags = (int)SvIV(ST(2))
;
	}
    try {
      THIS->ShowMessage( msg, flags );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__InfoBar_SetShowHideEffects); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__InfoBar_SetShowHideEffects)
{
    dVAR; dXSARGS;
    if (items != 3)
       croak_xs_usage(cv,  "THIS, showEffect, hideEffect");
    {
	wxInfoBar *    THIS = (wxInfoBar *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::InfoBar" )
;
	wxShowEffect	showEffect = (wxShowEffect)SvIV(ST(1))
;
	wxShowEffect	hideEffect = (wxShowEffect)SvIV(ST(2))
;
    try {
      THIS->SetShowHideEffects( showEffect, hideEffect );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__InfoBar_GetShowEffect); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__InfoBar_GetShowEffect)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxInfoBar *    THIS = (wxInfoBar *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::InfoBar" )
;
	wxShowEffect	RETVAL;
	dXSTARG;
    try {
      RETVAL = THIS->GetShowEffect();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__InfoBar_GetHideEffect); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__InfoBar_GetHideEffect)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxInfoBar *    THIS = (wxInfoBar *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::InfoBar" )
;
	wxShowEffect	RETVAL;
	dXSTARG;
    try {
      RETVAL = THIS->GetHideEffect();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__InfoBar_SetEffectDuration); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__InfoBar_SetEffectDuration)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, duration");
    {
	wxInfoBar *    THIS = (wxInfoBar *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::InfoBar" )
;
	int	duration = (int)SvIV(ST(1))
;
    try {
      THIS->SetEffectDuration( duration );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__InfoBar_GetEffectDuration); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__InfoBar_GetEffectDuration)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxInfoBar *    THIS = (wxInfoBar *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::InfoBar" )
;
	int	RETVAL;
	dXSTARG;
    try {
      RETVAL = THIS->GetEffectDuration();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__InfoBar_SetFont); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__InfoBar_SetFont)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, font");
    {
	wxInfoBar *    THIS = (wxInfoBar *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::InfoBar" )
;
	bool	RETVAL;
	wxFont*    font = (wxFont *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::Font" )
;
    try {
      RETVAL = THIS->SetFont( *( font ) );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}

#include "cpp/overload.h"
#if defined( XSpp_622a4aee_084652 )
#define XSubPPtmpAACA 1


XS_EUPXS(XS_Wx__InfoBar_new); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__InfoBar_new)
{
    dVAR; dXSARGS;
    if (items < 1)
       croak_xs_usage(cv,  "CLASS, ...");
    PERL_UNUSED_VAR(ax); /* -Wall */
    SP -= items;
    {
	char *	CLASS = (char *)SvPV_nolen(ST(0))
;
#if defined( XSpp_622a4aee_084652 )
    static wxPliPrototype void_proto( NULL, 0 );
#endif // defined( XSpp_622a4aee_084652 )
    static wxPliPrototype *wxPliOvl_all_prototypes[] = {
#if defined( XSpp_622a4aee_084652 )
        &void_proto,
#endif // defined( XSpp_622a4aee_084652 )
        NULL };
    BEGIN_OVERLOAD()
#if defined( XSpp_622a4aee_084652 )
        MATCH_VOIDM_REDISP( wxInfoBar0 )
#endif // defined( XSpp_622a4aee_084652 )
#if defined( XSpp_622a4aee_084652 )
        MATCH_ANY_REDISP( wxInfoBar1 )
#endif // defined( XSpp_622a4aee_084652 )
    END_OVERLOAD_MESSAGE( Wx::InfoBar::new, wxPliOvl_all_prototypes )
	PUTBACK;
	return;
    }
}

#endif // defined( XSpp_622a4aee_084652 )
#endif

/* INCLUDE: Returning to 'Controls.xs' from '/usr/bin/perl -I./ -MExtUtils::XSpp::Cmd -e xspp -- -t typemap.xsp interface/wx/infobar.h' */


/* INCLUDE_COMMAND:  Including output of '/usr/bin/perl -I./ -MExtUtils::XSpp::Cmd -e xspp -- -t typemap.xsp interface/wx/headerctrl.h' from 'Controls.xs' */

#include <exception>

#undef  xsp_constructor_class
#define xsp_constructor_class(c) (c)
#if WXPERL_W_VERSION_GE( 2, 9, 1 )
#define XSpp_11434cd6_087368
#include <wx/headerctrl.h>
#include "xspp/wxplheaderctrl.h"
#define XSubPPtmpAACB 1


XS_EUPXS(XS_Wx__HeaderCtrl_Create); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__HeaderCtrl_Create)
{
    dVAR; dXSARGS;
    if (items < 2 || items > 7)
       croak_xs_usage(cv,  "THIS, parent, winid= wxID_ANY, pos= wxDefaultPosition, size= wxDefaultSize, style= wxHD_DEFAULT_STYLE, name= wxHeaderCtrlNameStr");
    {
	wxHeaderCtrl *    THIS = (wxHeaderCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::HeaderCtrl" )
;
	bool	RETVAL;
	wxWindow*    parent = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::Window" )
;
	wxWindowID	winid;
	wxPoint	pos;
	wxSize	size;
	long	style;
	wxString	name;

	if (items < 3)
	    winid = wxID_ANY;
	else {
    winid = wxPli_get_wxwindowid( aTHX_ ST(2) )
;
	}

	if (items < 4)
	    pos = wxDefaultPosition;
	else {
    pos = wxPli_sv_2_wxpoint( aTHX_ ST(3) )
;
	}

	if (items < 5)
	    size = wxDefaultSize;
	else {
    size = wxPli_sv_2_wxsize( aTHX_ ST(4) )
;
	}

	if (items < 6)
	    style = wxHD_DEFAULT_STYLE;
	else {
	    style = (long)SvIV(ST(5))
;
	}

	if (items < 7)
	    name = wxHeaderCtrlNameStr;
	else {
    WXSTRING_INPUT( name, wxString, ST(6) )
;
	}
    try {
      RETVAL = THIS->Create( parent, winid, pos, size, style, name );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__HeaderCtrl_SetColumnCount); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__HeaderCtrl_SetColumnCount)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, count");
    {
	wxHeaderCtrl *    THIS = (wxHeaderCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::HeaderCtrl" )
;
	unsigned int    count = (unsigned int)SvUV( ST(1) )
;
    try {
      THIS->SetColumnCount( count );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__HeaderCtrl_GetColumnCount); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__HeaderCtrl_GetColumnCount)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxHeaderCtrl *    THIS = (wxHeaderCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::HeaderCtrl" )
;
	unsigned int	RETVAL;
	dXSTARG;
    try {
      RETVAL = THIS->GetColumnCount();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	XSprePUSH;
	PUSHu((UV)RETVAL );
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__HeaderCtrl_IsEmpty); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__HeaderCtrl_IsEmpty)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxHeaderCtrl *    THIS = (wxHeaderCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::HeaderCtrl" )
;
	bool	RETVAL;
    try {
      RETVAL = THIS->IsEmpty();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__HeaderCtrl_UpdateColumn); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__HeaderCtrl_UpdateColumn)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, idx");
    {
	wxHeaderCtrl *    THIS = (wxHeaderCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::HeaderCtrl" )
;
	unsigned int    idx = (unsigned int)SvUV( ST(1) )
;
    try {
      THIS->UpdateColumn( idx );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__HeaderCtrl_SetColumnsOrder); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__HeaderCtrl_SetColumnsOrder)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, order");
    {
	wxHeaderCtrl *    THIS = (wxHeaderCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::HeaderCtrl" )
;
	wxArrayInt	order;

    wxPli_av_2_arrayint( aTHX_ ST(1), & order )
;
    try {
      THIS->SetColumnsOrder( order );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__HeaderCtrl_GetColumnsOrder); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__HeaderCtrl_GetColumnsOrder)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    PERL_UNUSED_VAR(ax); /* -Wall */
    SP -= items;
    {
	wxHeaderCtrl *    THIS = (wxHeaderCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::HeaderCtrl" )
;
	wxArrayInt	RETVAL;
    try {
      RETVAL = THIS->GetColumnsOrder();
    PUTBACK;
    wxPli_intarray_push( aTHX_ RETVAL );
    SPAGAIN;
  ;
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	PUTBACK;
	return;
    }
}


XS_EUPXS(XS_Wx__HeaderCtrl_GetColumnAt); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__HeaderCtrl_GetColumnAt)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, pos");
    {
	wxHeaderCtrl *    THIS = (wxHeaderCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::HeaderCtrl" )
;
	unsigned int	RETVAL;
	dXSTARG;
	unsigned int    pos = (unsigned int)SvUV( ST(1) )
;
    try {
      RETVAL = THIS->GetColumnAt( pos );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	XSprePUSH;
	PUSHu((UV)RETVAL );
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__HeaderCtrl_GetColumnPos); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__HeaderCtrl_GetColumnPos)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, idx");
    {
	wxHeaderCtrl *    THIS = (wxHeaderCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::HeaderCtrl" )
;
	unsigned int	RETVAL;
	dXSTARG;
	unsigned int    idx = (unsigned int)SvUV( ST(1) )
;
    try {
      RETVAL = THIS->GetColumnPos( idx );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	XSprePUSH;
	PUSHu((UV)RETVAL );
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__HeaderCtrl_ResetColumnsOrder); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__HeaderCtrl_ResetColumnsOrder)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxHeaderCtrl *    THIS = (wxHeaderCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::HeaderCtrl" )
;
    try {
      THIS->ResetColumnsOrder();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__HeaderCtrl_MoveColumnInOrderArray); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__HeaderCtrl_MoveColumnInOrderArray)
{
    dVAR; dXSARGS;
    if (items != 3)
       croak_xs_usage(cv,  "order, idx, pos");
    {
	wxArrayInt	order;
	unsigned int    idx = (unsigned int)SvUV( ST(1) )
;
	unsigned int    pos = (unsigned int)SvUV( ST(2) )
;

    wxPli_av_2_arrayint( aTHX_ ST(0), & order )
;
    try {
      wxHeaderCtrl::MoveColumnInOrderArray( order, idx, pos );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__HeaderCtrl_ShowColumnsMenu); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__HeaderCtrl_ShowColumnsMenu)
{
    dVAR; dXSARGS;
    if (items < 2 || items > 3)
       croak_xs_usage(cv,  "THIS, pt, title= wxString()");
    {
	wxHeaderCtrl *    THIS = (wxHeaderCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::HeaderCtrl" )
;
	bool	RETVAL;
	wxPoint    pt = wxPli_sv_2_wxpoint( aTHX_ ST(1) )
;
	wxString	title;

	if (items < 3)
	    title = wxString();
	else {
    WXSTRING_INPUT( title, wxString, ST(2) )
;
	}
    try {
      RETVAL = THIS->ShowColumnsMenu( pt, title );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__HeaderCtrl_AddColumnsItems); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__HeaderCtrl_AddColumnsItems)
{
    dVAR; dXSARGS;
    if (items < 2 || items > 3)
       croak_xs_usage(cv,  "THIS, menu, idColumnsBase= 0");
    {
	wxHeaderCtrl *    THIS = (wxHeaderCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::HeaderCtrl" )
;
	wxMenu*    menu = (wxMenu *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::Menu" )
;
	int	idColumnsBase;

	if (items < 3)
	    idColumnsBase = 0;
	else {
	    idColumnsBase = (int)SvIV(ST(2))
;
	}
    try {
      THIS->AddColumnsItems( *( menu ), idColumnsBase );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__HeaderCtrl_ShowCustomizeDialog); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__HeaderCtrl_ShowCustomizeDialog)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxHeaderCtrl *    THIS = (wxHeaderCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::HeaderCtrl" )
;
	bool	RETVAL;
    try {
      RETVAL = THIS->ShowCustomizeDialog();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}

#include "cpp/overload.h"
#if defined( XSpp_11434cd6_087368 )
#define XSubPPtmpAACC 1


XS_EUPXS(XS_Wx__HeaderCtrl_new); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__HeaderCtrl_new)
{
    dVAR; dXSARGS;
    if (items < 1)
       croak_xs_usage(cv,  "CLASS, ...");
    PERL_UNUSED_VAR(ax); /* -Wall */
    SP -= items;
    {
	char *	CLASS = (char *)SvPV_nolen(ST(0))
;
#if defined( XSpp_11434cd6_087368 )
    static wxPliPrototype void_proto( NULL, 0 );
#endif // defined( XSpp_11434cd6_087368 )
    static wxPliPrototype *wxPliOvl_all_prototypes[] = {
#if defined( XSpp_11434cd6_087368 )
        &void_proto,
#endif // defined( XSpp_11434cd6_087368 )
        NULL };
    BEGIN_OVERLOAD()
#if defined( XSpp_11434cd6_087368 )
        MATCH_VOIDM_REDISP( wxHeaderCtrl0 )
#endif // defined( XSpp_11434cd6_087368 )
#if defined( XSpp_11434cd6_087368 )
        MATCH_ANY_REDISP( wxHeaderCtrl1 )
#endif // defined( XSpp_11434cd6_087368 )
    END_OVERLOAD_MESSAGE( Wx::HeaderCtrl::new, wxPliOvl_all_prototypes )
	PUTBACK;
	return;
    }
}

#endif // defined( XSpp_11434cd6_087368 )
#include "xspp/wxplheaderctrlsimple.h"

XS_EUPXS(XS_Wx__HeaderCtrlSimple_InsertColumn); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__HeaderCtrlSimple_InsertColumn)
{
    dVAR; dXSARGS;
    if (items != 3)
       croak_xs_usage(cv,  "THIS, col, idx");
    {
	wxHeaderCtrlSimple *    THIS = (wxHeaderCtrlSimple *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::HeaderCtrlSimple" )
;
	wxHeaderColumnSimple*    col = (wxHeaderColumnSimple *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::HeaderColumnSimple" )
;
	unsigned int    idx = (unsigned int)SvUV( ST(2) )
;
    try {
      THIS->InsertColumn( *( col ), idx );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__HeaderCtrlSimple_AppendColumn); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__HeaderCtrlSimple_AppendColumn)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, col");
    {
	wxHeaderCtrlSimple *    THIS = (wxHeaderCtrlSimple *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::HeaderCtrlSimple" )
;
	wxHeaderColumnSimple*    col = (wxHeaderColumnSimple *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::HeaderColumnSimple" )
;
    try {
      THIS->AppendColumn( *( col ) );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__HeaderCtrlSimple_DeleteColumn); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__HeaderCtrlSimple_DeleteColumn)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, idx");
    {
	wxHeaderCtrlSimple *    THIS = (wxHeaderCtrlSimple *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::HeaderCtrlSimple" )
;
	unsigned int    idx = (unsigned int)SvUV( ST(1) )
;
    try {
      THIS->DeleteColumn( idx );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__HeaderCtrlSimple_ShowColumn); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__HeaderCtrlSimple_ShowColumn)
{
    dVAR; dXSARGS;
    if (items < 2 || items > 3)
       croak_xs_usage(cv,  "THIS, idx, show= true");
    {
	wxHeaderCtrlSimple *    THIS = (wxHeaderCtrlSimple *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::HeaderCtrlSimple" )
;
	unsigned int    idx = (unsigned int)SvUV( ST(1) )
;
	bool	show;

	if (items < 3)
	    show = true;
	else {
	    show = (bool)SvTRUE(ST(2))
;
	}
    try {
      THIS->ShowColumn( idx, show );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__HeaderCtrlSimple_HideColumn); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__HeaderCtrlSimple_HideColumn)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, idx");
    {
	wxHeaderCtrlSimple *    THIS = (wxHeaderCtrlSimple *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::HeaderCtrlSimple" )
;
	unsigned int    idx = (unsigned int)SvUV( ST(1) )
;
    try {
      THIS->HideColumn( idx );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__HeaderCtrlSimple_ShowSortIndicator); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__HeaderCtrlSimple_ShowSortIndicator)
{
    dVAR; dXSARGS;
    if (items < 2 || items > 3)
       croak_xs_usage(cv,  "THIS, idx, sortOrder= true");
    {
	wxHeaderCtrlSimple *    THIS = (wxHeaderCtrlSimple *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::HeaderCtrlSimple" )
;
	unsigned int    idx = (unsigned int)SvUV( ST(1) )
;
	bool	sortOrder;

	if (items < 3)
	    sortOrder = true;
	else {
	    sortOrder = (bool)SvTRUE(ST(2))
;
	}
    try {
      THIS->ShowSortIndicator( idx, sortOrder );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__HeaderCtrlSimple_RemoveSortIndicator); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__HeaderCtrlSimple_RemoveSortIndicator)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxHeaderCtrlSimple *    THIS = (wxHeaderCtrlSimple *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::HeaderCtrlSimple" )
;
    try {
      THIS->RemoveSortIndicator();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}

#include "cpp/overload.h"
#if defined( XSpp_11434cd6_087368 )
#define XSubPPtmpAACD 1


XS_EUPXS(XS_Wx__HeaderCtrlSimple_new); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__HeaderCtrlSimple_new)
{
    dVAR; dXSARGS;
    if (items < 1)
       croak_xs_usage(cv,  "CLASS, ...");
    PERL_UNUSED_VAR(ax); /* -Wall */
    SP -= items;
    {
	char *	CLASS = (char *)SvPV_nolen(ST(0))
;
#if defined( XSpp_11434cd6_087368 )
    static wxPliPrototype void_proto( NULL, 0 );
#endif // defined( XSpp_11434cd6_087368 )
    static wxPliPrototype *wxPliOvl_all_prototypes[] = {
#if defined( XSpp_11434cd6_087368 )
        &void_proto,
#endif // defined( XSpp_11434cd6_087368 )
        NULL };
    BEGIN_OVERLOAD()
#if defined( XSpp_11434cd6_087368 )
        MATCH_VOIDM_REDISP( wxHeaderCtrlSimple0 )
#endif // defined( XSpp_11434cd6_087368 )
#if defined( XSpp_11434cd6_087368 )
        MATCH_ANY_REDISP( wxHeaderCtrlSimple1 )
#endif // defined( XSpp_11434cd6_087368 )
    END_OVERLOAD_MESSAGE( Wx::HeaderCtrlSimple::new, wxPliOvl_all_prototypes )
	PUTBACK;
	return;
    }
}

#endif // defined( XSpp_11434cd6_087368 )
#undef  xsp_constructor_class
#define xsp_constructor_class(c) (CLASS)

XS_EUPXS(XS_Wx__HeaderCtrlSimple_wxHeaderCtrlSimple0); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__HeaderCtrlSimple_wxHeaderCtrlSimple0)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "CLASS");
    {
	char *	CLASS = (char *)SvPV_nolen(ST(0))
;
	wxHeaderCtrlSimple *	RETVAL;
    RETVAL = new wxPlHeaderCtrlSimple( CLASS   );
     wxPli_create_evthandler( aTHX_ RETVAL, CLASS ); 
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_evthandler_2_sv( aTHX_ RETVALSV, RETVAL );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}

#undef  xsp_constructor_class
#define xsp_constructor_class(c) (c)
#undef  xsp_constructor_class
#define xsp_constructor_class(c) (CLASS)

XS_EUPXS(XS_Wx__HeaderCtrlSimple_wxHeaderCtrlSimple1); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__HeaderCtrlSimple_wxHeaderCtrlSimple1)
{
    dVAR; dXSARGS;
    if (items < 2 || items > 7)
       croak_xs_usage(cv,  "CLASS, parent, winid= wxID_ANY, pos= wxDefaultPosition, size= wxDefaultSize, style= wxHD_DEFAULT_STYLE, name= wxHeaderCtrlNameStr");
    {
	char *	CLASS = (char *)SvPV_nolen(ST(0))
;
	wxHeaderCtrlSimple *	RETVAL;
	wxWindow*    parent = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::Window" )
;
	wxWindowID	winid;
	wxPoint	pos;
	wxSize	size;
	long	style;
	wxString	name;

	if (items < 3)
	    winid = wxID_ANY;
	else {
    winid = wxPli_get_wxwindowid( aTHX_ ST(2) )
;
	}

	if (items < 4)
	    pos = wxDefaultPosition;
	else {
    pos = wxPli_sv_2_wxpoint( aTHX_ ST(3) )
;
	}

	if (items < 5)
	    size = wxDefaultSize;
	else {
    size = wxPli_sv_2_wxsize( aTHX_ ST(4) )
;
	}

	if (items < 6)
	    style = wxHD_DEFAULT_STYLE;
	else {
	    style = (long)SvIV(ST(5))
;
	}

	if (items < 7)
	    name = wxHeaderCtrlNameStr;
	else {
    WXSTRING_INPUT( name, wxString, ST(6) )
;
	}
    RETVAL = new wxPlHeaderCtrlSimple( CLASS , parent, winid, pos, size, style, name );
     wxPli_create_evthandler( aTHX_ RETVAL, CLASS ); 
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_evthandler_2_sv( aTHX_ RETVALSV, RETVAL );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}

#undef  xsp_constructor_class
#define xsp_constructor_class(c) (c)

XS_EUPXS(XS_Wx__HeaderCtrlEvent_GetColumn); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__HeaderCtrlEvent_GetColumn)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxHeaderCtrlEvent *    THIS = (wxHeaderCtrlEvent *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::HeaderCtrlEvent" )
;
	int	RETVAL;
	dXSTARG;
    try {
      RETVAL = THIS->GetColumn();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__HeaderCtrlEvent_GetWidth); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__HeaderCtrlEvent_GetWidth)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxHeaderCtrlEvent *    THIS = (wxHeaderCtrlEvent *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::HeaderCtrlEvent" )
;
	int	RETVAL;
	dXSTARG;
    try {
      RETVAL = THIS->GetWidth();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__HeaderCtrlEvent_GetNewOrder); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__HeaderCtrlEvent_GetNewOrder)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxHeaderCtrlEvent *    THIS = (wxHeaderCtrlEvent *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::HeaderCtrlEvent" )
;
	unsigned int	RETVAL;
	dXSTARG;
    try {
      RETVAL = THIS->GetNewOrder();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	XSprePUSH;
	PUSHu((UV)RETVAL );
    }
    XSRETURN(1);
}

#endif
#if defined( XSpp_11434cd6_087368 )
#undef  xsp_constructor_class
#define xsp_constructor_class(c) (CLASS)
#define XSubPPtmpAACE 1


XS_EUPXS(XS_Wx__PlHeaderCtrl_wxHeaderCtrl0); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__PlHeaderCtrl_wxHeaderCtrl0)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "CLASS");
    {
	char *	CLASS = (char *)SvPV_nolen(ST(0))
;
	wxPlHeaderCtrl *	RETVAL;
    RETVAL = new wxPlHeaderCtrl( CLASS   );
     wxPli_create_evthandler( aTHX_ RETVAL, CLASS ); 
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_evthandler_2_sv( aTHX_ RETVALSV, RETVAL );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}

#undef  xsp_constructor_class
#define xsp_constructor_class(c) (c)
#undef  xsp_constructor_class
#define xsp_constructor_class(c) (CLASS)

XS_EUPXS(XS_Wx__PlHeaderCtrl_wxHeaderCtrl1); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__PlHeaderCtrl_wxHeaderCtrl1)
{
    dVAR; dXSARGS;
    if (items < 2 || items > 7)
       croak_xs_usage(cv,  "CLASS, parent, winid= wxID_ANY, pos= wxDefaultPosition, size= wxDefaultSize, style= wxHD_DEFAULT_STYLE, name= wxHeaderCtrlNameStr");
    {
	char *	CLASS = (char *)SvPV_nolen(ST(0))
;
	wxPlHeaderCtrl *	RETVAL;
	wxWindow*    parent = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::Window" )
;
	wxWindowID	winid;
	wxPoint	pos;
	wxSize	size;
	long	style;
	wxString	name;

	if (items < 3)
	    winid = wxID_ANY;
	else {
    winid = wxPli_get_wxwindowid( aTHX_ ST(2) )
;
	}

	if (items < 4)
	    pos = wxDefaultPosition;
	else {
    pos = wxPli_sv_2_wxpoint( aTHX_ ST(3) )
;
	}

	if (items < 5)
	    size = wxDefaultSize;
	else {
    size = wxPli_sv_2_wxsize( aTHX_ ST(4) )
;
	}

	if (items < 6)
	    style = wxHD_DEFAULT_STYLE;
	else {
	    style = (long)SvIV(ST(5))
;
	}

	if (items < 7)
	    name = wxHeaderCtrlNameStr;
	else {
    WXSTRING_INPUT( name, wxString, ST(6) )
;
	}
    RETVAL = new wxPlHeaderCtrl( CLASS , parent, winid, pos, size, style, name );
     wxPli_create_evthandler( aTHX_ RETVAL, CLASS ); 
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_evthandler_2_sv( aTHX_ RETVALSV, RETVAL );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}

#undef  xsp_constructor_class
#define xsp_constructor_class(c) (c)
#endif // defined( XSpp_11434cd6_087368 )
#if defined( XSpp_11434cd6_087368 )
#if defined( XSpp_11434cd6_087368 )
#define XSubPPtmpAACF 1


XS_EUPXS(XS_Wx__HeaderCtrlSimple_GetBestFittingWidth); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__HeaderCtrlSimple_GetBestFittingWidth)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, idx");
    {
	wxPlHeaderCtrlSimple *    THIS = (wxPlHeaderCtrlSimple *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::PlHeaderCtrlSimple" )
;
	unsigned int    idx = (unsigned int)SvUV( ST(1) )
;
    try {
      THIS->base_GetBestFittingWidth( idx );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}

#endif // defined( XSpp_11434cd6_087368 )
#endif // defined( XSpp_11434cd6_087368 )
#include "xspp/const_headerctrl_h.h"
#include "xspp/evt_headerctrl_h.h"
#if 1 && defined( XSpp_11434cd6_087368 )
#define XSubPPtmpAACG 1

#endif // 1 && defined( XSpp_11434cd6_087368 )

/* INCLUDE: Returning to 'Controls.xs' from '/usr/bin/perl -I./ -MExtUtils::XSpp::Cmd -e xspp -- -t typemap.xsp interface/wx/headerctrl.h' */


/* INCLUDE_COMMAND:  Including output of '/usr/bin/perl -I./ -MExtUtils::XSpp::Cmd -e xspp -- -t typemap.xsp interface/wx/headercol.h' from 'Controls.xs' */

#include <exception>

#undef  xsp_constructor_class
#define xsp_constructor_class(c) (c)
#if WXPERL_W_VERSION_GE( 2, 9, 1 )
#define XSpp_512ff718_079351
#include <wx/headerctrl.h>
#include <wx/dataview.h> // wxDVC_DEFAULT_WIDTH
#include "xspp/wxplheadercolumn.h"
#define XSubPPtmpAACH 1


XS_EUPXS(XS_Wx__HeaderColumn_GetTitle); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__HeaderColumn_GetTitle)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxHeaderColumn *    THIS = (wxHeaderColumn *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::HeaderColumn" )
;
	wxString	RETVAL;
    try {
      RETVAL = THIS->GetTitle();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    WXSTRING_OUTPUT( RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__HeaderColumn_GetBitmap); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__HeaderColumn_GetBitmap)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxHeaderColumn *    THIS = (wxHeaderColumn *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::HeaderColumn" )
;
	wxBitmap *	RETVAL;
    try {
      RETVAL = new wxBitmap( THIS->GetBitmap() );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_object_2_sv( aTHX_ RETVALSV, RETVAL );
    wxPli_thread_sv_register( aTHX_ "Wx::Bitmap", RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__HeaderColumn_GetWidth); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__HeaderColumn_GetWidth)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxHeaderColumn *    THIS = (wxHeaderColumn *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::HeaderColumn" )
;
	int	RETVAL;
	dXSTARG;
    try {
      RETVAL = THIS->GetWidth();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__HeaderColumn_GetMinWidth); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__HeaderColumn_GetMinWidth)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxHeaderColumn *    THIS = (wxHeaderColumn *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::HeaderColumn" )
;
	int	RETVAL;
	dXSTARG;
    try {
      RETVAL = THIS->GetMinWidth();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__HeaderColumn_GetAlignment); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__HeaderColumn_GetAlignment)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxHeaderColumn *    THIS = (wxHeaderColumn *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::HeaderColumn" )
;
	wxAlignment	RETVAL;
	dXSTARG;
    try {
      RETVAL = THIS->GetAlignment();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__HeaderColumn_GetFlags); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__HeaderColumn_GetFlags)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxHeaderColumn *    THIS = (wxHeaderColumn *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::HeaderColumn" )
;
	int	RETVAL;
	dXSTARG;
    try {
      RETVAL = THIS->GetFlags();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__HeaderColumn_HasFlag); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__HeaderColumn_HasFlag)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, flag");
    {
	wxHeaderColumn *    THIS = (wxHeaderColumn *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::HeaderColumn" )
;
	bool	RETVAL;
	int	flag = (int)SvIV(ST(1))
;
    try {
      RETVAL = THIS->HasFlag( flag );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__HeaderColumn_IsResizeable); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__HeaderColumn_IsResizeable)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxHeaderColumn *    THIS = (wxHeaderColumn *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::HeaderColumn" )
;
	bool	RETVAL;
    try {
      RETVAL = THIS->IsResizeable();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__HeaderColumn_IsSortable); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__HeaderColumn_IsSortable)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxHeaderColumn *    THIS = (wxHeaderColumn *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::HeaderColumn" )
;
	bool	RETVAL;
    try {
      RETVAL = THIS->IsSortable();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__HeaderColumn_IsReorderable); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__HeaderColumn_IsReorderable)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxHeaderColumn *    THIS = (wxHeaderColumn *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::HeaderColumn" )
;
	bool	RETVAL;
    try {
      RETVAL = THIS->IsReorderable();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__HeaderColumn_IsHidden); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__HeaderColumn_IsHidden)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxHeaderColumn *    THIS = (wxHeaderColumn *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::HeaderColumn" )
;
	bool	RETVAL;
    try {
      RETVAL = THIS->IsHidden();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__HeaderColumn_IsShown); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__HeaderColumn_IsShown)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxHeaderColumn *    THIS = (wxHeaderColumn *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::HeaderColumn" )
;
	bool	RETVAL;
    try {
      RETVAL = THIS->IsShown();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__HeaderColumn_IsSortKey); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__HeaderColumn_IsSortKey)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxHeaderColumn *    THIS = (wxHeaderColumn *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::HeaderColumn" )
;
	bool	RETVAL;
    try {
      RETVAL = THIS->IsSortKey();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__HeaderColumn_IsSortOrderAscending); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__HeaderColumn_IsSortOrderAscending)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxHeaderColumn *    THIS = (wxHeaderColumn *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::HeaderColumn" )
;
	bool	RETVAL;
    try {
      RETVAL = THIS->IsSortOrderAscending();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}

#if WXPERL_W_VERSION_LE( 2, 9, 2 )
#define XSpp_512ff718_018178
#endif
#include "xspp/wxplsettableheadercolumn.h"

XS_EUPXS(XS_Wx__SettableHeaderColumn_SetTitle); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__SettableHeaderColumn_SetTitle)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, title");
    {
	wxSettableHeaderColumn *    THIS = (wxSettableHeaderColumn *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::SettableHeaderColumn" )
;
	wxString	title;

    WXSTRING_INPUT( title, wxString, ST(1) )
;
    try {
      THIS->SetTitle( title );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__SettableHeaderColumn_SetBitmap); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__SettableHeaderColumn_SetBitmap)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, bitmap");
    {
	wxSettableHeaderColumn *    THIS = (wxSettableHeaderColumn *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::SettableHeaderColumn" )
;
	wxBitmap*    bitmap = (wxBitmap *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::Bitmap" )
;
    try {
      THIS->SetBitmap( *( bitmap ) );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__SettableHeaderColumn_SetWidth); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__SettableHeaderColumn_SetWidth)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, width");
    {
	wxSettableHeaderColumn *    THIS = (wxSettableHeaderColumn *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::SettableHeaderColumn" )
;
	int	width = (int)SvIV(ST(1))
;
    try {
      THIS->SetWidth( width );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__SettableHeaderColumn_SetMinWidth); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__SettableHeaderColumn_SetMinWidth)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, minWidth");
    {
	wxSettableHeaderColumn *    THIS = (wxSettableHeaderColumn *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::SettableHeaderColumn" )
;
	int	minWidth = (int)SvIV(ST(1))
;
    try {
      THIS->SetMinWidth( minWidth );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__SettableHeaderColumn_SetAlignment); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__SettableHeaderColumn_SetAlignment)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, align");
    {
	wxSettableHeaderColumn *    THIS = (wxSettableHeaderColumn *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::SettableHeaderColumn" )
;
	wxAlignment	align = (wxAlignment)SvIV(ST(1))
;
    try {
      THIS->SetAlignment( align );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__SettableHeaderColumn_SetFlags); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__SettableHeaderColumn_SetFlags)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, flags");
    {
	wxSettableHeaderColumn *    THIS = (wxSettableHeaderColumn *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::SettableHeaderColumn" )
;
	int	flags = (int)SvIV(ST(1))
;
    try {
      THIS->SetFlags( flags );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__SettableHeaderColumn_ChangeFlag); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__SettableHeaderColumn_ChangeFlag)
{
    dVAR; dXSARGS;
    if (items != 3)
       croak_xs_usage(cv,  "THIS, flag, set");
    {
	wxSettableHeaderColumn *    THIS = (wxSettableHeaderColumn *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::SettableHeaderColumn" )
;
	int	flag = (int)SvIV(ST(1))
;
	bool	set = (bool)SvTRUE(ST(2))
;
    try {
      THIS->ChangeFlag( flag, set );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__SettableHeaderColumn_SetFlag); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__SettableHeaderColumn_SetFlag)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, flag");
    {
	wxSettableHeaderColumn *    THIS = (wxSettableHeaderColumn *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::SettableHeaderColumn" )
;
	int	flag = (int)SvIV(ST(1))
;
    try {
      THIS->SetFlag( flag );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__SettableHeaderColumn_ClearFlag); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__SettableHeaderColumn_ClearFlag)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, flag");
    {
	wxSettableHeaderColumn *    THIS = (wxSettableHeaderColumn *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::SettableHeaderColumn" )
;
	int	flag = (int)SvIV(ST(1))
;
    try {
      THIS->ClearFlag( flag );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__SettableHeaderColumn_ToggleFlag); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__SettableHeaderColumn_ToggleFlag)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, flag");
    {
	wxSettableHeaderColumn *    THIS = (wxSettableHeaderColumn *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::SettableHeaderColumn" )
;
	int	flag = (int)SvIV(ST(1))
;
    try {
      THIS->ToggleFlag( flag );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__SettableHeaderColumn_SetResizeable); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__SettableHeaderColumn_SetResizeable)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, resizeable");
    {
	wxSettableHeaderColumn *    THIS = (wxSettableHeaderColumn *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::SettableHeaderColumn" )
;
	bool	resizeable = (bool)SvTRUE(ST(1))
;
    try {
      THIS->SetResizeable( resizeable );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__SettableHeaderColumn_SetSortable); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__SettableHeaderColumn_SetSortable)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, sortable");
    {
	wxSettableHeaderColumn *    THIS = (wxSettableHeaderColumn *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::SettableHeaderColumn" )
;
	bool	sortable = (bool)SvTRUE(ST(1))
;
    try {
      THIS->SetSortable( sortable );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__SettableHeaderColumn_SetReorderable); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__SettableHeaderColumn_SetReorderable)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, reorderable");
    {
	wxSettableHeaderColumn *    THIS = (wxSettableHeaderColumn *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::SettableHeaderColumn" )
;
	bool	reorderable = (bool)SvTRUE(ST(1))
;
    try {
      THIS->SetReorderable( reorderable );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__SettableHeaderColumn_SetHidden); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__SettableHeaderColumn_SetHidden)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, hidden");
    {
	wxSettableHeaderColumn *    THIS = (wxSettableHeaderColumn *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::SettableHeaderColumn" )
;
	bool	hidden = (bool)SvTRUE(ST(1))
;
    try {
      THIS->SetHidden( hidden );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}

#if WXPERL_W_VERSION_LE( 2, 9, 2 )
#define XSpp_512ff718_018178
#define XSubPPtmpAACI 1


XS_EUPXS(XS_Wx__SettableHeaderColumn_SetAsSortKey); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__SettableHeaderColumn_SetAsSortKey)
{
    dVAR; dXSARGS;
    if (items < 1 || items > 2)
       croak_xs_usage(cv,  "THIS, sort= true");
    {
	wxSettableHeaderColumn *    THIS = (wxSettableHeaderColumn *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::SettableHeaderColumn" )
;
	bool	sort;

	if (items < 2)
	    sort = true;
	else {
	    sort = (bool)SvTRUE(ST(1))
;
	}
    try {
      THIS->SetAsSortKey( sort );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}

#endif

XS_EUPXS(XS_Wx__SettableHeaderColumn_UnsetAsSortKey); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__SettableHeaderColumn_UnsetAsSortKey)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxSettableHeaderColumn *    THIS = (wxSettableHeaderColumn *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::SettableHeaderColumn" )
;
    try {
      THIS->UnsetAsSortKey();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__SettableHeaderColumn_SetSortOrder); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__SettableHeaderColumn_SetSortOrder)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, ascending");
    {
	wxSettableHeaderColumn *    THIS = (wxSettableHeaderColumn *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::SettableHeaderColumn" )
;
	bool	ascending = (bool)SvTRUE(ST(1))
;
    try {
      THIS->SetSortOrder( ascending );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__SettableHeaderColumn_ToggleSortOrder); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__SettableHeaderColumn_ToggleSortOrder)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxSettableHeaderColumn *    THIS = (wxSettableHeaderColumn *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::SettableHeaderColumn" )
;
    try {
      THIS->ToggleSortOrder();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}

#undef  xsp_constructor_class
#define xsp_constructor_class(c) (CLASS)

XS_EUPXS(XS_Wx__HeaderColumnSimple_wxHeaderColumnSimple0); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__HeaderColumnSimple_wxHeaderColumnSimple0)
{
    dVAR; dXSARGS;
    if (items < 2 || items > 5)
       croak_xs_usage(cv,  "CLASS, title, width= wxCOL_WIDTH_DEFAULT, align= wxALIGN_NOT, flags= wxCOL_DEFAULT_FLAGS");
    {
	char *	CLASS = (char *)SvPV_nolen(ST(0))
;
	wxHeaderColumnSimple *	RETVAL;
	wxString	title;
	int	width;
	wxAlignment	align;
	int	flags;

    WXSTRING_INPUT( title, wxString, ST(1) )
;

	if (items < 3)
	    width = wxCOL_WIDTH_DEFAULT;
	else {
	    width = (int)SvIV(ST(2))
;
	}

	if (items < 4)
	    align = wxALIGN_NOT;
	else {
	    align = (wxAlignment)SvIV(ST(3))
;
	}

	if (items < 5)
	    flags = wxCOL_DEFAULT_FLAGS;
	else {
	    flags = (int)SvIV(ST(4))
;
	}
    try {
      RETVAL = new wxHeaderColumnSimple( title, width, align, flags );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_non_object_2_sv( aTHX_ RETVALSV, RETVAL, "Wx::HeaderColumnSimple" );
    wxPli_thread_sv_register( aTHX_ "Wx::HeaderColumnSimple", RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}

#undef  xsp_constructor_class
#define xsp_constructor_class(c) (c)
#undef  xsp_constructor_class
#define xsp_constructor_class(c) (CLASS)

XS_EUPXS(XS_Wx__HeaderColumnSimple_wxHeaderColumnSimple1); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__HeaderColumnSimple_wxHeaderColumnSimple1)
{
    dVAR; dXSARGS;
    if (items < 2 || items > 5)
       croak_xs_usage(cv,  "CLASS, bitmap, width= wxDVC_DEFAULT_WIDTH, align= wxALIGN_CENTER, flags= wxCOL_DEFAULT_FLAGS");
    {
	char *	CLASS = (char *)SvPV_nolen(ST(0))
;
	wxHeaderColumnSimple *	RETVAL;
	wxBitmap*    bitmap = (wxBitmap *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::Bitmap" )
;
	int	width;
	wxAlignment	align;
	int	flags;

	if (items < 3)
	    width = wxDVC_DEFAULT_WIDTH;
	else {
	    width = (int)SvIV(ST(2))
;
	}

	if (items < 4)
	    align = wxALIGN_CENTER;
	else {
	    align = (wxAlignment)SvIV(ST(3))
;
	}

	if (items < 5)
	    flags = wxCOL_DEFAULT_FLAGS;
	else {
	    flags = (int)SvIV(ST(4))
;
	}
    try {
      RETVAL = new wxHeaderColumnSimple( *( bitmap ), width, align, flags );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_non_object_2_sv( aTHX_ RETVALSV, RETVAL, "Wx::HeaderColumnSimple" );
    wxPli_thread_sv_register( aTHX_ "Wx::HeaderColumnSimple", RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}

#undef  xsp_constructor_class
#define xsp_constructor_class(c) (c)

XS_EUPXS(XS_Wx__HeaderColumnSimple_SetTitle); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__HeaderColumnSimple_SetTitle)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, title");
    {
	wxHeaderColumnSimple *    THIS = (wxHeaderColumnSimple *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::HeaderColumnSimple" )
;
	wxString	title;

    WXSTRING_INPUT( title, wxString, ST(1) )
;
    try {
      THIS->SetTitle( title );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__HeaderColumnSimple_GetTitle); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__HeaderColumnSimple_GetTitle)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxHeaderColumnSimple *    THIS = (wxHeaderColumnSimple *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::HeaderColumnSimple" )
;
	wxString	RETVAL;
    try {
      RETVAL = THIS->GetTitle();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    WXSTRING_OUTPUT( RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__HeaderColumnSimple_SetBitmap); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__HeaderColumnSimple_SetBitmap)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, bitmap");
    {
	wxHeaderColumnSimple *    THIS = (wxHeaderColumnSimple *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::HeaderColumnSimple" )
;
	wxBitmap*    bitmap = (wxBitmap *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::Bitmap" )
;
    try {
      THIS->SetBitmap( *( bitmap ) );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__HeaderColumnSimple_GetBitmap); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__HeaderColumnSimple_GetBitmap)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxHeaderColumnSimple *    THIS = (wxHeaderColumnSimple *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::HeaderColumnSimple" )
;
	wxBitmap *	RETVAL;
    try {
      RETVAL = new wxBitmap( THIS->GetBitmap() );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_object_2_sv( aTHX_ RETVALSV, RETVAL );
    wxPli_thread_sv_register( aTHX_ "Wx::Bitmap", RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__HeaderColumnSimple_SetWidth); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__HeaderColumnSimple_SetWidth)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, width");
    {
	wxHeaderColumnSimple *    THIS = (wxHeaderColumnSimple *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::HeaderColumnSimple" )
;
	int	width = (int)SvIV(ST(1))
;
    try {
      THIS->SetWidth( width );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__HeaderColumnSimple_GetWidth); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__HeaderColumnSimple_GetWidth)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxHeaderColumnSimple *    THIS = (wxHeaderColumnSimple *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::HeaderColumnSimple" )
;
	int	RETVAL;
	dXSTARG;
    try {
      RETVAL = THIS->GetWidth();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__HeaderColumnSimple_SetMinWidth); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__HeaderColumnSimple_SetMinWidth)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, minWidth");
    {
	wxHeaderColumnSimple *    THIS = (wxHeaderColumnSimple *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::HeaderColumnSimple" )
;
	int	minWidth = (int)SvIV(ST(1))
;
    try {
      THIS->SetMinWidth( minWidth );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__HeaderColumnSimple_GetMinWidth); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__HeaderColumnSimple_GetMinWidth)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxHeaderColumnSimple *    THIS = (wxHeaderColumnSimple *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::HeaderColumnSimple" )
;
	int	RETVAL;
	dXSTARG;
    try {
      RETVAL = THIS->GetMinWidth();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__HeaderColumnSimple_SetAlignment); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__HeaderColumnSimple_SetAlignment)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, align");
    {
	wxHeaderColumnSimple *    THIS = (wxHeaderColumnSimple *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::HeaderColumnSimple" )
;
	wxAlignment	align = (wxAlignment)SvIV(ST(1))
;
    try {
      THIS->SetAlignment( align );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__HeaderColumnSimple_GetAlignment); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__HeaderColumnSimple_GetAlignment)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxHeaderColumnSimple *    THIS = (wxHeaderColumnSimple *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::HeaderColumnSimple" )
;
	wxAlignment	RETVAL;
	dXSTARG;
    try {
      RETVAL = THIS->GetAlignment();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__HeaderColumnSimple_SetFlags); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__HeaderColumnSimple_SetFlags)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, flags");
    {
	wxHeaderColumnSimple *    THIS = (wxHeaderColumnSimple *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::HeaderColumnSimple" )
;
	int	flags = (int)SvIV(ST(1))
;
    try {
      THIS->SetFlags( flags );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__HeaderColumnSimple_GetFlags); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__HeaderColumnSimple_GetFlags)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxHeaderColumnSimple *    THIS = (wxHeaderColumnSimple *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::HeaderColumnSimple" )
;
	int	RETVAL;
	dXSTARG;
    try {
      RETVAL = THIS->GetFlags();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}

#if WXPERL_W_VERSION_LE( 2, 9, 2 )
#define XSpp_512ff718_072855
#define XSubPPtmpAACJ 1


XS_EUPXS(XS_Wx__HeaderColumnSimple_SetAsSortKey); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__HeaderColumnSimple_SetAsSortKey)
{
    dVAR; dXSARGS;
    if (items < 1 || items > 2)
       croak_xs_usage(cv,  "THIS, sort= true");
    {
	wxHeaderColumnSimple *    THIS = (wxHeaderColumnSimple *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::HeaderColumnSimple" )
;
	bool	sort;

	if (items < 2)
	    sort = true;
	else {
	    sort = (bool)SvTRUE(ST(1))
;
	}
    try {
      THIS->SetAsSortKey( sort );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}

#endif

XS_EUPXS(XS_Wx__HeaderColumnSimple_IsSortKey); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__HeaderColumnSimple_IsSortKey)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxHeaderColumnSimple *    THIS = (wxHeaderColumnSimple *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::HeaderColumnSimple" )
;
	bool	RETVAL;
    try {
      RETVAL = THIS->IsSortKey();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__HeaderColumnSimple_SetSortOrder); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__HeaderColumnSimple_SetSortOrder)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, ascending");
    {
	wxHeaderColumnSimple *    THIS = (wxHeaderColumnSimple *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::HeaderColumnSimple" )
;
	bool	ascending = (bool)SvTRUE(ST(1))
;
    try {
      THIS->SetSortOrder( ascending );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__HeaderColumnSimple_IsSortOrderAscending); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__HeaderColumnSimple_IsSortOrderAscending)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxHeaderColumnSimple *    THIS = (wxHeaderColumnSimple *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::HeaderColumnSimple" )
;
	bool	RETVAL;
    try {
      RETVAL = THIS->IsSortOrderAscending();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}

#include "cpp/overload.h"
#if defined( XSpp_512ff718_079351 )
#define XSubPPtmpAACK 1


XS_EUPXS(XS_Wx__HeaderColumnSimple_new); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__HeaderColumnSimple_new)
{
    dVAR; dXSARGS;
    if (items < 1)
       croak_xs_usage(cv,  "CLASS, ...");
    PERL_UNUSED_VAR(ax); /* -Wall */
    SP -= items;
    {
	char *	CLASS = (char *)SvPV_nolen(ST(0))
;
#if defined( XSpp_512ff718_079351 )
    static const char *wxHeaderColumnSimple0_types[] = { wxPliOvlstr, wxPliOvlnum, wxPliOvlnum, wxPliOvlnum };
    static wxPliPrototype wxHeaderColumnSimple0_proto( wxHeaderColumnSimple0_types, sizeof( wxHeaderColumnSimple0_types ) / sizeof( wxHeaderColumnSimple0_types[0] ) );
#endif // defined( XSpp_512ff718_079351 )
#if defined( XSpp_512ff718_079351 )
    static const char *wxHeaderColumnSimple1_types[] = { "Wx::Bitmap", wxPliOvlnum, wxPliOvlnum, wxPliOvlnum };
    static wxPliPrototype wxHeaderColumnSimple1_proto( wxHeaderColumnSimple1_types, sizeof( wxHeaderColumnSimple1_types ) / sizeof( wxHeaderColumnSimple1_types[0] ) );
#endif // defined( XSpp_512ff718_079351 )
    static wxPliPrototype *wxPliOvl_all_prototypes[] = {
#if defined( XSpp_512ff718_079351 )
        &wxHeaderColumnSimple0_proto,
#endif // defined( XSpp_512ff718_079351 )
#if defined( XSpp_512ff718_079351 )
        &wxHeaderColumnSimple1_proto,
#endif // defined( XSpp_512ff718_079351 )
        NULL };
    BEGIN_OVERLOAD()
#if defined( XSpp_512ff718_079351 )
        MATCH_REDISP_COUNT_ALLOWMORE( wxHeaderColumnSimple0_proto, wxHeaderColumnSimple0, 1 )
#endif // defined( XSpp_512ff718_079351 )
#if defined( XSpp_512ff718_079351 )
        MATCH_REDISP_COUNT_ALLOWMORE( wxHeaderColumnSimple1_proto, wxHeaderColumnSimple1, 1 )
#endif // defined( XSpp_512ff718_079351 )
    END_OVERLOAD_MESSAGE( Wx::HeaderColumnSimple::new, wxPliOvl_all_prototypes )
	PUTBACK;
	return;
    }
}

#endif // defined( XSpp_512ff718_079351 )
#endif
#if defined( XSpp_512ff718_079351 )
#undef  xsp_constructor_class
#define xsp_constructor_class(c) (CLASS)
#define XSubPPtmpAACL 1


XS_EUPXS(XS_Wx__PlHeaderColumn_new); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__PlHeaderColumn_new)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "CLASS");
    {
	char *	CLASS = (char *)SvPV_nolen(ST(0))
;
	wxPlHeaderColumn *	RETVAL;
    RETVAL = new wxPlHeaderColumn( CLASS   );
	{
	    SV * RETVALSV;
    RETVALSV = ( RETVAL == 0 ) ? &PL_sv_undef : RETVAL->GetSelf();
    SvREFCNT_inc( RETVALSV ); // xsubpp mortalizes it...
	    RETVALSV = sv_2mortal(RETVALSV);
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}

#undef  xsp_constructor_class
#define xsp_constructor_class(c) (c)
#endif // defined( XSpp_512ff718_079351 )
#if defined( XSpp_512ff718_079351 )
#undef  xsp_constructor_class
#define xsp_constructor_class(c) (CLASS)
#define XSubPPtmpAACM 1


XS_EUPXS(XS_Wx__PlSettableHeaderColumn_new); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__PlSettableHeaderColumn_new)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "CLASS");
    {
	char *	CLASS = (char *)SvPV_nolen(ST(0))
;
	wxPlSettableHeaderColumn *	RETVAL;
    RETVAL = new wxPlSettableHeaderColumn( CLASS   );
	{
	    SV * RETVALSV;
    RETVALSV = ( RETVAL == 0 ) ? &PL_sv_undef : RETVAL->GetSelf();
    SvREFCNT_inc( RETVALSV ); // xsubpp mortalizes it...
	    RETVALSV = sv_2mortal(RETVALSV);
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}

#undef  xsp_constructor_class
#define xsp_constructor_class(c) (c)
#endif // defined( XSpp_512ff718_079351 )
#include "xspp/const_headercol_h.h"

/* INCLUDE: Returning to 'Controls.xs' from '/usr/bin/perl -I./ -MExtUtils::XSpp::Cmd -e xspp -- -t typemap.xsp interface/wx/headercol.h' */


/* INCLUDE_COMMAND:  Including output of '/usr/bin/perl -I./ -MExtUtils::XSpp::Cmd -e xspp -- -t typemap.xsp interface/wx/button.h' from 'Controls.xs' */

#include <exception>

#undef  xsp_constructor_class
#define xsp_constructor_class(c) (c)
#include <wx/button.h>
#undef  xsp_constructor_class
#define xsp_constructor_class(c) (CLASS)

XS_EUPXS(XS_Wx__Button_newDefault); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Button_newDefault)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "CLASS");
    {
	char *	CLASS = (char *)SvPV_nolen(ST(0))
;
	wxButton *	RETVAL;
    try {
      RETVAL = new wxButton();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
     wxPli_create_evthandler( aTHX_ RETVAL, CLASS ); 
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_evthandler_2_sv( aTHX_ RETVALSV, RETVAL );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}

#undef  xsp_constructor_class
#define xsp_constructor_class(c) (c)
#undef  xsp_constructor_class
#define xsp_constructor_class(c) (CLASS)

XS_EUPXS(XS_Wx__Button_newFull); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Button_newFull)
{
    dVAR; dXSARGS;
    if (items < 3 || items > 9)
       croak_xs_usage(cv,  "CLASS, parent, id, label= wxEmptyString, pos= wxDefaultPosition, size= wxDefaultSize, style= 0, validator= wxDefaultValidatorPtr, name= wxButtonNameStr");
    {
	char *	CLASS = (char *)SvPV_nolen(ST(0))
;
	wxButton *	RETVAL;
	wxWindow*    parent = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::Window" )
;
	wxWindowID    id = wxPli_get_wxwindowid( aTHX_ ST(2) )
;
	wxString	label;
	wxPoint	pos;
	wxSize	size;
	long	style;
	wxValidator*	validator;
	wxString	name;

	if (items < 4)
	    label = wxEmptyString;
	else {
    WXSTRING_INPUT( label, wxString, ST(3) )
;
	}

	if (items < 5)
	    pos = wxDefaultPosition;
	else {
    pos = wxPli_sv_2_wxpoint( aTHX_ ST(4) )
;
	}

	if (items < 6)
	    size = wxDefaultSize;
	else {
    size = wxPli_sv_2_wxsize( aTHX_ ST(5) )
;
	}

	if (items < 7)
	    style = 0;
	else {
	    style = (long)SvIV(ST(6))
;
	}

	if (items < 8)
	    validator = wxDefaultValidatorPtr;
	else {
    validator = (wxValidator *) wxPli_sv_2_object( aTHX_ ST(7), "Wx::Validator" )
;
	}

	if (items < 9)
	    name = wxButtonNameStr;
	else {
    WXSTRING_INPUT( name, wxString, ST(8) )
;
	}
    try {
      RETVAL = new wxButton( parent, id, label, pos, size, style, *( validator ), name );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
     wxPli_create_evthandler( aTHX_ RETVAL, CLASS ); 
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_evthandler_2_sv( aTHX_ RETVALSV, RETVAL );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}

#undef  xsp_constructor_class
#define xsp_constructor_class(c) (c)

XS_EUPXS(XS_Wx__Button_Create); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Button_Create)
{
    dVAR; dXSARGS;
    if (items < 3 || items > 9)
       croak_xs_usage(cv,  "THIS, parent, id, label= wxEmptyString, pos= wxDefaultPosition, size= wxDefaultSize, style= 0, validator= wxDefaultValidatorPtr, name= wxButtonNameStr");
    {
	wxButton *    THIS = (wxButton *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Button" )
;
	bool	RETVAL;
	wxWindow*    parent = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::Window" )
;
	wxWindowID    id = wxPli_get_wxwindowid( aTHX_ ST(2) )
;
	wxString	label;
	wxPoint	pos;
	wxSize	size;
	long	style;
	wxValidator*	validator;
	wxString	name;

	if (items < 4)
	    label = wxEmptyString;
	else {
    WXSTRING_INPUT( label, wxString, ST(3) )
;
	}

	if (items < 5)
	    pos = wxDefaultPosition;
	else {
    pos = wxPli_sv_2_wxpoint( aTHX_ ST(4) )
;
	}

	if (items < 6)
	    size = wxDefaultSize;
	else {
    size = wxPli_sv_2_wxsize( aTHX_ ST(5) )
;
	}

	if (items < 7)
	    style = 0;
	else {
	    style = (long)SvIV(ST(6))
;
	}

	if (items < 8)
	    validator = wxDefaultValidatorPtr;
	else {
    validator = (wxValidator *) wxPli_sv_2_object( aTHX_ ST(7), "Wx::Validator" )
;
	}

	if (items < 9)
	    name = wxButtonNameStr;
	else {
    WXSTRING_INPUT( name, wxString, ST(8) )
;
	}
    try {
      RETVAL = THIS->Create( parent, id, label, pos, size, style, *( validator ), name );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}

#if WXPERL_W_VERSION_GE( 2, 9, 1 )
#define XSpp_238eacc7_050130
#define XSubPPtmpAACN 1


XS_EUPXS(XS_Wx__Button_GetAuthNeeded); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Button_GetAuthNeeded)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxButton *    THIS = (wxButton *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Button" )
;
	bool	RETVAL;
    try {
      RETVAL = THIS->GetAuthNeeded();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__Button_GetBitmap); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Button_GetBitmap)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxButton *    THIS = (wxButton *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Button" )
;
	wxBitmap *	RETVAL;
    try {
      RETVAL = new wxBitmap( THIS->GetBitmap() );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_object_2_sv( aTHX_ RETVALSV, RETVAL );
    wxPli_thread_sv_register( aTHX_ "Wx::Bitmap", RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__Button_GetBitmapCurrent); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Button_GetBitmapCurrent)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxButton *    THIS = (wxButton *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Button" )
;
	wxBitmap *	RETVAL;
    try {
      RETVAL = new wxBitmap( THIS->GetBitmapCurrent() );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_object_2_sv( aTHX_ RETVALSV, RETVAL );
    wxPli_thread_sv_register( aTHX_ "Wx::Bitmap", RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__Button_GetBitmapDisabled); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Button_GetBitmapDisabled)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxButton *    THIS = (wxButton *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Button" )
;
	wxBitmap *	RETVAL;
    try {
      RETVAL = new wxBitmap( THIS->GetBitmapDisabled() );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_object_2_sv( aTHX_ RETVALSV, RETVAL );
    wxPli_thread_sv_register( aTHX_ "Wx::Bitmap", RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__Button_GetBitmapFocus); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Button_GetBitmapFocus)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxButton *    THIS = (wxButton *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Button" )
;
	wxBitmap *	RETVAL;
    try {
      RETVAL = new wxBitmap( THIS->GetBitmapFocus() );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_object_2_sv( aTHX_ RETVALSV, RETVAL );
    wxPli_thread_sv_register( aTHX_ "Wx::Bitmap", RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__Button_GetBitmapLabel); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Button_GetBitmapLabel)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxButton *    THIS = (wxButton *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Button" )
;
	wxBitmap *	RETVAL;
    try {
      RETVAL = new wxBitmap( THIS->GetBitmapLabel() );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_object_2_sv( aTHX_ RETVALSV, RETVAL );
    wxPli_thread_sv_register( aTHX_ "Wx::Bitmap", RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__Button_GetBitmapPressed); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Button_GetBitmapPressed)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxButton *    THIS = (wxButton *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Button" )
;
	wxBitmap *	RETVAL;
    try {
      RETVAL = new wxBitmap( THIS->GetBitmapPressed() );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_object_2_sv( aTHX_ RETVALSV, RETVAL );
    wxPli_thread_sv_register( aTHX_ "Wx::Bitmap", RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__Button_GetBitmapMargins); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Button_GetBitmapMargins)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxButton *    THIS = (wxButton *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Button" )
;
	wxSize	RETVAL;
    try {
      RETVAL = THIS->GetBitmapMargins();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_non_object_2_sv( aTHX_ RETVALSV, new wxSize(RETVAL), "Wx::Size" );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}

#endif

XS_EUPXS(XS_Wx__Button_GetDefaultSize); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Button_GetDefaultSize)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	wxSize	RETVAL;
    try {
      RETVAL = wxButton::GetDefaultSize();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_non_object_2_sv( aTHX_ RETVALSV, new wxSize(RETVAL), "Wx::Size" );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__Button_GetLabel); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Button_GetLabel)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxButton *    THIS = (wxButton *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Button" )
;
	wxString	RETVAL;
    try {
      RETVAL = THIS->GetLabel();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    WXSTRING_OUTPUT( RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}

#if WXPERL_W_VERSION_GE( 2, 9, 1 )
#define XSpp_238eacc7_042573
#define XSubPPtmpAACO 1


XS_EUPXS(XS_Wx__Button_SetAuthNeeded); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Button_SetAuthNeeded)
{
    dVAR; dXSARGS;
    if (items < 1 || items > 2)
       croak_xs_usage(cv,  "THIS, needed= true");
    {
	wxButton *    THIS = (wxButton *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Button" )
;
	bool	needed;

	if (items < 2)
	    needed = true;
	else {
	    needed = (bool)SvTRUE(ST(1))
;
	}
    try {
      THIS->SetAuthNeeded( needed );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__Button_SetBitmap); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Button_SetBitmap)
{
    dVAR; dXSARGS;
    if (items < 2 || items > 3)
       croak_xs_usage(cv,  "THIS, bitmap, dir= wxLEFT");
    {
	wxButton *    THIS = (wxButton *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Button" )
;
	wxBitmap*    bitmap = (wxBitmap *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::Bitmap" )
;
	wxDirection	dir;

	if (items < 3)
	    dir = wxLEFT;
	else {
	    dir = (wxDirection)SvIV(ST(2))
;
	}
    try {
      THIS->SetBitmap( *( bitmap ), dir );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__Button_SetBitmapCurrent); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Button_SetBitmapCurrent)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, bitmap");
    {
	wxButton *    THIS = (wxButton *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Button" )
;
	wxBitmap*    bitmap = (wxBitmap *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::Bitmap" )
;
    try {
      THIS->SetBitmapCurrent( *( bitmap ) );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__Button_SetBitmapDisabled); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Button_SetBitmapDisabled)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, bitmap");
    {
	wxButton *    THIS = (wxButton *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Button" )
;
	wxBitmap*    bitmap = (wxBitmap *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::Bitmap" )
;
    try {
      THIS->SetBitmapDisabled( *( bitmap ) );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__Button_SetBitmapFocus); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Button_SetBitmapFocus)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, bitmap");
    {
	wxButton *    THIS = (wxButton *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Button" )
;
	wxBitmap*    bitmap = (wxBitmap *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::Bitmap" )
;
    try {
      THIS->SetBitmapFocus( *( bitmap ) );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__Button_SetBitmapLabel); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Button_SetBitmapLabel)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, bitmap");
    {
	wxButton *    THIS = (wxButton *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Button" )
;
	wxBitmap*    bitmap = (wxBitmap *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::Bitmap" )
;
    try {
      THIS->SetBitmapLabel( *( bitmap ) );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__Button_SetBitmapPressed); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Button_SetBitmapPressed)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, bitmap");
    {
	wxButton *    THIS = (wxButton *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Button" )
;
	wxBitmap*    bitmap = (wxBitmap *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::Bitmap" )
;
    try {
      THIS->SetBitmapPressed( *( bitmap ) );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__Button_SetBitmapMargins0); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Button_SetBitmapMargins0)
{
    dVAR; dXSARGS;
    if (items != 3)
       croak_xs_usage(cv,  "THIS, x, y");
    {
	wxButton *    THIS = (wxButton *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Button" )
;
	wxCoord	x = (wxCoord)SvIV(ST(1))
;
	wxCoord	y = (wxCoord)SvIV(ST(2))
;
    try {
      THIS->SetBitmapMargins( x, y );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__Button_SetBitmapMargins1); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Button_SetBitmapMargins1)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, sz");
    {
	wxButton *    THIS = (wxButton *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Button" )
;
	wxSize    sz = wxPli_sv_2_wxsize( aTHX_ ST(1) )
;
    try {
      THIS->SetBitmapMargins( sz );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__Button_SetBitmapPosition); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Button_SetBitmapPosition)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, dir");
    {
	wxButton *    THIS = (wxButton *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Button" )
;
	wxDirection	dir = (wxDirection)SvIV(ST(1))
;
    try {
      THIS->SetBitmapPosition( dir );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}

#endif
#if WXPERL_W_VERSION_GE( 2, 9, 1 )
#define XSpp_238eacc7_068176
#define XSubPPtmpAACP 1


XS_EUPXS(XS_Wx__Button_SetDefault0); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Button_SetDefault0)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxButton *    THIS = (wxButton *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Button" )
;
	wxWindow *	RETVAL;
    try {
      RETVAL = THIS->SetDefault();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_object_2_sv( aTHX_ RETVALSV, RETVAL );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}

#else
#define XSpp_238eacc7_045836
#define XSubPPtmpAACQ 1


XS_EUPXS(XS_Wx__Button_SetDefault1); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Button_SetDefault1)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxButton *    THIS = (wxButton *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Button" )
;
    try {
      THIS->SetDefault();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}

#endif

XS_EUPXS(XS_Wx__Button_SetLabel); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Button_SetLabel)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, label");
    {
	wxButton *    THIS = (wxButton *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Button" )
;
	wxString	label;

    WXSTRING_INPUT( label, wxString, ST(1) )
;
    try {
      THIS->SetLabel( label );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}

#include "cpp/overload.h"
#if 1
#define XSubPPtmpAACR 1


XS_EUPXS(XS_Wx__Button_SetBitmapMargins); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Button_SetBitmapMargins)
{
    dVAR; dXSARGS;
    if (items < 1)
       croak_xs_usage(cv,  "THIS, ...");
    PERL_UNUSED_VAR(ax); /* -Wall */
    SP -= items;
    {
	wxButton *    THIS = (wxButton *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Button" )
;
#if defined( XSpp_238eacc7_042573 )
    static const char *SetBitmapMargins0_types[] = { wxPliOvlnum, wxPliOvlnum };
    static wxPliPrototype SetBitmapMargins0_proto( SetBitmapMargins0_types, sizeof( SetBitmapMargins0_types ) / sizeof( SetBitmapMargins0_types[0] ) );
#endif // defined( XSpp_238eacc7_042573 )
#if defined( XSpp_238eacc7_042573 )
    static const char *SetBitmapMargins1_types[] = { wxPliOvlwsiz };
    static wxPliPrototype SetBitmapMargins1_proto( SetBitmapMargins1_types, sizeof( SetBitmapMargins1_types ) / sizeof( SetBitmapMargins1_types[0] ) );
#endif // defined( XSpp_238eacc7_042573 )
    static wxPliPrototype *wxPliOvl_all_prototypes[] = {
#if defined( XSpp_238eacc7_042573 )
        &SetBitmapMargins0_proto,
#endif // defined( XSpp_238eacc7_042573 )
#if defined( XSpp_238eacc7_042573 )
        &SetBitmapMargins1_proto,
#endif // defined( XSpp_238eacc7_042573 )
        NULL };
    BEGIN_OVERLOAD()
#if defined( XSpp_238eacc7_042573 )
        MATCH_REDISP_COUNT( SetBitmapMargins0_proto, SetBitmapMargins0, 2 )
#endif // defined( XSpp_238eacc7_042573 )
#if defined( XSpp_238eacc7_042573 )
        MATCH_REDISP_COUNT( SetBitmapMargins1_proto, SetBitmapMargins1, 1 )
#endif // defined( XSpp_238eacc7_042573 )
    END_OVERLOAD_MESSAGE( Wx::Button::SetBitmapMargins, wxPliOvl_all_prototypes )
	PUTBACK;
	return;
    }
}

#endif // 1
#if 1
#define XSubPPtmpAACS 1


XS_EUPXS(XS_Wx__Button_SetDefault); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Button_SetDefault)
{
    dVAR; dXSARGS;
    if (items < 1)
       croak_xs_usage(cv,  "THIS, ...");
    PERL_UNUSED_VAR(ax); /* -Wall */
    SP -= items;
    {
	wxButton *    THIS = (wxButton *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Button" )
;
#if defined( XSpp_238eacc7_068176 )
    static wxPliPrototype void_proto( NULL, 0 );
#endif // defined( XSpp_238eacc7_068176 )
#if defined( XSpp_238eacc7_045836 )
    static wxPliPrototype void_proto( NULL, 0 );
#endif // defined( XSpp_238eacc7_045836 )
    static wxPliPrototype *wxPliOvl_all_prototypes[] = {
#if defined( XSpp_238eacc7_068176 )
        &void_proto,
#endif // defined( XSpp_238eacc7_068176 )
#if defined( XSpp_238eacc7_045836 )
        &void_proto,
#endif // defined( XSpp_238eacc7_045836 )
        NULL };
    BEGIN_OVERLOAD()
#if defined( XSpp_238eacc7_068176 )
        MATCH_VOIDM_REDISP( SetDefault0 )
#endif // defined( XSpp_238eacc7_068176 )
#if defined( XSpp_238eacc7_045836 )
        MATCH_VOIDM_REDISP( SetDefault1 )
#endif // defined( XSpp_238eacc7_045836 )
    END_OVERLOAD_MESSAGE( Wx::Button::SetDefault, wxPliOvl_all_prototypes )
	PUTBACK;
	return;
    }
}

#endif // 1
#if 1
#define XSubPPtmpAACT 1


XS_EUPXS(XS_Wx__Button_new); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Button_new)
{
    dVAR; dXSARGS;
    if (items < 1)
       croak_xs_usage(cv,  "CLASS, ...");
    PERL_UNUSED_VAR(ax); /* -Wall */
    SP -= items;
    {
	char *	CLASS = (char *)SvPV_nolen(ST(0))
;
#if 1
    static wxPliPrototype void_proto( NULL, 0 );
#endif // 1
    static wxPliPrototype *wxPliOvl_all_prototypes[] = {
#if 1
        &void_proto,
#endif // 1
        NULL };
    BEGIN_OVERLOAD()
#if 1
        MATCH_VOIDM_REDISP( newDefault )
#endif // 1
#if 1
        MATCH_ANY_REDISP( newFull )
#endif // 1
    END_OVERLOAD_MESSAGE( Wx::Button::new, wxPliOvl_all_prototypes )
	PUTBACK;
	return;
    }
}

#endif // 1

/* INCLUDE: Returning to 'Controls.xs' from '/usr/bin/perl -I./ -MExtUtils::XSpp::Cmd -e xspp -- -t typemap.xsp interface/wx/button.h' */


/* INCLUDE_COMMAND:  Including output of '/usr/bin/perl -I./ -MExtUtils::XSpp::Cmd -e xspp -- -t typemap.xsp interface/wx/commandlinkbutton.h' from 'Controls.xs' */

#include <exception>

#undef  xsp_constructor_class
#define xsp_constructor_class(c) (c)
#if WXPERL_W_VERSION_GE( 2, 9, 2 )
#define XSpp_14221074_058233
#include <wx/commandlinkbutton.h>
#undef  xsp_constructor_class
#define xsp_constructor_class(c) (CLASS)
#define XSubPPtmpAACU 1


XS_EUPXS(XS_Wx__CommandLinkButton_newDefault); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__CommandLinkButton_newDefault)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "CLASS");
    {
	char *	CLASS = (char *)SvPV_nolen(ST(0))
;
	wxCommandLinkButton *	RETVAL;
    try {
      RETVAL = new wxCommandLinkButton();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
     wxPli_create_evthandler( aTHX_ RETVAL, CLASS ); 
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_evthandler_2_sv( aTHX_ RETVALSV, RETVAL );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}

#undef  xsp_constructor_class
#define xsp_constructor_class(c) (c)
#undef  xsp_constructor_class
#define xsp_constructor_class(c) (CLASS)

XS_EUPXS(XS_Wx__CommandLinkButton_newFull); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__CommandLinkButton_newFull)
{
    dVAR; dXSARGS;
    if (items < 3 || items > 10)
       croak_xs_usage(cv,  "CLASS, parent, id, mainLabel= wxEmptyString, note= wxEmptyString, pos= wxDefaultPosition, size= wxDefaultSize, style= 0, validator= wxDefaultValidatorPtr, name= wxButtonNameStr");
    {
	char *	CLASS = (char *)SvPV_nolen(ST(0))
;
	wxCommandLinkButton *	RETVAL;
	wxWindow*    parent = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::Window" )
;
	wxWindowID    id = wxPli_get_wxwindowid( aTHX_ ST(2) )
;
	wxString	mainLabel;
	wxString	note;
	wxPoint	pos;
	wxSize	size;
	long	style;
	wxValidator*	validator;
	wxString	name;

	if (items < 4)
	    mainLabel = wxEmptyString;
	else {
    WXSTRING_INPUT( mainLabel, wxString, ST(3) )
;
	}

	if (items < 5)
	    note = wxEmptyString;
	else {
    WXSTRING_INPUT( note, wxString, ST(4) )
;
	}

	if (items < 6)
	    pos = wxDefaultPosition;
	else {
    pos = wxPli_sv_2_wxpoint( aTHX_ ST(5) )
;
	}

	if (items < 7)
	    size = wxDefaultSize;
	else {
    size = wxPli_sv_2_wxsize( aTHX_ ST(6) )
;
	}

	if (items < 8)
	    style = 0;
	else {
	    style = (long)SvIV(ST(7))
;
	}

	if (items < 9)
	    validator = wxDefaultValidatorPtr;
	else {
    validator = (wxValidator *) wxPli_sv_2_object( aTHX_ ST(8), "Wx::Validator" )
;
	}

	if (items < 10)
	    name = wxButtonNameStr;
	else {
    WXSTRING_INPUT( name, wxString, ST(9) )
;
	}
    try {
      RETVAL = new wxCommandLinkButton( parent, id, mainLabel, note, pos, size, style, *( validator ), name );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
     wxPli_create_evthandler( aTHX_ RETVAL, CLASS ); 
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_evthandler_2_sv( aTHX_ RETVALSV, RETVAL );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}

#undef  xsp_constructor_class
#define xsp_constructor_class(c) (c)

XS_EUPXS(XS_Wx__CommandLinkButton_Create); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__CommandLinkButton_Create)
{
    dVAR; dXSARGS;
    if (items < 3 || items > 10)
       croak_xs_usage(cv,  "THIS, parent, id, mainLabel= wxEmptyString, note= wxEmptyString, pos= wxDefaultPosition, size= wxDefaultSize, style= 0, validator= wxDefaultValidatorPtr, name= wxButtonNameStr");
    {
	wxCommandLinkButton *    THIS = (wxCommandLinkButton *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::CommandLinkButton" )
;
	bool	RETVAL;
	wxWindow*    parent = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::Window" )
;
	wxWindowID    id = wxPli_get_wxwindowid( aTHX_ ST(2) )
;
	wxString	mainLabel;
	wxString	note;
	wxPoint	pos;
	wxSize	size;
	long	style;
	wxValidator*	validator;
	wxString	name;

	if (items < 4)
	    mainLabel = wxEmptyString;
	else {
    WXSTRING_INPUT( mainLabel, wxString, ST(3) )
;
	}

	if (items < 5)
	    note = wxEmptyString;
	else {
    WXSTRING_INPUT( note, wxString, ST(4) )
;
	}

	if (items < 6)
	    pos = wxDefaultPosition;
	else {
    pos = wxPli_sv_2_wxpoint( aTHX_ ST(5) )
;
	}

	if (items < 7)
	    size = wxDefaultSize;
	else {
    size = wxPli_sv_2_wxsize( aTHX_ ST(6) )
;
	}

	if (items < 8)
	    style = 0;
	else {
	    style = (long)SvIV(ST(7))
;
	}

	if (items < 9)
	    validator = wxDefaultValidatorPtr;
	else {
    validator = (wxValidator *) wxPli_sv_2_object( aTHX_ ST(8), "Wx::Validator" )
;
	}

	if (items < 10)
	    name = wxButtonNameStr;
	else {
    WXSTRING_INPUT( name, wxString, ST(9) )
;
	}
    try {
      RETVAL = THIS->Create( parent, id, mainLabel, note, pos, size, style, *( validator ), name );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__CommandLinkButton_SetMainLabelAndNote); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__CommandLinkButton_SetMainLabelAndNote)
{
    dVAR; dXSARGS;
    if (items != 3)
       croak_xs_usage(cv,  "THIS, mainLabel, note");
    {
	wxCommandLinkButton *    THIS = (wxCommandLinkButton *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::CommandLinkButton" )
;
	wxString	mainLabel;
	wxString	note;

    WXSTRING_INPUT( mainLabel, wxString, ST(1) )
;

    WXSTRING_INPUT( note, wxString, ST(2) )
;
    try {
      THIS->SetMainLabelAndNote( mainLabel, note );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__CommandLinkButton_SetLabel); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__CommandLinkButton_SetLabel)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, label");
    {
	wxCommandLinkButton *    THIS = (wxCommandLinkButton *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::CommandLinkButton" )
;
	wxString	label;

    WXSTRING_INPUT( label, wxString, ST(1) )
;
    try {
      THIS->SetLabel( label );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__CommandLinkButton_GetLabel); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__CommandLinkButton_GetLabel)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxCommandLinkButton *    THIS = (wxCommandLinkButton *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::CommandLinkButton" )
;
	wxString	RETVAL;
    try {
      RETVAL = THIS->GetLabel();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    WXSTRING_OUTPUT( RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__CommandLinkButton_SetMainLabel); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__CommandLinkButton_SetMainLabel)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, mainLabel");
    {
	wxCommandLinkButton *    THIS = (wxCommandLinkButton *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::CommandLinkButton" )
;
	wxString	mainLabel;

    WXSTRING_INPUT( mainLabel, wxString, ST(1) )
;
    try {
      THIS->SetMainLabel( mainLabel );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__CommandLinkButton_SetNote); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__CommandLinkButton_SetNote)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, note");
    {
	wxCommandLinkButton *    THIS = (wxCommandLinkButton *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::CommandLinkButton" )
;
	wxString	note;

    WXSTRING_INPUT( note, wxString, ST(1) )
;
    try {
      THIS->SetNote( note );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__CommandLinkButton_GetMainLabel); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__CommandLinkButton_GetMainLabel)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxCommandLinkButton *    THIS = (wxCommandLinkButton *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::CommandLinkButton" )
;
	wxString	RETVAL;
    try {
      RETVAL = THIS->GetMainLabel();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    WXSTRING_OUTPUT( RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__CommandLinkButton_GetNote); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__CommandLinkButton_GetNote)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxCommandLinkButton *    THIS = (wxCommandLinkButton *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::CommandLinkButton" )
;
	wxString	RETVAL;
    try {
      RETVAL = THIS->GetNote();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    WXSTRING_OUTPUT( RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}

#include "cpp/overload.h"
#if defined( XSpp_14221074_058233 )
#define XSubPPtmpAACV 1


XS_EUPXS(XS_Wx__CommandLinkButton_new); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__CommandLinkButton_new)
{
    dVAR; dXSARGS;
    if (items < 1)
       croak_xs_usage(cv,  "CLASS, ...");
    PERL_UNUSED_VAR(ax); /* -Wall */
    SP -= items;
    {
	char *	CLASS = (char *)SvPV_nolen(ST(0))
;
#if defined( XSpp_14221074_058233 )
    static wxPliPrototype void_proto( NULL, 0 );
#endif // defined( XSpp_14221074_058233 )
    static wxPliPrototype *wxPliOvl_all_prototypes[] = {
#if defined( XSpp_14221074_058233 )
        &void_proto,
#endif // defined( XSpp_14221074_058233 )
        NULL };
    BEGIN_OVERLOAD()
#if defined( XSpp_14221074_058233 )
        MATCH_VOIDM_REDISP( newDefault )
#endif // defined( XSpp_14221074_058233 )
#if defined( XSpp_14221074_058233 )
        MATCH_ANY_REDISP( newFull )
#endif // defined( XSpp_14221074_058233 )
    END_OVERLOAD_MESSAGE( Wx::CommandLinkButton::new, wxPliOvl_all_prototypes )
	PUTBACK;
	return;
    }
}

#endif // defined( XSpp_14221074_058233 )
#endif

/* INCLUDE: Returning to 'Controls.xs' from '/usr/bin/perl -I./ -MExtUtils::XSpp::Cmd -e xspp -- -t typemap.xsp interface/wx/commandlinkbutton.h' */


/* INCLUDE_COMMAND:  Including output of '/usr/bin/perl -I./ -MExtUtils::XSpp::Cmd -e xspp -- -t typemap.xsp interface/wx/treelist.h' from 'Controls.xs' */

#include <exception>

#undef  xsp_constructor_class
#define xsp_constructor_class(c) (c)
#if WXPERL_W_VERSION_GE( 2, 9, 3 )
#define XSpp_9e3a6f40_027014
#include <wx/treelist.h>
#define XSubPPtmpAACW 1


XS_EUPXS(XS_Wx__TreeListItem_CLONE); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__TreeListItem_CLONE)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "CLASS");
    {
	char *	CLASS = (char *)SvPV_nolen(ST(0))
;
    wxPli_thread_sv_clone( aTHX_ CLASS, (wxPliCloneSV)wxPli_detach_object );
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__TreeListItem_DESTROY); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__TreeListItem_DESTROY)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxTreeListItem *    THIS = (wxTreeListItem *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::TreeListItem" )
;
      wxPli_thread_sv_unregister( aTHX_ "Wx::TreeListItem", THIS, ST(0) ); 
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__TreeListItem_IsOk); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__TreeListItem_IsOk)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxTreeListItem *    THIS = (wxTreeListItem *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::TreeListItem" )
;
	bool	RETVAL;
    try {
      RETVAL = THIS->IsOk();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}

#include "xspp/wxpltreelistitemcomparator.h"

XS_EUPXS(XS_Wx__TreeListItemComparator_Compare); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__TreeListItemComparator_Compare)
{
    dVAR; dXSARGS;
    if (items != 5)
       croak_xs_usage(cv,  "THIS, treelist, column, first, second");
    {
	wxTreeListItemComparator *    THIS = (wxTreeListItemComparator *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::TreeListItemComparator" )
;
	int	RETVAL;
	dXSTARG;
	wxTreeListCtrl*    treelist = (wxTreeListCtrl *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::TreeListCtrl" )
;
	unsigned int    column = (unsigned int)SvUV( ST(2) )
;
	wxTreeListItem*    first = (wxTreeListItem *) wxPli_sv_2_object( aTHX_ ST(3), "Wx::TreeListItem" )
;
	wxTreeListItem*    second = (wxTreeListItem *) wxPli_sv_2_object( aTHX_ ST(4), "Wx::TreeListItem" )
;
    try {
      RETVAL = THIS->Compare( treelist, column, *( first ), *( second ) );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}

#undef  xsp_constructor_class
#define xsp_constructor_class(c) (CLASS)

XS_EUPXS(XS_Wx__TreeListCtrl_newDefault); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__TreeListCtrl_newDefault)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "CLASS");
    {
	char *	CLASS = (char *)SvPV_nolen(ST(0))
;
	wxTreeListCtrl *	RETVAL;
    try {
      RETVAL = new wxTreeListCtrl();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
     wxPli_create_evthandler( aTHX_ RETVAL, CLASS ); 
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_evthandler_2_sv( aTHX_ RETVALSV, RETVAL );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}

#undef  xsp_constructor_class
#define xsp_constructor_class(c) (c)
#undef  xsp_constructor_class
#define xsp_constructor_class(c) (CLASS)

XS_EUPXS(XS_Wx__TreeListCtrl_newFull); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__TreeListCtrl_newFull)
{
    dVAR; dXSARGS;
    if (items < 3 || items > 7)
       croak_xs_usage(cv,  "CLASS, parent, id, pos= wxDefaultPosition, size= wxDefaultSize, style= wxTL_DEFAULT_STYLE, name= wxTreeListCtrlNameStr");
    {
	char *	CLASS = (char *)SvPV_nolen(ST(0))
;
	wxTreeListCtrl *	RETVAL;
	wxWindow*    parent = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::Window" )
;
	wxWindowID    id = wxPli_get_wxwindowid( aTHX_ ST(2) )
;
	wxPoint	pos;
	wxSize	size;
	long	style;
	wxString	name;

	if (items < 4)
	    pos = wxDefaultPosition;
	else {
    pos = wxPli_sv_2_wxpoint( aTHX_ ST(3) )
;
	}

	if (items < 5)
	    size = wxDefaultSize;
	else {
    size = wxPli_sv_2_wxsize( aTHX_ ST(4) )
;
	}

	if (items < 6)
	    style = wxTL_DEFAULT_STYLE;
	else {
	    style = (long)SvIV(ST(5))
;
	}

	if (items < 7)
	    name = wxTreeListCtrlNameStr;
	else {
    WXSTRING_INPUT( name, wxString, ST(6) )
;
	}
    try {
      RETVAL = new wxTreeListCtrl( parent, id, pos, size, style, name );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
     wxPli_create_evthandler( aTHX_ RETVAL, CLASS ); 
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_evthandler_2_sv( aTHX_ RETVALSV, RETVAL );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}

#undef  xsp_constructor_class
#define xsp_constructor_class(c) (c)

XS_EUPXS(XS_Wx__TreeListCtrl_Create); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__TreeListCtrl_Create)
{
    dVAR; dXSARGS;
    if (items < 3 || items > 7)
       croak_xs_usage(cv,  "THIS, parent, id, pos= wxDefaultPosition, size= wxDefaultSize, style= wxTL_DEFAULT_STYLE, name= wxTreeListCtrlNameStr");
    {
	wxTreeListCtrl *    THIS = (wxTreeListCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::TreeListCtrl" )
;
	bool	RETVAL;
	wxWindow*    parent = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::Window" )
;
	wxWindowID    id = wxPli_get_wxwindowid( aTHX_ ST(2) )
;
	wxPoint	pos;
	wxSize	size;
	long	style;
	wxString	name;

	if (items < 4)
	    pos = wxDefaultPosition;
	else {
    pos = wxPli_sv_2_wxpoint( aTHX_ ST(3) )
;
	}

	if (items < 5)
	    size = wxDefaultSize;
	else {
    size = wxPli_sv_2_wxsize( aTHX_ ST(4) )
;
	}

	if (items < 6)
	    style = wxTL_DEFAULT_STYLE;
	else {
	    style = (long)SvIV(ST(5))
;
	}

	if (items < 7)
	    name = wxTreeListCtrlNameStr;
	else {
    WXSTRING_INPUT( name, wxString, ST(6) )
;
	}
    try {
      RETVAL = THIS->Create( parent, id, pos, size, style, name );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__TreeListCtrl_AssignImageList); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__TreeListCtrl_AssignImageList)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, imagelist");
    {
	wxImageList*    imagelist = (wxImageList *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::ImageList" )
;
	wxTreeListCtrl *    THIS = (wxTreeListCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::TreeListCtrl" )
;
    wxPli_object_set_deleteable( aTHX_ ST(1), false );
    THIS->AssignImageList( imagelist );
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__TreeListCtrl_GetImageList); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__TreeListCtrl_GetImageList)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxTreeListCtrl *    THIS = (wxTreeListCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::TreeListCtrl" )
;
	wxImageList *	RETVAL;

	RETVAL = THIS->GetImageList();
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_object_2_sv( aTHX_ RETVALSV, RETVAL );
    wxPli_thread_sv_register( aTHX_ "Wx::ImageList", RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    wxPli_object_set_deleteable( aTHX_ ST(0), false );
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__TreeListCtrl_SetImageList); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__TreeListCtrl_SetImageList)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, imageList");
    {
	wxTreeListCtrl *    THIS = (wxTreeListCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::TreeListCtrl" )
;
	wxImageList*    imageList = (wxImageList *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::ImageList" )
;
    try {
      THIS->SetImageList( imageList );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__TreeListCtrl_AppendColumn); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__TreeListCtrl_AppendColumn)
{
    dVAR; dXSARGS;
    if (items < 2 || items > 5)
       croak_xs_usage(cv,  "THIS, title, width= wxCOL_WIDTH_AUTOSIZE, align= wxALIGN_LEFT, flags= wxCOL_RESIZABLE");
    {
	wxTreeListCtrl *    THIS = (wxTreeListCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::TreeListCtrl" )
;
	int	RETVAL;
	dXSTARG;
	wxString	title;
	int	width;
	wxAlignment	align;
	int	flags;

    WXSTRING_INPUT( title, wxString, ST(1) )
;

	if (items < 3)
	    width = wxCOL_WIDTH_AUTOSIZE;
	else {
	    width = (int)SvIV(ST(2))
;
	}

	if (items < 4)
	    align = wxALIGN_LEFT;
	else {
	    align = (wxAlignment)SvIV(ST(3))
;
	}

	if (items < 5)
	    flags = wxCOL_RESIZABLE;
	else {
	    flags = (int)SvIV(ST(4))
;
	}
    try {
      RETVAL = THIS->AppendColumn( title, width, align, flags );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__TreeListCtrl_GetColumnCount); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__TreeListCtrl_GetColumnCount)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxTreeListCtrl *    THIS = (wxTreeListCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::TreeListCtrl" )
;
	unsigned int	RETVAL;
	dXSTARG;
    try {
      RETVAL = THIS->GetColumnCount();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	XSprePUSH;
	PUSHu((UV)RETVAL );
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__TreeListCtrl_DeleteColumn); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__TreeListCtrl_DeleteColumn)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, col");
    {
	wxTreeListCtrl *    THIS = (wxTreeListCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::TreeListCtrl" )
;
	bool	RETVAL;
	unsigned int    col = (unsigned int)SvUV( ST(1) )
;
    try {
      RETVAL = THIS->DeleteColumn( col );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__TreeListCtrl_ClearColumns); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__TreeListCtrl_ClearColumns)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxTreeListCtrl *    THIS = (wxTreeListCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::TreeListCtrl" )
;
    try {
      THIS->ClearColumns();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__TreeListCtrl_SetColumnWidth); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__TreeListCtrl_SetColumnWidth)
{
    dVAR; dXSARGS;
    if (items != 3)
       croak_xs_usage(cv,  "THIS, col, width");
    {
	wxTreeListCtrl *    THIS = (wxTreeListCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::TreeListCtrl" )
;
	unsigned int    col = (unsigned int)SvUV( ST(1) )
;
	int	width = (int)SvIV(ST(2))
;
    try {
      THIS->SetColumnWidth( col, width );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__TreeListCtrl_GetColumnWidth); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__TreeListCtrl_GetColumnWidth)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, col");
    {
	wxTreeListCtrl *    THIS = (wxTreeListCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::TreeListCtrl" )
;
	int	RETVAL;
	dXSTARG;
	unsigned int    col = (unsigned int)SvUV( ST(1) )
;
    try {
      RETVAL = THIS->GetColumnWidth( col );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__TreeListCtrl_WidthFor); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__TreeListCtrl_WidthFor)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, text");
    {
	wxTreeListCtrl *    THIS = (wxTreeListCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::TreeListCtrl" )
;
	int	RETVAL;
	dXSTARG;
	wxString	text;

    WXSTRING_INPUT( text, wxString, ST(1) )
;
    try {
      RETVAL = THIS->WidthFor( text );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__TreeListCtrl_AppendItem); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__TreeListCtrl_AppendItem)
{
    dVAR; dXSARGS;
    if (items < 3 || items > 6)
       croak_xs_usage(cv,  "THIS, parent, text, imageClosed= -1, imageOpened= -1, data= NULL");
    {
	wxTreeListCtrl *    THIS = (wxTreeListCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::TreeListCtrl" )
;
	wxTreeListItem *	RETVAL;
	wxTreeListItem*    parent = (wxTreeListItem *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::TreeListItem" )
;
	wxString	text;
	int	imageClosed;
	int	imageOpened;
	wxPliUserDataCD*	data;

    WXSTRING_INPUT( text, wxString, ST(2) )
;

	if (items < 4)
	    imageClosed = -1;
	else {
	    imageClosed = (int)SvIV(ST(3))
;
	}

	if (items < 5)
	    imageOpened = -1;
	else {
	    imageOpened = (int)SvIV(ST(4))
;
	}

	if (items < 6)
	    data = NULL;
	else {
    if( SvOK( ST(5) ) )
    {
	data = new wxPliUserDataCD( ST(5) );
    }
    else
	data = 0
;
	}
    try {
      RETVAL = new wxTreeListItem( THIS->AppendItem( *( parent ), text, imageClosed, imageOpened, data ) );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_non_object_2_sv( aTHX_ RETVALSV, RETVAL, "Wx::TreeListItem" );
    wxPli_thread_sv_register( aTHX_ "Wx::TreeListItem", RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__TreeListCtrl_InsertItem); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__TreeListCtrl_InsertItem)
{
    dVAR; dXSARGS;
    if (items < 4 || items > 7)
       croak_xs_usage(cv,  "THIS, parent, previous, text, imageClosed= -1, imageOpened= -1, data= NULL");
    {
	wxTreeListCtrl *    THIS = (wxTreeListCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::TreeListCtrl" )
;
	wxTreeListItem *	RETVAL;
	wxTreeListItem*    parent = (wxTreeListItem *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::TreeListItem" )
;
	wxTreeListItem*    previous = (wxTreeListItem *) wxPli_sv_2_object( aTHX_ ST(2), "Wx::TreeListItem" )
;
	wxString	text;
	int	imageClosed;
	int	imageOpened;
	wxPliUserDataCD*	data;

    WXSTRING_INPUT( text, wxString, ST(3) )
;

	if (items < 5)
	    imageClosed = -1;
	else {
	    imageClosed = (int)SvIV(ST(4))
;
	}

	if (items < 6)
	    imageOpened = -1;
	else {
	    imageOpened = (int)SvIV(ST(5))
;
	}

	if (items < 7)
	    data = NULL;
	else {
    if( SvOK( ST(6) ) )
    {
	data = new wxPliUserDataCD( ST(6) );
    }
    else
	data = 0
;
	}
    try {
      RETVAL = new wxTreeListItem( THIS->InsertItem( *( parent ), *( previous ), text, imageClosed, imageOpened, data ) );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_non_object_2_sv( aTHX_ RETVALSV, RETVAL, "Wx::TreeListItem" );
    wxPli_thread_sv_register( aTHX_ "Wx::TreeListItem", RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__TreeListCtrl_PrependItem); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__TreeListCtrl_PrependItem)
{
    dVAR; dXSARGS;
    if (items < 3 || items > 6)
       croak_xs_usage(cv,  "THIS, parent, text, imageClosed= -1, imageOpened= -1, data= NULL");
    {
	wxTreeListCtrl *    THIS = (wxTreeListCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::TreeListCtrl" )
;
	wxTreeListItem *	RETVAL;
	wxTreeListItem*    parent = (wxTreeListItem *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::TreeListItem" )
;
	wxString	text;
	int	imageClosed;
	int	imageOpened;
	wxPliUserDataCD*	data;

    WXSTRING_INPUT( text, wxString, ST(2) )
;

	if (items < 4)
	    imageClosed = -1;
	else {
	    imageClosed = (int)SvIV(ST(3))
;
	}

	if (items < 5)
	    imageOpened = -1;
	else {
	    imageOpened = (int)SvIV(ST(4))
;
	}

	if (items < 6)
	    data = NULL;
	else {
    if( SvOK( ST(5) ) )
    {
	data = new wxPliUserDataCD( ST(5) );
    }
    else
	data = 0
;
	}
    try {
      RETVAL = new wxTreeListItem( THIS->PrependItem( *( parent ), text, imageClosed, imageOpened, data ) );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_non_object_2_sv( aTHX_ RETVALSV, RETVAL, "Wx::TreeListItem" );
    wxPli_thread_sv_register( aTHX_ "Wx::TreeListItem", RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__TreeListCtrl_DeleteItem); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__TreeListCtrl_DeleteItem)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, item");
    {
	wxTreeListCtrl *    THIS = (wxTreeListCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::TreeListCtrl" )
;
	wxTreeListItem*    item = (wxTreeListItem *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::TreeListItem" )
;
    try {
      THIS->DeleteItem( *( item ) );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__TreeListCtrl_DeleteAllItems); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__TreeListCtrl_DeleteAllItems)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxTreeListCtrl *    THIS = (wxTreeListCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::TreeListCtrl" )
;
    try {
      THIS->DeleteAllItems();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__TreeListCtrl_GetRootItem); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__TreeListCtrl_GetRootItem)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxTreeListCtrl *    THIS = (wxTreeListCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::TreeListCtrl" )
;
	wxTreeListItem *	RETVAL;
    try {
      RETVAL = new wxTreeListItem( THIS->GetRootItem() );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_non_object_2_sv( aTHX_ RETVALSV, RETVAL, "Wx::TreeListItem" );
    wxPli_thread_sv_register( aTHX_ "Wx::TreeListItem", RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__TreeListCtrl_GetItemParent); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__TreeListCtrl_GetItemParent)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, item");
    {
	wxTreeListCtrl *    THIS = (wxTreeListCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::TreeListCtrl" )
;
	wxTreeListItem *	RETVAL;
	wxTreeListItem*    item = (wxTreeListItem *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::TreeListItem" )
;
    try {
      RETVAL = new wxTreeListItem( THIS->GetItemParent( *( item ) ) );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_non_object_2_sv( aTHX_ RETVALSV, RETVAL, "Wx::TreeListItem" );
    wxPli_thread_sv_register( aTHX_ "Wx::TreeListItem", RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__TreeListCtrl_GetFirstChild); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__TreeListCtrl_GetFirstChild)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, item");
    {
	wxTreeListCtrl *    THIS = (wxTreeListCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::TreeListCtrl" )
;
	wxTreeListItem *	RETVAL;
	wxTreeListItem*    item = (wxTreeListItem *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::TreeListItem" )
;
    try {
      RETVAL = new wxTreeListItem( THIS->GetFirstChild( *( item ) ) );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_non_object_2_sv( aTHX_ RETVALSV, RETVAL, "Wx::TreeListItem" );
    wxPli_thread_sv_register( aTHX_ "Wx::TreeListItem", RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__TreeListCtrl_GetNextSibling); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__TreeListCtrl_GetNextSibling)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, item");
    {
	wxTreeListCtrl *    THIS = (wxTreeListCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::TreeListCtrl" )
;
	wxTreeListItem *	RETVAL;
	wxTreeListItem*    item = (wxTreeListItem *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::TreeListItem" )
;
    try {
      RETVAL = new wxTreeListItem( THIS->GetNextSibling( *( item ) ) );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_non_object_2_sv( aTHX_ RETVALSV, RETVAL, "Wx::TreeListItem" );
    wxPli_thread_sv_register( aTHX_ "Wx::TreeListItem", RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__TreeListCtrl_GetFirstItem); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__TreeListCtrl_GetFirstItem)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxTreeListCtrl *    THIS = (wxTreeListCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::TreeListCtrl" )
;
	wxTreeListItem *	RETVAL;
    try {
      RETVAL = new wxTreeListItem( THIS->GetFirstItem() );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_non_object_2_sv( aTHX_ RETVALSV, RETVAL, "Wx::TreeListItem" );
    wxPli_thread_sv_register( aTHX_ "Wx::TreeListItem", RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__TreeListCtrl_GetNextItem); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__TreeListCtrl_GetNextItem)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, item");
    {
	wxTreeListCtrl *    THIS = (wxTreeListCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::TreeListCtrl" )
;
	wxTreeListItem *	RETVAL;
	wxTreeListItem*    item = (wxTreeListItem *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::TreeListItem" )
;
    try {
      RETVAL = new wxTreeListItem( THIS->GetNextItem( *( item ) ) );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_non_object_2_sv( aTHX_ RETVALSV, RETVAL, "Wx::TreeListItem" );
    wxPli_thread_sv_register( aTHX_ "Wx::TreeListItem", RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__TreeListCtrl_GetItemText); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__TreeListCtrl_GetItemText)
{
    dVAR; dXSARGS;
    if (items < 2 || items > 3)
       croak_xs_usage(cv,  "THIS, item, col= 0");
    {
	wxTreeListCtrl *    THIS = (wxTreeListCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::TreeListCtrl" )
;
	wxString	RETVAL;
	wxTreeListItem*    item = (wxTreeListItem *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::TreeListItem" )
;
	unsigned int	col;

	if (items < 3)
	    col = 0;
	else {
    col = (unsigned int)SvUV( ST(2) )
;
	}
    try {
      RETVAL = THIS->GetItemText( *( item ), col );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    WXSTRING_OUTPUT( RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__TreeListCtrl_SetItemText0); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__TreeListCtrl_SetItemText0)
{
    dVAR; dXSARGS;
    if (items != 4)
       croak_xs_usage(cv,  "THIS, item, col, text");
    {
	wxTreeListCtrl *    THIS = (wxTreeListCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::TreeListCtrl" )
;
	wxTreeListItem*    item = (wxTreeListItem *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::TreeListItem" )
;
	unsigned int    col = (unsigned int)SvUV( ST(2) )
;
	wxString	text;

    WXSTRING_INPUT( text, wxString, ST(3) )
;
    try {
      THIS->SetItemText( *( item ), col, text );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__TreeListCtrl_SetItemText1); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__TreeListCtrl_SetItemText1)
{
    dVAR; dXSARGS;
    if (items != 3)
       croak_xs_usage(cv,  "THIS, item, text");
    {
	wxTreeListCtrl *    THIS = (wxTreeListCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::TreeListCtrl" )
;
	wxTreeListItem*    item = (wxTreeListItem *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::TreeListItem" )
;
	wxString	text;

    WXSTRING_INPUT( text, wxString, ST(2) )
;
    try {
      THIS->SetItemText( *( item ), text );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__TreeListCtrl_SetItemImage); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__TreeListCtrl_SetItemImage)
{
    dVAR; dXSARGS;
    if (items < 3 || items > 4)
       croak_xs_usage(cv,  "THIS, item, closed, opened= -1");
    {
	wxTreeListCtrl *    THIS = (wxTreeListCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::TreeListCtrl" )
;
	wxTreeListItem*    item = (wxTreeListItem *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::TreeListItem" )
;
	int	closed = (int)SvIV(ST(2))
;
	int	opened;

	if (items < 4)
	    opened = -1;
	else {
	    opened = (int)SvIV(ST(3))
;
	}
    try {
      THIS->SetItemImage( *( item ), closed, opened );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__TreeListCtrl_GetItemData); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__TreeListCtrl_GetItemData)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, item");
    {
	wxTreeListCtrl *    THIS = (wxTreeListCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::TreeListCtrl" )
;
	wxPliUserDataCD *	RETVAL;
	wxTreeListItem*    item = (wxTreeListItem *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::TreeListItem" )
;
     RETVAL = (wxPliUserDataCD*) THIS->GetItemData( *item ); 
	{
	    SV * RETVALSV;
    RETVALSV = ( RETVAL == 0 ) ? &PL_sv_undef : RETVAL->GetData();
    SvREFCNT_inc( RETVALSV ); // xsubpp mortalizes it...
	    RETVALSV = sv_2mortal(RETVALSV);
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__TreeListCtrl_SetItemData); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__TreeListCtrl_SetItemData)
{
    dVAR; dXSARGS;
    if (items != 3)
       croak_xs_usage(cv,  "THIS, item, data");
    {
	wxTreeListCtrl *    THIS = (wxTreeListCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::TreeListCtrl" )
;
	wxTreeListItem*    item = (wxTreeListItem *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::TreeListItem" )
;
	wxPliUserDataCD*	data;

    if( SvOK( ST(2) ) )
    {
        data = new wxPliUserDataCD( ST(2) );
    }
    else
        data = 0
;
    try {
      THIS->SetItemData( *( item ), data );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__TreeListCtrl_Expand); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__TreeListCtrl_Expand)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, item");
    {
	wxTreeListCtrl *    THIS = (wxTreeListCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::TreeListCtrl" )
;
	wxTreeListItem*    item = (wxTreeListItem *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::TreeListItem" )
;
    try {
      THIS->Expand( *( item ) );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__TreeListCtrl_Collapse); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__TreeListCtrl_Collapse)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, item");
    {
	wxTreeListCtrl *    THIS = (wxTreeListCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::TreeListCtrl" )
;
	wxTreeListItem*    item = (wxTreeListItem *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::TreeListItem" )
;
    try {
      THIS->Collapse( *( item ) );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__TreeListCtrl_IsExpanded); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__TreeListCtrl_IsExpanded)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, item");
    {
	wxTreeListCtrl *    THIS = (wxTreeListCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::TreeListCtrl" )
;
	bool	RETVAL;
	wxTreeListItem*    item = (wxTreeListItem *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::TreeListItem" )
;
    try {
      RETVAL = THIS->IsExpanded( *( item ) );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__TreeListCtrl_GetSelection); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__TreeListCtrl_GetSelection)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxTreeListCtrl *    THIS = (wxTreeListCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::TreeListCtrl" )
;
	wxTreeListItem *	RETVAL;
    try {
      RETVAL = new wxTreeListItem( THIS->GetSelection() );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_non_object_2_sv( aTHX_ RETVALSV, RETVAL, "Wx::TreeListItem" );
    wxPli_thread_sv_register( aTHX_ "Wx::TreeListItem", RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__TreeListCtrl_GetSelections); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__TreeListCtrl_GetSelections)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    PERL_UNUSED_VAR(ax); /* -Wall */
    SP -= items;
    {
    wxTreeListItems selections;
	wxTreeListCtrl *    THIS = (wxTreeListCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::TreeListCtrl" )
;
    size_t num = THIS->GetSelections( selections );
    EXTEND( SP, (IV)num );
    for( size_t i = 0; i < num; ++i )
    {
        PUSHs( wxPli_non_object_2_sv( aTHX_ sv_newmortal(),
                                      new wxTreeListItem( selections[i] ),
                                      "Wx::TreeListItem" ) );
    }    
	PUTBACK;
	return;
    }
}


XS_EUPXS(XS_Wx__TreeListCtrl_Select); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__TreeListCtrl_Select)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, item");
    {
	wxTreeListCtrl *    THIS = (wxTreeListCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::TreeListCtrl" )
;
	wxTreeListItem*    item = (wxTreeListItem *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::TreeListItem" )
;
    try {
      THIS->Select( *( item ) );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__TreeListCtrl_Unselect); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__TreeListCtrl_Unselect)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, item");
    {
	wxTreeListCtrl *    THIS = (wxTreeListCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::TreeListCtrl" )
;
	wxTreeListItem*    item = (wxTreeListItem *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::TreeListItem" )
;
    try {
      THIS->Unselect( *( item ) );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__TreeListCtrl_IsSelected); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__TreeListCtrl_IsSelected)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, item");
    {
	wxTreeListCtrl *    THIS = (wxTreeListCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::TreeListCtrl" )
;
	bool	RETVAL;
	wxTreeListItem*    item = (wxTreeListItem *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::TreeListItem" )
;
    try {
      RETVAL = THIS->IsSelected( *( item ) );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__TreeListCtrl_SelectAll); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__TreeListCtrl_SelectAll)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxTreeListCtrl *    THIS = (wxTreeListCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::TreeListCtrl" )
;
    try {
      THIS->SelectAll();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__TreeListCtrl_UnselectAll); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__TreeListCtrl_UnselectAll)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxTreeListCtrl *    THIS = (wxTreeListCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::TreeListCtrl" )
;
    try {
      THIS->UnselectAll();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__TreeListCtrl_CheckItem); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__TreeListCtrl_CheckItem)
{
    dVAR; dXSARGS;
    if (items < 2 || items > 3)
       croak_xs_usage(cv,  "THIS, item, state= wxCHK_CHECKED");
    {
	wxTreeListCtrl *    THIS = (wxTreeListCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::TreeListCtrl" )
;
	wxTreeListItem*    item = (wxTreeListItem *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::TreeListItem" )
;
	wxCheckBoxState	state;

	if (items < 3)
	    state = wxCHK_CHECKED;
	else {
	    state = (wxCheckBoxState)SvIV(ST(2))
;
	}
    try {
      THIS->CheckItem( *( item ), state );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__TreeListCtrl_CheckItemRecursively); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__TreeListCtrl_CheckItemRecursively)
{
    dVAR; dXSARGS;
    if (items < 2 || items > 3)
       croak_xs_usage(cv,  "THIS, item, state= wxCHK_CHECKED");
    {
	wxTreeListCtrl *    THIS = (wxTreeListCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::TreeListCtrl" )
;
	wxTreeListItem*    item = (wxTreeListItem *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::TreeListItem" )
;
	wxCheckBoxState	state;

	if (items < 3)
	    state = wxCHK_CHECKED;
	else {
	    state = (wxCheckBoxState)SvIV(ST(2))
;
	}
    try {
      THIS->CheckItemRecursively( *( item ), state );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__TreeListCtrl_UncheckItem); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__TreeListCtrl_UncheckItem)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, item");
    {
	wxTreeListCtrl *    THIS = (wxTreeListCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::TreeListCtrl" )
;
	wxTreeListItem*    item = (wxTreeListItem *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::TreeListItem" )
;
    try {
      THIS->UncheckItem( *( item ) );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__TreeListCtrl_UpdateItemParentStateRecursively); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__TreeListCtrl_UpdateItemParentStateRecursively)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, item");
    {
	wxTreeListCtrl *    THIS = (wxTreeListCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::TreeListCtrl" )
;
	wxTreeListItem*    item = (wxTreeListItem *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::TreeListItem" )
;
    try {
      THIS->UpdateItemParentStateRecursively( *( item ) );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__TreeListCtrl_GetCheckedState); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__TreeListCtrl_GetCheckedState)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, item");
    {
	wxTreeListCtrl *    THIS = (wxTreeListCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::TreeListCtrl" )
;
	wxCheckBoxState	RETVAL;
	dXSTARG;
	wxTreeListItem*    item = (wxTreeListItem *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::TreeListItem" )
;
    try {
      RETVAL = THIS->GetCheckedState( *( item ) );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__TreeListCtrl_AreAllChildrenInState); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__TreeListCtrl_AreAllChildrenInState)
{
    dVAR; dXSARGS;
    if (items != 3)
       croak_xs_usage(cv,  "THIS, item, state");
    {
	wxTreeListCtrl *    THIS = (wxTreeListCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::TreeListCtrl" )
;
	bool	RETVAL;
	wxTreeListItem*    item = (wxTreeListItem *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::TreeListItem" )
;
	wxCheckBoxState	state = (wxCheckBoxState)SvIV(ST(2))
;
    try {
      RETVAL = THIS->AreAllChildrenInState( *( item ), state );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__TreeListCtrl_SetSortColumn); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__TreeListCtrl_SetSortColumn)
{
    dVAR; dXSARGS;
    if (items < 2 || items > 3)
       croak_xs_usage(cv,  "THIS, col, ascendingOrder= true");
    {
	wxTreeListCtrl *    THIS = (wxTreeListCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::TreeListCtrl" )
;
	unsigned int    col = (unsigned int)SvUV( ST(1) )
;
	bool	ascendingOrder;

	if (items < 3)
	    ascendingOrder = true;
	else {
	    ascendingOrder = (bool)SvTRUE(ST(2))
;
	}
    try {
      THIS->SetSortColumn( col, ascendingOrder );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__TreeListCtrl_GetSortColumn); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__TreeListCtrl_GetSortColumn)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    PERL_UNUSED_VAR(ax); /* -Wall */
    SP -= items;
    {
    unsigned col;
    bool ascendingOrder;
    bool issorted;
	wxTreeListCtrl *    THIS = (wxTreeListCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::TreeListCtrl" )
;
    issorted = THIS->GetSortColumn( &col, &ascendingOrder );
    EXTEND( SP, 2 );
    if( issorted )
    {
        PUSHs( sv_2mortal( newSVuv( col ) ) );
        PUSHs( sv_2mortal( newSViv( ascendingOrder ) ) );
    }
    else {
        PUSHs( sv_newmortal() );
        PUSHs( sv_newmortal() );
    }
	PUTBACK;
	return;
    }
}


XS_EUPXS(XS_Wx__TreeListCtrl_SetItemComparator); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__TreeListCtrl_SetItemComparator)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, comparator");
    {
	wxTreeListCtrl *    THIS = (wxTreeListCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::TreeListCtrl" )
;
	wxTreeListItemComparator*    comparator = (wxTreeListItemComparator *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::TreeListItemComparator" )
;
    try {
      THIS->SetItemComparator( comparator );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__TreeListCtrl_GetView); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__TreeListCtrl_GetView)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxTreeListCtrl *    THIS = (wxTreeListCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::TreeListCtrl" )
;
	wxWindow *	RETVAL;
    try {
      RETVAL = THIS->GetView();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_object_2_sv( aTHX_ RETVALSV, RETVAL );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}

#include "cpp/overload.h"
#if defined( XSpp_9e3a6f40_027014 )
#define XSubPPtmpAACX 1


XS_EUPXS(XS_Wx__TreeListCtrl_SetItemText); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__TreeListCtrl_SetItemText)
{
    dVAR; dXSARGS;
    if (items < 1)
       croak_xs_usage(cv,  "THIS, ...");
    PERL_UNUSED_VAR(ax); /* -Wall */
    SP -= items;
    {
	wxTreeListCtrl *    THIS = (wxTreeListCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::TreeListCtrl" )
;
#if defined( XSpp_9e3a6f40_027014 )
    static const char *SetItemText0_types[] = { "Wx::TreeListItem", wxPliOvlnum, wxPliOvlstr };
    static wxPliPrototype SetItemText0_proto( SetItemText0_types, sizeof( SetItemText0_types ) / sizeof( SetItemText0_types[0] ) );
#endif // defined( XSpp_9e3a6f40_027014 )
#if defined( XSpp_9e3a6f40_027014 )
    static const char *SetItemText1_types[] = { "Wx::TreeListItem", wxPliOvlstr };
    static wxPliPrototype SetItemText1_proto( SetItemText1_types, sizeof( SetItemText1_types ) / sizeof( SetItemText1_types[0] ) );
#endif // defined( XSpp_9e3a6f40_027014 )
    static wxPliPrototype *wxPliOvl_all_prototypes[] = {
#if defined( XSpp_9e3a6f40_027014 )
        &SetItemText0_proto,
#endif // defined( XSpp_9e3a6f40_027014 )
#if defined( XSpp_9e3a6f40_027014 )
        &SetItemText1_proto,
#endif // defined( XSpp_9e3a6f40_027014 )
        NULL };
    BEGIN_OVERLOAD()
#if defined( XSpp_9e3a6f40_027014 )
        MATCH_REDISP_COUNT( SetItemText0_proto, SetItemText0, 3 )
#endif // defined( XSpp_9e3a6f40_027014 )
#if defined( XSpp_9e3a6f40_027014 )
        MATCH_REDISP_COUNT( SetItemText1_proto, SetItemText1, 2 )
#endif // defined( XSpp_9e3a6f40_027014 )
    END_OVERLOAD_MESSAGE( Wx::TreeListCtrl::SetItemText, wxPliOvl_all_prototypes )
	PUTBACK;
	return;
    }
}

#endif // defined( XSpp_9e3a6f40_027014 )
#if defined( XSpp_9e3a6f40_027014 )
#define XSubPPtmpAACY 1


XS_EUPXS(XS_Wx__TreeListCtrl_new); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__TreeListCtrl_new)
{
    dVAR; dXSARGS;
    if (items < 1)
       croak_xs_usage(cv,  "CLASS, ...");
    PERL_UNUSED_VAR(ax); /* -Wall */
    SP -= items;
    {
	char *	CLASS = (char *)SvPV_nolen(ST(0))
;
#if defined( XSpp_9e3a6f40_027014 )
    static wxPliPrototype void_proto( NULL, 0 );
#endif // defined( XSpp_9e3a6f40_027014 )
    static wxPliPrototype *wxPliOvl_all_prototypes[] = {
#if defined( XSpp_9e3a6f40_027014 )
        &void_proto,
#endif // defined( XSpp_9e3a6f40_027014 )
        NULL };
    BEGIN_OVERLOAD()
#if defined( XSpp_9e3a6f40_027014 )
        MATCH_VOIDM_REDISP( newDefault )
#endif // defined( XSpp_9e3a6f40_027014 )
#if defined( XSpp_9e3a6f40_027014 )
        MATCH_ANY_REDISP( newFull )
#endif // defined( XSpp_9e3a6f40_027014 )
    END_OVERLOAD_MESSAGE( Wx::TreeListCtrl::new, wxPliOvl_all_prototypes )
	PUTBACK;
	return;
    }
}

#endif // defined( XSpp_9e3a6f40_027014 )

XS_EUPXS(XS_Wx__TreeListEvent_GetItem); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__TreeListEvent_GetItem)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxTreeListEvent *    THIS = (wxTreeListEvent *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::TreeListEvent" )
;
	wxTreeListItem *	RETVAL;
    try {
      RETVAL = new wxTreeListItem( THIS->GetItem() );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_non_object_2_sv( aTHX_ RETVALSV, RETVAL, "Wx::TreeListItem" );
    wxPli_thread_sv_register( aTHX_ "Wx::TreeListItem", RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__TreeListEvent_GetOldCheckedState); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__TreeListEvent_GetOldCheckedState)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxTreeListEvent *    THIS = (wxTreeListEvent *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::TreeListEvent" )
;
	wxCheckBoxState	RETVAL;
	dXSTARG;
    try {
      RETVAL = THIS->GetOldCheckedState();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__TreeListEvent_GetColumn); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__TreeListEvent_GetColumn)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxTreeListEvent *    THIS = (wxTreeListEvent *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::TreeListEvent" )
;
	unsigned int	RETVAL;
	dXSTARG;
    try {
      RETVAL = THIS->GetColumn();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	XSprePUSH;
	PUSHu((UV)RETVAL );
    }
    XSRETURN(1);
}

#endif
#if defined( XSpp_9e3a6f40_027014 )
#undef  xsp_constructor_class
#define xsp_constructor_class(c) (CLASS)
#define XSubPPtmpAACZ 1


XS_EUPXS(XS_Wx__PlTreeListItemComparator_new); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__PlTreeListItemComparator_new)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "CLASS");
    {
	char *	CLASS = (char *)SvPV_nolen(ST(0))
;
	wxPlTreeListItemComparator *	RETVAL;
    RETVAL = new wxPlTreeListItemComparator( CLASS   );
	{
	    SV * RETVALSV;
    RETVALSV = ( RETVAL == 0 ) ? &PL_sv_undef : RETVAL->GetSelf();
    SvREFCNT_inc( RETVALSV ); // xsubpp mortalizes it...
	    RETVALSV = sv_2mortal(RETVALSV);
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}

#undef  xsp_constructor_class
#define xsp_constructor_class(c) (c)
#endif // defined( XSpp_9e3a6f40_027014 )
#include "xspp/const_treelist_h.h"
#include "xspp/evt_treelist_h.h"
#if 1 && defined( XSpp_9e3a6f40_027014 )
#define XSubPPtmpAADA 1

#endif // 1 && defined( XSpp_9e3a6f40_027014 )

/* INCLUDE: Returning to 'Controls.xs' from '/usr/bin/perl -I./ -MExtUtils::XSpp::Cmd -e xspp -- -t typemap.xsp interface/wx/treelist.h' */


/* INCLUDE_COMMAND:  Including output of '/usr/bin/perl -I./ -MExtUtils::XSpp::Cmd -e xspp -- -t typemap.xsp interface/wx/richtooltip.h' from 'Controls.xs' */

#include <exception>

#undef  xsp_constructor_class
#define xsp_constructor_class(c) (c)
#if WXPERL_W_VERSION_GE( 2, 9, 3 )
#define XSpp_1921ac58_059516
#include <wx/richtooltip.h>
#define XSubPPtmpAADB 1


XS_EUPXS(XS_Wx__RichToolTip_CLONE); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichToolTip_CLONE)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "CLASS");
    {
	char *	CLASS = (char *)SvPV_nolen(ST(0))
;
    wxPli_thread_sv_clone( aTHX_ CLASS, (wxPliCloneSV)wxPli_detach_object );
    }
    XSRETURN_EMPTY;
}

#undef  xsp_constructor_class
#define xsp_constructor_class(c) (CLASS)

XS_EUPXS(XS_Wx__RichToolTip_new); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichToolTip_new)
{
    dVAR; dXSARGS;
    if (items != 3)
       croak_xs_usage(cv,  "CLASS, title, message");
    {
	char *	CLASS = (char *)SvPV_nolen(ST(0))
;
	wxRichToolTip *	RETVAL;
	wxString	title;
	wxString	message;

    WXSTRING_INPUT( title, wxString, ST(1) )
;

    WXSTRING_INPUT( message, wxString, ST(2) )
;
    try {
      RETVAL = new wxRichToolTip( title, message );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_non_object_2_sv( aTHX_ RETVALSV, RETVAL, "Wx::RichToolTip" );
    wxPli_thread_sv_register( aTHX_ "Wx::RichToolTip", RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}

#undef  xsp_constructor_class
#define xsp_constructor_class(c) (c)

XS_EUPXS(XS_Wx__RichToolTip_SetBackgroundColour); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichToolTip_SetBackgroundColour)
{
    dVAR; dXSARGS;
    if (items < 2 || items > 3)
       croak_xs_usage(cv,  "THIS, col, colEnd= wxNullColourPtr");
    {
	wxRichToolTip *    THIS = (wxRichToolTip *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichToolTip" )
;
	wxColour*    col = (wxColour *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::Colour" )
;
	wxColour*	colEnd;

	if (items < 3)
	    colEnd = wxNullColourPtr;
	else {
    colEnd = (wxColour *) wxPli_sv_2_object( aTHX_ ST(2), "Wx::Colour" )
;
	}
    try {
      THIS->SetBackgroundColour( *( col ), *( colEnd ) );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__RichToolTip_SetIconId); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichToolTip_SetIconId)
{
    dVAR; dXSARGS;
    if (items < 1 || items > 2)
       croak_xs_usage(cv,  "THIS, icon= wxICON_INFORMATION");
    {
	wxRichToolTip *    THIS = (wxRichToolTip *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichToolTip" )
;
	int	icon;

	if (items < 2)
	    icon = wxICON_INFORMATION;
	else {
	    icon = (int)SvIV(ST(1))
;
	}
    try {
      THIS->SetIcon( icon );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__RichToolTip_SetIconIcon); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichToolTip_SetIconIcon)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, icon");
    {
	wxRichToolTip *    THIS = (wxRichToolTip *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichToolTip" )
;
	wxIcon*    icon = (wxIcon *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::Icon" )
;
    try {
      THIS->SetIcon( *( icon ) );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__RichToolTip_SetTimeout); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichToolTip_SetTimeout)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, milliseconds");
    {
	wxRichToolTip *    THIS = (wxRichToolTip *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichToolTip" )
;
	unsigned int    milliseconds = (unsigned int)SvUV( ST(1) )
;
    try {
      THIS->SetTimeout( milliseconds );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__RichToolTip_SetTipKind); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichToolTip_SetTipKind)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, tipKind");
    {
	wxRichToolTip *    THIS = (wxRichToolTip *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichToolTip" )
;
	wxTipKind	tipKind = (wxTipKind)SvIV(ST(1))
;
    try {
      THIS->SetTipKind( tipKind );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__RichToolTip_ShowFor); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichToolTip_ShowFor)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, win");
    {
	wxRichToolTip *    THIS = (wxRichToolTip *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichToolTip" )
;
	wxWindow*    win = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::Window" )
;
    try {
      THIS->ShowFor( win );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__RichToolTip_DESTROY); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichToolTip_DESTROY)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxRichToolTip *    THIS = (wxRichToolTip *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichToolTip" )
;
      wxPli_thread_sv_unregister( aTHX_ "Wx::RichToolTip", THIS, ST(0) );
                 delete THIS;
    }
    XSRETURN_EMPTY;
}

#include "cpp/overload.h"
#if defined( XSpp_1921ac58_059516 )
#define XSubPPtmpAADC 1


XS_EUPXS(XS_Wx__RichToolTip_SetIcon); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichToolTip_SetIcon)
{
    dVAR; dXSARGS;
    if (items < 1)
       croak_xs_usage(cv,  "THIS, ...");
    PERL_UNUSED_VAR(ax); /* -Wall */
    SP -= items;
    {
	wxRichToolTip *    THIS = (wxRichToolTip *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichToolTip" )
;
#if defined( XSpp_1921ac58_059516 )
    static const char *SetIconId_types[] = { wxPliOvlnum };
    static wxPliPrototype SetIconId_proto( SetIconId_types, sizeof( SetIconId_types ) / sizeof( SetIconId_types[0] ) );
#endif // defined( XSpp_1921ac58_059516 )
#if defined( XSpp_1921ac58_059516 )
    static const char *SetIconIcon_types[] = { "Wx::Icon" };
    static wxPliPrototype SetIconIcon_proto( SetIconIcon_types, sizeof( SetIconIcon_types ) / sizeof( SetIconIcon_types[0] ) );
#endif // defined( XSpp_1921ac58_059516 )
    static wxPliPrototype *wxPliOvl_all_prototypes[] = {
#if defined( XSpp_1921ac58_059516 )
        &SetIconId_proto,
#endif // defined( XSpp_1921ac58_059516 )
#if defined( XSpp_1921ac58_059516 )
        &SetIconIcon_proto,
#endif // defined( XSpp_1921ac58_059516 )
        NULL };
    BEGIN_OVERLOAD()
#if defined( XSpp_1921ac58_059516 )
        MATCH_REDISP_COUNT_ALLOWMORE( SetIconId_proto, SetIconId, 0 )
#endif // defined( XSpp_1921ac58_059516 )
#if defined( XSpp_1921ac58_059516 )
        MATCH_REDISP_COUNT( SetIconIcon_proto, SetIconIcon, 1 )
#endif // defined( XSpp_1921ac58_059516 )
    END_OVERLOAD_MESSAGE( Wx::RichToolTip::SetIcon, wxPliOvl_all_prototypes )
	PUTBACK;
	return;
    }
}

#endif // defined( XSpp_1921ac58_059516 )
#endif
#include "xspp/const_richtooltip_h.h"

/* INCLUDE: Returning to 'Controls.xs' from '/usr/bin/perl -I./ -MExtUtils::XSpp::Cmd -e xspp -- -t typemap.xsp interface/wx/richtooltip.h' */


/* INCLUDE_COMMAND:  Including output of '/usr/bin/perl -I./ -MExtUtils::XSpp::Cmd -e xspp -- -t typemap.xsp interface/wx/bannerwindow.h' from 'Controls.xs' */

#include <exception>

#undef  xsp_constructor_class
#define xsp_constructor_class(c) (c)
#if WXPERL_W_VERSION_GE( 2, 9, 3 )
#define XSpp_7efdd844_029941
#include <wx/bannerwindow.h>
#undef  xsp_constructor_class
#define xsp_constructor_class(c) (CLASS)
#define XSubPPtmpAADD 1


XS_EUPXS(XS_Wx__BannerWindow_newDefault); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__BannerWindow_newDefault)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "CLASS");
    {
	char *	CLASS = (char *)SvPV_nolen(ST(0))
;
	wxBannerWindow *	RETVAL;
    try {
      RETVAL = new wxBannerWindow();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
     wxPli_create_evthandler( aTHX_ RETVAL, CLASS ); 
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_evthandler_2_sv( aTHX_ RETVALSV, RETVAL );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}

#undef  xsp_constructor_class
#define xsp_constructor_class(c) (c)
#undef  xsp_constructor_class
#define xsp_constructor_class(c) (CLASS)

XS_EUPXS(XS_Wx__BannerWindow_newShort); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__BannerWindow_newShort)
{
    dVAR; dXSARGS;
    if (items < 2 || items > 3)
       croak_xs_usage(cv,  "CLASS, parent, dir= wxLEFT");
    {
	char *	CLASS = (char *)SvPV_nolen(ST(0))
;
	wxBannerWindow *	RETVAL;
	wxWindow*    parent = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::Window" )
;
	wxDirection	dir;

	if (items < 3)
	    dir = wxLEFT;
	else {
	    dir = (wxDirection)SvIV(ST(2))
;
	}
    try {
      RETVAL = new wxBannerWindow( parent, dir );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
     wxPli_create_evthandler( aTHX_ RETVAL, CLASS ); 
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_evthandler_2_sv( aTHX_ RETVALSV, RETVAL );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}

#undef  xsp_constructor_class
#define xsp_constructor_class(c) (c)
#undef  xsp_constructor_class
#define xsp_constructor_class(c) (CLASS)

XS_EUPXS(XS_Wx__BannerWindow_newFull); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__BannerWindow_newFull)
{
    dVAR; dXSARGS;
    if (items < 4 || items > 8)
       croak_xs_usage(cv,  "CLASS, parent, winid, dir, pos= wxDefaultPosition, size= wxDefaultSize, style= 0, name= wxBannerWindowNameStr");
    {
	char *	CLASS = (char *)SvPV_nolen(ST(0))
;
	wxBannerWindow *	RETVAL;
	wxWindow*    parent = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::Window" )
;
	wxWindowID    winid = wxPli_get_wxwindowid( aTHX_ ST(2) )
;
	wxDirection	dir = (wxDirection)SvIV(ST(3))
;
	wxPoint	pos;
	wxSize	size;
	long	style;
	wxString	name;

	if (items < 5)
	    pos = wxDefaultPosition;
	else {
    pos = wxPli_sv_2_wxpoint( aTHX_ ST(4) )
;
	}

	if (items < 6)
	    size = wxDefaultSize;
	else {
    size = wxPli_sv_2_wxsize( aTHX_ ST(5) )
;
	}

	if (items < 7)
	    style = 0;
	else {
	    style = (long)SvIV(ST(6))
;
	}

	if (items < 8)
	    name = wxBannerWindowNameStr;
	else {
    WXSTRING_INPUT( name, wxString, ST(7) )
;
	}
    try {
      RETVAL = new wxBannerWindow( parent, winid, dir, pos, size, style, name );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
     wxPli_create_evthandler( aTHX_ RETVAL, CLASS ); 
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_evthandler_2_sv( aTHX_ RETVALSV, RETVAL );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}

#undef  xsp_constructor_class
#define xsp_constructor_class(c) (c)

XS_EUPXS(XS_Wx__BannerWindow_Create); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__BannerWindow_Create)
{
    dVAR; dXSARGS;
    if (items < 3 || items > 8)
       croak_xs_usage(cv,  "THIS, parent, winid, dir= wxLEFT, pos= wxDefaultPosition, size= wxDefaultSize, style= 0, name= wxBannerWindowNameStr");
    {
	wxBannerWindow *    THIS = (wxBannerWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::BannerWindow" )
;
	bool	RETVAL;
	wxWindow*    parent = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::Window" )
;
	wxWindowID    winid = wxPli_get_wxwindowid( aTHX_ ST(2) )
;
	wxDirection	dir;
	wxPoint	pos;
	wxSize	size;
	long	style;
	wxString	name;

	if (items < 4)
	    dir = wxLEFT;
	else {
	    dir = (wxDirection)SvIV(ST(3))
;
	}

	if (items < 5)
	    pos = wxDefaultPosition;
	else {
    pos = wxPli_sv_2_wxpoint( aTHX_ ST(4) )
;
	}

	if (items < 6)
	    size = wxDefaultSize;
	else {
    size = wxPli_sv_2_wxsize( aTHX_ ST(5) )
;
	}

	if (items < 7)
	    style = 0;
	else {
	    style = (long)SvIV(ST(6))
;
	}

	if (items < 8)
	    name = wxBannerWindowNameStr;
	else {
    WXSTRING_INPUT( name, wxString, ST(7) )
;
	}
    try {
      RETVAL = THIS->Create( parent, winid, dir, pos, size, style, name );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__BannerWindow_SetBitmap); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__BannerWindow_SetBitmap)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, bmp");
    {
	wxBannerWindow *    THIS = (wxBannerWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::BannerWindow" )
;
	wxBitmap*    bmp = (wxBitmap *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::Bitmap" )
;
    try {
      THIS->SetBitmap( *( bmp ) );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__BannerWindow_SetText); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__BannerWindow_SetText)
{
    dVAR; dXSARGS;
    if (items != 3)
       croak_xs_usage(cv,  "THIS, title, message");
    {
	wxBannerWindow *    THIS = (wxBannerWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::BannerWindow" )
;
	wxString	title;
	wxString	message;

    WXSTRING_INPUT( title, wxString, ST(1) )
;

    WXSTRING_INPUT( message, wxString, ST(2) )
;
    try {
      THIS->SetText( title, message );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__BannerWindow_SetGradient); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__BannerWindow_SetGradient)
{
    dVAR; dXSARGS;
    if (items != 3)
       croak_xs_usage(cv,  "THIS, start, end");
    {
	wxBannerWindow *    THIS = (wxBannerWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::BannerWindow" )
;
	wxColour*    start = (wxColour *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::Colour" )
;
	wxColour*    end = (wxColour *) wxPli_sv_2_object( aTHX_ ST(2), "Wx::Colour" )
;
    try {
      THIS->SetGradient( *( start ), *( end ) );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}

#include "cpp/overload.h"
#if defined( XSpp_7efdd844_029941 )
#define XSubPPtmpAADE 1


XS_EUPXS(XS_Wx__BannerWindow_new); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__BannerWindow_new)
{
    dVAR; dXSARGS;
    if (items < 1)
       croak_xs_usage(cv,  "CLASS, ...");
    PERL_UNUSED_VAR(ax); /* -Wall */
    SP -= items;
    {
	char *	CLASS = (char *)SvPV_nolen(ST(0))
;
#if defined( XSpp_7efdd844_029941 )
    static wxPliPrototype void_proto( NULL, 0 );
#endif // defined( XSpp_7efdd844_029941 )
#if defined( XSpp_7efdd844_029941 )
    static const char *newShort_types[] = { "Wx::Window", wxPliOvlnum };
    static wxPliPrototype newShort_proto( newShort_types, sizeof( newShort_types ) / sizeof( newShort_types[0] ) );
#endif // defined( XSpp_7efdd844_029941 )
#if defined( XSpp_7efdd844_029941 )
    static const char *newFull_types[] = { "Wx::Window", "Wx::WindowID", wxPliOvlnum, wxPliOvlwpoi, wxPliOvlwsiz, wxPliOvlnum, wxPliOvlstr };
    static wxPliPrototype newFull_proto( newFull_types, sizeof( newFull_types ) / sizeof( newFull_types[0] ) );
#endif // defined( XSpp_7efdd844_029941 )
    static wxPliPrototype *wxPliOvl_all_prototypes[] = {
#if defined( XSpp_7efdd844_029941 )
        &void_proto,
#endif // defined( XSpp_7efdd844_029941 )
#if defined( XSpp_7efdd844_029941 )
        &newShort_proto,
#endif // defined( XSpp_7efdd844_029941 )
#if defined( XSpp_7efdd844_029941 )
        &newFull_proto,
#endif // defined( XSpp_7efdd844_029941 )
        NULL };
    BEGIN_OVERLOAD()
#if defined( XSpp_7efdd844_029941 )
        MATCH_VOIDM_REDISP( newDefault )
#endif // defined( XSpp_7efdd844_029941 )
#if defined( XSpp_7efdd844_029941 )
        MATCH_REDISP_COUNT_ALLOWMORE( newShort_proto, newShort, 1 )
#endif // defined( XSpp_7efdd844_029941 )
#if defined( XSpp_7efdd844_029941 )
        MATCH_REDISP_COUNT_ALLOWMORE( newFull_proto, newFull, 3 )
#endif // defined( XSpp_7efdd844_029941 )
    END_OVERLOAD_MESSAGE( Wx::BannerWindow::new, wxPliOvl_all_prototypes )
	PUTBACK;
	return;
    }
}

#endif // defined( XSpp_7efdd844_029941 )
#endif

/* INCLUDE: Returning to 'Controls.xs' from '/usr/bin/perl -I./ -MExtUtils::XSpp::Cmd -e xspp -- -t typemap.xsp interface/wx/bannerwindow.h' */


/* INCLUDE_COMMAND:  Including output of '/usr/bin/perl -I./ -MExtUtils::XSpp::Cmd -e xspp -- -t typemap.xsp interface/wx/rearrangectrl.h' from 'Controls.xs' */

#include <exception>

#undef  xsp_constructor_class
#define xsp_constructor_class(c) (c)
#if WXPERL_W_VERSION_GE( 2, 9, 3 )
#define XSpp_270e2145_033981
#include <wx/rearrangectrl.h>
#undef  xsp_constructor_class
#define xsp_constructor_class(c) (CLASS)
#define XSubPPtmpAADF 1


XS_EUPXS(XS_Wx__RearrangeList_newDefault); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RearrangeList_newDefault)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "CLASS");
    {
	char *	CLASS = (char *)SvPV_nolen(ST(0))
;
	wxRearrangeList *	RETVAL;
    try {
      RETVAL = new wxRearrangeList();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
     wxPli_create_evthandler( aTHX_ RETVAL, CLASS ); 
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_namedobject_2_sv( aTHX_ RETVALSV, RETVAL, "Wx::RearrangeList" );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}

#undef  xsp_constructor_class
#define xsp_constructor_class(c) (c)
#undef  xsp_constructor_class
#define xsp_constructor_class(c) (CLASS)

XS_EUPXS(XS_Wx__RearrangeList_newFull); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RearrangeList_newFull)
{
    dVAR; dXSARGS;
    if (items < 7 || items > 10)
       croak_xs_usage(cv,  "CLASS, parent, id, pos, size, order, strings, style= 0, validator= wxDefaultValidatorPtr, name= wxRearrangeListNameStr");
    {
	char *	CLASS = (char *)SvPV_nolen(ST(0))
;
	wxRearrangeList *	RETVAL;
	wxWindow*    parent = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::Window" )
;
	wxWindowID    id = wxPli_get_wxwindowid( aTHX_ ST(2) )
;
	wxPoint    pos = wxPli_sv_2_wxpoint( aTHX_ ST(3) )
;
	wxSize    size = wxPli_sv_2_wxsize( aTHX_ ST(4) )
;
	wxArrayInt	order;
	wxArrayString	strings;
	long	style;
	wxValidator*	validator;
	wxString	name;

    wxPli_av_2_arrayint( aTHX_ ST(5), & order )
;

    wxPli_av_2_arraystring( aTHX_ ST(6), & strings )
;

	if (items < 8)
	    style = 0;
	else {
	    style = (long)SvIV(ST(7))
;
	}

	if (items < 9)
	    validator = wxDefaultValidatorPtr;
	else {
    validator = (wxValidator *) wxPli_sv_2_object( aTHX_ ST(8), "Wx::Validator" )
;
	}

	if (items < 10)
	    name = wxRearrangeListNameStr;
	else {
    WXSTRING_INPUT( name, wxString, ST(9) )
;
	}
    try {
      RETVAL = new wxRearrangeList( parent, id, pos, size, order, strings, style, *( validator ), name );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
     wxPli_create_evthandler( aTHX_ RETVAL, CLASS ); 
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_namedobject_2_sv( aTHX_ RETVALSV, RETVAL, "Wx::RearrangeList" );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}

#undef  xsp_constructor_class
#define xsp_constructor_class(c) (c)

XS_EUPXS(XS_Wx__RearrangeList_Create); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RearrangeList_Create)
{
    dVAR; dXSARGS;
    if (items < 7 || items > 10)
       croak_xs_usage(cv,  "THIS, parent, id, pos, size, order, strings, style= 0, validator= wxDefaultValidatorPtr, name= wxRearrangeListNameStr");
    {
	wxRearrangeList *    THIS = (wxRearrangeList *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RearrangeList" )
;
	bool	RETVAL;
	wxWindow*    parent = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::Window" )
;
	wxWindowID    id = wxPli_get_wxwindowid( aTHX_ ST(2) )
;
	wxPoint    pos = wxPli_sv_2_wxpoint( aTHX_ ST(3) )
;
	wxSize    size = wxPli_sv_2_wxsize( aTHX_ ST(4) )
;
	wxArrayInt	order;
	wxArrayString	strings;
	long	style;
	wxValidator*	validator;
	wxString	name;

    wxPli_av_2_arrayint( aTHX_ ST(5), & order )
;

    wxPli_av_2_arraystring( aTHX_ ST(6), & strings )
;

	if (items < 8)
	    style = 0;
	else {
	    style = (long)SvIV(ST(7))
;
	}

	if (items < 9)
	    validator = wxDefaultValidatorPtr;
	else {
    validator = (wxValidator *) wxPli_sv_2_object( aTHX_ ST(8), "Wx::Validator" )
;
	}

	if (items < 10)
	    name = wxRearrangeListNameStr;
	else {
    WXSTRING_INPUT( name, wxString, ST(9) )
;
	}
    try {
      RETVAL = THIS->Create( parent, id, pos, size, order, strings, style, *( validator ), name );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__RearrangeList_GetCurrentOrder); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RearrangeList_GetCurrentOrder)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    PERL_UNUSED_VAR(ax); /* -Wall */
    SP -= items;
    {
	wxRearrangeList *    THIS = (wxRearrangeList *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RearrangeList" )
;
	wxArrayInt	RETVAL;
    try {
      RETVAL = THIS->GetCurrentOrder();
    PUTBACK;
    wxPli_intarray_push( aTHX_ RETVAL );
    SPAGAIN;
  ;
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	PUTBACK;
	return;
    }
}


XS_EUPXS(XS_Wx__RearrangeList_CanMoveCurrentUp); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RearrangeList_CanMoveCurrentUp)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxRearrangeList *    THIS = (wxRearrangeList *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RearrangeList" )
;
	bool	RETVAL;
    try {
      RETVAL = THIS->CanMoveCurrentUp();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__RearrangeList_CanMoveCurrentDown); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RearrangeList_CanMoveCurrentDown)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxRearrangeList *    THIS = (wxRearrangeList *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RearrangeList" )
;
	bool	RETVAL;
    try {
      RETVAL = THIS->CanMoveCurrentDown();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__RearrangeList_MoveCurrentUp); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RearrangeList_MoveCurrentUp)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxRearrangeList *    THIS = (wxRearrangeList *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RearrangeList" )
;
	bool	RETVAL;
    try {
      RETVAL = THIS->MoveCurrentUp();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__RearrangeList_MoveCurrentDown); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RearrangeList_MoveCurrentDown)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxRearrangeList *    THIS = (wxRearrangeList *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RearrangeList" )
;
	bool	RETVAL;
    try {
      RETVAL = THIS->MoveCurrentDown();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}

#include "cpp/overload.h"
#if defined( XSpp_270e2145_033981 )
#define XSubPPtmpAADG 1


XS_EUPXS(XS_Wx__RearrangeList_new); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RearrangeList_new)
{
    dVAR; dXSARGS;
    if (items < 1)
       croak_xs_usage(cv,  "CLASS, ...");
    PERL_UNUSED_VAR(ax); /* -Wall */
    SP -= items;
    {
	char *	CLASS = (char *)SvPV_nolen(ST(0))
;
#if defined( XSpp_270e2145_033981 )
    static wxPliPrototype void_proto( NULL, 0 );
#endif // defined( XSpp_270e2145_033981 )
    static wxPliPrototype *wxPliOvl_all_prototypes[] = {
#if defined( XSpp_270e2145_033981 )
        &void_proto,
#endif // defined( XSpp_270e2145_033981 )
        NULL };
    BEGIN_OVERLOAD()
#if defined( XSpp_270e2145_033981 )
        MATCH_VOIDM_REDISP( newDefault )
#endif // defined( XSpp_270e2145_033981 )
#if defined( XSpp_270e2145_033981 )
        MATCH_ANY_REDISP( newFull )
#endif // defined( XSpp_270e2145_033981 )
    END_OVERLOAD_MESSAGE( Wx::RearrangeList::new, wxPliOvl_all_prototypes )
	PUTBACK;
	return;
    }
}

#endif // defined( XSpp_270e2145_033981 )
#undef  xsp_constructor_class
#define xsp_constructor_class(c) (CLASS)

XS_EUPXS(XS_Wx__RearrangeCtrl_newDefault); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RearrangeCtrl_newDefault)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "CLASS");
    {
	char *	CLASS = (char *)SvPV_nolen(ST(0))
;
	wxRearrangeCtrl *	RETVAL;
    try {
      RETVAL = new wxRearrangeCtrl();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
     wxPli_create_evthandler( aTHX_ RETVAL, CLASS ); 
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_namedobject_2_sv( aTHX_ RETVALSV, RETVAL, "Wx::RearrangeCtrl" );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}

#undef  xsp_constructor_class
#define xsp_constructor_class(c) (c)
#undef  xsp_constructor_class
#define xsp_constructor_class(c) (CLASS)

XS_EUPXS(XS_Wx__RearrangeCtrl_newFull); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RearrangeCtrl_newFull)
{
    dVAR; dXSARGS;
    if (items < 7 || items > 10)
       croak_xs_usage(cv,  "CLASS, parent, id, pos, size, order, strings, style= 0, validator= wxDefaultValidatorPtr, name= wxRearrangeListNameStr");
    {
	char *	CLASS = (char *)SvPV_nolen(ST(0))
;
	wxRearrangeCtrl *	RETVAL;
	wxWindow*    parent = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::Window" )
;
	wxWindowID    id = wxPli_get_wxwindowid( aTHX_ ST(2) )
;
	wxPoint    pos = wxPli_sv_2_wxpoint( aTHX_ ST(3) )
;
	wxSize    size = wxPli_sv_2_wxsize( aTHX_ ST(4) )
;
	wxArrayInt	order;
	wxArrayString	strings;
	long	style;
	wxValidator*	validator;
	wxString	name;

    wxPli_av_2_arrayint( aTHX_ ST(5), & order )
;

    wxPli_av_2_arraystring( aTHX_ ST(6), & strings )
;

	if (items < 8)
	    style = 0;
	else {
	    style = (long)SvIV(ST(7))
;
	}

	if (items < 9)
	    validator = wxDefaultValidatorPtr;
	else {
    validator = (wxValidator *) wxPli_sv_2_object( aTHX_ ST(8), "Wx::Validator" )
;
	}

	if (items < 10)
	    name = wxRearrangeListNameStr;
	else {
    WXSTRING_INPUT( name, wxString, ST(9) )
;
	}
    try {
      RETVAL = new wxRearrangeCtrl( parent, id, pos, size, order, strings, style, *( validator ), name );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
     wxPli_create_evthandler( aTHX_ RETVAL, CLASS ); 
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_namedobject_2_sv( aTHX_ RETVALSV, RETVAL, "Wx::RearrangeCtrl" );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}

#undef  xsp_constructor_class
#define xsp_constructor_class(c) (c)

XS_EUPXS(XS_Wx__RearrangeCtrl_Create); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RearrangeCtrl_Create)
{
    dVAR; dXSARGS;
    if (items < 7 || items > 10)
       croak_xs_usage(cv,  "THIS, parent, id, pos, size, order, strings, style= 0, validator= wxDefaultValidatorPtr, name= wxRearrangeListNameStr");
    {
	wxRearrangeCtrl *    THIS = (wxRearrangeCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RearrangeCtrl" )
;
	bool	RETVAL;
	wxWindow*    parent = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::Window" )
;
	wxWindowID    id = wxPli_get_wxwindowid( aTHX_ ST(2) )
;
	wxPoint    pos = wxPli_sv_2_wxpoint( aTHX_ ST(3) )
;
	wxSize    size = wxPli_sv_2_wxsize( aTHX_ ST(4) )
;
	wxArrayInt	order;
	wxArrayString	strings;
	long	style;
	wxValidator*	validator;
	wxString	name;

    wxPli_av_2_arrayint( aTHX_ ST(5), & order )
;

    wxPli_av_2_arraystring( aTHX_ ST(6), & strings )
;

	if (items < 8)
	    style = 0;
	else {
	    style = (long)SvIV(ST(7))
;
	}

	if (items < 9)
	    validator = wxDefaultValidatorPtr;
	else {
    validator = (wxValidator *) wxPli_sv_2_object( aTHX_ ST(8), "Wx::Validator" )
;
	}

	if (items < 10)
	    name = wxRearrangeListNameStr;
	else {
    WXSTRING_INPUT( name, wxString, ST(9) )
;
	}
    try {
      RETVAL = THIS->Create( parent, id, pos, size, order, strings, style, *( validator ), name );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__RearrangeCtrl_GetList); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RearrangeCtrl_GetList)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxRearrangeCtrl *    THIS = (wxRearrangeCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RearrangeCtrl" )
;
	wxRearrangeList *	RETVAL;
    try {
      RETVAL = THIS->GetList();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_namedobject_2_sv( aTHX_ RETVALSV, RETVAL, "Wx::RearrangeList" );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}

#include "cpp/overload.h"
#if defined( XSpp_270e2145_033981 )
#define XSubPPtmpAADH 1


XS_EUPXS(XS_Wx__RearrangeCtrl_new); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RearrangeCtrl_new)
{
    dVAR; dXSARGS;
    if (items < 1)
       croak_xs_usage(cv,  "CLASS, ...");
    PERL_UNUSED_VAR(ax); /* -Wall */
    SP -= items;
    {
	char *	CLASS = (char *)SvPV_nolen(ST(0))
;
#if defined( XSpp_270e2145_033981 )
    static wxPliPrototype void_proto( NULL, 0 );
#endif // defined( XSpp_270e2145_033981 )
    static wxPliPrototype *wxPliOvl_all_prototypes[] = {
#if defined( XSpp_270e2145_033981 )
        &void_proto,
#endif // defined( XSpp_270e2145_033981 )
        NULL };
    BEGIN_OVERLOAD()
#if defined( XSpp_270e2145_033981 )
        MATCH_VOIDM_REDISP( newDefault )
#endif // defined( XSpp_270e2145_033981 )
#if defined( XSpp_270e2145_033981 )
        MATCH_ANY_REDISP( newFull )
#endif // defined( XSpp_270e2145_033981 )
    END_OVERLOAD_MESSAGE( Wx::RearrangeCtrl::new, wxPliOvl_all_prototypes )
	PUTBACK;
	return;
    }
}

#endif // defined( XSpp_270e2145_033981 )
#undef  xsp_constructor_class
#define xsp_constructor_class(c) (CLASS)

XS_EUPXS(XS_Wx__RearrangeDialog_newDefault); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RearrangeDialog_newDefault)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "CLASS");
    {
	char *	CLASS = (char *)SvPV_nolen(ST(0))
;
	wxRearrangeDialog *	RETVAL;
    try {
      RETVAL = new wxRearrangeDialog();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_namedobject_2_sv( aTHX_ RETVALSV, RETVAL, "Wx::RearrangeDialog" );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}

#undef  xsp_constructor_class
#define xsp_constructor_class(c) (c)
#undef  xsp_constructor_class
#define xsp_constructor_class(c) (CLASS)

XS_EUPXS(XS_Wx__RearrangeDialog_newFull); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RearrangeDialog_newFull)
{
    dVAR; dXSARGS;
    if (items < 6 || items > 8)
       croak_xs_usage(cv,  "CLASS, parent, message, title, order, strings, pos= wxDefaultPosition, name= wxRearrangeDialogNameStr");
    {
	char *	CLASS = (char *)SvPV_nolen(ST(0))
;
	wxRearrangeDialog *	RETVAL;
	wxWindow*    parent = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::Window" )
;
	wxString	message;
	wxString	title;
	wxArrayInt	order;
	wxArrayString	strings;
	wxPoint	pos;
	wxString	name;

    WXSTRING_INPUT( message, wxString, ST(2) )
;

    WXSTRING_INPUT( title, wxString, ST(3) )
;

    wxPli_av_2_arrayint( aTHX_ ST(4), & order )
;

    wxPli_av_2_arraystring( aTHX_ ST(5), & strings )
;

	if (items < 7)
	    pos = wxDefaultPosition;
	else {
    pos = wxPli_sv_2_wxpoint( aTHX_ ST(6) )
;
	}

	if (items < 8)
	    name = wxRearrangeDialogNameStr;
	else {
    WXSTRING_INPUT( name, wxString, ST(7) )
;
	}
    try {
      RETVAL = new wxRearrangeDialog( parent, message, title, order, strings, pos, name );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_namedobject_2_sv( aTHX_ RETVALSV, RETVAL, "Wx::RearrangeDialog" );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}

#undef  xsp_constructor_class
#define xsp_constructor_class(c) (c)

XS_EUPXS(XS_Wx__RearrangeDialog_Create); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RearrangeDialog_Create)
{
    dVAR; dXSARGS;
    if (items < 6 || items > 8)
       croak_xs_usage(cv,  "THIS, parent, message, title, order, strings, pos= wxDefaultPosition, name= wxRearrangeDialogNameStr");
    {
	wxRearrangeDialog *    THIS = (wxRearrangeDialog *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RearrangeDialog" )
;
	bool	RETVAL;
	wxWindow*    parent = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::Window" )
;
	wxString	message;
	wxString	title;
	wxArrayInt	order;
	wxArrayString	strings;
	wxPoint	pos;
	wxString	name;

    WXSTRING_INPUT( message, wxString, ST(2) )
;

    WXSTRING_INPUT( title, wxString, ST(3) )
;

    wxPli_av_2_arrayint( aTHX_ ST(4), & order )
;

    wxPli_av_2_arraystring( aTHX_ ST(5), & strings )
;

	if (items < 7)
	    pos = wxDefaultPosition;
	else {
    pos = wxPli_sv_2_wxpoint( aTHX_ ST(6) )
;
	}

	if (items < 8)
	    name = wxRearrangeDialogNameStr;
	else {
    WXSTRING_INPUT( name, wxString, ST(7) )
;
	}
    try {
      RETVAL = THIS->Create( parent, message, title, order, strings, pos, name );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__RearrangeDialog_AddExtraControls); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RearrangeDialog_AddExtraControls)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, win");
    {
	wxRearrangeDialog *    THIS = (wxRearrangeDialog *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RearrangeDialog" )
;
	wxWindow*    win = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::Window" )
;
    try {
      THIS->AddExtraControls( win );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__RearrangeDialog_GetList); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RearrangeDialog_GetList)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxRearrangeDialog *    THIS = (wxRearrangeDialog *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RearrangeDialog" )
;
	wxRearrangeList *	RETVAL;
    try {
      RETVAL = THIS->GetList();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_namedobject_2_sv( aTHX_ RETVALSV, RETVAL, "Wx::RearrangeList" );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__RearrangeDialog_GetOrder); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RearrangeDialog_GetOrder)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    PERL_UNUSED_VAR(ax); /* -Wall */
    SP -= items;
    {
	wxRearrangeDialog *    THIS = (wxRearrangeDialog *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RearrangeDialog" )
;
	wxArrayInt	RETVAL;
    try {
      RETVAL = THIS->GetOrder();
    PUTBACK;
    wxPli_intarray_push( aTHX_ RETVAL );
    SPAGAIN;
  ;
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	PUTBACK;
	return;
    }
}

#include "cpp/overload.h"
#if defined( XSpp_270e2145_033981 )
#define XSubPPtmpAADI 1


XS_EUPXS(XS_Wx__RearrangeDialog_new); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RearrangeDialog_new)
{
    dVAR; dXSARGS;
    if (items < 1)
       croak_xs_usage(cv,  "CLASS, ...");
    PERL_UNUSED_VAR(ax); /* -Wall */
    SP -= items;
    {
	char *	CLASS = (char *)SvPV_nolen(ST(0))
;
#if defined( XSpp_270e2145_033981 )
    static wxPliPrototype void_proto( NULL, 0 );
#endif // defined( XSpp_270e2145_033981 )
    static wxPliPrototype *wxPliOvl_all_prototypes[] = {
#if defined( XSpp_270e2145_033981 )
        &void_proto,
#endif // defined( XSpp_270e2145_033981 )
        NULL };
    BEGIN_OVERLOAD()
#if defined( XSpp_270e2145_033981 )
        MATCH_VOIDM_REDISP( newDefault )
#endif // defined( XSpp_270e2145_033981 )
#if defined( XSpp_270e2145_033981 )
        MATCH_ANY_REDISP( newFull )
#endif // defined( XSpp_270e2145_033981 )
    END_OVERLOAD_MESSAGE( Wx::RearrangeDialog::new, wxPliOvl_all_prototypes )
	PUTBACK;
	return;
    }
}

#endif // defined( XSpp_270e2145_033981 )
#endif

/* INCLUDE: Returning to 'Controls.xs' from '/usr/bin/perl -I./ -MExtUtils::XSpp::Cmd -e xspp -- -t typemap.xsp interface/wx/rearrangectrl.h' */


/* INCLUDE:  Including 'XS/CheckBox.xs' from 'Controls.xs' */


/* INCLUDE:  Including 'XS/CheckListBox.xs' from 'XS/CheckBox.xs' */


/* INCLUDE:  Including 'XS/Choice.xs' from 'XS/CheckListBox.xs' */


/* INCLUDE:  Including 'XS/ComboBox.xs' from 'XS/Choice.xs' */


/* INCLUDE:  Including 'XS/Gauge.xs' from 'XS/ComboBox.xs' */


/* INCLUDE:  Including 'XS/ListBox.xs' from 'XS/Gauge.xs' */


/* INCLUDE:  Including 'XS/ListCtrl.xs' from 'XS/ListBox.xs' */


/* INCLUDE:  Including 'XS/Notebook.xs' from 'XS/ListCtrl.xs' */


/* INCLUDE:  Including 'XS/RadioBox.xs' from 'XS/Notebook.xs' */


/* INCLUDE:  Including 'XS/RadioButton.xs' from 'XS/RadioBox.xs' */


/* INCLUDE:  Including 'XS/ScrollBar.xs' from 'XS/RadioButton.xs' */


/* INCLUDE:  Including 'XS/Slider.xs' from 'XS/ScrollBar.xs' */


/* INCLUDE:  Including 'XS/SpinButton.xs' from 'XS/Slider.xs' */


/* INCLUDE:  Including 'XS/SpinCtrl.xs' from 'XS/SpinButton.xs' */


/* INCLUDE:  Including 'XS/StaticBitmap.xs' from 'XS/SpinCtrl.xs' */


/* INCLUDE:  Including 'XS/StaticBox.xs' from 'XS/StaticBitmap.xs' */


/* INCLUDE:  Including 'XS/StaticLine.xs' from 'XS/StaticBox.xs' */


/* INCLUDE:  Including 'XS/StaticText.xs' from 'XS/StaticLine.xs' */


/* INCLUDE:  Including 'XS/ToggleButton.xs' from 'XS/StaticText.xs' */


/* INCLUDE:  Including 'XS/TreeCtrl.xs' from 'XS/ToggleButton.xs' */

#include <wx/treectrl.h>
#include "cpp/overload.h"

XS_EUPXS(XS_Wx__TreeItemData_new); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__TreeItemData_new)
{
    dVAR; dXSARGS;
    if (items < 1 || items > 2)
       croak_xs_usage(cv,  "CLASS, data = 0");
    {
	SV_null*	data;
	char *	CLASS = (char *)SvPV_nolen(ST(0))
;
	wxTreeItemData *	RETVAL;

	if (items < 2)
	    data = 0;
	else {
    data = SvOK( ST(1) ) ? ST(1) : 0
;
	}
    RETVAL = new wxPliTreeItemData( data );
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_non_object_2_sv( aTHX_ RETVALSV, RETVAL, "Wx::TreeItemData" );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__TreeItemData_Destroy); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__TreeItemData_Destroy)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxTreeItemData *    THIS = (wxTreeItemData *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::TreeItemData" )
;
    delete THIS;
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__TreeItemData_GetData); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__TreeItemData_GetData)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxTreeItemData *    THIS = (wxTreeItemData *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::TreeItemData" )
;
	SV_null *	RETVAL;
    RETVAL = ((wxPliTreeItemData*)THIS)->m_data;
	{
	    SV * RETVALSV;
    RETVALSV = ( RETVAL == 0 ) ? &PL_sv_undef : RETVAL;
    SvREFCNT_inc( RETVALSV ); // xsubpp mortalizes it...
	    RETVALSV = sv_2mortal(RETVALSV);
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__TreeItemData_SetData); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__TreeItemData_SetData)
{
    dVAR; dXSARGS;
    if (items < 1 || items > 2)
       croak_xs_usage(cv,  "THIS, data = 0");
    {
	SV_null*	data;
	wxTreeItemData *    THIS = (wxTreeItemData *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::TreeItemData" )
;

	if (items < 2)
	    data = 0;
	else {
    data = SvOK( ST(1) ) ? ST(1) : 0
;
	}
    ((wxPliTreeItemData*)THIS)->SetData( data );
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__TreeItemData_GetId); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__TreeItemData_GetId)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxTreeItemData *    THIS = (wxTreeItemData *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::TreeItemData" )
;
	wxTreeItemId *	RETVAL;
    RETVAL = new wxTreeItemId( THIS->GetId() );
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_non_object_2_sv( aTHX_ RETVALSV, RETVAL, "Wx::TreeItemId" );
    wxPli_thread_sv_register( aTHX_ "Wx::TreeItemId", RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__TreeItemData_SetId); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__TreeItemData_SetId)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, id");
    {
	wxTreeItemId*    id = (wxTreeItemId *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::TreeItemId" )
;
	wxTreeItemData *    THIS = (wxTreeItemData *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::TreeItemData" )
;

	THIS->SetId(*id);
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__TreeItemId_CLONE); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__TreeItemId_CLONE)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "CLASS");
    {
	char *	CLASS = (char *)SvPV_nolen(ST(0))
;
    wxPli_thread_sv_clone( aTHX_ CLASS, (wxPliCloneSV)wxPli_detach_object );
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__TreeItemId_DESTROY); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__TreeItemId_DESTROY)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxTreeItemId *    THIS = (wxTreeItemId *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::TreeItemId" )
;
    wxPli_thread_sv_unregister( aTHX_ "Wx::TreeItemId", THIS, ST(0) );
    delete THIS;
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__TreeItemId_IsOk); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__TreeItemId_IsOk)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxTreeItemId *    THIS = (wxTreeItemId *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::TreeItemId" )
;
	bool	RETVAL;

	RETVAL = THIS->IsOk();
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__TreeItemId_tiid_spaceship); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__TreeItemId_tiid_spaceship)
{
    dVAR; dXSARGS;
    if (items < 2)
       croak_xs_usage(cv,  "tid1, tid2, ...");
    {
	SV*	tid1 = ST(0)
;
	SV*	tid2 = ST(1)
;
	int	RETVAL;
	dXSTARG;
    // this is not a proper spaceship method
    // it just allows autogeneration of != and ==
    // anyway, comparing ids is useless
    RETVAL = -1;
    if( SvROK( tid1 ) && SvROK( tid2 ) &&
        sv_derived_from( tid1, CHAR_P "Wx::TreeItemId" ) &&
        sv_derived_from( tid2, CHAR_P "Wx::TreeItemId" ) )
    {
        wxTreeItemId* id1 = (wxTreeItemId*)
            wxPli_sv_2_object( aTHX_ tid1, "Wx::TreeItemId" );
        wxTreeItemId* id2 = (wxTreeItemId*)
            wxPli_sv_2_object( aTHX_ tid2, "Wx::TreeItemId" );

        RETVAL = *id1 == *id2 ? 0 : 1;
    } else
      RETVAL = 1;
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__TreeEvent_new); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__TreeEvent_new)
{
    dVAR; dXSARGS;
    if (items < 1 || items > 3)
       croak_xs_usage(cv,  "CLASS, commandType = wxEVT_NULL, id = 0");
    {
	wxEventType	commandType;
	int	id;
	char *	CLASS = (char *)SvPV_nolen(ST(0))
;
	wxTreeEvent *	RETVAL;

	if (items < 2)
	    commandType = wxEVT_NULL;
	else {
	    commandType = (wxEventType)SvIV(ST(1))
;
	}

	if (items < 3)
	    id = 0;
	else {
	    id = (int)SvIV(ST(2))
;
	}

	RETVAL = new wxTreeEvent(commandType, id);
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_object_2_sv( aTHX_ RETVALSV, RETVAL );
    wxPli_thread_sv_register( aTHX_ "Wx::TreeEvent", RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__TreeEvent_GetItem); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__TreeEvent_GetItem)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxTreeEvent *    THIS = (wxTreeEvent *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::TreeEvent" )
;
	wxTreeItemId *	RETVAL;
    RETVAL = new wxTreeItemId( THIS->GetItem() );
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_non_object_2_sv( aTHX_ RETVALSV, RETVAL, "Wx::TreeItemId" );
    wxPli_thread_sv_register( aTHX_ "Wx::TreeItemId", RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}

#if WXPERL_W_VERSION_GE( 2, 7, 2 )
#define XSubPPtmpAADJ 1


XS_EUPXS(XS_Wx__TreeEvent_SetQuickBestSize); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__TreeEvent_SetQuickBestSize)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, q");
    {
	bool	q = (bool)SvTRUE(ST(1))
;
	wxTreeCtrl *    THIS = (wxTreeCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::TreeCtrl" )
;

	THIS->SetQuickBestSize(q);
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__TreeEvent_GetQuickBestSize); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__TreeEvent_GetQuickBestSize)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxTreeCtrl *    THIS = (wxTreeCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::TreeCtrl" )
;
	bool	RETVAL;

	RETVAL = THIS->GetQuickBestSize();
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}

#endif

XS_EUPXS(XS_Wx__TreeEvent_GetKeyCode); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__TreeEvent_GetKeyCode)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxTreeEvent *    THIS = (wxTreeEvent *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::TreeEvent" )
;
	int	RETVAL;
	dXSTARG;

	RETVAL = THIS->GetKeyCode();
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__TreeEvent_GetKeyEvent); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__TreeEvent_GetKeyEvent)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxTreeEvent *    THIS = (wxTreeEvent *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::TreeEvent" )
;
	wxKeyEvent *	RETVAL;
    RETVAL = new wxKeyEvent ( THIS->GetKeyEvent() );
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_object_2_sv( aTHX_ RETVALSV, RETVAL );
    wxPli_thread_sv_register( aTHX_ "Wx::KeyEvent", RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__TreeEvent_GetOldItem); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__TreeEvent_GetOldItem)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxTreeEvent *    THIS = (wxTreeEvent *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::TreeEvent" )
;
	wxTreeItemId *	RETVAL;
    RETVAL = new wxTreeItemId( THIS->GetOldItem() );
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_non_object_2_sv( aTHX_ RETVALSV, RETVAL, "Wx::TreeItemId" );
    wxPli_thread_sv_register( aTHX_ "Wx::TreeItemId", RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__TreeEvent_GetPoint); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__TreeEvent_GetPoint)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxTreeEvent *    THIS = (wxTreeEvent *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::TreeEvent" )
;
	wxPoint *	RETVAL;
    RETVAL = new wxPoint( THIS->GetPoint() );
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_non_object_2_sv( aTHX_ RETVALSV, RETVAL, "Wx::Point" );
    wxPli_thread_sv_register( aTHX_ "Wx::Point", RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__TreeEvent_IsEditCancelled); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__TreeEvent_IsEditCancelled)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxTreeEvent *    THIS = (wxTreeEvent *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::TreeEvent" )
;
	bool	RETVAL;

	RETVAL = THIS->IsEditCancelled();
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__TreeEvent_GetLabel); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__TreeEvent_GetLabel)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxTreeEvent *    THIS = (wxTreeEvent *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::TreeEvent" )
;
	wxString	RETVAL;

	RETVAL = THIS->GetLabel();
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    WXSTRING_OUTPUT( RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__TreeEvent_SetToolTip); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__TreeEvent_SetToolTip)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, tooltip");
    {
	wxString	tooltip;
	wxTreeEvent *    THIS = (wxTreeEvent *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::TreeEvent" )
;

    WXSTRING_INPUT( tooltip, wxString, ST(1) )
;

	THIS->SetToolTip(tooltip);
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__TreeCtrl_new); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__TreeCtrl_new)
{
    dVAR; dXSARGS;
    PERL_UNUSED_VAR(cv); /* -W */
    PERL_UNUSED_VAR(items); /* -W */
    PERL_UNUSED_VAR(ax); /* -Wall */
    SP -= items;
    {
    BEGIN_OVERLOAD()
        MATCH_VOIDM_REDISP( newDefault )
        MATCH_ANY_REDISP( newFull )
    END_OVERLOAD( "Wx::TreeCtrl::new" )
	PUTBACK;
	return;
    }
}


XS_EUPXS(XS_Wx__TreeCtrl_newDefault); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__TreeCtrl_newDefault)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "CLASS");
    {
	PlClassName    CLASS = wxPli_get_class( aTHX_ ST(0) )
;
	wxTreeCtrl *	RETVAL;
    RETVAL = new wxPliTreeCtrl( CLASS );
    wxPli_create_evthandler( aTHX_ RETVAL, CLASS );
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_object_2_sv( aTHX_ RETVALSV, RETVAL );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__TreeCtrl_newFull); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__TreeCtrl_newFull)
{
    dVAR; dXSARGS;
    if (items < 2 || items > 8)
       croak_xs_usage(cv,  "CLASS, parent, id = wxID_ANY, pos = wxDefaultPosition, size = wxDefaultSize, style = wxTR_HAS_BUTTONS, validator = (wxValidator*)&wxDefaultValidator, name = wxTreeCtrlNameStr");
    {
	PlClassName    CLASS = wxPli_get_class( aTHX_ ST(0) )
;
	wxWindow*    parent = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::Window" )
;
	wxWindowID	id;
	wxPoint	pos;
	wxSize	size;
	long	style;
	wxValidator*	validator;
	wxString	name;
	wxTreeCtrl *	RETVAL;

	if (items < 3)
	    id = wxID_ANY;
	else {
    id = wxPli_get_wxwindowid( aTHX_ ST(2) )
;
	}

	if (items < 4)
	    pos = wxDefaultPosition;
	else {
    pos = wxPli_sv_2_wxpoint( aTHX_ ST(3) )
;
	}

	if (items < 5)
	    size = wxDefaultSize;
	else {
    size = wxPli_sv_2_wxsize( aTHX_ ST(4) )
;
	}

	if (items < 6)
	    style = wxTR_HAS_BUTTONS;
	else {
	    style = (long)SvIV(ST(5))
;
	}

	if (items < 7)
	    validator = (wxValidator*)&wxDefaultValidator;
	else {
    validator = (wxValidator *) wxPli_sv_2_object( aTHX_ ST(6), "Wx::Validator" )
;
	}

	if (items < 8)
	    name = wxTreeCtrlNameStr;
	else {
    WXSTRING_INPUT( name, wxString, ST(7) )
;
	}
    RETVAL = new wxPliTreeCtrl( CLASS, parent, id, pos, size,
        style, *validator, name );
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_object_2_sv( aTHX_ RETVALSV, RETVAL );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__TreeCtrl_Create); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__TreeCtrl_Create)
{
    dVAR; dXSARGS;
    if (items < 2 || items > 8)
       croak_xs_usage(cv,  "THIS, parent, id = wxID_ANY, pos = wxDefaultPosition, size = wxDefaultSize, style = wxTR_HAS_BUTTONS, validator = (wxValidator*)&wxDefaultValidator, name = wxTreeCtrlNameStr");
    {
	wxWindow*    parent = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::Window" )
;
	wxWindowID	id;
	wxPoint	pos;
	wxSize	size;
	long	style;
	wxValidator*	validator;
	wxString	name;
	wxTreeCtrl *    THIS = (wxTreeCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::TreeCtrl" )
;
	bool	RETVAL;

	if (items < 3)
	    id = wxID_ANY;
	else {
    id = wxPli_get_wxwindowid( aTHX_ ST(2) )
;
	}

	if (items < 4)
	    pos = wxDefaultPosition;
	else {
    pos = wxPli_sv_2_wxpoint( aTHX_ ST(3) )
;
	}

	if (items < 5)
	    size = wxDefaultSize;
	else {
    size = wxPli_sv_2_wxsize( aTHX_ ST(4) )
;
	}

	if (items < 6)
	    style = wxTR_HAS_BUTTONS;
	else {
	    style = (long)SvIV(ST(5))
;
	}

	if (items < 7)
	    validator = (wxValidator*)&wxDefaultValidator;
	else {
    validator = (wxValidator *) wxPli_sv_2_object( aTHX_ ST(6), "Wx::Validator" )
;
	}

	if (items < 8)
	    name = wxTreeCtrlNameStr;
	else {
    WXSTRING_INPUT( name, wxString, ST(7) )
;
	}

	RETVAL = THIS->Create(parent, id, pos, size, style, *validator, name);
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__TreeCtrl_AddRoot); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__TreeCtrl_AddRoot)
{
    dVAR; dXSARGS;
    if (items < 2 || items > 5)
       croak_xs_usage(cv,  "THIS, text, image = -1, selImage = -1, data = 0");
    {
	wxString	text;
	int	image;
	int	selImage;
	wxTreeItemData*	data;
	wxTreeCtrl *    THIS = (wxTreeCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::TreeCtrl" )
;
	wxTreeItemId *	RETVAL;

    WXSTRING_INPUT( text, wxString, ST(1) )
;

	if (items < 3)
	    image = -1;
	else {
	    image = (int)SvIV(ST(2))
;
	}

	if (items < 4)
	    selImage = -1;
	else {
	    selImage = (int)SvIV(ST(3))
;
	}

	if (items < 5)
	    data = 0;
	else {
    data = (wxTreeItemData *) wxPli_sv_2_object( aTHX_ ST(4), "Wx::TreeItemData" )
;
	}
    RETVAL = new wxTreeItemId( THIS->AddRoot( text, image, selImage, data ) );
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_non_object_2_sv( aTHX_ RETVALSV, RETVAL, "Wx::TreeItemId" );
    wxPli_thread_sv_register( aTHX_ "Wx::TreeItemId", RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__TreeCtrl_AppendItem); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__TreeCtrl_AppendItem)
{
    dVAR; dXSARGS;
    if (items < 3 || items > 6)
       croak_xs_usage(cv,  "THIS, parent, text, image = -1, selImage = -1, data = 0");
    {
	wxTreeItemId*    parent = (wxTreeItemId *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::TreeItemId" )
;
	wxString	text;
	int	image;
	int	selImage;
	wxTreeItemData*	data;
	wxTreeCtrl *    THIS = (wxTreeCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::TreeCtrl" )
;
	wxTreeItemId *	RETVAL;

    WXSTRING_INPUT( text, wxString, ST(2) )
;

	if (items < 4)
	    image = -1;
	else {
	    image = (int)SvIV(ST(3))
;
	}

	if (items < 5)
	    selImage = -1;
	else {
	    selImage = (int)SvIV(ST(4))
;
	}

	if (items < 6)
	    data = 0;
	else {
    data = (wxTreeItemData *) wxPli_sv_2_object( aTHX_ ST(5), "Wx::TreeItemData" )
;
	}
    RETVAL = new wxTreeItemId( THIS->AppendItem( *parent, text, image,
        selImage, data ) );
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_non_object_2_sv( aTHX_ RETVALSV, RETVAL, "Wx::TreeItemId" );
    wxPli_thread_sv_register( aTHX_ "Wx::TreeItemId", RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__TreeCtrl_Collapse); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__TreeCtrl_Collapse)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, item");
    {
	wxTreeItemId*    item = (wxTreeItemId *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::TreeItemId" )
;
	wxTreeCtrl *    THIS = (wxTreeCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::TreeCtrl" )
;
    THIS->Collapse( *item );
    }
    XSRETURN_EMPTY;
}

#if WXPERL_W_VERSION_GE( 2, 8, 3 )
#define XSubPPtmpAADK 1


XS_EUPXS(XS_Wx__TreeCtrl_CollapseAll); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__TreeCtrl_CollapseAll)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxTreeCtrl *    THIS = (wxTreeCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::TreeCtrl" )
;

	THIS->CollapseAll();
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__TreeCtrl_CollapseAllChildren); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__TreeCtrl_CollapseAllChildren)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, item");
    {
	wxTreeItemId*    item = (wxTreeItemId *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::TreeItemId" )
;
	wxTreeCtrl *    THIS = (wxTreeCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::TreeCtrl" )
;

	THIS->CollapseAllChildren(*item);
    }
    XSRETURN_EMPTY;
}

#endif

XS_EUPXS(XS_Wx__TreeCtrl_CollapseAndReset); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__TreeCtrl_CollapseAndReset)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, item");
    {
	wxTreeItemId*    item = (wxTreeItemId *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::TreeItemId" )
;
	wxTreeCtrl *    THIS = (wxTreeCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::TreeCtrl" )
;

	THIS->CollapseAndReset(*item);
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__TreeCtrl_Delete); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__TreeCtrl_Delete)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, item");
    {
	wxTreeItemId*    item = (wxTreeItemId *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::TreeItemId" )
;
	wxTreeCtrl *    THIS = (wxTreeCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::TreeCtrl" )
;

	THIS->Delete(*item);
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__TreeCtrl_DeleteChildren); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__TreeCtrl_DeleteChildren)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, item");
    {
	wxTreeItemId*    item = (wxTreeItemId *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::TreeItemId" )
;
	wxTreeCtrl *    THIS = (wxTreeCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::TreeCtrl" )
;

	THIS->DeleteChildren(*item);
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__TreeCtrl_DeleteAllItems); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__TreeCtrl_DeleteAllItems)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxTreeCtrl *    THIS = (wxTreeCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::TreeCtrl" )
;

	THIS->DeleteAllItems();
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__TreeCtrl_EditLabel); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__TreeCtrl_EditLabel)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, item");
    {
	wxTreeItemId*    item = (wxTreeItemId *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::TreeItemId" )
;
	wxTreeCtrl *    THIS = (wxTreeCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::TreeCtrl" )
;
    THIS->EditLabel( *item );
    }
    XSRETURN_EMPTY;
}

#if defined( __WXMSW__ )
#if WXPERL_W_VERSION_GE( 2, 5, 3 )
#define XSubPPtmpAADL 1


XS_EUPXS(XS_Wx__TreeCtrl_EndEditLabel); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__TreeCtrl_EndEditLabel)
{
    dVAR; dXSARGS;
    if (items < 2 || items > 3)
       croak_xs_usage(cv,  "THIS, item, discardChanges = false");
    {
	wxTreeItemId*    item = (wxTreeItemId *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::TreeItemId" )
;
	bool	discardChanges;
	wxTreeCtrl *    THIS = (wxTreeCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::TreeCtrl" )
;

	if (items < 3)
	    discardChanges = false;
	else {
	    discardChanges = (bool)SvTRUE(ST(2))
;
	}

	THIS->EndEditLabel(*item, discardChanges);
    }
    XSRETURN_EMPTY;
}

#else
#define XSubPPtmpAADM 1


XS_EUPXS(XS_Wx__TreeCtrl_EndEditLabel); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__TreeCtrl_EndEditLabel)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, cancelEdit");
    {
	bool	cancelEdit = (bool)SvTRUE(ST(1))
;
	wxTreeCtrl *    THIS = (wxTreeCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::TreeCtrl" )
;

	THIS->EndEditLabel(cancelEdit);
    }
    XSRETURN_EMPTY;
}

#endif
#endif

XS_EUPXS(XS_Wx__TreeCtrl_EnsureVisible); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__TreeCtrl_EnsureVisible)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, item");
    {
	wxTreeItemId*    item = (wxTreeItemId *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::TreeItemId" )
;
	wxTreeCtrl *    THIS = (wxTreeCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::TreeCtrl" )
;

	THIS->EnsureVisible(*item);
    }
    XSRETURN_EMPTY;
}

#if WXPERL_W_VERSION_GE( 2, 7, 2 )
#define XSubPPtmpAADN 1


XS_EUPXS(XS_Wx__TreeCtrl_ExpandAll); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__TreeCtrl_ExpandAll)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxTreeCtrl *    THIS = (wxTreeCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::TreeCtrl" )
;

	THIS->ExpandAll();
    }
    XSRETURN_EMPTY;
}

#endif

XS_EUPXS(XS_Wx__TreeCtrl_Expand); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__TreeCtrl_Expand)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, item");
    {
	wxTreeItemId*    item = (wxTreeItemId *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::TreeItemId" )
;
	wxTreeCtrl *    THIS = (wxTreeCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::TreeCtrl" )
;

	THIS->Expand(*item);
    }
    XSRETURN_EMPTY;
}

#if WXPERL_W_VERSION_GE( 2, 7, 0 )
#define XSubPPtmpAADO 1


XS_EUPXS(XS_Wx__TreeCtrl_ExpandAllChildren); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__TreeCtrl_ExpandAllChildren)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, item");
    {
	wxTreeItemId*    item = (wxTreeItemId *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::TreeItemId" )
;
	wxTreeCtrl *    THIS = (wxTreeCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::TreeCtrl" )
;

	THIS->ExpandAllChildren(*item);
    }
    XSRETURN_EMPTY;
}

#endif

XS_EUPXS(XS_Wx__TreeCtrl_GetBoundingRect); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__TreeCtrl_GetBoundingRect)
{
    dVAR; dXSARGS;
    if (items < 2 || items > 3)
       croak_xs_usage(cv,  "THIS, item, textOnly = false");
    PERL_UNUSED_VAR(ax); /* -Wall */
    SP -= items;
    {
	wxTreeItemId*    item = (wxTreeItemId *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::TreeItemId" )
;
	bool	textOnly;
    wxRect rect;
	wxTreeCtrl *    THIS = (wxTreeCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::TreeCtrl" )
;

	if (items < 3)
	    textOnly = false;
	else {
	    textOnly = (bool)SvTRUE(ST(2))
;
	}
    bool ret = THIS->GetBoundingRect( *item, rect, textOnly );
    if( ret )
    {
        SV* ret = sv_newmortal();
        wxPli_non_object_2_sv( aTHX_ ret, new wxRect( rect ), "Wx::Rect" );
        XPUSHs( ret );
    }
    else
    {
        XSRETURN_UNDEF;
    }
	PUTBACK;
	return;
    }
}


XS_EUPXS(XS_Wx__TreeCtrl_GetChildrenCount); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__TreeCtrl_GetChildrenCount)
{
    dVAR; dXSARGS;
    if (items < 2 || items > 3)
       croak_xs_usage(cv,  "THIS, item, recursively = true");
    {
	wxTreeItemId*    item = (wxTreeItemId *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::TreeItemId" )
;
	bool	recursively;
	wxTreeCtrl *    THIS = (wxTreeCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::TreeCtrl" )
;
	size_t	RETVAL;
	dXSTARG;

	if (items < 3)
	    recursively = true;
	else {
	    recursively = (bool)SvTRUE(ST(2))
;
	}

	RETVAL = THIS->GetChildrenCount(*item, recursively);
	XSprePUSH;
	PUSHu((UV)RETVAL );
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__TreeCtrl_GetCount); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__TreeCtrl_GetCount)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxTreeCtrl *    THIS = (wxTreeCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::TreeCtrl" )
;
	int	RETVAL;
	dXSTARG;

	RETVAL = THIS->GetCount();
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__TreeCtrl_GetItemData); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__TreeCtrl_GetItemData)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, item");
    {
	wxTreeItemId*    item = (wxTreeItemId *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::TreeItemId" )
;
	wxTreeCtrl *    THIS = (wxTreeCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::TreeCtrl" )
;
	wxTreeItemData *	RETVAL;
    RETVAL = (wxPliTreeItemData*) THIS->GetItemData( *item );
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_non_object_2_sv( aTHX_ RETVALSV, RETVAL, "Wx::TreeItemData" );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__TreeCtrl_GetPlData); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__TreeCtrl_GetPlData)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, item");
    {
	wxTreeItemId*    item = (wxTreeItemId *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::TreeItemId" )
;
	wxTreeCtrl *    THIS = (wxTreeCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::TreeCtrl" )
;
	SV_null *	RETVAL;
    wxPliTreeItemData* data = (wxPliTreeItemData*) THIS->GetItemData( *item );
    RETVAL = data ? data->m_data : 0;
	{
	    SV * RETVALSV;
    RETVALSV = ( RETVAL == 0 ) ? &PL_sv_undef : RETVAL;
    SvREFCNT_inc( RETVALSV ); // xsubpp mortalizes it...
	    RETVALSV = sv_2mortal(RETVALSV);
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}

#if defined( __WXMSW__ ) || defined( __WXPERL_FORCE__ )
#define XSubPPtmpAADP 1


XS_EUPXS(XS_Wx__TreeCtrl_GetEditControl); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__TreeCtrl_GetEditControl)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxTreeCtrl *    THIS = (wxTreeCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::TreeCtrl" )
;
	wxTextCtrl *	RETVAL;

	RETVAL = THIS->GetEditControl();
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_object_2_sv( aTHX_ RETVALSV, RETVAL );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}

#endif

XS_EUPXS(XS_Wx__TreeCtrl_GetFirstChild); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__TreeCtrl_GetFirstChild)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, item");
    PERL_UNUSED_VAR(ax); /* -Wall */
    SP -= items;
    {
	wxTreeItemId*    item = (wxTreeItemId *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::TreeItemId" )
;
#if WXPERL_W_VERSION_GE( 2, 5, 1 )
    void* cookie;
#else
    long cookie;
#endif
	wxTreeCtrl *    THIS = (wxTreeCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::TreeCtrl" )
;
    wxTreeItemId ret = THIS->GetFirstChild( *item, cookie );
#if WXPERL_W_VERSION_LT( 2, 5, 1 )
    if( !ret.IsOk() ) cookie = -1;
#endif
    EXTEND( SP, 2 );
    PUSHs( wxPli_non_object_2_sv( aTHX_ sv_newmortal(),
                                  new wxTreeItemId( ret ),
                                  "Wx::TreeItemId" ) );
#if WXPERL_W_VERSION_GE( 2, 5, 1 )
    PUSHs( sv_2mortal( newSViv( PTR2IV( cookie ) ) ) );
#else
    PUSHs( sv_2mortal( newSViv( cookie ) ) );
#endif
	PUTBACK;
	return;
    }
}


XS_EUPXS(XS_Wx__TreeCtrl_GetFirstVisibleItem); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__TreeCtrl_GetFirstVisibleItem)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxTreeCtrl *    THIS = (wxTreeCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::TreeCtrl" )
;
	wxTreeItemId *	RETVAL;
    RETVAL = new wxTreeItemId( THIS->GetFirstVisibleItem() );
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_non_object_2_sv( aTHX_ RETVALSV, RETVAL, "Wx::TreeItemId" );
    wxPli_thread_sv_register( aTHX_ "Wx::TreeItemId", RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__TreeCtrl_GetImageList); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__TreeCtrl_GetImageList)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxTreeCtrl *    THIS = (wxTreeCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::TreeCtrl" )
;
	wxImageList *	RETVAL;

	RETVAL = THIS->GetImageList();
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_object_2_sv( aTHX_ RETVALSV, RETVAL );
    wxPli_thread_sv_register( aTHX_ "Wx::ImageList", RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    wxPli_object_set_deleteable( aTHX_ ST(0), false );
    }
    XSRETURN(1);
}

#if !defined( __WXMSW__ )
#define XSubPPtmpAADQ 1


XS_EUPXS(XS_Wx__TreeCtrl_GetButtonsImageList); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__TreeCtrl_GetButtonsImageList)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxTreeCtrl *    THIS = (wxTreeCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::TreeCtrl" )
;
	wxImageList *	RETVAL;

	RETVAL = THIS->GetButtonsImageList();
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_object_2_sv( aTHX_ RETVALSV, RETVAL );
    wxPli_thread_sv_register( aTHX_ "Wx::ImageList", RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    wxPli_object_set_deleteable( aTHX_ ST(0), false );
    }
    XSRETURN(1);
}

#endif    

XS_EUPXS(XS_Wx__TreeCtrl_GetIndent); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__TreeCtrl_GetIndent)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxTreeCtrl *    THIS = (wxTreeCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::TreeCtrl" )
;
	int	RETVAL;
	dXSTARG;

	RETVAL = THIS->GetIndent();
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__TreeCtrl_GetItemImage); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__TreeCtrl_GetItemImage)
{
    dVAR; dXSARGS;
    if (items < 2 || items > 3)
       croak_xs_usage(cv,  "THIS, item, which = wxTreeItemIcon_Normal");
    {
	wxTreeItemId*    item = (wxTreeItemId *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::TreeItemId" )
;
	wxTreeItemIcon	which;
	wxTreeCtrl *    THIS = (wxTreeCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::TreeCtrl" )
;
	int	RETVAL;
	dXSTARG;

	if (items < 3)
	    which = wxTreeItemIcon_Normal;
	else {
    which = (wxTreeItemIcon)SvUV( ST(2) )
;
	}

	RETVAL = THIS->GetItemImage(*item, which);
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__TreeCtrl_GetItemText); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__TreeCtrl_GetItemText)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, item");
    {
	wxTreeItemId*    item = (wxTreeItemId *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::TreeItemId" )
;
	wxTreeCtrl *    THIS = (wxTreeCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::TreeCtrl" )
;
	wxString	RETVAL;

	RETVAL = THIS->GetItemText(*item);
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    WXSTRING_OUTPUT( RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__TreeCtrl_GetItemBackgroundColour); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__TreeCtrl_GetItemBackgroundColour)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, item");
    {
	wxTreeItemId*    item = (wxTreeItemId *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::TreeItemId" )
;
	wxTreeCtrl *    THIS = (wxTreeCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::TreeCtrl" )
;
	wxColour *	RETVAL;
    RETVAL = new wxColour( THIS->GetItemBackgroundColour( *item ) );
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_non_object_2_sv( aTHX_ RETVALSV, RETVAL, "Wx::Colour" );
    wxPli_thread_sv_register( aTHX_ "Wx::Colour", RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__TreeCtrl_GetItemTextColour); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__TreeCtrl_GetItemTextColour)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, item");
    {
	wxTreeItemId*    item = (wxTreeItemId *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::TreeItemId" )
;
	wxTreeCtrl *    THIS = (wxTreeCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::TreeCtrl" )
;
	wxColour *	RETVAL;
    RETVAL = new wxColour( THIS->GetItemTextColour( *item ) );
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_non_object_2_sv( aTHX_ RETVALSV, RETVAL, "Wx::Colour" );
    wxPli_thread_sv_register( aTHX_ "Wx::Colour", RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__TreeCtrl_GetItemFont); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__TreeCtrl_GetItemFont)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, item");
    {
	wxTreeItemId*    item = (wxTreeItemId *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::TreeItemId" )
;
	wxTreeCtrl *    THIS = (wxTreeCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::TreeCtrl" )
;
	wxFont *	RETVAL;
    RETVAL = new wxFont( THIS->GetItemFont( *item ) );
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_object_2_sv( aTHX_ RETVALSV, RETVAL );
    wxPli_thread_sv_register( aTHX_ "Wx::Font", RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__TreeCtrl_GetLastChild); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__TreeCtrl_GetLastChild)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, item");
    {
	wxTreeItemId*    item = (wxTreeItemId *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::TreeItemId" )
;
	wxTreeCtrl *    THIS = (wxTreeCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::TreeCtrl" )
;
	wxTreeItemId *	RETVAL;
    RETVAL = new wxTreeItemId( THIS->GetLastChild( *item ) );
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_non_object_2_sv( aTHX_ RETVALSV, RETVAL, "Wx::TreeItemId" );
    wxPli_thread_sv_register( aTHX_ "Wx::TreeItemId", RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}

#if WXPERL_W_VERSION_GE( 2, 5, 1 )
#define XSubPPtmpAADR 1


XS_EUPXS(XS_Wx__TreeCtrl_GetNextChild); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__TreeCtrl_GetNextChild)
{
    dVAR; dXSARGS;
    if (items != 3)
       croak_xs_usage(cv,  "THIS, item, cookie");
    PERL_UNUSED_VAR(ax); /* -Wall */
    SP -= items;
    {
	wxTreeItemId*    item = (wxTreeItemId *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::TreeItemId" )
;
	IV	cookie = (IV)SvIV(ST(2))
;
    void* realcookie = INT2PTR( void*, cookie );
	wxTreeCtrl *    THIS = (wxTreeCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::TreeCtrl" )
;
    wxTreeItemId ret = THIS->GetNextChild( *item, realcookie );
    EXTEND( SP, 2 );
    PUSHs( wxPli_non_object_2_sv( aTHX_ sv_newmortal(),
                                  new wxTreeItemId( ret ),
                                  "Wx::TreeItemId" ) );
    PUSHs( sv_2mortal( newSViv( PTR2IV( realcookie ) ) ) );
	PUTBACK;
	return;
    }
}

#else
#define XSubPPtmpAADS 1


XS_EUPXS(XS_Wx__TreeCtrl_GetNextChild); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__TreeCtrl_GetNextChild)
{
    dVAR; dXSARGS;
    if (items != 3)
       croak_xs_usage(cv,  "THIS, item, cookie");
    PERL_UNUSED_VAR(ax); /* -Wall */
    SP -= items;
    {
	wxTreeItemId*    item = (wxTreeItemId *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::TreeItemId" )
;
	long	cookie = (long)SvIV(ST(2))
;
	wxTreeCtrl *    THIS = (wxTreeCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::TreeCtrl" )
;
    wxTreeItemId ret = THIS->GetNextChild( *item, cookie );
    EXTEND( SP, 2 );
    PUSHs( wxPli_non_object_2_sv( aTHX_ sv_newmortal(),
                                  new wxTreeItemId( ret ),
                                  "Wx::TreeItemId" ) );
    PUSHs( sv_2mortal( newSViv( cookie ) ) );
	PUTBACK;
	return;
    }
}

#endif

XS_EUPXS(XS_Wx__TreeCtrl_GetNextSibling); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__TreeCtrl_GetNextSibling)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, item");
    {
	wxTreeItemId*    item = (wxTreeItemId *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::TreeItemId" )
;
	wxTreeCtrl *    THIS = (wxTreeCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::TreeCtrl" )
;
	wxTreeItemId *	RETVAL;
    RETVAL = new wxTreeItemId( THIS->GetNextSibling( *item ) );
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_non_object_2_sv( aTHX_ RETVALSV, RETVAL, "Wx::TreeItemId" );
    wxPli_thread_sv_register( aTHX_ "Wx::TreeItemId", RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__TreeCtrl_GetNextVisible); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__TreeCtrl_GetNextVisible)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, item");
    {
	wxTreeItemId*    item = (wxTreeItemId *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::TreeItemId" )
;
	wxTreeCtrl *    THIS = (wxTreeCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::TreeCtrl" )
;
	wxTreeItemId *	RETVAL;
    RETVAL = new wxTreeItemId( THIS->GetNextVisible( *item ) );
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_non_object_2_sv( aTHX_ RETVALSV, RETVAL, "Wx::TreeItemId" );
    wxPli_thread_sv_register( aTHX_ "Wx::TreeItemId", RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__TreeCtrl_GetParent); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__TreeCtrl_GetParent)
{
    dVAR; dXSARGS;
    if (items < 1)
       croak_xs_usage(cv,  "THIS, ...");
    PERL_UNUSED_VAR(ax); /* -Wall */
    SP -= items;
    {
	wxTreeCtrl *    THIS = (wxTreeCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::TreeCtrl" )
;
    BEGIN_OVERLOAD()
        MATCH_VOIDM_REDISP( Wx::Window::GetParent )
        MATCH_REDISP( wxPliOvl_wtid, GetItemParent )
    END_OVERLOAD( Wx::TreeCtrl::GetParent )
	PUTBACK;
	return;
    }
}


XS_EUPXS(XS_Wx__TreeCtrl_GetItemParent); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__TreeCtrl_GetItemParent)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, item");
    {
	wxTreeItemId*    item = (wxTreeItemId *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::TreeItemId" )
;
	wxTreeCtrl *    THIS = (wxTreeCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::TreeCtrl" )
;
	wxTreeItemId *	RETVAL;
    RETVAL = new wxTreeItemId( 
       THIS->GetItemParent( *item )
     );
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_non_object_2_sv( aTHX_ RETVALSV, RETVAL, "Wx::TreeItemId" );
    wxPli_thread_sv_register( aTHX_ "Wx::TreeItemId", RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__TreeCtrl_GetPrevSibling); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__TreeCtrl_GetPrevSibling)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, item");
    {
	wxTreeItemId*    item = (wxTreeItemId *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::TreeItemId" )
;
	wxTreeCtrl *    THIS = (wxTreeCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::TreeCtrl" )
;
	wxTreeItemId *	RETVAL;
    RETVAL = new wxTreeItemId( THIS->GetPrevSibling( *item ) );
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_non_object_2_sv( aTHX_ RETVALSV, RETVAL, "Wx::TreeItemId" );
    wxPli_thread_sv_register( aTHX_ "Wx::TreeItemId", RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__TreeCtrl_GetPrevVisible); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__TreeCtrl_GetPrevVisible)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, item");
    {
	wxTreeItemId*    item = (wxTreeItemId *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::TreeItemId" )
;
	wxTreeCtrl *    THIS = (wxTreeCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::TreeCtrl" )
;
	wxTreeItemId *	RETVAL;
    RETVAL = new wxTreeItemId( THIS->GetPrevVisible( *item ) );
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_non_object_2_sv( aTHX_ RETVALSV, RETVAL, "Wx::TreeItemId" );
    wxPli_thread_sv_register( aTHX_ "Wx::TreeItemId", RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__TreeCtrl_GetRootItem); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__TreeCtrl_GetRootItem)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxTreeCtrl *    THIS = (wxTreeCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::TreeCtrl" )
;
	wxTreeItemId *	RETVAL;
    RETVAL = new wxTreeItemId( THIS->GetRootItem() );
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_non_object_2_sv( aTHX_ RETVALSV, RETVAL, "Wx::TreeItemId" );
    wxPli_thread_sv_register( aTHX_ "Wx::TreeItemId", RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__TreeCtrl_GetSelection); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__TreeCtrl_GetSelection)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxTreeCtrl *    THIS = (wxTreeCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::TreeCtrl" )
;
	wxTreeItemId *	RETVAL;
    RETVAL = new wxTreeItemId( THIS->GetSelection() );
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_non_object_2_sv( aTHX_ RETVALSV, RETVAL, "Wx::TreeItemId" );
    wxPli_thread_sv_register( aTHX_ "Wx::TreeItemId", RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__TreeCtrl_GetSelections); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__TreeCtrl_GetSelections)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    PERL_UNUSED_VAR(ax); /* -Wall */
    SP -= items;
    {
    wxArrayTreeItemIds selections;
	wxTreeCtrl *    THIS = (wxTreeCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::TreeCtrl" )
;
    size_t num = THIS->GetSelections( selections );
    EXTEND( SP, (IV)num );
    for( size_t i = 0; i < num; ++i )
    {
        PUSHs( wxPli_non_object_2_sv( aTHX_ sv_newmortal(),
                                      new wxTreeItemId( selections[i] ),
                                      "Wx::TreeItemId" ) );
    }
	PUTBACK;
	return;
    }
}


XS_EUPXS(XS_Wx__TreeCtrl_GetStateImageList); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__TreeCtrl_GetStateImageList)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxTreeCtrl *    THIS = (wxTreeCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::TreeCtrl" )
;
	wxImageList *	RETVAL;

	RETVAL = THIS->GetStateImageList();
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_object_2_sv( aTHX_ RETVALSV, RETVAL );
    wxPli_thread_sv_register( aTHX_ "Wx::ImageList", RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    wxPli_object_set_deleteable( aTHX_ ST(0), false );
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__TreeCtrl_HitTest); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__TreeCtrl_HitTest)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, point");
    PERL_UNUSED_VAR(ax); /* -Wall */
    SP -= items;
    {
	wxPoint    point = wxPli_sv_2_wxpoint( aTHX_ ST(1) )
;
    int flags;
	wxTreeCtrl *    THIS = (wxTreeCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::TreeCtrl" )
;
    wxTreeItemId ret = THIS->HitTest( point, flags );
    EXTEND( SP, 2 );
    PUSHs( wxPli_non_object_2_sv( aTHX_ sv_newmortal(),
                                  new wxTreeItemId( ret ),
                                  "Wx::TreeItemId" ) );
    PUSHs( sv_2mortal( newSViv( flags ) ) );
	PUTBACK;
	return;
    }
}


XS_EUPXS(XS_Wx__TreeCtrl_InsertItem); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__TreeCtrl_InsertItem)
{
    dVAR; dXSARGS;
    if (items < 1)
       croak_xs_usage(cv,  "THIS, ...");
    PERL_UNUSED_VAR(ax); /* -Wall */
    SP -= items;
    {
	wxTreeCtrl *    THIS = (wxTreeCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::TreeCtrl" )
;
    BEGIN_OVERLOAD()
        MATCH_REDISP_COUNT_ALLOWMORE( wxPliOvl_wtid_wtid_s_n_n, InsertItemPrev, 3 )
        MATCH_REDISP_COUNT_ALLOWMORE( wxPliOvl_wtid_n_s_n_n, InsertItemBef, 3 )
    END_OVERLOAD( Wx::TreeCtrl::InsertItem )
	PUTBACK;
	return;
    }
}


XS_EUPXS(XS_Wx__TreeCtrl_InsertItemPrev); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__TreeCtrl_InsertItemPrev)
{
    dVAR; dXSARGS;
    if (items < 4 || items > 7)
       croak_xs_usage(cv,  "THIS, parent, previous, text, image = -1, selImage = -1, data = 0");
    {
	wxTreeItemId*    parent = (wxTreeItemId *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::TreeItemId" )
;
	wxTreeItemId*    previous = (wxTreeItemId *) wxPli_sv_2_object( aTHX_ ST(2), "Wx::TreeItemId" )
;
	wxString	text;
	int	image;
	int	selImage;
	wxTreeItemData*	data;
	wxTreeCtrl *    THIS = (wxTreeCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::TreeCtrl" )
;
	wxTreeItemId *	RETVAL;

    WXSTRING_INPUT( text, wxString, ST(3) )
;

	if (items < 5)
	    image = -1;
	else {
	    image = (int)SvIV(ST(4))
;
	}

	if (items < 6)
	    selImage = -1;
	else {
	    selImage = (int)SvIV(ST(5))
;
	}

	if (items < 7)
	    data = 0;
	else {
    data = (wxTreeItemData *) wxPli_sv_2_object( aTHX_ ST(6), "Wx::TreeItemData" )
;
	}
    RETVAL = new wxTreeItemId( THIS->InsertItem( *parent, *previous, text,
                image, selImage, data ) );
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_non_object_2_sv( aTHX_ RETVALSV, RETVAL, "Wx::TreeItemId" );
    wxPli_thread_sv_register( aTHX_ "Wx::TreeItemId", RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__TreeCtrl_InsertItemBef); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__TreeCtrl_InsertItemBef)
{
    dVAR; dXSARGS;
    if (items < 4 || items > 7)
       croak_xs_usage(cv,  "THIS, parent, before, text, image = -1, selImage = -1, data = 0");
    {
	wxTreeItemId*    parent = (wxTreeItemId *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::TreeItemId" )
;
	size_t    before = (size_t)SvUV( ST(2) )
;
	wxString	text;
	int	image;
	int	selImage;
	wxTreeItemData*	data;
	wxTreeCtrl *    THIS = (wxTreeCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::TreeCtrl" )
;
	wxTreeItemId *	RETVAL;

    WXSTRING_INPUT( text, wxString, ST(3) )
;

	if (items < 5)
	    image = -1;
	else {
	    image = (int)SvIV(ST(4))
;
	}

	if (items < 6)
	    selImage = -1;
	else {
	    selImage = (int)SvIV(ST(5))
;
	}

	if (items < 7)
	    data = 0;
	else {
    data = (wxTreeItemData *) wxPli_sv_2_object( aTHX_ ST(6), "Wx::TreeItemData" )
;
	}
    RETVAL = new wxTreeItemId( THIS->InsertItem( *parent, before, text,
                image, selImage, data ) );
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_non_object_2_sv( aTHX_ RETVALSV, RETVAL, "Wx::TreeItemId" );
    wxPli_thread_sv_register( aTHX_ "Wx::TreeItemId", RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__TreeCtrl_IsBold); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__TreeCtrl_IsBold)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, item");
    {
	wxTreeItemId*    item = (wxTreeItemId *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::TreeItemId" )
;
	wxTreeCtrl *    THIS = (wxTreeCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::TreeCtrl" )
;
	bool	RETVAL;

	RETVAL = THIS->IsBold(*item);
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__TreeCtrl_IsExpanded); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__TreeCtrl_IsExpanded)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, item");
    {
	wxTreeItemId*    item = (wxTreeItemId *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::TreeItemId" )
;
	wxTreeCtrl *    THIS = (wxTreeCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::TreeCtrl" )
;
	bool	RETVAL;

	RETVAL = THIS->IsExpanded(*item);
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__TreeCtrl_IsSelected); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__TreeCtrl_IsSelected)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, item");
    {
	wxTreeItemId*    item = (wxTreeItemId *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::TreeItemId" )
;
	wxTreeCtrl *    THIS = (wxTreeCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::TreeCtrl" )
;
	bool	RETVAL;

	RETVAL = THIS->IsSelected(*item);
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__TreeCtrl_IsVisible); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__TreeCtrl_IsVisible)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, item");
    {
	wxTreeItemId*    item = (wxTreeItemId *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::TreeItemId" )
;
	wxTreeCtrl *    THIS = (wxTreeCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::TreeCtrl" )
;
	bool	RETVAL;

	RETVAL = THIS->IsVisible(*item);
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}

#if WXPERL_W_VERSION_GE( 2, 8, 3 )
#define XSubPPtmpAADT 1


XS_EUPXS(XS_Wx__TreeCtrl_IsEmpty); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__TreeCtrl_IsEmpty)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxTreeCtrl *    THIS = (wxTreeCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::TreeCtrl" )
;
	bool	RETVAL;

	RETVAL = THIS->IsEmpty();
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}

#endif

XS_EUPXS(XS_Wx__TreeCtrl_ItemHasChildren); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__TreeCtrl_ItemHasChildren)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, item");
    {
	wxTreeItemId*    item = (wxTreeItemId *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::TreeItemId" )
;
	wxTreeCtrl *    THIS = (wxTreeCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::TreeCtrl" )
;
	bool	RETVAL;

	RETVAL = THIS->ItemHasChildren(*item);
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__TreeCtrl_OnCompareItems); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__TreeCtrl_OnCompareItems)
{
    dVAR; dXSARGS;
    if (items != 3)
       croak_xs_usage(cv,  "THIS, item1, item2");
    {
	wxTreeItemId*    item1 = (wxTreeItemId *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::TreeItemId" )
;
	wxTreeItemId*    item2 = (wxTreeItemId *) wxPli_sv_2_object( aTHX_ ST(2), "Wx::TreeItemId" )
;
	wxTreeCtrl *    THIS = (wxTreeCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::TreeCtrl" )
;
	int	RETVAL;
	dXSTARG;
    RETVAL = THIS->wxTreeCtrl::OnCompareItems( *item1, *item2 );
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__TreeCtrl_PrependItem); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__TreeCtrl_PrependItem)
{
    dVAR; dXSARGS;
    if (items < 3 || items > 6)
       croak_xs_usage(cv,  "THIS, parent, text, image = -1, selImage = -1, data = 0");
    {
	wxTreeItemId*    parent = (wxTreeItemId *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::TreeItemId" )
;
	wxString	text;
	int	image;
	int	selImage;
	wxTreeItemData*	data;
	wxTreeCtrl *    THIS = (wxTreeCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::TreeCtrl" )
;
	wxTreeItemId *	RETVAL;

    WXSTRING_INPUT( text, wxString, ST(2) )
;

	if (items < 4)
	    image = -1;
	else {
	    image = (int)SvIV(ST(3))
;
	}

	if (items < 5)
	    selImage = -1;
	else {
	    selImage = (int)SvIV(ST(4))
;
	}

	if (items < 6)
	    data = 0;
	else {
    data = (wxTreeItemData *) wxPli_sv_2_object( aTHX_ ST(5), "Wx::TreeItemData" )
;
	}
    RETVAL = new wxTreeItemId( THIS->PrependItem( *parent, text, image,
         selImage, data ) );
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_non_object_2_sv( aTHX_ RETVALSV, RETVAL, "Wx::TreeItemId" );
    wxPli_thread_sv_register( aTHX_ "Wx::TreeItemId", RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__TreeCtrl_ScrollTo); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__TreeCtrl_ScrollTo)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, item");
    {
	wxTreeItemId*    item = (wxTreeItemId *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::TreeItemId" )
;
	wxTreeCtrl *    THIS = (wxTreeCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::TreeCtrl" )
;

	THIS->ScrollTo(*item);
    }
    XSRETURN_EMPTY;
}

#if WXPERL_W_VERSION_GE( 2, 5, 2 )
#define XSubPPtmpAADU 1


XS_EUPXS(XS_Wx__TreeCtrl_SelectItem); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__TreeCtrl_SelectItem)
{
    dVAR; dXSARGS;
    if (items < 2 || items > 3)
       croak_xs_usage(cv,  "THIS, item, select = true");
    {
	wxTreeItemId*    item = (wxTreeItemId *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::TreeItemId" )
;
	bool	select;
	wxTreeCtrl *    THIS = (wxTreeCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::TreeCtrl" )
;

	if (items < 3)
	    select = true;
	else {
	    select = (bool)SvTRUE(ST(2))
;
	}

	THIS->SelectItem(*item, select);
    }
    XSRETURN_EMPTY;
}

#else
#define XSubPPtmpAADV 1


XS_EUPXS(XS_Wx__TreeCtrl_SelectItem); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__TreeCtrl_SelectItem)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, item");
    {
	wxTreeItemId*    item = (wxTreeItemId *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::TreeItemId" )
;
	wxTreeCtrl *    THIS = (wxTreeCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::TreeCtrl" )
;

	THIS->SelectItem(*item);
    }
    XSRETURN_EMPTY;
}

#endif

XS_EUPXS(XS_Wx__TreeCtrl_SetIndent); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__TreeCtrl_SetIndent)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, indent");
    {
	int	indent = (int)SvIV(ST(1))
;
	wxTreeCtrl *    THIS = (wxTreeCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::TreeCtrl" )
;

	THIS->SetIndent(indent);
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__TreeCtrl_SetImageList); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__TreeCtrl_SetImageList)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, list");
    {
	wxImageList*    list = (wxImageList *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::ImageList" )
;
	wxTreeCtrl *    THIS = (wxTreeCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::TreeCtrl" )
;

	THIS->SetImageList(list);
    }
    XSRETURN_EMPTY;
}

#if !defined( __WXMSW__ )
#define XSubPPtmpAADW 1


XS_EUPXS(XS_Wx__TreeCtrl_SetButtonsImageList); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__TreeCtrl_SetButtonsImageList)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, list");
    {
	wxImageList*    list = (wxImageList *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::ImageList" )
;
	wxTreeCtrl *    THIS = (wxTreeCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::TreeCtrl" )
;

	THIS->SetButtonsImageList(list);
    }
    XSRETURN_EMPTY;
}

#endif    

XS_EUPXS(XS_Wx__TreeCtrl_SetStateImageList); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__TreeCtrl_SetStateImageList)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, list");
    {
	wxImageList*    list = (wxImageList *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::ImageList" )
;
	wxTreeCtrl *    THIS = (wxTreeCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::TreeCtrl" )
;

	THIS->SetStateImageList(list);
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__TreeCtrl_AssignImageList); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__TreeCtrl_AssignImageList)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, list");
    {
	wxImageList*    list = (wxImageList *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::ImageList" )
;
	wxTreeCtrl *    THIS = (wxTreeCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::TreeCtrl" )
;
    wxPli_object_set_deleteable( aTHX_ ST(1), false );
    THIS->AssignImageList( list );
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__TreeCtrl_AssignButtonsImageList); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__TreeCtrl_AssignButtonsImageList)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, list");
    {
	wxImageList*    list = (wxImageList *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::ImageList" )
;
	wxTreeCtrl *    THIS = (wxTreeCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::TreeCtrl" )
;
    wxPli_object_set_deleteable( aTHX_ ST(1), false );
    THIS->AssignStateImageList( list );
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__TreeCtrl_AssignStateImageList); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__TreeCtrl_AssignStateImageList)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, list");
    {
	wxImageList*    list = (wxImageList *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::ImageList" )
;
	wxTreeCtrl *    THIS = (wxTreeCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::TreeCtrl" )
;
    wxPli_object_set_deleteable( aTHX_ ST(1), false );
    THIS->AssignStateImageList( list );
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__TreeCtrl_SetItemBackgroundColour); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__TreeCtrl_SetItemBackgroundColour)
{
    dVAR; dXSARGS;
    if (items != 3)
       croak_xs_usage(cv,  "THIS, item, col");
    {
	wxTreeItemId*    item = (wxTreeItemId *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::TreeItemId" )
;
	wxColour    col = *(wxColour *) wxPli_sv_2_object( aTHX_ ST(2), "Wx::Colour" )
;
	wxTreeCtrl *    THIS = (wxTreeCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::TreeCtrl" )
;

	THIS->SetItemBackgroundColour(*item, col);
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__TreeCtrl_SetItemBold); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__TreeCtrl_SetItemBold)
{
    dVAR; dXSARGS;
    if (items < 2 || items > 3)
       croak_xs_usage(cv,  "THIS, item, bold = true");
    {
	wxTreeItemId*    item = (wxTreeItemId *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::TreeItemId" )
;
	bool	bold;
	wxTreeCtrl *    THIS = (wxTreeCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::TreeCtrl" )
;

	if (items < 3)
	    bold = true;
	else {
	    bold = (bool)SvTRUE(ST(2))
;
	}

	THIS->SetItemBold(*item, bold);
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__TreeCtrl_SetItemData); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__TreeCtrl_SetItemData)
{
    dVAR; dXSARGS;
    if (items != 3)
       croak_xs_usage(cv,  "THIS, item, data");
    {
	wxTreeItemId*    item = (wxTreeItemId *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::TreeItemId" )
;
	wxTreeItemData*    data = (wxTreeItemData *) wxPli_sv_2_object( aTHX_ ST(2), "Wx::TreeItemData" )
;
	wxTreeCtrl *    THIS = (wxTreeCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::TreeCtrl" )
;
    wxTreeItemData* tid = THIS->GetItemData( *item );
    if( tid ) delete tid;
    THIS->SetItemData( *item, data );
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__TreeCtrl_SetPlData); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__TreeCtrl_SetPlData)
{
    dVAR; dXSARGS;
    if (items != 3)
       croak_xs_usage(cv,  "THIS, item, data");
    {
	wxTreeItemId*    item = (wxTreeItemId *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::TreeItemId" )
;
	SV_null*    data = SvOK( ST(2) ) ? ST(2) : 0
;
	wxTreeCtrl *    THIS = (wxTreeCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::TreeCtrl" )
;
    wxTreeItemData* tid = THIS->GetItemData( *item );
    if( tid ) delete tid;
    THIS->SetItemData( *item, data ? new wxPliTreeItemData( data ) : 0 );
    }
    XSRETURN_EMPTY;
}

#if defined( __WXMSW__ )
#define XSubPPtmpAADX 1


XS_EUPXS(XS_Wx__TreeCtrl_SetItemDropHighlight); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__TreeCtrl_SetItemDropHighlight)
{
    dVAR; dXSARGS;
    if (items < 2 || items > 3)
       croak_xs_usage(cv,  "THIS, item, highlight = true");
    {
	wxTreeItemId*    item = (wxTreeItemId *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::TreeItemId" )
;
	bool	highlight;
	wxTreeCtrl *    THIS = (wxTreeCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::TreeCtrl" )
;

	if (items < 3)
	    highlight = true;
	else {
	    highlight = (bool)SvTRUE(ST(2))
;
	}

	THIS->SetItemDropHighlight(*item, highlight);
    }
    XSRETURN_EMPTY;
}

#endif

XS_EUPXS(XS_Wx__TreeCtrl_SetItemFont); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__TreeCtrl_SetItemFont)
{
    dVAR; dXSARGS;
    if (items != 3)
       croak_xs_usage(cv,  "THIS, item, font");
    {
	wxTreeItemId*    item = (wxTreeItemId *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::TreeItemId" )
;
	wxFont*    font = (wxFont *) wxPli_sv_2_object( aTHX_ ST(2), "Wx::Font" )
;
	wxTreeCtrl *    THIS = (wxTreeCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::TreeCtrl" )
;

	THIS->SetItemFont(*item, *font);
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__TreeCtrl_SetItemHasChildren); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__TreeCtrl_SetItemHasChildren)
{
    dVAR; dXSARGS;
    if (items < 2 || items > 3)
       croak_xs_usage(cv,  "THIS, item, hasChildren = true");
    {
	wxTreeItemId*    item = (wxTreeItemId *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::TreeItemId" )
;
	bool	hasChildren;
	wxTreeCtrl *    THIS = (wxTreeCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::TreeCtrl" )
;

	if (items < 3)
	    hasChildren = true;
	else {
	    hasChildren = (bool)SvTRUE(ST(2))
;
	}

	THIS->SetItemHasChildren(*item, hasChildren);
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__TreeCtrl_SetItemImage); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__TreeCtrl_SetItemImage)
{
    dVAR; dXSARGS;
    if (items < 3 || items > 4)
       croak_xs_usage(cv,  "THIS, item, image, which = wxTreeItemIcon_Normal");
    {
	wxTreeItemId*    item = (wxTreeItemId *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::TreeItemId" )
;
	int	image = (int)SvIV(ST(2))
;
	wxTreeItemIcon	which;
	wxTreeCtrl *    THIS = (wxTreeCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::TreeCtrl" )
;

	if (items < 4)
	    which = wxTreeItemIcon_Normal;
	else {
    which = (wxTreeItemIcon)SvUV( ST(3) )
;
	}

	THIS->SetItemImage(*item, image, which);
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__TreeCtrl_SetItemText); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__TreeCtrl_SetItemText)
{
    dVAR; dXSARGS;
    if (items != 3)
       croak_xs_usage(cv,  "THIS, item, text");
    {
	wxTreeItemId*    item = (wxTreeItemId *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::TreeItemId" )
;
	wxString	text;
	wxTreeCtrl *    THIS = (wxTreeCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::TreeCtrl" )
;

    WXSTRING_INPUT( text, wxString, ST(2) )
;

	THIS->SetItemText(*item, text);
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__TreeCtrl_SetItemTextColour); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__TreeCtrl_SetItemTextColour)
{
    dVAR; dXSARGS;
    if (items != 3)
       croak_xs_usage(cv,  "THIS, item, col");
    {
	wxTreeItemId*    item = (wxTreeItemId *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::TreeItemId" )
;
	wxColour    col = *(wxColour *) wxPli_sv_2_object( aTHX_ ST(2), "Wx::Colour" )
;
	wxTreeCtrl *    THIS = (wxTreeCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::TreeCtrl" )
;

	THIS->SetItemTextColour(*item, col);
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__TreeCtrl_SortChildren); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__TreeCtrl_SortChildren)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, item");
    {
	wxTreeItemId*    item = (wxTreeItemId *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::TreeItemId" )
;
	wxTreeCtrl *    THIS = (wxTreeCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::TreeCtrl" )
;

	THIS->SortChildren(*item);
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__TreeCtrl_Toggle); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__TreeCtrl_Toggle)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, item");
    {
	wxTreeItemId*    item = (wxTreeItemId *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::TreeItemId" )
;
	wxTreeCtrl *    THIS = (wxTreeCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::TreeCtrl" )
;

	THIS->Toggle(*item);
    }
    XSRETURN_EMPTY;
}

#if WXPERL_W_VERSION_GE( 2, 5, 3 )
#define XSubPPtmpAADY 1


XS_EUPXS(XS_Wx__TreeCtrl_UnselectItem); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__TreeCtrl_UnselectItem)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, item");
    {
	wxTreeItemId*    item = (wxTreeItemId *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::TreeItemId" )
;
	wxTreeCtrl *    THIS = (wxTreeCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::TreeCtrl" )
;

	THIS->UnselectItem(*item);
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__TreeCtrl_ToggleItemSelection); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__TreeCtrl_ToggleItemSelection)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, item");
    {
	wxTreeItemId*    item = (wxTreeItemId *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::TreeItemId" )
;
	wxTreeCtrl *    THIS = (wxTreeCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::TreeCtrl" )
;

	THIS->ToggleItemSelection(*item);
    }
    XSRETURN_EMPTY;
}

#endif

XS_EUPXS(XS_Wx__TreeCtrl_Unselect); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__TreeCtrl_Unselect)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxTreeCtrl *    THIS = (wxTreeCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::TreeCtrl" )
;

	THIS->Unselect();
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__TreeCtrl_UnselectAll); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__TreeCtrl_UnselectAll)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxTreeCtrl *    THIS = (wxTreeCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::TreeCtrl" )
;

	THIS->UnselectAll();
    }
    XSRETURN_EMPTY;
}


/* INCLUDE: Returning to 'XS/ToggleButton.xs' from 'XS/TreeCtrl.xs' */

#if wxPERL_USE_TOGGLEBTN
#include <wx/tglbtn.h>
#define XSubPPtmpAADZ 1


XS_EUPXS(XS_Wx__ToggleButton_new); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ToggleButton_new)
{
    dVAR; dXSARGS;
    PERL_UNUSED_VAR(cv); /* -W */
    PERL_UNUSED_VAR(items); /* -W */
    PERL_UNUSED_VAR(ax); /* -Wall */
    SP -= items;
    {
    BEGIN_OVERLOAD()
        MATCH_VOIDM_REDISP( newDefault )
        MATCH_ANY_REDISP( newFull )
    END_OVERLOAD( "Wx::ToggleButton::new" )
	PUTBACK;
	return;
    }
}


XS_EUPXS(XS_Wx__ToggleButton_newDefault); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ToggleButton_newDefault)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "CLASS");
    {
	PlClassName    CLASS = wxPli_get_class( aTHX_ ST(0) )
;
	wxToggleButton *	RETVAL;
    RETVAL = new wxToggleButton();
    wxPli_create_evthandler( aTHX_ RETVAL, CLASS );
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_evthandler_2_sv( aTHX_ RETVALSV, RETVAL );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__ToggleButton_newFull); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ToggleButton_newFull)
{
    dVAR; dXSARGS;
    if (items < 4 || items > 9)
       croak_xs_usage(cv,  "CLASS, parent, id, label, pos = wxDefaultPosition, size = wxDefaultSize, style = 0, validator = (wxValidator*)&wxDefaultValidator, name = wxCheckBoxNameStr");
    {
	PlClassName    CLASS = wxPli_get_class( aTHX_ ST(0) )
;
	wxWindow*    parent = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::Window" )
;
	wxWindowID    id = wxPli_get_wxwindowid( aTHX_ ST(2) )
;
	wxString	label;
	wxPoint	pos;
	wxSize	size;
	long	style;
	wxValidator*	validator;
	wxString	name;
	wxToggleButton *	RETVAL;

    WXSTRING_INPUT( label, wxString, ST(3) )
;

	if (items < 5)
	    pos = wxDefaultPosition;
	else {
    pos = wxPli_sv_2_wxpoint( aTHX_ ST(4) )
;
	}

	if (items < 6)
	    size = wxDefaultSize;
	else {
    size = wxPli_sv_2_wxsize( aTHX_ ST(5) )
;
	}

	if (items < 7)
	    style = 0;
	else {
	    style = (long)SvIV(ST(6))
;
	}

	if (items < 8)
	    validator = (wxValidator*)&wxDefaultValidator;
	else {
    validator = (wxValidator *) wxPli_sv_2_object( aTHX_ ST(7), "Wx::Validator" )
;
	}

	if (items < 9)
	    name = wxCheckBoxNameStr;
	else {
    WXSTRING_INPUT( name, wxString, ST(8) )
;
	}
    RETVAL = new wxToggleButton( parent, id, label, pos, size, 
        style, *validator, name );
    wxPli_create_evthandler( aTHX_ RETVAL, CLASS );
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_evthandler_2_sv( aTHX_ RETVALSV, RETVAL );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__ToggleButton_Create); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ToggleButton_Create)
{
    dVAR; dXSARGS;
    if (items < 4 || items > 9)
       croak_xs_usage(cv,  "THIS, parent, id, label, pos = wxDefaultPosition, size = wxDefaultSize, style = 0, validator = (wxValidator*)&wxDefaultValidator, name = wxCheckBoxNameStr");
    {
	wxWindow*    parent = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::Window" )
;
	wxWindowID    id = wxPli_get_wxwindowid( aTHX_ ST(2) )
;
	wxString	label;
	wxPoint	pos;
	wxSize	size;
	long	style;
	wxValidator*	validator;
	wxString	name;
	wxToggleButton *    THIS = (wxToggleButton *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::ToggleButton" )
;
	bool	RETVAL;

    WXSTRING_INPUT( label, wxString, ST(3) )
;

	if (items < 5)
	    pos = wxDefaultPosition;
	else {
    pos = wxPli_sv_2_wxpoint( aTHX_ ST(4) )
;
	}

	if (items < 6)
	    size = wxDefaultSize;
	else {
    size = wxPli_sv_2_wxsize( aTHX_ ST(5) )
;
	}

	if (items < 7)
	    style = 0;
	else {
	    style = (long)SvIV(ST(6))
;
	}

	if (items < 8)
	    validator = (wxValidator*)&wxDefaultValidator;
	else {
    validator = (wxValidator *) wxPli_sv_2_object( aTHX_ ST(7), "Wx::Validator" )
;
	}

	if (items < 9)
	    name = wxCheckBoxNameStr;
	else {
    WXSTRING_INPUT( name, wxString, ST(8) )
;
	}

	RETVAL = THIS->Create(parent, id, label, pos, size, style, *validator, name);
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__ToggleButton_GetValue); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ToggleButton_GetValue)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxToggleButton *    THIS = (wxToggleButton *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::ToggleButton" )
;
	bool	RETVAL;

	RETVAL = THIS->GetValue();
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__ToggleButton_SetValue); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ToggleButton_SetValue)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, value");
    {
	bool	value = (bool)SvTRUE(ST(1))
;
	wxToggleButton *    THIS = (wxToggleButton *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::ToggleButton" )
;

	THIS->SetValue(value);
    }
    XSRETURN_EMPTY;
}

#if WXPERL_W_VERSION_GE( 2, 9, 0 ) && !defined(__WXMSW__)
#define XSubPPtmpAAEA 1


XS_EUPXS(XS_Wx__BitmapToggleButton_new); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__BitmapToggleButton_new)
{
    dVAR; dXSARGS;
    PERL_UNUSED_VAR(cv); /* -W */
    PERL_UNUSED_VAR(items); /* -W */
    PERL_UNUSED_VAR(ax); /* -Wall */
    SP -= items;
    {
    BEGIN_OVERLOAD()
        MATCH_VOIDM_REDISP( newDefault )
        MATCH_ANY_REDISP( newFull )
    END_OVERLOAD( "Wx::BitmapToggleButton::new" )
	PUTBACK;
	return;
    }
}


XS_EUPXS(XS_Wx__BitmapToggleButton_newDefault); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__BitmapToggleButton_newDefault)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "CLASS");
    {
	PlClassName    CLASS = wxPli_get_class( aTHX_ ST(0) )
;
	wxBitmapToggleButton *	RETVAL;
    RETVAL = new wxBitmapToggleButton();
    wxPli_create_evthandler( aTHX_ RETVAL, CLASS );
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_evthandler_2_sv( aTHX_ RETVALSV, RETVAL );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__BitmapToggleButton_newFull); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__BitmapToggleButton_newFull)
{
    dVAR; dXSARGS;
    if (items < 4 || items > 9)
       croak_xs_usage(cv,  "CLASS, parent, id, label, pos = wxDefaultPosition, size = wxDefaultSize, style = 0, validator = (wxValidator*)&wxDefaultValidator, name = wxCheckBoxNameStr");
    {
	PlClassName    CLASS = wxPli_get_class( aTHX_ ST(0) )
;
	wxWindow*    parent = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::Window" )
;
	wxWindowID    id = wxPli_get_wxwindowid( aTHX_ ST(2) )
;
	wxBitmap*    label = (wxBitmap *) wxPli_sv_2_object( aTHX_ ST(3), "Wx::Bitmap" )
;
	wxPoint	pos;
	wxSize	size;
	long	style;
	wxValidator*	validator;
	wxString	name;
	wxBitmapToggleButton *	RETVAL;

	if (items < 5)
	    pos = wxDefaultPosition;
	else {
    pos = wxPli_sv_2_wxpoint( aTHX_ ST(4) )
;
	}

	if (items < 6)
	    size = wxDefaultSize;
	else {
    size = wxPli_sv_2_wxsize( aTHX_ ST(5) )
;
	}

	if (items < 7)
	    style = 0;
	else {
	    style = (long)SvIV(ST(6))
;
	}

	if (items < 8)
	    validator = (wxValidator*)&wxDefaultValidator;
	else {
    validator = (wxValidator *) wxPli_sv_2_object( aTHX_ ST(7), "Wx::Validator" )
;
	}

	if (items < 9)
	    name = wxCheckBoxNameStr;
	else {
    WXSTRING_INPUT( name, wxString, ST(8) )
;
	}
    RETVAL = new wxBitmapToggleButton( parent, id, *label, pos, size, 
                                       style, *validator, name );
    wxPli_create_evthandler( aTHX_ RETVAL, CLASS );
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_evthandler_2_sv( aTHX_ RETVALSV, RETVAL );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__BitmapToggleButton_Create); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__BitmapToggleButton_Create)
{
    dVAR; dXSARGS;
    if (items < 4 || items > 9)
       croak_xs_usage(cv,  "THIS, parent, id, label, pos = wxDefaultPosition, size = wxDefaultSize, style = 0, validator = (wxValidator*)&wxDefaultValidator, name = wxCheckBoxNameStr");
    {
	wxWindow*    parent = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::Window" )
;
	wxWindowID    id = wxPli_get_wxwindowid( aTHX_ ST(2) )
;
	wxBitmap*    label = (wxBitmap *) wxPli_sv_2_object( aTHX_ ST(3), "Wx::Bitmap" )
;
	wxPoint	pos;
	wxSize	size;
	long	style;
	wxValidator*	validator;
	wxString	name;
	wxBitmapToggleButton *    THIS = (wxBitmapToggleButton *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::BitmapToggleButton" )
;
	bool	RETVAL;

	if (items < 5)
	    pos = wxDefaultPosition;
	else {
    pos = wxPli_sv_2_wxpoint( aTHX_ ST(4) )
;
	}

	if (items < 6)
	    size = wxDefaultSize;
	else {
    size = wxPli_sv_2_wxsize( aTHX_ ST(5) )
;
	}

	if (items < 7)
	    style = 0;
	else {
	    style = (long)SvIV(ST(6))
;
	}

	if (items < 8)
	    validator = (wxValidator*)&wxDefaultValidator;
	else {
    validator = (wxValidator *) wxPli_sv_2_object( aTHX_ ST(7), "Wx::Validator" )
;
	}

	if (items < 9)
	    name = wxCheckBoxNameStr;
	else {
    WXSTRING_INPUT( name, wxString, ST(8) )
;
	}

	RETVAL = THIS->Create(parent, id, *label, pos, size, style, *validator, name);
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__BitmapToggleButton_GetValue); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__BitmapToggleButton_GetValue)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxBitmapToggleButton *    THIS = (wxBitmapToggleButton *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::BitmapToggleButton" )
;
	bool	RETVAL;

	RETVAL = THIS->GetValue();
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__BitmapToggleButton_SetValue); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__BitmapToggleButton_SetValue)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, value");
    {
	bool	value = (bool)SvTRUE(ST(1))
;
	wxBitmapToggleButton *    THIS = (wxBitmapToggleButton *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::BitmapToggleButton" )
;

	THIS->SetValue(value);
    }
    XSRETURN_EMPTY;
}

#endif
#endif

/* INCLUDE: Returning to 'XS/StaticText.xs' from 'XS/ToggleButton.xs' */

#include <wx/stattext.h>

XS_EUPXS(XS_Wx__StaticText_new); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StaticText_new)
{
    dVAR; dXSARGS;
    if (items < 4 || items > 8)
       croak_xs_usage(cv,  "CLASS, parent, id, label, pos = wxDefaultPosition, size = wxDefaultSize, style = 0, name = wxStaticTextNameStr");
    {
	wxWindow*    parent = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::Window" )
;
	wxWindowID    id = wxPli_get_wxwindowid( aTHX_ ST(2) )
;
	wxString	label;
	wxPoint	pos;
	wxSize	size;
	long	style;
	wxString	name;
	char *	CLASS = (char *)SvPV_nolen(ST(0))
;
	wxStaticText *	RETVAL;

    WXSTRING_INPUT( label, wxString, ST(3) )
;

	if (items < 5)
	    pos = wxDefaultPosition;
	else {
    pos = wxPli_sv_2_wxpoint( aTHX_ ST(4) )
;
	}

	if (items < 6)
	    size = wxDefaultSize;
	else {
    size = wxPli_sv_2_wxsize( aTHX_ ST(5) )
;
	}

	if (items < 7)
	    style = 0;
	else {
	    style = (long)SvIV(ST(6))
;
	}

	if (items < 8)
	    name = wxStaticTextNameStr;
	else {
    WXSTRING_INPUT( name, wxString, ST(7) )
;
	}
    RETVAL = new wxStaticText( parent, id, label,
        pos, size, style, name );
    wxPli_create_evthandler( aTHX_ RETVAL, CLASS );
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_evthandler_2_sv( aTHX_ RETVALSV, RETVAL );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__StaticText_Create); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StaticText_Create)
{
    dVAR; dXSARGS;
    if (items < 4 || items > 8)
       croak_xs_usage(cv,  "THIS, parent, id, label, pos = wxDefaultPosition, size = wxDefaultSize, style = 0, name = wxStaticTextNameStr");
    {
	wxWindow*    parent = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::Window" )
;
	wxWindowID    id = wxPli_get_wxwindowid( aTHX_ ST(2) )
;
	wxString	label;
	wxPoint	pos;
	wxSize	size;
	long	style;
	wxString	name;
	wxStaticText *    THIS = (wxStaticText *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StaticText" )
;
	bool	RETVAL;

    WXSTRING_INPUT( label, wxString, ST(3) )
;

	if (items < 5)
	    pos = wxDefaultPosition;
	else {
    pos = wxPli_sv_2_wxpoint( aTHX_ ST(4) )
;
	}

	if (items < 6)
	    size = wxDefaultSize;
	else {
    size = wxPli_sv_2_wxsize( aTHX_ ST(5) )
;
	}

	if (items < 7)
	    style = 0;
	else {
	    style = (long)SvIV(ST(6))
;
	}

	if (items < 8)
	    name = wxStaticTextNameStr;
	else {
    WXSTRING_INPUT( name, wxString, ST(7) )
;
	}

	RETVAL = THIS->Create(parent, id, label, pos, size, style, name);
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}

#if WXPERL_W_VERSION_GE( 2, 6, 3 )
#define XSubPPtmpAAEB 1


XS_EUPXS(XS_Wx__StaticText_Wrap); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StaticText_Wrap)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, width");
    {
	int	width = (int)SvIV(ST(1))
;
	wxStaticText *    THIS = (wxStaticText *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StaticText" )
;

	THIS->Wrap(width);
    }
    XSRETURN_EMPTY;
}

#endif

/* INCLUDE: Returning to 'XS/StaticLine.xs' from 'XS/StaticText.xs' */

#include <wx/statline.h>

XS_EUPXS(XS_Wx__StaticLine_new); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StaticLine_new)
{
    dVAR; dXSARGS;
    if (items < 2 || items > 7)
       croak_xs_usage(cv,  "CLASS, parent, id = wxID_ANY, pos = wxDefaultPosition, size = wxDefaultSize, style = wxLI_HORIZONTAL, name = wxStaticTextNameStr");
    {
	wxWindow*    parent = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::Window" )
;
	wxWindowID	id;
	wxPoint	pos;
	wxSize	size;
	long	style;
	wxString	name;
	char *	CLASS = (char *)SvPV_nolen(ST(0))
;
	wxStaticLine *	RETVAL;

	if (items < 3)
	    id = wxID_ANY;
	else {
    id = wxPli_get_wxwindowid( aTHX_ ST(2) )
;
	}

	if (items < 4)
	    pos = wxDefaultPosition;
	else {
    pos = wxPli_sv_2_wxpoint( aTHX_ ST(3) )
;
	}

	if (items < 5)
	    size = wxDefaultSize;
	else {
    size = wxPli_sv_2_wxsize( aTHX_ ST(4) )
;
	}

	if (items < 6)
	    style = wxLI_HORIZONTAL;
	else {
	    style = (long)SvIV(ST(5))
;
	}

	if (items < 7)
	    name = wxStaticTextNameStr;
	else {
    WXSTRING_INPUT( name, wxString, ST(6) )
;
	}
    RETVAL = new wxStaticLine( parent, id, pos, size, style, name );
    wxPli_create_evthandler( aTHX_ RETVAL, CLASS );
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_evthandler_2_sv( aTHX_ RETVALSV, RETVAL );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__StaticLine_Create); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StaticLine_Create)
{
    dVAR; dXSARGS;
    if (items < 2 || items > 7)
       croak_xs_usage(cv,  "THIS, parent, id = wxID_ANY, pos = wxDefaultPosition, size = wxDefaultSize, style = wxLI_HORIZONTAL, name = wxStaticTextNameStr");
    {
	wxWindow*    parent = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::Window" )
;
	wxWindowID	id;
	wxPoint	pos;
	wxSize	size;
	long	style;
	wxString	name;
	wxStaticLine *    THIS = (wxStaticLine *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StaticLine" )
;
	bool	RETVAL;

	if (items < 3)
	    id = wxID_ANY;
	else {
    id = wxPli_get_wxwindowid( aTHX_ ST(2) )
;
	}

	if (items < 4)
	    pos = wxDefaultPosition;
	else {
    pos = wxPli_sv_2_wxpoint( aTHX_ ST(3) )
;
	}

	if (items < 5)
	    size = wxDefaultSize;
	else {
    size = wxPli_sv_2_wxsize( aTHX_ ST(4) )
;
	}

	if (items < 6)
	    style = wxLI_HORIZONTAL;
	else {
	    style = (long)SvIV(ST(5))
;
	}

	if (items < 7)
	    name = wxStaticTextNameStr;
	else {
    WXSTRING_INPUT( name, wxString, ST(6) )
;
	}

	RETVAL = THIS->Create(parent, id, pos, size, style, name);
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__StaticLine_IsVertical); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StaticLine_IsVertical)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxStaticLine *    THIS = (wxStaticLine *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StaticLine" )
;
	bool	RETVAL;

	RETVAL = THIS->IsVertical();
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__StaticLine_GetDefaultSize); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StaticLine_GetDefaultSize)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxStaticLine *    THIS = (wxStaticLine *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StaticLine" )
;
	int	RETVAL;
	dXSTARG;

	RETVAL = THIS->GetDefaultSize();
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


/* INCLUDE: Returning to 'XS/StaticBox.xs' from 'XS/StaticLine.xs' */

#include <wx/statbox.h>

XS_EUPXS(XS_Wx__StaticBox_new); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StaticBox_new)
{
    dVAR; dXSARGS;
    if (items < 4 || items > 8)
       croak_xs_usage(cv,  "CLASS, parent, id, label, pos = wxDefaultPosition, size = wxDefaultSize, style = 0, name = wxStaticBoxNameStr");
    {
	wxWindow*    parent = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::Window" )
;
	wxWindowID    id = wxPli_get_wxwindowid( aTHX_ ST(2) )
;
	wxString	label;
	wxPoint	pos;
	wxSize	size;
	long	style;
	wxString	name;
	char *	CLASS = (char *)SvPV_nolen(ST(0))
;
	wxStaticBox *	RETVAL;

    WXSTRING_INPUT( label, wxString, ST(3) )
;

	if (items < 5)
	    pos = wxDefaultPosition;
	else {
    pos = wxPli_sv_2_wxpoint( aTHX_ ST(4) )
;
	}

	if (items < 6)
	    size = wxDefaultSize;
	else {
    size = wxPli_sv_2_wxsize( aTHX_ ST(5) )
;
	}

	if (items < 7)
	    style = 0;
	else {
	    style = (long)SvIV(ST(6))
;
	}

	if (items < 8)
	    name = wxStaticBoxNameStr;
	else {
    WXSTRING_INPUT( name, wxString, ST(7) )
;
	}
    RETVAL = new wxStaticBox( parent, id, label, pos, 
        size, style, name );
    wxPli_create_evthandler( aTHX_ RETVAL, CLASS );
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_evthandler_2_sv( aTHX_ RETVALSV, RETVAL );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__StaticBox_Create); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StaticBox_Create)
{
    dVAR; dXSARGS;
    if (items < 4 || items > 8)
       croak_xs_usage(cv,  "THIS, parent, id, label, pos = wxDefaultPosition, size = wxDefaultSize, style = 0, name = wxStaticBoxNameStr");
    {
	wxWindow*    parent = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::Window" )
;
	wxWindowID    id = wxPli_get_wxwindowid( aTHX_ ST(2) )
;
	wxString	label;
	wxPoint	pos;
	wxSize	size;
	long	style;
	wxString	name;
	wxStaticBox *    THIS = (wxStaticBox *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StaticBox" )
;
	bool	RETVAL;

    WXSTRING_INPUT( label, wxString, ST(3) )
;

	if (items < 5)
	    pos = wxDefaultPosition;
	else {
    pos = wxPli_sv_2_wxpoint( aTHX_ ST(4) )
;
	}

	if (items < 6)
	    size = wxDefaultSize;
	else {
    size = wxPli_sv_2_wxsize( aTHX_ ST(5) )
;
	}

	if (items < 7)
	    style = 0;
	else {
	    style = (long)SvIV(ST(6))
;
	}

	if (items < 8)
	    name = wxStaticBoxNameStr;
	else {
    WXSTRING_INPUT( name, wxString, ST(7) )
;
	}

	RETVAL = THIS->Create(parent, id, label, pos, size, style, name);
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


/* INCLUDE: Returning to 'XS/StaticBitmap.xs' from 'XS/StaticBox.xs' */

#include "cpp/overload.h"
#include <wx/statbmp.h>

XS_EUPXS(XS_Wx__StaticBitmap_new); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StaticBitmap_new)
{
    dVAR; dXSARGS;
    if (items < 1)
       croak_xs_usage(cv,  "CLASS, ...");
    PERL_UNUSED_VAR(ax); /* -Wall */
    SP -= items;
    {
	char *	CLASS = (char *)SvPV_nolen(ST(0))
;
    BEGIN_OVERLOAD()
        MATCH_REDISP( wxPliOvl_wwin_n_wico, newIcon )
        MATCH_REDISP( wxPliOvl_wwin_n_wbmp, newBitmap )
    END_OVERLOAD( Wx::StaticBitmap::new )
	PUTBACK;
	return;
    }
}


XS_EUPXS(XS_Wx__StaticBitmap_newBitmap); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StaticBitmap_newBitmap)
{
    dVAR; dXSARGS;
    if (items < 4 || items > 8)
       croak_xs_usage(cv,  "cls, parent, id, bitmap, pos = wxDefaultPosition, size = wxDefaultSize, style = 0, name = wxStaticBitmapNameStr");
    {
	SV*	cls = ST(0)
;
	wxWindow*    parent = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::Window" )
;
	wxWindowID    id = wxPli_get_wxwindowid( aTHX_ ST(2) )
;
	wxBitmap*    bitmap = (wxBitmap *) wxPli_sv_2_object( aTHX_ ST(3), "Wx::Bitmap" )
;
	wxPoint	pos;
	wxSize	size;
	long	style;
	wxString	name;
    const char* CLASS = wxPli_get_class( aTHX_ cls );
	wxStaticBitmap *	RETVAL;

	if (items < 5)
	    pos = wxDefaultPosition;
	else {
    pos = wxPli_sv_2_wxpoint( aTHX_ ST(4) )
;
	}

	if (items < 6)
	    size = wxDefaultSize;
	else {
    size = wxPli_sv_2_wxsize( aTHX_ ST(5) )
;
	}

	if (items < 7)
	    style = 0;
	else {
	    style = (long)SvIV(ST(6))
;
	}

	if (items < 8)
	    name = wxStaticBitmapNameStr;
	else {
    WXSTRING_INPUT( name, wxString, ST(7) )
;
	}
    RETVAL = new wxStaticBitmap( parent, id, *bitmap, pos, size,
         style, name );
    wxPli_create_evthandler( aTHX_ RETVAL, CLASS );
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_evthandler_2_sv( aTHX_ RETVALSV, RETVAL );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}

#if !defined(__WXUNIVERSAL__) || defined(__WXPERL_FORCE__)
#define XSubPPtmpAAEC 1


XS_EUPXS(XS_Wx__StaticBitmap_newIcon); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StaticBitmap_newIcon)
{
    dVAR; dXSARGS;
    if (items < 4 || items > 8)
       croak_xs_usage(cv,  "cls, parent, id, icon, pos = wxDefaultPosition, size = wxDefaultSize, style = 0, name = wxStaticBitmapNameStr");
    {
	SV*	cls = ST(0)
;
	wxWindow*    parent = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::Window" )
;
	wxWindowID    id = wxPli_get_wxwindowid( aTHX_ ST(2) )
;
	wxIcon*    icon = (wxIcon *) wxPli_sv_2_object( aTHX_ ST(3), "Wx::Icon" )
;
	wxPoint	pos;
	wxSize	size;
	long	style;
	wxString	name;
    const char* CLASS = wxPli_get_class( aTHX_ cls );
	wxStaticBitmap *	RETVAL;

	if (items < 5)
	    pos = wxDefaultPosition;
	else {
    pos = wxPli_sv_2_wxpoint( aTHX_ ST(4) )
;
	}

	if (items < 6)
	    size = wxDefaultSize;
	else {
    size = wxPli_sv_2_wxsize( aTHX_ ST(5) )
;
	}

	if (items < 7)
	    style = 0;
	else {
	    style = (long)SvIV(ST(6))
;
	}

	if (items < 8)
	    name = wxStaticBitmapNameStr;
	else {
    WXSTRING_INPUT( name, wxString, ST(7) )
;
	}
    RETVAL = new wxStaticBitmap( parent, id, *icon, pos, size,
         style, name );
    wxPli_create_evthandler( aTHX_ RETVAL, CLASS );
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_evthandler_2_sv( aTHX_ RETVALSV, RETVAL );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}

#endif

XS_EUPXS(XS_Wx__StaticBitmap_GetBitmap); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StaticBitmap_GetBitmap)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxStaticBitmap *    THIS = (wxStaticBitmap *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StaticBitmap" )
;
	wxBitmap *	RETVAL;
    RETVAL = new wxBitmap( THIS->GetBitmap() );
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_object_2_sv( aTHX_ RETVALSV, RETVAL );
    wxPli_thread_sv_register( aTHX_ "Wx::Bitmap", RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__StaticBitmap_SetBitmap); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StaticBitmap_SetBitmap)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, bitmap");
    {
	wxBitmap*    bitmap = (wxBitmap *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::Bitmap" )
;
	wxStaticBitmap *    THIS = (wxStaticBitmap *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StaticBitmap" )
;

	THIS->SetBitmap(*bitmap);
    }
    XSRETURN_EMPTY;
}

#if !defined(__WXUNIVERSAL__) || defined(__WXPERL_FORCE__)
#define XSubPPtmpAAED 1


XS_EUPXS(XS_Wx__StaticBitmap_GetIcon); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StaticBitmap_GetIcon)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxStaticBitmap *    THIS = (wxStaticBitmap *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StaticBitmap" )
;
	wxIcon *	RETVAL;
    RETVAL = new wxIcon( THIS->GetIcon() );
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_object_2_sv( aTHX_ RETVALSV, RETVAL );
    wxPli_thread_sv_register( aTHX_ "Wx::Icon", RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__StaticBitmap_SetIcon); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StaticBitmap_SetIcon)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, icon");
    {
	wxIcon*    icon = (wxIcon *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::Icon" )
;
	wxStaticBitmap *    THIS = (wxStaticBitmap *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StaticBitmap" )
;

	THIS->SetIcon(*icon);
    }
    XSRETURN_EMPTY;
}

#endif

/* INCLUDE: Returning to 'XS/SpinCtrl.xs' from 'XS/StaticBitmap.xs' */

#include <wx/spinctrl.h>

XS_EUPXS(XS_Wx__SpinCtrl_new); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__SpinCtrl_new)
{
    dVAR; dXSARGS;
    PERL_UNUSED_VAR(cv); /* -W */
    PERL_UNUSED_VAR(items); /* -W */
    PERL_UNUSED_VAR(ax); /* -Wall */
    SP -= items;
    {
    BEGIN_OVERLOAD()
        MATCH_VOIDM_REDISP( newDefault )
        MATCH_ANY_REDISP( newFull )
    END_OVERLOAD( "Wx::SpinCtrl::new" )
	PUTBACK;
	return;
    }
}


XS_EUPXS(XS_Wx__SpinCtrl_newDefault); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__SpinCtrl_newDefault)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "CLASS");
    {
	PlClassName    CLASS = wxPli_get_class( aTHX_ ST(0) )
;
	wxSpinCtrl *	RETVAL;
    RETVAL = new wxSpinCtrl();
    wxPli_create_evthandler( aTHX_ RETVAL, CLASS );
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_evthandler_2_sv( aTHX_ RETVALSV, RETVAL );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__SpinCtrl_newFull); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__SpinCtrl_newFull)
{
    dVAR; dXSARGS;
    if (items < 2 || items > 11)
       croak_xs_usage(cv,  "CLASS, parent, id = wxID_ANY, value = wxEmptyString, pos = wxDefaultPosition, size = wxDefaultSize, style = wxSP_ARROW_KEYS, min = 0, max = 100, initial = 0, name = wxT(\"spinCtrl\")");
    {
	PlClassName    CLASS = wxPli_get_class( aTHX_ ST(0) )
;
	wxWindow*    parent = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::Window" )
;
	wxWindowID	id;
	wxString	value;
	wxPoint	pos;
	wxSize	size;
	long	style;
	int	min;
	int	max;
	int	initial;
	wxString	name;
	wxSpinCtrl *	RETVAL;

	if (items < 3)
	    id = wxID_ANY;
	else {
    id = wxPli_get_wxwindowid( aTHX_ ST(2) )
;
	}

	if (items < 4)
	    value = wxEmptyString;
	else {
    WXSTRING_INPUT( value, wxString, ST(3) )
;
	}

	if (items < 5)
	    pos = wxDefaultPosition;
	else {
    pos = wxPli_sv_2_wxpoint( aTHX_ ST(4) )
;
	}

	if (items < 6)
	    size = wxDefaultSize;
	else {
    size = wxPli_sv_2_wxsize( aTHX_ ST(5) )
;
	}

	if (items < 7)
	    style = wxSP_ARROW_KEYS;
	else {
	    style = (long)SvIV(ST(6))
;
	}

	if (items < 8)
	    min = 0;
	else {
	    min = (int)SvIV(ST(7))
;
	}

	if (items < 9)
	    max = 100;
	else {
	    max = (int)SvIV(ST(8))
;
	}

	if (items < 10)
	    initial = 0;
	else {
	    initial = (int)SvIV(ST(9))
;
	}

	if (items < 11)
	    name = wxT("spinCtrl");
	else {
    WXSTRING_INPUT( name, wxString, ST(10) )
;
	}
    RETVAL = new wxSpinCtrl( parent, id, value, pos, size,
        style, min, max, initial, name );
    wxPli_create_evthandler( aTHX_ RETVAL, CLASS );
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_evthandler_2_sv( aTHX_ RETVALSV, RETVAL );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__SpinCtrl_Create); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__SpinCtrl_Create)
{
    dVAR; dXSARGS;
    if (items < 2 || items > 11)
       croak_xs_usage(cv,  "THIS, parent, id = wxID_ANY, value = wxEmptyString, pos = wxDefaultPosition, size = wxDefaultSize, style = wxSP_ARROW_KEYS, min = 0, max = 100, initial = 0, name = wxT(\"spinCtrl\")");
    {
	wxWindow*    parent = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::Window" )
;
	wxWindowID	id;
	wxString	value;
	wxPoint	pos;
	wxSize	size;
	long	style;
	int	min;
	int	max;
	int	initial;
	wxString	name;
	wxSpinCtrl *    THIS = (wxSpinCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::SpinCtrl" )
;
	bool	RETVAL;

	if (items < 3)
	    id = wxID_ANY;
	else {
    id = wxPli_get_wxwindowid( aTHX_ ST(2) )
;
	}

	if (items < 4)
	    value = wxEmptyString;
	else {
    WXSTRING_INPUT( value, wxString, ST(3) )
;
	}

	if (items < 5)
	    pos = wxDefaultPosition;
	else {
    pos = wxPli_sv_2_wxpoint( aTHX_ ST(4) )
;
	}

	if (items < 6)
	    size = wxDefaultSize;
	else {
    size = wxPli_sv_2_wxsize( aTHX_ ST(5) )
;
	}

	if (items < 7)
	    style = wxSP_ARROW_KEYS;
	else {
	    style = (long)SvIV(ST(6))
;
	}

	if (items < 8)
	    min = 0;
	else {
	    min = (int)SvIV(ST(7))
;
	}

	if (items < 9)
	    max = 100;
	else {
	    max = (int)SvIV(ST(8))
;
	}

	if (items < 10)
	    initial = 0;
	else {
	    initial = (int)SvIV(ST(9))
;
	}

	if (items < 11)
	    name = wxT("spinCtrl");
	else {
    WXSTRING_INPUT( name, wxString, ST(10) )
;
	}

	RETVAL = THIS->Create(parent, id, value, pos, size, style, min, max, initial, name);
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__SpinCtrl_GetMin); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__SpinCtrl_GetMin)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxSpinCtrl *    THIS = (wxSpinCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::SpinCtrl" )
;
	int	RETVAL;
	dXSTARG;

	RETVAL = THIS->GetMin();
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__SpinCtrl_GetMax); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__SpinCtrl_GetMax)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxSpinCtrl *    THIS = (wxSpinCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::SpinCtrl" )
;
	int	RETVAL;
	dXSTARG;

	RETVAL = THIS->GetMax();
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__SpinCtrl_GetValue); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__SpinCtrl_GetValue)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxSpinCtrl *    THIS = (wxSpinCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::SpinCtrl" )
;
	int	RETVAL;
	dXSTARG;

	RETVAL = THIS->GetValue();
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__SpinCtrl_SetRange); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__SpinCtrl_SetRange)
{
    dVAR; dXSARGS;
    if (items != 3)
       croak_xs_usage(cv,  "THIS, min, max");
    {
	int	min = (int)SvIV(ST(1))
;
	int	max = (int)SvIV(ST(2))
;
	wxSpinCtrl *    THIS = (wxSpinCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::SpinCtrl" )
;

	THIS->SetRange(min, max);
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__SpinCtrl_SetValue); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__SpinCtrl_SetValue)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, text");
    {
	wxString	text;
	wxSpinCtrl *    THIS = (wxSpinCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::SpinCtrl" )
;

    WXSTRING_INPUT( text, wxString, ST(1) )
;

	THIS->SetValue(text);
    }
    XSRETURN_EMPTY;
}

#if !defined(__WXGTK__)
#define XSubPPtmpAAEE 1


XS_EUPXS(XS_Wx__SpinCtrl_SetSelection); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__SpinCtrl_SetSelection)
{
    dVAR; dXSARGS;
    if (items != 3)
       croak_xs_usage(cv,  "THIS, from, to");
    {
	long	from = (long)SvIV(ST(1))
;
	long	to = (long)SvIV(ST(2))
;
	wxSpinCtrl *    THIS = (wxSpinCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::SpinCtrl" )
;

	THIS->SetSelection(from, to);
    }
    XSRETURN_EMPTY;
}

#endif

/* INCLUDE: Returning to 'XS/SpinButton.xs' from 'XS/SpinCtrl.xs' */

#include <wx/spinctrl.h>
#include <wx/spinbutt.h>

XS_EUPXS(XS_Wx__SpinEvent_new); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__SpinEvent_new)
{
    dVAR; dXSARGS;
    if (items < 1 || items > 3)
       croak_xs_usage(cv,  "CLASS, commandType = wxEVT_NULL, id = 0");
    {
	wxEventType	commandType;
	int	id;
	char *	CLASS = (char *)SvPV_nolen(ST(0))
;
	wxSpinEvent *	RETVAL;

	if (items < 2)
	    commandType = wxEVT_NULL;
	else {
	    commandType = (wxEventType)SvIV(ST(1))
;
	}

	if (items < 3)
	    id = 0;
	else {
	    id = (int)SvIV(ST(2))
;
	}

	RETVAL = new wxSpinEvent(commandType, id);
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_object_2_sv( aTHX_ RETVALSV, RETVAL );
    wxPli_thread_sv_register( aTHX_ "Wx::SpinEvent", RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__SpinEvent_GetPosition); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__SpinEvent_GetPosition)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxSpinEvent *    THIS = (wxSpinEvent *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::SpinEvent" )
;
	int	RETVAL;
	dXSTARG;

	RETVAL = THIS->GetPosition();
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__SpinEvent_SetPosition); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__SpinEvent_SetPosition)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, pos");
    {
	int	pos = (int)SvIV(ST(1))
;
	wxSpinEvent *    THIS = (wxSpinEvent *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::SpinEvent" )
;

	THIS->SetPosition(pos);
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__SpinButton_new); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__SpinButton_new)
{
    dVAR; dXSARGS;
    PERL_UNUSED_VAR(cv); /* -W */
    PERL_UNUSED_VAR(items); /* -W */
    PERL_UNUSED_VAR(ax); /* -Wall */
    SP -= items;
    {
    BEGIN_OVERLOAD()
        MATCH_VOIDM_REDISP( newDefault )
        MATCH_ANY_REDISP( newFull )
    END_OVERLOAD( "Wx::SpinButton::new" )
	PUTBACK;
	return;
    }
}


XS_EUPXS(XS_Wx__SpinButton_newDefault); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__SpinButton_newDefault)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "CLASS");
    {
	PlClassName    CLASS = wxPli_get_class( aTHX_ ST(0) )
;
	wxSpinButton *	RETVAL;
    RETVAL = new wxSpinButton();
    wxPli_create_evthandler( aTHX_ RETVAL, CLASS );
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_evthandler_2_sv( aTHX_ RETVALSV, RETVAL );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__SpinButton_newFull); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__SpinButton_newFull)
{
    dVAR; dXSARGS;
    if (items < 2 || items > 7)
       croak_xs_usage(cv,  "CLASS, parent, id = wxID_ANY, pos = wxDefaultPosition, size = wxDefaultSize, style = wxSP_HORIZONTAL, name = wxSPIN_BUTTON_NAME");
    {
	PlClassName    CLASS = wxPli_get_class( aTHX_ ST(0) )
;
	wxWindow*    parent = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::Window" )
;
	wxWindowID	id;
	wxPoint	pos;
	wxSize	size;
	long	style;
	wxString	name;
	wxSpinButton *	RETVAL;

	if (items < 3)
	    id = wxID_ANY;
	else {
    id = wxPli_get_wxwindowid( aTHX_ ST(2) )
;
	}

	if (items < 4)
	    pos = wxDefaultPosition;
	else {
    pos = wxPli_sv_2_wxpoint( aTHX_ ST(3) )
;
	}

	if (items < 5)
	    size = wxDefaultSize;
	else {
    size = wxPli_sv_2_wxsize( aTHX_ ST(4) )
;
	}

	if (items < 6)
	    style = wxSP_HORIZONTAL;
	else {
	    style = (long)SvIV(ST(5))
;
	}

	if (items < 7)
	    name = wxSPIN_BUTTON_NAME;
	else {
    WXSTRING_INPUT( name, wxString, ST(6) )
;
	}
    RETVAL = new wxSpinButton( parent, id, pos, size, style, name );
    wxPli_create_evthandler( aTHX_ RETVAL, CLASS );
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_evthandler_2_sv( aTHX_ RETVALSV, RETVAL );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__SpinButton_Create); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__SpinButton_Create)
{
    dVAR; dXSARGS;
    if (items < 2 || items > 7)
       croak_xs_usage(cv,  "THIS, parent, id = wxID_ANY, pos = wxDefaultPosition, size = wxDefaultSize, style = wxSP_HORIZONTAL, name = wxSPIN_BUTTON_NAME");
    {
	wxWindow*    parent = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::Window" )
;
	wxWindowID	id;
	wxPoint	pos;
	wxSize	size;
	long	style;
	wxString	name;
	wxSpinButton *    THIS = (wxSpinButton *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::SpinButton" )
;
	bool	RETVAL;

	if (items < 3)
	    id = wxID_ANY;
	else {
    id = wxPli_get_wxwindowid( aTHX_ ST(2) )
;
	}

	if (items < 4)
	    pos = wxDefaultPosition;
	else {
    pos = wxPli_sv_2_wxpoint( aTHX_ ST(3) )
;
	}

	if (items < 5)
	    size = wxDefaultSize;
	else {
    size = wxPli_sv_2_wxsize( aTHX_ ST(4) )
;
	}

	if (items < 6)
	    style = wxSP_HORIZONTAL;
	else {
	    style = (long)SvIV(ST(5))
;
	}

	if (items < 7)
	    name = wxSPIN_BUTTON_NAME;
	else {
    WXSTRING_INPUT( name, wxString, ST(6) )
;
	}

	RETVAL = THIS->Create(parent, id, pos, size, style, name);
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__SpinButton_GetMax); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__SpinButton_GetMax)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxSpinButton *    THIS = (wxSpinButton *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::SpinButton" )
;
	int	RETVAL;
	dXSTARG;

	RETVAL = THIS->GetMax();
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__SpinButton_GetMin); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__SpinButton_GetMin)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxSpinButton *    THIS = (wxSpinButton *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::SpinButton" )
;
	int	RETVAL;
	dXSTARG;

	RETVAL = THIS->GetMin();
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__SpinButton_GetValue); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__SpinButton_GetValue)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxSpinButton *    THIS = (wxSpinButton *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::SpinButton" )
;
	int	RETVAL;
	dXSTARG;

	RETVAL = THIS->GetValue();
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__SpinButton_SetRange); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__SpinButton_SetRange)
{
    dVAR; dXSARGS;
    if (items != 3)
       croak_xs_usage(cv,  "THIS, min, max");
    {
	int	min = (int)SvIV(ST(1))
;
	int	max = (int)SvIV(ST(2))
;
	wxSpinButton *    THIS = (wxSpinButton *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::SpinButton" )
;

	THIS->SetRange(min, max);
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__SpinButton_SetValue); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__SpinButton_SetValue)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, value");
    {
	int	value = (int)SvIV(ST(1))
;
	wxSpinButton *    THIS = (wxSpinButton *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::SpinButton" )
;

	THIS->SetValue(value);
    }
    XSRETURN_EMPTY;
}


/* INCLUDE: Returning to 'XS/Slider.xs' from 'XS/SpinButton.xs' */

#include <wx/slider.h>

XS_EUPXS(XS_Wx__Slider_new); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Slider_new)
{
    dVAR; dXSARGS;
    PERL_UNUSED_VAR(cv); /* -W */
    PERL_UNUSED_VAR(items); /* -W */
    PERL_UNUSED_VAR(ax); /* -Wall */
    SP -= items;
    {
    BEGIN_OVERLOAD()
        MATCH_VOIDM_REDISP( newDefault )
        MATCH_ANY_REDISP( newFull )
    END_OVERLOAD( "Wx::Slider::new" )
	PUTBACK;
	return;
    }
}


XS_EUPXS(XS_Wx__Slider_newDefault); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Slider_newDefault)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "CLASS");
    {
	PlClassName    CLASS = wxPli_get_class( aTHX_ ST(0) )
;
	wxSlider *	RETVAL;
    RETVAL = new wxSlider();
    wxPli_create_evthandler( aTHX_ RETVAL, CLASS );
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_evthandler_2_sv( aTHX_ RETVALSV, RETVAL );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__Slider_newFull); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Slider_newFull)
{
    dVAR; dXSARGS;
    if (items < 6 || items > 11)
       croak_xs_usage(cv,  "CLASS, parent, id, value, minValue, maxValue, pos = wxDefaultPosition, size = wxDefaultSize, style = wxSL_HORIZONTAL, validator = (wxValidator*)&wxDefaultValidator, name = wxSliderNameStr");
    {
	PlClassName    CLASS = wxPli_get_class( aTHX_ ST(0) )
;
	wxWindow*    parent = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::Window" )
;
	wxWindowID    id = wxPli_get_wxwindowid( aTHX_ ST(2) )
;
	int	value = (int)SvIV(ST(3))
;
	int	minValue = (int)SvIV(ST(4))
;
	int	maxValue = (int)SvIV(ST(5))
;
	wxPoint	pos;
	wxSize	size;
	long	style;
	wxValidator*	validator;
	wxString	name;
	wxSlider *	RETVAL;

	if (items < 7)
	    pos = wxDefaultPosition;
	else {
    pos = wxPli_sv_2_wxpoint( aTHX_ ST(6) )
;
	}

	if (items < 8)
	    size = wxDefaultSize;
	else {
    size = wxPli_sv_2_wxsize( aTHX_ ST(7) )
;
	}

	if (items < 9)
	    style = wxSL_HORIZONTAL;
	else {
	    style = (long)SvIV(ST(8))
;
	}

	if (items < 10)
	    validator = (wxValidator*)&wxDefaultValidator;
	else {
    validator = (wxValidator *) wxPli_sv_2_object( aTHX_ ST(9), "Wx::Validator" )
;
	}

	if (items < 11)
	    name = wxSliderNameStr;
	else {
    WXSTRING_INPUT( name, wxString, ST(10) )
;
	}
    RETVAL = new wxSlider( parent, id, value, minValue, maxValue,
        pos, size, style, *validator, name );
    wxPli_create_evthandler( aTHX_ RETVAL, CLASS );
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_evthandler_2_sv( aTHX_ RETVALSV, RETVAL );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__Slider_Create); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Slider_Create)
{
    dVAR; dXSARGS;
    if (items < 6 || items > 11)
       croak_xs_usage(cv,  "THIS, parent, id, value, minValue, maxValue, pos = wxDefaultPosition, size = wxDefaultSize, style = wxSL_HORIZONTAL, validator = (wxValidator*)&wxDefaultValidator, name = wxSliderNameStr");
    {
	wxWindow*    parent = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::Window" )
;
	wxWindowID    id = wxPli_get_wxwindowid( aTHX_ ST(2) )
;
	int	value = (int)SvIV(ST(3))
;
	int	minValue = (int)SvIV(ST(4))
;
	int	maxValue = (int)SvIV(ST(5))
;
	wxPoint	pos;
	wxSize	size;
	long	style;
	wxValidator*	validator;
	wxString	name;
	wxSlider *    THIS = (wxSlider *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Slider" )
;
	bool	RETVAL;

	if (items < 7)
	    pos = wxDefaultPosition;
	else {
    pos = wxPli_sv_2_wxpoint( aTHX_ ST(6) )
;
	}

	if (items < 8)
	    size = wxDefaultSize;
	else {
    size = wxPli_sv_2_wxsize( aTHX_ ST(7) )
;
	}

	if (items < 9)
	    style = wxSL_HORIZONTAL;
	else {
	    style = (long)SvIV(ST(8))
;
	}

	if (items < 10)
	    validator = (wxValidator*)&wxDefaultValidator;
	else {
    validator = (wxValidator *) wxPli_sv_2_object( aTHX_ ST(9), "Wx::Validator" )
;
	}

	if (items < 11)
	    name = wxSliderNameStr;
	else {
    WXSTRING_INPUT( name, wxString, ST(10) )
;
	}

	RETVAL = THIS->Create(parent, id, value, minValue, maxValue, pos, size, style, *validator, name);
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}

#if defined( __WXMSW__ ) || defined( __WXPERL_FORCE__ )
#define XSubPPtmpAAEF 1


XS_EUPXS(XS_Wx__Slider_ClearSel); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Slider_ClearSel)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxSlider *    THIS = (wxSlider *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Slider" )
;

	THIS->ClearSel();
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__Slider_ClearTicks); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Slider_ClearTicks)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxSlider *    THIS = (wxSlider *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Slider" )
;

	THIS->ClearTicks();
    }
    XSRETURN_EMPTY;
}

#endif

XS_EUPXS(XS_Wx__Slider_GetLineSize); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Slider_GetLineSize)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxSlider *    THIS = (wxSlider *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Slider" )
;
	int	RETVAL;
	dXSTARG;

	RETVAL = THIS->GetLineSize();
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__Slider_GetMax); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Slider_GetMax)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxSlider *    THIS = (wxSlider *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Slider" )
;
	int	RETVAL;
	dXSTARG;

	RETVAL = THIS->GetMax();
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__Slider_GetMin); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Slider_GetMin)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxSlider *    THIS = (wxSlider *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Slider" )
;
	int	RETVAL;
	dXSTARG;

	RETVAL = THIS->GetMin();
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__Slider_GetPageSize); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Slider_GetPageSize)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxSlider *    THIS = (wxSlider *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Slider" )
;
	int	RETVAL;
	dXSTARG;

	RETVAL = THIS->GetPageSize();
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}

#if defined( __WXMSW__ ) || defined( __WXPERL_FORCE__ )
#define XSubPPtmpAAEG 1


XS_EUPXS(XS_Wx__Slider_GetSelEnd); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Slider_GetSelEnd)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxSlider *    THIS = (wxSlider *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Slider" )
;
	int	RETVAL;
	dXSTARG;

	RETVAL = THIS->GetSelEnd();
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__Slider_GetSelStart); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Slider_GetSelStart)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxSlider *    THIS = (wxSlider *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Slider" )
;
	int	RETVAL;
	dXSTARG;

	RETVAL = THIS->GetSelStart();
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__Slider_GetThumbLength); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Slider_GetThumbLength)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxSlider *    THIS = (wxSlider *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Slider" )
;
	int	RETVAL;
	dXSTARG;

	RETVAL = THIS->GetThumbLength();
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__Slider_GetTickFreq); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Slider_GetTickFreq)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxSlider *    THIS = (wxSlider *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Slider" )
;
	int	RETVAL;
	dXSTARG;

	RETVAL = THIS->GetTickFreq();
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}

#endif

XS_EUPXS(XS_Wx__Slider_GetValue); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Slider_GetValue)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxSlider *    THIS = (wxSlider *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Slider" )
;
	int	RETVAL;
	dXSTARG;

	RETVAL = THIS->GetValue();
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__Slider_SetRange); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Slider_SetRange)
{
    dVAR; dXSARGS;
    if (items != 3)
       croak_xs_usage(cv,  "THIS, minValue, maxValue");
    {
	int	minValue = (int)SvIV(ST(1))
;
	int	maxValue = (int)SvIV(ST(2))
;
	wxSlider *    THIS = (wxSlider *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Slider" )
;

	THIS->SetRange(minValue, maxValue);
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__Slider_SetTickFreq); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Slider_SetTickFreq)
{
    dVAR; dXSARGS;
    if (items != 3)
       croak_xs_usage(cv,  "THIS, n, pos");
    {
	int	n = (int)SvIV(ST(1))
;
	int	pos = (int)SvIV(ST(2))
;
	wxSlider *    THIS = (wxSlider *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Slider" )
;

	THIS->SetTickFreq(n, pos);
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__Slider_SetLineSize); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Slider_SetLineSize)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, lineSize");
    {
	int	lineSize = (int)SvIV(ST(1))
;
	wxSlider *    THIS = (wxSlider *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Slider" )
;

	THIS->SetLineSize(lineSize);
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__Slider_SetPageSize); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Slider_SetPageSize)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, pageSize");
    {
	int	pageSize = (int)SvIV(ST(1))
;
	wxSlider *    THIS = (wxSlider *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Slider" )
;

	THIS->SetPageSize(pageSize);
    }
    XSRETURN_EMPTY;
}

#if defined( __WXPERL_FORCE__ )
#define XSubPPtmpAAEH 1


XS_EUPXS(XS_Wx__Slider_StartSelection); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Slider_StartSelection)
{
    dVAR; dXSARGS;
    if (items != 3)
       croak_xs_usage(cv,  "THIS, startPos, endPos");
    {
	int	startPos = (int)SvIV(ST(1))
;
	int	endPos = (int)SvIV(ST(2))
;
	wxSlider *    THIS = (wxSlider *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Slider" )
;

	THIS->StartSelection(startPos, endPos);
    }
    XSRETURN_EMPTY;
}

#endif
#if defined( __WXMSW__ ) || defined( __WXPERL_FORCE__ )
#define XSubPPtmpAAEI 1


XS_EUPXS(XS_Wx__Slider_SetThumbLength); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Slider_SetThumbLength)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, len");
    {
	int	len = (int)SvIV(ST(1))
;
	wxSlider *    THIS = (wxSlider *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Slider" )
;

	THIS->SetThumbLength(len);
    }
    XSRETURN_EMPTY;
}

#endif

XS_EUPXS(XS_Wx__Slider_SetValue); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Slider_SetValue)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, value");
    {
	int	value = (int)SvIV(ST(1))
;
	wxSlider *    THIS = (wxSlider *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Slider" )
;

	THIS->SetValue(value);
    }
    XSRETURN_EMPTY;
}


/* INCLUDE: Returning to 'XS/ScrollBar.xs' from 'XS/Slider.xs' */

#include <wx/scrolbar.h>

XS_EUPXS(XS_Wx__ScrollBar_new); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ScrollBar_new)
{
    dVAR; dXSARGS;
    PERL_UNUSED_VAR(cv); /* -W */
    PERL_UNUSED_VAR(items); /* -W */
    PERL_UNUSED_VAR(ax); /* -Wall */
    SP -= items;
    {
    BEGIN_OVERLOAD()
        MATCH_VOIDM_REDISP( newDefault )
        MATCH_ANY_REDISP( newFull )
    END_OVERLOAD( "Wx::ScrollBar::new" )
	PUTBACK;
	return;
    }
}


XS_EUPXS(XS_Wx__ScrollBar_newDefault); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ScrollBar_newDefault)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "CLASS");
    {
	PlClassName    CLASS = wxPli_get_class( aTHX_ ST(0) )
;
	wxScrollBar *	RETVAL;
    RETVAL = new wxScrollBar();
    wxPli_create_evthandler( aTHX_ RETVAL, CLASS );
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_evthandler_2_sv( aTHX_ RETVALSV, RETVAL );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__ScrollBar_newFull); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ScrollBar_newFull)
{
    dVAR; dXSARGS;
    if (items < 2 || items > 8)
       croak_xs_usage(cv,  "CLASS, parent, id = wxID_ANY, pos = wxDefaultPosition, size = wxDefaultSize, style = wxSB_HORIZONTAL, validator = (wxValidator*)&wxDefaultValidator, name = wxScrollBarNameStr");
    {
	PlClassName    CLASS = wxPli_get_class( aTHX_ ST(0) )
;
	wxWindow*    parent = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::Window" )
;
	wxWindowID	id;
	wxPoint	pos;
	wxSize	size;
	long	style;
	wxValidator*	validator;
	wxString	name;
	wxScrollBar *	RETVAL;

	if (items < 3)
	    id = wxID_ANY;
	else {
    id = wxPli_get_wxwindowid( aTHX_ ST(2) )
;
	}

	if (items < 4)
	    pos = wxDefaultPosition;
	else {
    pos = wxPli_sv_2_wxpoint( aTHX_ ST(3) )
;
	}

	if (items < 5)
	    size = wxDefaultSize;
	else {
    size = wxPli_sv_2_wxsize( aTHX_ ST(4) )
;
	}

	if (items < 6)
	    style = wxSB_HORIZONTAL;
	else {
	    style = (long)SvIV(ST(5))
;
	}

	if (items < 7)
	    validator = (wxValidator*)&wxDefaultValidator;
	else {
    validator = (wxValidator *) wxPli_sv_2_object( aTHX_ ST(6), "Wx::Validator" )
;
	}

	if (items < 8)
	    name = wxScrollBarNameStr;
	else {
    WXSTRING_INPUT( name, wxString, ST(7) )
;
	}
    RETVAL = new wxScrollBar( parent, id, pos, size, style, 
        *validator, name );
    wxPli_create_evthandler( aTHX_ RETVAL, CLASS );
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_evthandler_2_sv( aTHX_ RETVALSV, RETVAL );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__ScrollBar_Create); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ScrollBar_Create)
{
    dVAR; dXSARGS;
    if (items < 2 || items > 8)
       croak_xs_usage(cv,  "THIS, parent, id = wxID_ANY, pos = wxDefaultPosition, size = wxDefaultSize, style = wxSB_HORIZONTAL, validator = (wxValidator*)&wxDefaultValidator, name = wxScrollBarNameStr");
    {
	wxWindow*    parent = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::Window" )
;
	wxWindowID	id;
	wxPoint	pos;
	wxSize	size;
	long	style;
	wxValidator*	validator;
	wxString	name;
	wxScrollBar *    THIS = (wxScrollBar *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::ScrollBar" )
;
	bool	RETVAL;

	if (items < 3)
	    id = wxID_ANY;
	else {
    id = wxPli_get_wxwindowid( aTHX_ ST(2) )
;
	}

	if (items < 4)
	    pos = wxDefaultPosition;
	else {
    pos = wxPli_sv_2_wxpoint( aTHX_ ST(3) )
;
	}

	if (items < 5)
	    size = wxDefaultSize;
	else {
    size = wxPli_sv_2_wxsize( aTHX_ ST(4) )
;
	}

	if (items < 6)
	    style = wxSB_HORIZONTAL;
	else {
	    style = (long)SvIV(ST(5))
;
	}

	if (items < 7)
	    validator = (wxValidator*)&wxDefaultValidator;
	else {
    validator = (wxValidator *) wxPli_sv_2_object( aTHX_ ST(6), "Wx::Validator" )
;
	}

	if (items < 8)
	    name = wxScrollBarNameStr;
	else {
    WXSTRING_INPUT( name, wxString, ST(7) )
;
	}

	RETVAL = THIS->Create(parent, id, pos, size, style, *validator, name);
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__ScrollBar_GetRange); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ScrollBar_GetRange)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxScrollBar *    THIS = (wxScrollBar *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::ScrollBar" )
;
	int	RETVAL;
	dXSTARG;

	RETVAL = THIS->GetRange();
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__ScrollBar_GetPageSize); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ScrollBar_GetPageSize)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxScrollBar *    THIS = (wxScrollBar *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::ScrollBar" )
;
	int	RETVAL;
	dXSTARG;

	RETVAL = THIS->GetPageSize();
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__ScrollBar_GetThumbPosition); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ScrollBar_GetThumbPosition)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxScrollBar *    THIS = (wxScrollBar *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::ScrollBar" )
;
	int	RETVAL;
	dXSTARG;

	RETVAL = THIS->GetThumbPosition();
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__ScrollBar_GetThumbSize); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ScrollBar_GetThumbSize)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxScrollBar *    THIS = (wxScrollBar *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::ScrollBar" )
;
	int	RETVAL;
	dXSTARG;

	RETVAL = THIS->GetThumbSize();
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__ScrollBar_SetThumbPosition); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ScrollBar_SetThumbPosition)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, viewStart");
    {
	int	viewStart = (int)SvIV(ST(1))
;
	wxScrollBar *    THIS = (wxScrollBar *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::ScrollBar" )
;

	THIS->SetThumbPosition(viewStart);
    }
    XSRETURN_EMPTY;
}

#if !defined(__WXMAC__) && !defined(__WXMOTIF__)
#define XSubPPtmpAAEJ 1


XS_EUPXS(XS_Wx__ScrollBar_SetPageSize); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ScrollBar_SetPageSize)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, size");
    {
	int	size = (int)SvIV(ST(1))
;
	wxScrollBar *    THIS = (wxScrollBar *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::ScrollBar" )
;

	THIS->SetPageSize(size);
    }
    XSRETURN_EMPTY;
}

#endif

XS_EUPXS(XS_Wx__ScrollBar_SetScrollbar); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ScrollBar_SetScrollbar)
{
    dVAR; dXSARGS;
    if (items < 5 || items > 6)
       croak_xs_usage(cv,  "THIS, position, thumbSize, range, pageSize, refresh = true");
    {
	int	position = (int)SvIV(ST(1))
;
	int	thumbSize = (int)SvIV(ST(2))
;
	int	range = (int)SvIV(ST(3))
;
	int	pageSize = (int)SvIV(ST(4))
;
	bool	refresh;
	wxScrollBar *    THIS = (wxScrollBar *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::ScrollBar" )
;

	if (items < 6)
	    refresh = true;
	else {
	    refresh = (bool)SvTRUE(ST(5))
;
	}

	THIS->SetScrollbar(position, thumbSize, range, pageSize, refresh);
    }
    XSRETURN_EMPTY;
}


/* INCLUDE: Returning to 'XS/RadioButton.xs' from 'XS/ScrollBar.xs' */

#include <wx/radiobut.h>

XS_EUPXS(XS_Wx__RadioButton_new); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RadioButton_new)
{
    dVAR; dXSARGS;
    PERL_UNUSED_VAR(cv); /* -W */
    PERL_UNUSED_VAR(items); /* -W */
    PERL_UNUSED_VAR(ax); /* -Wall */
    SP -= items;
    {
    BEGIN_OVERLOAD()
        MATCH_VOIDM_REDISP( newDefault )
        MATCH_ANY_REDISP( newFull )
    END_OVERLOAD( "Wx::RadioButton::new" )
	PUTBACK;
	return;
    }
}


XS_EUPXS(XS_Wx__RadioButton_newDefault); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RadioButton_newDefault)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "CLASS");
    {
	PlClassName    CLASS = wxPli_get_class( aTHX_ ST(0) )
;
	wxRadioButton *	RETVAL;
    RETVAL = new wxRadioButton();
    wxPli_create_evthandler( aTHX_ RETVAL, CLASS );
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_evthandler_2_sv( aTHX_ RETVALSV, RETVAL );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__RadioButton_newFull); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RadioButton_newFull)
{
    dVAR; dXSARGS;
    if (items < 4 || items > 9)
       croak_xs_usage(cv,  "CLASS, parent, id, label, pos = wxDefaultPosition, size = wxDefaultSize, style = 0, validator = (wxValidator*)&wxDefaultValidator, name = wxRadioButtonNameStr");
    {
	PlClassName    CLASS = wxPli_get_class( aTHX_ ST(0) )
;
	wxWindow*    parent = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::Window" )
;
	wxWindowID    id = wxPli_get_wxwindowid( aTHX_ ST(2) )
;
	wxString	label;
	wxPoint	pos;
	wxSize	size;
	long	style;
	wxValidator*	validator;
	wxString	name;
	wxRadioButton *	RETVAL;

    WXSTRING_INPUT( label, wxString, ST(3) )
;

	if (items < 5)
	    pos = wxDefaultPosition;
	else {
    pos = wxPli_sv_2_wxpoint( aTHX_ ST(4) )
;
	}

	if (items < 6)
	    size = wxDefaultSize;
	else {
    size = wxPli_sv_2_wxsize( aTHX_ ST(5) )
;
	}

	if (items < 7)
	    style = 0;
	else {
	    style = (long)SvIV(ST(6))
;
	}

	if (items < 8)
	    validator = (wxValidator*)&wxDefaultValidator;
	else {
    validator = (wxValidator *) wxPli_sv_2_object( aTHX_ ST(7), "Wx::Validator" )
;
	}

	if (items < 9)
	    name = wxRadioButtonNameStr;
	else {
    WXSTRING_INPUT( name, wxString, ST(8) )
;
	}
    RETVAL = new wxRadioButton( parent, id, label, pos, size, 
        style, *validator, name );
    wxPli_create_evthandler( aTHX_ RETVAL, CLASS );
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_evthandler_2_sv( aTHX_ RETVALSV, RETVAL );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__RadioButton_Create); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RadioButton_Create)
{
    dVAR; dXSARGS;
    if (items < 4 || items > 9)
       croak_xs_usage(cv,  "THIS, parent, id, label, pos = wxDefaultPosition, size = wxDefaultSize, style = 0, validator = (wxValidator*)&wxDefaultValidator, name = wxRadioButtonNameStr");
    {
	wxWindow*    parent = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::Window" )
;
	wxWindowID    id = wxPli_get_wxwindowid( aTHX_ ST(2) )
;
	wxString	label;
	wxPoint	pos;
	wxSize	size;
	long	style;
	wxValidator*	validator;
	wxString	name;
	wxRadioButton *    THIS = (wxRadioButton *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RadioButton" )
;
	bool	RETVAL;

    WXSTRING_INPUT( label, wxString, ST(3) )
;

	if (items < 5)
	    pos = wxDefaultPosition;
	else {
    pos = wxPli_sv_2_wxpoint( aTHX_ ST(4) )
;
	}

	if (items < 6)
	    size = wxDefaultSize;
	else {
    size = wxPli_sv_2_wxsize( aTHX_ ST(5) )
;
	}

	if (items < 7)
	    style = 0;
	else {
	    style = (long)SvIV(ST(6))
;
	}

	if (items < 8)
	    validator = (wxValidator*)&wxDefaultValidator;
	else {
    validator = (wxValidator *) wxPli_sv_2_object( aTHX_ ST(7), "Wx::Validator" )
;
	}

	if (items < 9)
	    name = wxRadioButtonNameStr;
	else {
    WXSTRING_INPUT( name, wxString, ST(8) )
;
	}

	RETVAL = THIS->Create(parent, id, label, pos, size, style, *validator, name);
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__RadioButton_GetValue); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RadioButton_GetValue)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxRadioButton *    THIS = (wxRadioButton *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RadioButton" )
;
	bool	RETVAL;

	RETVAL = THIS->GetValue();
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__RadioButton_SetValue); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RadioButton_SetValue)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, value");
    {
	bool	value = (bool)SvTRUE(ST(1))
;
	wxRadioButton *    THIS = (wxRadioButton *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RadioButton" )
;

	THIS->SetValue(value);
    }
    XSRETURN_EMPTY;
}


/* INCLUDE: Returning to 'XS/RadioBox.xs' from 'XS/RadioButton.xs' */

#include <wx/radiobox.h>
#include <wx/tooltip.h>

XS_EUPXS(XS_Wx__RadioBox_new); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RadioBox_new)
{
    dVAR; dXSARGS;
    PERL_UNUSED_VAR(cv); /* -W */
    PERL_UNUSED_VAR(items); /* -W */
    PERL_UNUSED_VAR(ax); /* -Wall */
    SP -= items;
    {
    BEGIN_OVERLOAD()
        MATCH_VOIDM_REDISP( newDefault )
        MATCH_ANY_REDISP( newFull )
    END_OVERLOAD( "Wx::RadioBox::new" )
	PUTBACK;
	return;
    }
}


XS_EUPXS(XS_Wx__RadioBox_newDefault); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RadioBox_newDefault)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "CLASS");
    {
	PlClassName    CLASS = wxPli_get_class( aTHX_ ST(0) )
;
	wxRadioBox *	RETVAL;
    RETVAL = new wxRadioBox();
    wxPli_create_evthandler( aTHX_ RETVAL, CLASS );
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_evthandler_2_sv( aTHX_ RETVALSV, RETVAL );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__RadioBox_newFull); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RadioBox_newFull)
{
    dVAR; dXSARGS;
    if (items < 4 || items > 11)
       croak_xs_usage(cv,  "CLASS, parent, id, label, point = wxDefaultPosition, size = wxDefaultSize, choices = 0, majorDimension = 0, style = wxRA_SPECIFY_COLS, validator = (wxValidator*)&wxDefaultValidator, name = wxRadioBoxNameStr");
    {
	PlClassName    CLASS = wxPli_get_class( aTHX_ ST(0) )
;
	wxWindow*    parent = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::Window" )
;
	wxWindowID    id = wxPli_get_wxwindowid( aTHX_ ST(2) )
;
	wxString	label;
	wxPoint	point;
	wxSize	size;
	SV*	choices;
	int	majorDimension;
	long	style;
	wxValidator*	validator;
	wxString	name;
    int n;
    wxString* chs;
	wxRadioBox *	RETVAL;

    WXSTRING_INPUT( label, wxString, ST(3) )
;

	if (items < 5)
	    point = wxDefaultPosition;
	else {
    point = wxPli_sv_2_wxpoint( aTHX_ ST(4) )
;
	}

	if (items < 6)
	    size = wxDefaultSize;
	else {
    size = wxPli_sv_2_wxsize( aTHX_ ST(5) )
;
	}

	if (items < 7)
	    choices = 0;
	else {
	    choices = ST(6)
;
	}

	if (items < 8)
	    majorDimension = 0;
	else {
	    majorDimension = (int)SvIV(ST(7))
;
	}

	if (items < 9)
	    style = wxRA_SPECIFY_COLS;
	else {
	    style = (long)SvIV(ST(8))
;
	}

	if (items < 10)
	    validator = (wxValidator*)&wxDefaultValidator;
	else {
    validator = (wxValidator *) wxPli_sv_2_object( aTHX_ ST(9), "Wx::Validator" )
;
	}

	if (items < 11)
	    name = wxRadioBoxNameStr;
	else {
    WXSTRING_INPUT( name, wxString, ST(10) )
;
	}
    if( choices )
        n = wxPli_av_2_stringarray( aTHX_ choices, &chs );
    else {
        n = 0;
        chs = 0;
    }

    RETVAL = new wxRadioBox( parent, id, label, point, size,
        n, chs, majorDimension, style, *validator, name );
    wxPli_create_evthandler( aTHX_ RETVAL, CLASS );

    delete[] chs;
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_evthandler_2_sv( aTHX_ RETVALSV, RETVAL );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__RadioBox_Create); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RadioBox_Create)
{
    dVAR; dXSARGS;
    if (items < 4 || items > 11)
       croak_xs_usage(cv,  "THIS, parent, id, label, point = wxDefaultPosition, size = wxDefaultSize, choices = 0, majorDimension = 0, style = wxRA_SPECIFY_COLS, validator = (wxValidator*)&wxDefaultValidator, name = wxRadioBoxNameStr");
    {
	wxWindow*    parent = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::Window" )
;
	wxWindowID    id = wxPli_get_wxwindowid( aTHX_ ST(2) )
;
	wxString	label;
	wxPoint	point;
	wxSize	size;
	SV*	choices;
	int	majorDimension;
	long	style;
	wxValidator*	validator;
	wxString	name;
    int n;
    wxString* chs;
	wxRadioBox *    THIS = (wxRadioBox *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RadioBox" )
;
	bool	RETVAL;

    WXSTRING_INPUT( label, wxString, ST(3) )
;

	if (items < 5)
	    point = wxDefaultPosition;
	else {
    point = wxPli_sv_2_wxpoint( aTHX_ ST(4) )
;
	}

	if (items < 6)
	    size = wxDefaultSize;
	else {
    size = wxPli_sv_2_wxsize( aTHX_ ST(5) )
;
	}

	if (items < 7)
	    choices = 0;
	else {
	    choices = ST(6)
;
	}

	if (items < 8)
	    majorDimension = 0;
	else {
	    majorDimension = (int)SvIV(ST(7))
;
	}

	if (items < 9)
	    style = wxRA_SPECIFY_COLS;
	else {
	    style = (long)SvIV(ST(8))
;
	}

	if (items < 10)
	    validator = (wxValidator*)&wxDefaultValidator;
	else {
    validator = (wxValidator *) wxPli_sv_2_object( aTHX_ ST(9), "Wx::Validator" )
;
	}

	if (items < 11)
	    name = wxRadioBoxNameStr;
	else {
    WXSTRING_INPUT( name, wxString, ST(10) )
;
	}
    if( choices )
        n = wxPli_av_2_stringarray( aTHX_ choices, &chs );
    else {
        n = 0;
        chs = 0;
    }

    RETVAL = THIS->Create( parent, id, label, point, size,
        n, chs, majorDimension, style, *validator, name );

    delete[] chs;
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__RadioBox_EnableItem); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RadioBox_EnableItem)
{
    dVAR; dXSARGS;
    if (items != 3)
       croak_xs_usage(cv,  "THIS, n, enable");
    {
	int	n = (int)SvIV(ST(1))
;
	bool	enable = (bool)SvTRUE(ST(2))
;
	wxRadioBox *    THIS = (wxRadioBox *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RadioBox" )
;
    THIS->Enable( n, enable );
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__RadioBox_FindString); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RadioBox_FindString)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, string");
    {
	wxString	string;
	wxRadioBox *    THIS = (wxRadioBox *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RadioBox" )
;
	int	RETVAL;
	dXSTARG;

    WXSTRING_INPUT( string, wxString, ST(1) )
;

	RETVAL = THIS->FindString(string);
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}

#if WXPERL_W_VERSION_GE( 2, 7, 2 )
#define XSubPPtmpAAEK 1


XS_EUPXS(XS_Wx__RadioBox_GetColumnCount); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RadioBox_GetColumnCount)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxRadioBox *    THIS = (wxRadioBox *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RadioBox" )
;
	unsigned int	RETVAL;
	dXSTARG;

	RETVAL = THIS->GetColumnCount();
	XSprePUSH;
	PUSHu((UV)RETVAL );
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__RadioBox_GetRowCount); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RadioBox_GetRowCount)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxRadioBox *    THIS = (wxRadioBox *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RadioBox" )
;
	unsigned int	RETVAL;
	dXSTARG;

	RETVAL = THIS->GetRowCount();
	XSprePUSH;
	PUSHu((UV)RETVAL );
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__RadioBox_GetItemFromPoint); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RadioBox_GetItemFromPoint)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, pt");
    {
	wxPoint    pt = wxPli_sv_2_wxpoint( aTHX_ ST(1) )
;
	wxRadioBox *    THIS = (wxRadioBox *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RadioBox" )
;
	int	RETVAL;
	dXSTARG;

	RETVAL = THIS->GetItemFromPoint(pt);
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}

#endif

XS_EUPXS(XS_Wx__RadioBox_GetString); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RadioBox_GetString)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, n");
    {
	int	n = (int)SvIV(ST(1))
;
	wxRadioBox *    THIS = (wxRadioBox *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RadioBox" )
;
	wxString	RETVAL;

	RETVAL = THIS->GetString(n);
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    WXSTRING_OUTPUT( RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__RadioBox_GetItemLabel); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RadioBox_GetItemLabel)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, n");
    {
	int	n = (int)SvIV(ST(1))
;
	wxRadioBox *    THIS = (wxRadioBox *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RadioBox" )
;
	wxString	RETVAL;
    RETVAL = THIS->GetString( n );
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    WXSTRING_OUTPUT( RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__RadioBox_GetSelection); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RadioBox_GetSelection)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxRadioBox *    THIS = (wxRadioBox *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RadioBox" )
;
	int	RETVAL;
	dXSTARG;

	RETVAL = THIS->GetSelection();
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__RadioBox_GetStringSelection); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RadioBox_GetStringSelection)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxRadioBox *    THIS = (wxRadioBox *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RadioBox" )
;
	wxString	RETVAL;

	RETVAL = THIS->GetStringSelection();
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    WXSTRING_OUTPUT( RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}

#if WXPERL_W_VERSION_GE( 2, 7, 0 )
#define XSubPPtmpAAEL 1


XS_EUPXS(XS_Wx__RadioBox_IsItemEnabled); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RadioBox_IsItemEnabled)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, item");
    {
	wxRadioBox *    THIS = (wxRadioBox *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RadioBox" )
;
	bool	RETVAL;
	unsigned int    item = (unsigned int)SvUV( ST(1) )
;

	RETVAL = THIS->IsItemEnabled(item);
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__RadioBox_IsItemShown); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RadioBox_IsItemShown)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, item");
    {
	wxRadioBox *    THIS = (wxRadioBox *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RadioBox" )
;
	bool	RETVAL;
	unsigned int    item = (unsigned int)SvUV( ST(1) )
;

	RETVAL = THIS->IsItemShown(item);
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}

#endif

XS_EUPXS(XS_Wx__RadioBox_SetString); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RadioBox_SetString)
{
    dVAR; dXSARGS;
    if (items != 3)
       croak_xs_usage(cv,  "THIS, n, label");
    {
	int	n = (int)SvIV(ST(1))
;
	wxString	label;
	wxRadioBox *    THIS = (wxRadioBox *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RadioBox" )
;

    WXSTRING_INPUT( label, wxString, ST(2) )
;

	THIS->SetString(n, label);
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__RadioBox_SetItemLabel); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RadioBox_SetItemLabel)
{
    dVAR; dXSARGS;
    if (items != 3)
       croak_xs_usage(cv,  "THIS, n, label");
    {
	int	n = (int)SvIV(ST(1))
;
	wxString	label;
	wxRadioBox *    THIS = (wxRadioBox *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RadioBox" )
;

    WXSTRING_INPUT( label, wxString, ST(2) )
;
    THIS->SetString( n, label );
    }
    XSRETURN_EMPTY;
}

#if wxPERL_USE_TOOLTIPS && WXPERL_W_VERSION_GE( 2, 7, 0 )
#define XSubPPtmpAAEM 1


XS_EUPXS(XS_Wx__RadioBox_SetItemToolTip); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RadioBox_SetItemToolTip)
{
    dVAR; dXSARGS;
    if (items != 3)
       croak_xs_usage(cv,  "THIS, item, text");
    {
	unsigned int    item = (unsigned int)SvUV( ST(1) )
;
	wxString	text;
	wxRadioBox *    THIS = (wxRadioBox *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RadioBox" )
;

    WXSTRING_INPUT( text, wxString, ST(2) )
;

	THIS->SetItemToolTip(item, text);
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__RadioBox_GetItemToolTip); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RadioBox_GetItemToolTip)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, item");
    {
	unsigned int    item = (unsigned int)SvUV( ST(1) )
;
	wxRadioBox *    THIS = (wxRadioBox *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RadioBox" )
;
	wxToolTip *	RETVAL;

	RETVAL = THIS->GetItemToolTip(item);
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_object_2_sv( aTHX_ RETVALSV, RETVAL );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}

#endif
#if wxPERL_USE_HELP && WXPERL_W_VERSION_GE( 2, 7, 0 )
#define XSubPPtmpAAEN 1


XS_EUPXS(XS_Wx__RadioBox_SetItemHelpText); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RadioBox_SetItemHelpText)
{
    dVAR; dXSARGS;
    if (items != 3)
       croak_xs_usage(cv,  "THIS, item, text");
    {
	unsigned int    item = (unsigned int)SvUV( ST(1) )
;
	wxString	text;
	wxRadioBox *    THIS = (wxRadioBox *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RadioBox" )
;

    WXSTRING_INPUT( text, wxString, ST(2) )
;

	THIS->SetItemHelpText(item, text);
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__RadioBox_GetItemHelpText); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RadioBox_GetItemHelpText)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, item");
    {
	unsigned int    item = (unsigned int)SvUV( ST(1) )
;
	wxRadioBox *    THIS = (wxRadioBox *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RadioBox" )
;
	wxString	RETVAL;

	RETVAL = THIS->GetItemHelpText(item);
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    WXSTRING_OUTPUT( RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}

#endif

XS_EUPXS(XS_Wx__RadioBox_SetSelection); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RadioBox_SetSelection)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, n");
    {
	int	n = (int)SvIV(ST(1))
;
	wxRadioBox *    THIS = (wxRadioBox *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RadioBox" )
;

	THIS->SetSelection(n);
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__RadioBox_SetStringSelection); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RadioBox_SetStringSelection)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, string");
    {
	wxString	string;
	wxRadioBox *    THIS = (wxRadioBox *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RadioBox" )
;

    WXSTRING_INPUT( string, wxString, ST(1) )
;

	THIS->SetStringSelection(string);
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__RadioBox_ShowItem); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RadioBox_ShowItem)
{
    dVAR; dXSARGS;
    if (items != 3)
       croak_xs_usage(cv,  "THIS, n, show");
    {
	int	n = (int)SvIV(ST(1))
;
	bool	show = (bool)SvTRUE(ST(2))
;
	wxRadioBox *    THIS = (wxRadioBox *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RadioBox" )
;
    THIS->Show( n, show );
    }
    XSRETURN_EMPTY;
}


/* INCLUDE: Returning to 'XS/Notebook.xs' from 'XS/RadioBox.xs' */

#include <wx/notebook.h>
#if WXPERL_W_VERSION_LT( 2, 6, 0 )
#define wxNotebookNameStr wxT("notebook")
#endif

XS_EUPXS(XS_Wx__NotebookEvent_new); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__NotebookEvent_new)
{
    dVAR; dXSARGS;
    if (items < 1 || items > 5)
       croak_xs_usage(cv,  "CLASS, eventType = wxEVT_NULL, id = 0, sel = -1, oldSel = -1");
    {
	wxEventType	eventType;
	int	id;
	int	sel;
	int	oldSel;
	char *	CLASS = (char *)SvPV_nolen(ST(0))
;
	wxNotebookEvent *	RETVAL;

	if (items < 2)
	    eventType = wxEVT_NULL;
	else {
	    eventType = (wxEventType)SvIV(ST(1))
;
	}

	if (items < 3)
	    id = 0;
	else {
	    id = (int)SvIV(ST(2))
;
	}

	if (items < 4)
	    sel = -1;
	else {
	    sel = (int)SvIV(ST(3))
;
	}

	if (items < 5)
	    oldSel = -1;
	else {
	    oldSel = (int)SvIV(ST(4))
;
	}

	RETVAL = new wxNotebookEvent(eventType, id, sel, oldSel);
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_object_2_sv( aTHX_ RETVALSV, RETVAL );
    wxPli_thread_sv_register( aTHX_ "Wx::NotebookEvent", RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}

#if WXPERL_W_VERSION_LE( 2, 5, 1 )
#define XSubPPtmpAAEO 1


XS_EUPXS(XS_Wx__NotebookEvent_GetOldSelection); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__NotebookEvent_GetOldSelection)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxNotebookEvent *    THIS = (wxNotebookEvent *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::NotebookEvent" )
;
	int	RETVAL;
	dXSTARG;

	RETVAL = THIS->GetOldSelection();
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__NotebookEvent_GetSelection); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__NotebookEvent_GetSelection)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxNotebookEvent *    THIS = (wxNotebookEvent *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::NotebookEvent" )
;
	int	RETVAL;
	dXSTARG;

	RETVAL = THIS->GetSelection();
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__NotebookEvent_SetOldSelection); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__NotebookEvent_SetOldSelection)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, sel");
    {
	int	sel = (int)SvIV(ST(1))
;
	wxNotebookEvent *    THIS = (wxNotebookEvent *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::NotebookEvent" )
;

	THIS->SetOldSelection(sel);
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__NotebookEvent_SetSelection); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__NotebookEvent_SetSelection)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, oldSel");
    {
	int	oldSel = (int)SvIV(ST(1))
;
	wxNotebookEvent *    THIS = (wxNotebookEvent *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::NotebookEvent" )
;

	THIS->SetSelection(oldSel);
    }
    XSRETURN_EMPTY;
}

#endif

XS_EUPXS(XS_Wx__Notebook_new); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Notebook_new)
{
    dVAR; dXSARGS;
    PERL_UNUSED_VAR(cv); /* -W */
    PERL_UNUSED_VAR(items); /* -W */
    PERL_UNUSED_VAR(ax); /* -Wall */
    SP -= items;
    {
    BEGIN_OVERLOAD()
        MATCH_VOIDM_REDISP( newDefault )
        MATCH_ANY_REDISP( newFull )
    END_OVERLOAD( "Wx::Notebook::new" )
	PUTBACK;
	return;
    }
}


XS_EUPXS(XS_Wx__Notebook_newDefault); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Notebook_newDefault)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "CLASS");
    {
	PlClassName    CLASS = wxPli_get_class( aTHX_ ST(0) )
;
	wxNotebook *	RETVAL;
    RETVAL = new wxNotebook();
    wxPli_create_evthandler( aTHX_ RETVAL, CLASS );
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_evthandler_2_sv( aTHX_ RETVALSV, RETVAL );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__Notebook_newFull); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Notebook_newFull)
{
    dVAR; dXSARGS;
    if (items < 2 || items > 7)
       croak_xs_usage(cv,  "CLASS, parent, id = wxID_ANY, pos = wxDefaultPosition, size = wxDefaultSize, style = 0, name = wxNotebookNameStr");
    {
	PlClassName    CLASS = wxPli_get_class( aTHX_ ST(0) )
;
	wxWindow*    parent = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::Window" )
;
	wxWindowID	id;
	wxPoint	pos;
	wxSize	size;
	long	style;
	wxString	name;
	wxNotebook *	RETVAL;

	if (items < 3)
	    id = wxID_ANY;
	else {
    id = wxPli_get_wxwindowid( aTHX_ ST(2) )
;
	}

	if (items < 4)
	    pos = wxDefaultPosition;
	else {
    pos = wxPli_sv_2_wxpoint( aTHX_ ST(3) )
;
	}

	if (items < 5)
	    size = wxDefaultSize;
	else {
    size = wxPli_sv_2_wxsize( aTHX_ ST(4) )
;
	}

	if (items < 6)
	    style = 0;
	else {
	    style = (long)SvIV(ST(5))
;
	}

	if (items < 7)
	    name = wxNotebookNameStr;
	else {
    WXSTRING_INPUT( name, wxString, ST(6) )
;
	}
    RETVAL = new wxNotebook( parent, id, pos, size, style, name );
    wxPli_create_evthandler( aTHX_ RETVAL, CLASS );
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_evthandler_2_sv( aTHX_ RETVALSV, RETVAL );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__Notebook_Create); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Notebook_Create)
{
    dVAR; dXSARGS;
    if (items < 2 || items > 7)
       croak_xs_usage(cv,  "THIS, parent, id = wxID_ANY, pos = wxDefaultPosition, size = wxDefaultSize, style = 0, name = wxNotebookNameStr");
    {
	wxWindow*    parent = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::Window" )
;
	wxWindowID	id;
	wxPoint	pos;
	wxSize	size;
	long	style;
	wxString	name;
	wxNotebook *    THIS = (wxNotebook *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Notebook" )
;
	bool	RETVAL;

	if (items < 3)
	    id = wxID_ANY;
	else {
    id = wxPli_get_wxwindowid( aTHX_ ST(2) )
;
	}

	if (items < 4)
	    pos = wxDefaultPosition;
	else {
    pos = wxPli_sv_2_wxpoint( aTHX_ ST(3) )
;
	}

	if (items < 5)
	    size = wxDefaultSize;
	else {
    size = wxPli_sv_2_wxsize( aTHX_ ST(4) )
;
	}

	if (items < 6)
	    style = 0;
	else {
	    style = (long)SvIV(ST(5))
;
	}

	if (items < 7)
	    name = wxNotebookNameStr;
	else {
    WXSTRING_INPUT( name, wxString, ST(6) )
;
	}

	RETVAL = THIS->Create(parent, id, pos, size, style, name);
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}

#if WXPERL_W_VERSION_LE( 2, 5, 1 )
#define XSubPPtmpAAEP 1


XS_EUPXS(XS_Wx__Notebook_AddPage); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Notebook_AddPage)
{
    dVAR; dXSARGS;
    if (items < 3 || items > 5)
       croak_xs_usage(cv,  "THIS, page, text, select = false, imageId = -1");
    {
	wxWindow*    page = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::Window" )
;
	wxString	text;
	bool	select;
	int	imageId;
	wxNotebook *    THIS = (wxNotebook *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Notebook" )
;
	bool	RETVAL;

    WXSTRING_INPUT( text, wxString, ST(2) )
;

	if (items < 4)
	    select = false;
	else {
	    select = (bool)SvTRUE(ST(3))
;
	}

	if (items < 5)
	    imageId = -1;
	else {
	    imageId = (int)SvIV(ST(4))
;
	}

	RETVAL = THIS->AddPage(page, text, select, imageId);
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__Notebook_AdvanceSelection); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Notebook_AdvanceSelection)
{
    dVAR; dXSARGS;
    if (items < 1 || items > 2)
       croak_xs_usage(cv,  "THIS, forward = true");
    {
	bool	forward;
	wxNotebook *    THIS = (wxNotebook *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Notebook" )
;

	if (items < 2)
	    forward = true;
	else {
	    forward = (bool)SvTRUE(ST(1))
;
	}

	THIS->AdvanceSelection(forward);
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__Notebook_DeleteAllPages); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Notebook_DeleteAllPages)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxNotebook *    THIS = (wxNotebook *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Notebook" )
;
	bool	RETVAL;

	RETVAL = THIS->DeleteAllPages();
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__Notebook_DeletePage); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Notebook_DeletePage)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, page");
    {
	int	page = (int)SvIV(ST(1))
;
	wxNotebook *    THIS = (wxNotebook *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Notebook" )
;
	bool	RETVAL;

	RETVAL = THIS->DeletePage(page);
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__Notebook_GetImageList); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Notebook_GetImageList)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxNotebook *    THIS = (wxNotebook *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Notebook" )
;
	wxImageList *	RETVAL;

	RETVAL = THIS->GetImageList();
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_object_2_sv( aTHX_ RETVALSV, RETVAL );
    wxPli_thread_sv_register( aTHX_ "Wx::ImageList", RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    wxPli_object_set_deleteable( aTHX_ ST(0), false );
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__Notebook_GetPage); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Notebook_GetPage)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, page");
    {
	int	page = (int)SvIV(ST(1))
;
	wxNotebook *    THIS = (wxNotebook *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Notebook" )
;
	wxWindow *	RETVAL;

	RETVAL = THIS->GetPage(page);
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_object_2_sv( aTHX_ RETVALSV, RETVAL );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__Notebook_GetPageCount); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Notebook_GetPageCount)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxNotebook *    THIS = (wxNotebook *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Notebook" )
;
	int	RETVAL;
	dXSTARG;

	RETVAL = THIS->GetPageCount();
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__Notebook_GetPageImage); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Notebook_GetPageImage)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, page");
    {
	int	page = (int)SvIV(ST(1))
;
	wxNotebook *    THIS = (wxNotebook *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Notebook" )
;
	int	RETVAL;
	dXSTARG;

	RETVAL = THIS->GetPageImage(page);
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__Notebook_GetPageText); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Notebook_GetPageText)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, page");
    {
	int	page = (int)SvIV(ST(1))
;
	wxNotebook *    THIS = (wxNotebook *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Notebook" )
;
	wxString	RETVAL;

	RETVAL = THIS->GetPageText(page);
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    WXSTRING_OUTPUT( RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__Notebook_GetSelection); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Notebook_GetSelection)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxNotebook *    THIS = (wxNotebook *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Notebook" )
;
	int	RETVAL;
	dXSTARG;

	RETVAL = THIS->GetSelection();
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__Notebook_InsertPage); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Notebook_InsertPage)
{
    dVAR; dXSARGS;
    if (items < 4 || items > 6)
       croak_xs_usage(cv,  "THIS, index, page, text, select = false, imageId = -1");
    {
	int	index = (int)SvIV(ST(1))
;
	wxWindow*    page = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(2), "Wx::Window" )
;
	wxString	text;
	bool	select;
	int	imageId;
	wxNotebook *    THIS = (wxNotebook *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Notebook" )
;
	bool	RETVAL;

    WXSTRING_INPUT( text, wxString, ST(3) )
;

	if (items < 5)
	    select = false;
	else {
	    select = (bool)SvTRUE(ST(4))
;
	}

	if (items < 6)
	    imageId = -1;
	else {
	    imageId = (int)SvIV(ST(5))
;
	}

	RETVAL = THIS->InsertPage(index, page, text, select, imageId);
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__Notebook_RemovePage); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Notebook_RemovePage)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, page");
    {
	int	page = (int)SvIV(ST(1))
;
	wxNotebook *    THIS = (wxNotebook *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Notebook" )
;
	bool	RETVAL;

	RETVAL = THIS->RemovePage(page);
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__Notebook_SetImageList); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Notebook_SetImageList)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, imagelist");
    {
	wxImageList*    imagelist = (wxImageList *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::ImageList" )
;
	wxNotebook *    THIS = (wxNotebook *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Notebook" )
;

	THIS->SetImageList(imagelist);
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__Notebook_SetPageImage); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Notebook_SetPageImage)
{
    dVAR; dXSARGS;
    if (items != 3)
       croak_xs_usage(cv,  "THIS, page, image");
    {
	int	page = (int)SvIV(ST(1))
;
	int	image = (int)SvIV(ST(2))
;
	wxNotebook *    THIS = (wxNotebook *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Notebook" )
;
	bool	RETVAL;

	RETVAL = THIS->SetPageImage(page, image);
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__Notebook_SetPageText); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Notebook_SetPageText)
{
    dVAR; dXSARGS;
    if (items != 3)
       croak_xs_usage(cv,  "THIS, page, text");
    {
	int	page = (int)SvIV(ST(1))
;
	wxString	text;
	wxNotebook *    THIS = (wxNotebook *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Notebook" )
;
	bool	RETVAL;

    WXSTRING_INPUT( text, wxString, ST(2) )
;

	RETVAL = THIS->SetPageText(page, text);
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__Notebook_SetSelection); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Notebook_SetSelection)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, page");
    {
	int	page = (int)SvIV(ST(1))
;
	wxNotebook *    THIS = (wxNotebook *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Notebook" )
;
	int	RETVAL;
	dXSTARG;

	RETVAL = THIS->SetSelection(page);
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}

#endif
#if WXPERL_W_VERSION_GE( 2, 5, 2 ) && WXPERL_W_VERSION_LT( 2, 7, 0 )
#define XSubPPtmpAAEQ 1


XS_EUPXS(XS_Wx__Notebook_HitTest); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Notebook_HitTest)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, point");
    PERL_UNUSED_VAR(ax); /* -Wall */
    SP -= items;
    {
	wxPoint    point = wxPli_sv_2_wxpoint( aTHX_ ST(1) )
;
    long flags;
    int item;
	wxNotebook *    THIS = (wxNotebook *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Notebook" )
;
    item = THIS->HitTest( point, &flags );
    EXTEND( SP, 2 );
    PUSHs( sv_2mortal( newSViv( item ) ) );
    PUSHs( sv_2mortal( newSViv( flags ) ) );
	PUTBACK;
	return;
    }
}

#endif

XS_EUPXS(XS_Wx__Notebook_GetRowCount); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Notebook_GetRowCount)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxNotebook *    THIS = (wxNotebook *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Notebook" )
;
	int	RETVAL;
	dXSTARG;

	RETVAL = THIS->GetRowCount();
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}

#if !defined( __WXMOTIF__ ) && !defined( __WXGTK__ ) || \
  defined( __WXPERL_FORCE__ )
#define XSubPPtmpAAER 1


XS_EUPXS(XS_Wx__Notebook_SetPadding); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Notebook_SetPadding)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, padding");
    {
	wxSize    padding = wxPli_sv_2_wxsize( aTHX_ ST(1) )
;
	wxNotebook *    THIS = (wxNotebook *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Notebook" )
;

	THIS->SetPadding(padding);
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__Notebook_SetPageSize); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Notebook_SetPageSize)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, padding");
    {
	wxSize    padding = wxPli_sv_2_wxsize( aTHX_ ST(1) )
;
	wxNotebook *    THIS = (wxNotebook *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Notebook" )
;

	THIS->SetPageSize(padding);
    }
    XSRETURN_EMPTY;
}

#endif

/* INCLUDE: Returning to 'XS/ListCtrl.xs' from 'XS/Notebook.xs' */

#include <wx/colour.h>
#include <wx/listctrl.h>
#if WXPERL_W_VERSION_LT( 2, 6, 0 )
#define wxListCtrlNameStr wxT("listCtrl")
#endif

XS_EUPXS(XS_Wx__ListEvent_new); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ListEvent_new)
{
    dVAR; dXSARGS;
    if (items < 1 || items > 3)
       croak_xs_usage(cv,  "CLASS, eventType = wxEVT_NULL, id = 0");
    {
	wxEventType	eventType;
	int	id;
	char *	CLASS = (char *)SvPV_nolen(ST(0))
;
	wxListEvent *	RETVAL;

	if (items < 2)
	    eventType = wxEVT_NULL;
	else {
	    eventType = (wxEventType)SvIV(ST(1))
;
	}

	if (items < 3)
	    id = 0;
	else {
	    id = (int)SvIV(ST(2))
;
	}

	RETVAL = new wxListEvent(eventType, id);
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_object_2_sv( aTHX_ RETVALSV, RETVAL );
    wxPli_thread_sv_register( aTHX_ "Wx::ListEvent", RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}

#if WXPERL_W_VERSION_GE( 2, 5, 1 )
#define XSubPPtmpAAES 1


XS_EUPXS(XS_Wx__ListEvent_IsEditCancelled); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ListEvent_IsEditCancelled)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxListEvent *    THIS = (wxListEvent *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::ListEvent" )
;
	bool	RETVAL;

	RETVAL = THIS->IsEditCancelled();
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}

#endif

XS_EUPXS(XS_Wx__ListEvent_GetCacheFrom); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ListEvent_GetCacheFrom)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxListEvent *    THIS = (wxListEvent *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::ListEvent" )
;
	long	RETVAL;
	dXSTARG;

	RETVAL = THIS->GetCacheFrom();
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__ListEvent_GetCacheTo); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ListEvent_GetCacheTo)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxListEvent *    THIS = (wxListEvent *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::ListEvent" )
;
	long	RETVAL;
	dXSTARG;

	RETVAL = THIS->GetCacheTo();
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__ListEvent_GetIndex); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ListEvent_GetIndex)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxListEvent *    THIS = (wxListEvent *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::ListEvent" )
;
	long	RETVAL;
	dXSTARG;

	RETVAL = THIS->GetIndex();
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__ListEvent_GetColumn); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ListEvent_GetColumn)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxListEvent *    THIS = (wxListEvent *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::ListEvent" )
;
	int	RETVAL;
	dXSTARG;

	RETVAL = THIS->GetColumn();
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__ListEvent_GetKeyCode); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ListEvent_GetKeyCode)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxListEvent *    THIS = (wxListEvent *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::ListEvent" )
;
	int	RETVAL;
	dXSTARG;

	RETVAL = THIS->GetKeyCode();
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__ListEvent_GetPoint); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ListEvent_GetPoint)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxListEvent *    THIS = (wxListEvent *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::ListEvent" )
;
	wxPoint *	RETVAL;
    RETVAL = new wxPoint( THIS->GetPoint() );
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_non_object_2_sv( aTHX_ RETVALSV, RETVAL, "Wx::Point" );
    wxPli_thread_sv_register( aTHX_ "Wx::Point", RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__ListEvent_GetLabel); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ListEvent_GetLabel)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxListEvent *    THIS = (wxListEvent *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::ListEvent" )
;
	wxString	RETVAL;

	RETVAL = THIS->GetLabel();
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    WXSTRING_OUTPUT( RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__ListEvent_GetText); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ListEvent_GetText)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxListEvent *    THIS = (wxListEvent *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::ListEvent" )
;
	wxString	RETVAL;

	RETVAL = THIS->GetText();
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    WXSTRING_OUTPUT( RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__ListEvent_GetImage); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ListEvent_GetImage)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxListEvent *    THIS = (wxListEvent *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::ListEvent" )
;
	int	RETVAL;
	dXSTARG;

	RETVAL = THIS->GetImage();
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__ListEvent_GetData); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ListEvent_GetData)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxListEvent *    THIS = (wxListEvent *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::ListEvent" )
;
	long	RETVAL;
	dXSTARG;

	RETVAL = THIS->GetData();
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__ListEvent_GetMask); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ListEvent_GetMask)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxListEvent *    THIS = (wxListEvent *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::ListEvent" )
;
	long	RETVAL;
	dXSTARG;

	RETVAL = THIS->GetMask();
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__ListEvent_GetItem); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ListEvent_GetItem)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxListEvent *    THIS = (wxListEvent *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::ListEvent" )
;
	wxListItem *	RETVAL;
    RETVAL = new wxListItem( THIS->GetItem() );
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_non_object_2_sv( aTHX_ RETVALSV, RETVAL, "Wx::ListItem" );
    wxPli_thread_sv_register( aTHX_ "Wx::ListItem", RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__ListItem_new); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ListItem_new)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "CLASS");
    {
	char *	CLASS = (char *)SvPV_nolen(ST(0))
;
	wxListItem *	RETVAL;

	RETVAL = new wxListItem();
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_non_object_2_sv( aTHX_ RETVALSV, RETVAL, "Wx::ListItem" );
    wxPli_thread_sv_register( aTHX_ "Wx::ListItem", RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__ListItem_CLONE); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ListItem_CLONE)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "CLASS");
    {
	char *	CLASS = (char *)SvPV_nolen(ST(0))
;
    wxPli_thread_sv_clone( aTHX_ CLASS, (wxPliCloneSV)wxPli_detach_object );
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__ListItem_DESTROY); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ListItem_DESTROY)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxListItem *    THIS = (wxListItem *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::ListItem" )
;
    wxPli_thread_sv_unregister( aTHX_ "Wx::ListItem", THIS, ST(0) );
    delete THIS;
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__ListItem_Clear); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ListItem_Clear)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxListItem *    THIS = (wxListItem *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::ListItem" )
;

	THIS->Clear();
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__ListItem_ClearAttributes); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ListItem_ClearAttributes)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxListItem *    THIS = (wxListItem *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::ListItem" )
;

	THIS->ClearAttributes();
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__ListItem_SetMask); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ListItem_SetMask)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, mask");
    {
	long	mask = (long)SvIV(ST(1))
;
	wxListItem *    THIS = (wxListItem *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::ListItem" )
;

	THIS->SetMask(mask);
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__ListItem_SetId); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ListItem_SetId)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, id");
    {
	long	id = (long)SvIV(ST(1))
;
	wxListItem *    THIS = (wxListItem *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::ListItem" )
;

	THIS->SetId(id);
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__ListItem_SetColumn); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ListItem_SetColumn)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, column");
    {
	int	column = (int)SvIV(ST(1))
;
	wxListItem *    THIS = (wxListItem *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::ListItem" )
;

	THIS->SetColumn(column);
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__ListItem_SetState); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ListItem_SetState)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, state");
    {
	long	state = (long)SvIV(ST(1))
;
	wxListItem *    THIS = (wxListItem *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::ListItem" )
;

	THIS->SetState(state);
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__ListItem_SetStateMask); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ListItem_SetStateMask)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, stateMask");
    {
	long	stateMask = (long)SvIV(ST(1))
;
	wxListItem *    THIS = (wxListItem *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::ListItem" )
;

	THIS->SetStateMask(stateMask);
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__ListItem_SetText); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ListItem_SetText)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, text");
    {
	wxString	text;
	wxListItem *    THIS = (wxListItem *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::ListItem" )
;

    WXSTRING_INPUT( text, wxString, ST(1) )
;

	THIS->SetText(text);
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__ListItem_SetImage); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ListItem_SetImage)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, image");
    {
	int	image = (int)SvIV(ST(1))
;
	wxListItem *    THIS = (wxListItem *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::ListItem" )
;

	THIS->SetImage(image);
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__ListItem_SetData); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ListItem_SetData)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, data");
    {
	long	data = (long)SvIV(ST(1))
;
	wxListItem *    THIS = (wxListItem *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::ListItem" )
;

	THIS->SetData(data);
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__ListItem_SetWidth); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ListItem_SetWidth)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, width");
    {
	int	width = (int)SvIV(ST(1))
;
	wxListItem *    THIS = (wxListItem *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::ListItem" )
;

	THIS->SetWidth(width);
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__ListItem_SetAlign); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ListItem_SetAlign)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, align");
    {
	wxListColumnFormat	align = (wxListColumnFormat)SvIV(ST(1))
;
	wxListItem *    THIS = (wxListItem *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::ListItem" )
;

	THIS->SetAlign(align);
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__ListItem_SetTextColour); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ListItem_SetTextColour)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, colour");
    {
	wxColour    colour = *(wxColour *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::Colour" )
;
	wxListItem *    THIS = (wxListItem *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::ListItem" )
;

	THIS->SetTextColour(colour);
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__ListItem_SetBackgroundColour); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ListItem_SetBackgroundColour)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, colour");
    {
	wxColour    colour = *(wxColour *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::Colour" )
;
	wxListItem *    THIS = (wxListItem *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::ListItem" )
;

	THIS->SetBackgroundColour(colour);
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__ListItem_SetFont); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ListItem_SetFont)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, font");
    {
	wxFont*    font = (wxFont *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::Font" )
;
	wxListItem *    THIS = (wxListItem *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::ListItem" )
;

	THIS->SetFont(*font);
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__ListItem_GetMask); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ListItem_GetMask)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxListItem *    THIS = (wxListItem *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::ListItem" )
;
	long	RETVAL;
	dXSTARG;

	RETVAL = THIS->GetMask();
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__ListItem_GetId); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ListItem_GetId)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxListItem *    THIS = (wxListItem *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::ListItem" )
;
	long	RETVAL;
	dXSTARG;

	RETVAL = THIS->GetId();
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__ListItem_GetColumn); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ListItem_GetColumn)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxListItem *    THIS = (wxListItem *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::ListItem" )
;
	int	RETVAL;
	dXSTARG;

	RETVAL = THIS->GetColumn();
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__ListItem_GetState); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ListItem_GetState)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxListItem *    THIS = (wxListItem *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::ListItem" )
;
	long	RETVAL;
	dXSTARG;

	RETVAL = THIS->GetState();
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__ListItem_GetText); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ListItem_GetText)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxListItem *    THIS = (wxListItem *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::ListItem" )
;
	wxString	RETVAL;

	RETVAL = THIS->GetText();
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    WXSTRING_OUTPUT( RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__ListItem_GetImage); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ListItem_GetImage)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxListItem *    THIS = (wxListItem *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::ListItem" )
;
	int	RETVAL;
	dXSTARG;

	RETVAL = THIS->GetImage();
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__ListItem_GetData); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ListItem_GetData)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxListItem *    THIS = (wxListItem *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::ListItem" )
;
	long	RETVAL;
	dXSTARG;

	RETVAL = THIS->GetData();
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__ListItem_GetWidth); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ListItem_GetWidth)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxListItem *    THIS = (wxListItem *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::ListItem" )
;
	int	RETVAL;
	dXSTARG;

	RETVAL = THIS->GetWidth();
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__ListItem_GetAlign); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ListItem_GetAlign)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxListItem *    THIS = (wxListItem *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::ListItem" )
;
	wxListColumnFormat	RETVAL;
	dXSTARG;

	RETVAL = THIS->GetAlign();
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__ListItem_GetTextColour); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ListItem_GetTextColour)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxListItem *    THIS = (wxListItem *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::ListItem" )
;
	wxColour *	RETVAL;
    RETVAL = new wxColour( THIS->GetTextColour() );
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_non_object_2_sv( aTHX_ RETVALSV, RETVAL, "Wx::Colour" );
    wxPli_thread_sv_register( aTHX_ "Wx::Colour", RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__ListItem_GetBackgroundColour); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ListItem_GetBackgroundColour)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxListItem *    THIS = (wxListItem *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::ListItem" )
;
	wxColour *	RETVAL;
    RETVAL = new wxColour( THIS->GetBackgroundColour() );
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_non_object_2_sv( aTHX_ RETVALSV, RETVAL, "Wx::Colour" );
    wxPli_thread_sv_register( aTHX_ "Wx::Colour", RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__ListItem_GetFont); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ListItem_GetFont)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxListItem *    THIS = (wxListItem *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::ListItem" )
;
	wxFont *	RETVAL;
    RETVAL = new wxFont( THIS->GetFont() );
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_object_2_sv( aTHX_ RETVALSV, RETVAL );
    wxPli_thread_sv_register( aTHX_ "Wx::Font", RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__ListItemAttr_new); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ListItemAttr_new)
{
    dVAR; dXSARGS;
    if (items < 1)
       croak_xs_usage(cv,  "CLASS, ...");
    if (items == 1)
    {
	char *	CLASS = (char *)SvPV_nolen(ST(0))
;
	wxListItemAttr *	RETVAL;
      RETVAL = new wxListItemAttr();
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_non_object_2_sv( aTHX_ RETVALSV, RETVAL, "Wx::ListItemAttr" );
    wxPli_thread_sv_register( aTHX_ "Wx::ListItemAttr", RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    else if (items == 4)
    {
	wxColour	text;
	wxColour	back;
	wxFont*	font;
	char *	CLASS = (char *)SvPV_nolen(ST(0))
;
	wxListItemAttr *	RETVAL;
      text = *(wxColour *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::Colour" );
      back = *(wxColour *) wxPli_sv_2_object( aTHX_ ST(2), "Wx::Colour" );
      font = (wxFont *) wxPli_sv_2_object( aTHX_ ST(3), "Wx::Font" );
      RETVAL = new wxListItemAttr( text, back, *font );
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_non_object_2_sv( aTHX_ RETVALSV, RETVAL, "Wx::ListItemAttr" );
    wxPli_thread_sv_register( aTHX_ "Wx::ListItemAttr", RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    else
    {
	char *	CLASS = (char *)SvPV_nolen(ST(0))
;
	wxListItemAttr *	RETVAL;
      croak( "Usage: Wx::ListItemAttr::new(THIS [, text, back, font ] )" );
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__ListItemAttr_CLONE); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ListItemAttr_CLONE)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "CLASS");
    {
	char *	CLASS = (char *)SvPV_nolen(ST(0))
;
    wxPli_thread_sv_clone( aTHX_ CLASS, (wxPliCloneSV)wxPli_detach_object );
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__ListItemAttr_DESTROY); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ListItemAttr_DESTROY)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxListItemAttr *    THIS = (wxListItemAttr *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::ListItemAttr" )
;
    wxPli_thread_sv_unregister( aTHX_ "Wx::ListItemAttr", THIS, ST(0) );
    delete THIS;
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__ListItemAttr_SetTextColour); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ListItemAttr_SetTextColour)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, text");
    {
	wxColour    text = *(wxColour *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::Colour" )
;
	wxListItemAttr *    THIS = (wxListItemAttr *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::ListItemAttr" )
;

	THIS->SetTextColour(text);
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__ListItemAttr_SetBackgroundColour); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ListItemAttr_SetBackgroundColour)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, back");
    {
	wxColour    back = *(wxColour *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::Colour" )
;
	wxListItemAttr *    THIS = (wxListItemAttr *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::ListItemAttr" )
;

	THIS->SetBackgroundColour(back);
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__ListItemAttr_SetFont); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ListItemAttr_SetFont)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, font");
    {
	wxFont*    font = (wxFont *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::Font" )
;
	wxListItemAttr *    THIS = (wxListItemAttr *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::ListItemAttr" )
;
    THIS->SetFont( *font );
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__ListItemAttr_HasTextColour); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ListItemAttr_HasTextColour)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxListItemAttr *    THIS = (wxListItemAttr *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::ListItemAttr" )
;
	bool	RETVAL;

	RETVAL = THIS->HasTextColour();
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__ListItemAttr_HasBackgroundColour); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ListItemAttr_HasBackgroundColour)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxListItemAttr *    THIS = (wxListItemAttr *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::ListItemAttr" )
;
	bool	RETVAL;

	RETVAL = THIS->HasBackgroundColour();
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__ListItemAttr_HasFont); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ListItemAttr_HasFont)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxListItemAttr *    THIS = (wxListItemAttr *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::ListItemAttr" )
;
	bool	RETVAL;

	RETVAL = THIS->HasFont();
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__ListItemAttr_GetTextColour); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ListItemAttr_GetTextColour)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxListItemAttr *    THIS = (wxListItemAttr *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::ListItemAttr" )
;
	wxColour *	RETVAL;
    RETVAL = new wxColour( THIS->GetTextColour() );
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_non_object_2_sv( aTHX_ RETVALSV, RETVAL, "Wx::Colour" );
    wxPli_thread_sv_register( aTHX_ "Wx::Colour", RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__ListItemAttr_GetBackgroundColour); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ListItemAttr_GetBackgroundColour)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxListItemAttr *    THIS = (wxListItemAttr *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::ListItemAttr" )
;
	wxColour *	RETVAL;
    RETVAL = new wxColour( THIS->GetBackgroundColour() );
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_non_object_2_sv( aTHX_ RETVALSV, RETVAL, "Wx::Colour" );
    wxPli_thread_sv_register( aTHX_ "Wx::Colour", RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__ListItemAttr_GetFont); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ListItemAttr_GetFont)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxListItemAttr *    THIS = (wxListItemAttr *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::ListItemAttr" )
;
	wxFont *	RETVAL;
    RETVAL = new wxFont( THIS->GetFont() );
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_object_2_sv( aTHX_ RETVALSV, RETVAL );
    wxPli_thread_sv_register( aTHX_ "Wx::Font", RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__ListCtrl_new); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ListCtrl_new)
{
    dVAR; dXSARGS;
    PERL_UNUSED_VAR(cv); /* -W */
    PERL_UNUSED_VAR(items); /* -W */
    PERL_UNUSED_VAR(ax); /* -Wall */
    SP -= items;
    {
    BEGIN_OVERLOAD()
        MATCH_VOIDM_REDISP( newDefault )
        MATCH_ANY_REDISP( newFull )
    END_OVERLOAD( "Wx::ListCtrl::new" )
	PUTBACK;
	return;
    }
}


XS_EUPXS(XS_Wx__ListCtrl_newDefault); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ListCtrl_newDefault)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "CLASS");
    {
	PlClassName    CLASS = wxPli_get_class( aTHX_ ST(0) )
;
	wxListCtrl *	RETVAL;
    RETVAL = new wxPliListCtrl( CLASS );
    wxPli_create_evthandler( aTHX_ RETVAL, CLASS );
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_object_2_sv( aTHX_ RETVALSV, RETVAL );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__ListCtrl_newFull); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ListCtrl_newFull)
{
    dVAR; dXSARGS;
    if (items < 2 || items > 8)
       croak_xs_usage(cv,  "CLASS, parent, id = wxID_ANY, pos = wxDefaultPosition, size = wxDefaultSize, style = wxLC_ICON, validator = (wxValidator*)&wxDefaultValidator, name = wxListCtrlNameStr");
    {
	PlClassName    CLASS = wxPli_get_class( aTHX_ ST(0) )
;
	wxWindow*    parent = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::Window" )
;
	wxWindowID	id;
	wxPoint	pos;
	wxSize	size;
	long	style;
	wxValidator*	validator;
	wxString	name;
	wxListCtrl *	RETVAL;

	if (items < 3)
	    id = wxID_ANY;
	else {
    id = wxPli_get_wxwindowid( aTHX_ ST(2) )
;
	}

	if (items < 4)
	    pos = wxDefaultPosition;
	else {
    pos = wxPli_sv_2_wxpoint( aTHX_ ST(3) )
;
	}

	if (items < 5)
	    size = wxDefaultSize;
	else {
    size = wxPli_sv_2_wxsize( aTHX_ ST(4) )
;
	}

	if (items < 6)
	    style = wxLC_ICON;
	else {
	    style = (long)SvIV(ST(5))
;
	}

	if (items < 7)
	    validator = (wxValidator*)&wxDefaultValidator;
	else {
    validator = (wxValidator *) wxPli_sv_2_object( aTHX_ ST(6), "Wx::Validator" )
;
	}

	if (items < 8)
	    name = wxListCtrlNameStr;
	else {
    WXSTRING_INPUT( name, wxString, ST(7) )
;
	}
    RETVAL = new wxPliListCtrl( CLASS, parent, id, pos, size, style,
        *validator, name );
    wxPli_create_evthandler( aTHX_ RETVAL, CLASS );
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_object_2_sv( aTHX_ RETVALSV, RETVAL );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__ListCtrl_Create); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ListCtrl_Create)
{
    dVAR; dXSARGS;
    if (items < 2 || items > 8)
       croak_xs_usage(cv,  "THIS, parent, id = wxID_ANY, pos = wxDefaultPosition, size = wxDefaultSize, style = wxLC_ICON, validator = (wxValidator*)&wxDefaultValidator, name = wxListCtrlNameStr");
    {
	wxWindow*    parent = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::Window" )
;
	wxWindowID	id;
	wxPoint	pos;
	wxSize	size;
	long	style;
	wxValidator*	validator;
	wxString	name;
	wxListCtrl *    THIS = (wxListCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::ListCtrl" )
;
	bool	RETVAL;

	if (items < 3)
	    id = wxID_ANY;
	else {
    id = wxPli_get_wxwindowid( aTHX_ ST(2) )
;
	}

	if (items < 4)
	    pos = wxDefaultPosition;
	else {
    pos = wxPli_sv_2_wxpoint( aTHX_ ST(3) )
;
	}

	if (items < 5)
	    size = wxDefaultSize;
	else {
    size = wxPli_sv_2_wxsize( aTHX_ ST(4) )
;
	}

	if (items < 6)
	    style = wxLC_ICON;
	else {
	    style = (long)SvIV(ST(5))
;
	}

	if (items < 7)
	    validator = (wxValidator*)&wxDefaultValidator;
	else {
    validator = (wxValidator *) wxPli_sv_2_object( aTHX_ ST(6), "Wx::Validator" )
;
	}

	if (items < 8)
	    name = wxListCtrlNameStr;
	else {
    WXSTRING_INPUT( name, wxString, ST(7) )
;
	}

	RETVAL = THIS->Create(parent, id, pos, size, style, *validator, name);
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__ListCtrl_Arrange); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ListCtrl_Arrange)
{
    dVAR; dXSARGS;
    if (items < 1 || items > 2)
       croak_xs_usage(cv,  "THIS, flag = wxLIST_ALIGN_DEFAULT");
    {
	int	flag;
	wxListCtrl *    THIS = (wxListCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::ListCtrl" )
;
	bool	RETVAL;

	if (items < 2)
	    flag = wxLIST_ALIGN_DEFAULT;
	else {
	    flag = (int)SvIV(ST(1))
;
	}

	RETVAL = THIS->Arrange(flag);
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__ListCtrl_AssignImageList); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ListCtrl_AssignImageList)
{
    dVAR; dXSARGS;
    if (items != 3)
       croak_xs_usage(cv,  "THIS, imagelist, which");
    {
	wxImageList*    imagelist = (wxImageList *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::ImageList" )
;
	int	which = (int)SvIV(ST(2))
;
	wxListCtrl *    THIS = (wxListCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::ListCtrl" )
;
    wxPli_object_set_deleteable( aTHX_ ST(1), false );
    THIS->AssignImageList( imagelist, which );
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__ListCtrl_ClearAll); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ListCtrl_ClearAll)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxListCtrl *    THIS = (wxListCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::ListCtrl" )
;

	THIS->ClearAll();
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__ListCtrl_DeleteItem); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ListCtrl_DeleteItem)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, item");
    {
	long	item = (long)SvIV(ST(1))
;
	wxListCtrl *    THIS = (wxListCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::ListCtrl" )
;
	bool	RETVAL;

	RETVAL = THIS->DeleteItem(item);
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__ListCtrl_DeleteAllItems); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ListCtrl_DeleteAllItems)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxListCtrl *    THIS = (wxListCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::ListCtrl" )
;
	bool	RETVAL;

	RETVAL = THIS->DeleteAllItems();
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__ListCtrl_DeleteColumn); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ListCtrl_DeleteColumn)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, col");
    {
	int	col = (int)SvIV(ST(1))
;
	wxListCtrl *    THIS = (wxListCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::ListCtrl" )
;
	bool	RETVAL;

	RETVAL = THIS->DeleteColumn(col);
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__ListCtrl_EditLabel); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ListCtrl_EditLabel)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, item");
    {
	long	item = (long)SvIV(ST(1))
;
	wxListCtrl *    THIS = (wxListCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::ListCtrl" )
;

	THIS->EditLabel(item);
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__ListCtrl_EnsureVisible); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ListCtrl_EnsureVisible)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, item");
    {
	long	item = (long)SvIV(ST(1))
;
	wxListCtrl *    THIS = (wxListCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::ListCtrl" )
;
	bool	RETVAL;

	RETVAL = THIS->EnsureVisible(item);
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__ListCtrl_FindItem); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ListCtrl_FindItem)
{
    dVAR; dXSARGS;
    if (items < 3 || items > 4)
       croak_xs_usage(cv,  "THIS, start, str, partial = false");
    {
	long	start = (long)SvIV(ST(1))
;
	wxString	str;
	bool	partial;
	wxListCtrl *    THIS = (wxListCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::ListCtrl" )
;
	long	RETVAL;
	dXSTARG;

    WXSTRING_INPUT( str, wxString, ST(2) )
;

	if (items < 4)
	    partial = false;
	else {
	    partial = (bool)SvTRUE(ST(3))
;
	}
    RETVAL = THIS->FindItem( start, str, partial );
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__ListCtrl_FindItemData); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ListCtrl_FindItemData)
{
    dVAR; dXSARGS;
    if (items != 3)
       croak_xs_usage(cv,  "THIS, start, data");
    {
	long	start = (long)SvIV(ST(1))
;
	wxUIntPtr    data = (wxUIntPtr)SvUV( ST(2) )
;
	wxListCtrl *    THIS = (wxListCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::ListCtrl" )
;
	long	RETVAL;
	dXSTARG;
    RETVAL = THIS->FindItem( start, data );
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__ListCtrl_FindItemAtPos); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ListCtrl_FindItemAtPos)
{
    dVAR; dXSARGS;
    if (items != 4)
       croak_xs_usage(cv,  "THIS, start, pt, direction");
    {
	long	start = (long)SvIV(ST(1))
;
	wxPoint    pt = wxPli_sv_2_wxpoint( aTHX_ ST(2) )
;
	int	direction = (int)SvIV(ST(3))
;
	wxListCtrl *    THIS = (wxListCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::ListCtrl" )
;
	long	RETVAL;
	dXSTARG;
    RETVAL = THIS->FindItem( start, pt, direction );
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__ListCtrl_GetColumn); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ListCtrl_GetColumn)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, col");
    {
	int	col = (int)SvIV(ST(1))
;
    wxListItem item;
	wxListCtrl *    THIS = (wxListCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::ListCtrl" )
;
	wxListItem *	RETVAL;
    item.SetMask( wxLIST_MASK_TEXT|wxLIST_MASK_IMAGE|wxLIST_MASK_FORMAT );
    if( THIS->GetColumn( col, item ) )
    {
      RETVAL = new wxListItem( item );
    }
    else
    {
      RETVAL = 0;
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_non_object_2_sv( aTHX_ RETVALSV, RETVAL, "Wx::ListItem" );
    wxPli_thread_sv_register( aTHX_ "Wx::ListItem", RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__ListCtrl_GetColumnCount); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ListCtrl_GetColumnCount)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxListCtrl *    THIS = (wxListCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::ListCtrl" )
;
	int	RETVAL;
	dXSTARG;

	RETVAL = THIS->GetColumnCount();
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__ListCtrl_GetColumnWidth); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ListCtrl_GetColumnWidth)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, col");
    {
	int	col = (int)SvIV(ST(1))
;
	wxListCtrl *    THIS = (wxListCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::ListCtrl" )
;
	int	RETVAL;
	dXSTARG;

	RETVAL = THIS->GetColumnWidth(col);
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__ListCtrl_GetCountPerPage); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ListCtrl_GetCountPerPage)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxListCtrl *    THIS = (wxListCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::ListCtrl" )
;
	int	RETVAL;
	dXSTARG;

	RETVAL = THIS->GetCountPerPage();
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}

#if defined( __WXMSW__ ) || defined( __WXPERL_FORCE__ )
#define XSubPPtmpAAET 1


XS_EUPXS(XS_Wx__ListCtrl_GetEditControl); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ListCtrl_GetEditControl)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxListCtrl *    THIS = (wxListCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::ListCtrl" )
;
	wxTextCtrl *	RETVAL;

	RETVAL = THIS->GetEditControl();
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_object_2_sv( aTHX_ RETVALSV, RETVAL );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}

#endif

XS_EUPXS(XS_Wx__ListCtrl_GetImageList); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ListCtrl_GetImageList)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, which");
    {
	int	which = (int)SvIV(ST(1))
;
	wxListCtrl *    THIS = (wxListCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::ListCtrl" )
;
	wxImageList *	RETVAL;
    RETVAL = (wxImageList*)THIS->GetImageList( which );
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_object_2_sv( aTHX_ RETVALSV, RETVAL );
    wxPli_thread_sv_register( aTHX_ "Wx::ImageList", RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    wxPli_object_set_deleteable( aTHX_ ST(0), false );
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__ListCtrl_GetItem); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ListCtrl_GetItem)
{
    dVAR; dXSARGS;
    if (items < 2 || items > 3)
       croak_xs_usage(cv,  "THIS, id, col = -1");
    {
	long	id = (long)SvIV(ST(1))
;
	int	col;
    wxListItem item;
	wxListCtrl *    THIS = (wxListCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::ListCtrl" )
;
	wxListItem *	RETVAL;

	if (items < 3)
	    col = -1;
	else {
	    col = (int)SvIV(ST(2))
;
	}
    item.SetId( id );
    if( col != -1 ) { item.SetColumn( col ); }
    item.SetMask( wxLIST_MASK_TEXT|wxLIST_MASK_DATA|wxLIST_MASK_IMAGE|
        wxLIST_MASK_STATE );
    if( THIS->GetItem( item ) )
    {
      RETVAL = new wxListItem( item );
    }
    else
    {
      RETVAL = 0;
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_non_object_2_sv( aTHX_ RETVALSV, RETVAL, "Wx::ListItem" );
    wxPli_thread_sv_register( aTHX_ "Wx::ListItem", RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}

#if WXPERL_W_VERSION_GE( 2, 8, 4 )
#define XSubPPtmpAAEU 1


XS_EUPXS(XS_Wx__ListCtrl_GetItemData); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ListCtrl_GetItemData)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, item");
    {
	long	item = (long)SvIV(ST(1))
;
	wxListCtrl *    THIS = (wxListCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::ListCtrl" )
;
	wxUIntPtr	RETVAL;
	dXSTARG;

	RETVAL = THIS->GetItemData(item);
	XSprePUSH;
	PUSHu((UV)RETVAL );
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__ListCtrl_SetItemPtrData); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ListCtrl_SetItemPtrData)
{
    dVAR; dXSARGS;
    if (items != 3)
       croak_xs_usage(cv,  "THIS, item, data");
    {
	long	item = (long)SvIV(ST(1))
;
	wxUIntPtr    data = (wxUIntPtr)SvUV( ST(2) )
;
	wxListCtrl *    THIS = (wxListCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::ListCtrl" )
;
	bool	RETVAL;

	RETVAL = THIS->SetItemPtrData(item, data);
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__ListCtrl_SetItemData); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ListCtrl_SetItemData)
{
    dVAR; dXSARGS;
    if (items != 3)
       croak_xs_usage(cv,  "THIS, item, data");
    {
	long	item = (long)SvIV(ST(1))
;
	wxUIntPtr    data = (wxUIntPtr)SvUV( ST(2) )
;
	wxListCtrl *    THIS = (wxListCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::ListCtrl" )
;
	bool	RETVAL;
    RETVAL = THIS->SetItemPtrData( item, data);
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}

#else
#define XSubPPtmpAAEV 1


XS_EUPXS(XS_Wx__ListCtrl_GetItemData); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ListCtrl_GetItemData)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, item");
    {
	long	item = (long)SvIV(ST(1))
;
	wxListCtrl *    THIS = (wxListCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::ListCtrl" )
;
	long	RETVAL;
	dXSTARG;

	RETVAL = THIS->GetItemData(item);
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__ListCtrl_SetItemData); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ListCtrl_SetItemData)
{
    dVAR; dXSARGS;
    if (items != 3)
       croak_xs_usage(cv,  "THIS, item, data");
    {
	long	item = (long)SvIV(ST(1))
;
	long	data = (long)SvIV(ST(2))
;
	wxListCtrl *    THIS = (wxListCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::ListCtrl" )
;
	bool	RETVAL;

	RETVAL = THIS->SetItemData(item, data);
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}

#endif

XS_EUPXS(XS_Wx__ListCtrl_GetItemPosition); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ListCtrl_GetItemPosition)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, item");
    {
	long	item = (long)SvIV(ST(1))
;
    wxPoint point;
	wxListCtrl *    THIS = (wxListCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::ListCtrl" )
;
	wxPoint *	RETVAL;
    if( THIS->GetItemPosition( item, point ) )
    {
      RETVAL = new wxPoint( point );
    }
    else
    {
      RETVAL = 0;
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_non_object_2_sv( aTHX_ RETVALSV, RETVAL, "Wx::Point" );
    wxPli_thread_sv_register( aTHX_ "Wx::Point", RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__ListCtrl_GetItemRect); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ListCtrl_GetItemRect)
{
    dVAR; dXSARGS;
    if (items < 2 || items > 3)
       croak_xs_usage(cv,  "THIS, item, code = wxLIST_RECT_BOUNDS");
    {
	long	item = (long)SvIV(ST(1))
;
	int	code;
    wxRect rect;
	wxListCtrl *    THIS = (wxListCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::ListCtrl" )
;
	wxRect *	RETVAL;

	if (items < 3)
	    code = wxLIST_RECT_BOUNDS;
	else {
	    code = (int)SvIV(ST(2))
;
	}
    if( THIS->GetItemRect( item, rect, code ) )
    {
        RETVAL = new wxRect( rect );
    }
    else
    {
        RETVAL = 0;
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_non_object_2_sv( aTHX_ RETVALSV, RETVAL, "Wx::Rect" );
    wxPli_thread_sv_register( aTHX_ "Wx::Rect", RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}

#if WXPERL_W_VERSION_GE( 2, 7, 2 ) && defined(__WXMSW__)
#define XSubPPtmpAAEW 1


XS_EUPXS(XS_Wx__ListCtrl_GetSubItemRect); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ListCtrl_GetSubItemRect)
{
    dVAR; dXSARGS;
    if (items < 3 || items > 4)
       croak_xs_usage(cv,  "THIS, item, subItem, code = wxLIST_RECT_BOUNDS");
    {
	long	item = (long)SvIV(ST(1))
;
	long	subItem = (long)SvIV(ST(2))
;
	int	code;
    wxRect rect;
	wxListCtrl *    THIS = (wxListCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::ListCtrl" )
;
	wxRect *	RETVAL;

	if (items < 4)
	    code = wxLIST_RECT_BOUNDS;
	else {
	    code = (int)SvIV(ST(3))
;
	}
    if( THIS->GetSubItemRect( item, subItem, rect, code ) )
    {
        RETVAL = new wxRect( rect );
    }
    else
    {
        RETVAL = 0;
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_non_object_2_sv( aTHX_ RETVALSV, RETVAL, "Wx::Rect" );
    wxPli_thread_sv_register( aTHX_ "Wx::Rect", RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}

#endif

XS_EUPXS(XS_Wx__ListCtrl_GetItemState); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ListCtrl_GetItemState)
{
    dVAR; dXSARGS;
    if (items != 3)
       croak_xs_usage(cv,  "THIS, item, stateMask");
    {
	long	item = (long)SvIV(ST(1))
;
	long	stateMask = (long)SvIV(ST(2))
;
	wxListCtrl *    THIS = (wxListCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::ListCtrl" )
;
	int	RETVAL;
	dXSTARG;

	RETVAL = THIS->GetItemState(item, stateMask);
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__ListCtrl_GetItemCount); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ListCtrl_GetItemCount)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxListCtrl *    THIS = (wxListCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::ListCtrl" )
;
	int	RETVAL;
	dXSTARG;

	RETVAL = THIS->GetItemCount();
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}

#if WXPERL_W_VERSION_LE( 2, 5, 1 )
#define XSubPPtmpAAEX 1


XS_EUPXS(XS_Wx__ListCtrl_GetItemSpacing); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ListCtrl_GetItemSpacing)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, isSmall");
    {
	bool	isSmall = (bool)SvTRUE(ST(1))
;
	wxListCtrl *    THIS = (wxListCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::ListCtrl" )
;
	int	RETVAL;
	dXSTARG;

	RETVAL = THIS->GetItemSpacing(isSmall);
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}

#else
#define XSubPPtmpAAEY 1


XS_EUPXS(XS_Wx__ListCtrl_GetItemSpacing); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ListCtrl_GetItemSpacing)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxListCtrl *    THIS = (wxListCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::ListCtrl" )
;
	wxSize *	RETVAL;
    RETVAL = new wxSize( THIS->GetItemSpacing() );
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_non_object_2_sv( aTHX_ RETVALSV, RETVAL, "Wx::Size" );
    wxPli_thread_sv_register( aTHX_ "Wx::Size", RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}

#endif

XS_EUPXS(XS_Wx__ListCtrl_GetItemText); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ListCtrl_GetItemText)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, item");
    {
	long	item = (long)SvIV(ST(1))
;
	wxListCtrl *    THIS = (wxListCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::ListCtrl" )
;
	wxString	RETVAL;

	RETVAL = THIS->GetItemText(item);
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    WXSTRING_OUTPUT( RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__ListCtrl_GetItemFont); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ListCtrl_GetItemFont)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, item");
    {
	long	item = (long)SvIV(ST(1))
;
	wxListCtrl *    THIS = (wxListCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::ListCtrl" )
;
	wxFont *	RETVAL;
    RETVAL = new wxFont( THIS->GetItemFont( item ) );
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_object_2_sv( aTHX_ RETVALSV, RETVAL );
    wxPli_thread_sv_register( aTHX_ "Wx::Font", RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__ListCtrl_GetItemTextColour); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ListCtrl_GetItemTextColour)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, item");
    {
	long	item = (long)SvIV(ST(1))
;
	wxListCtrl *    THIS = (wxListCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::ListCtrl" )
;
	wxColour *	RETVAL;
    RETVAL = new wxColour( THIS->GetItemTextColour( item ) );
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_non_object_2_sv( aTHX_ RETVALSV, RETVAL, "Wx::Colour" );
    wxPli_thread_sv_register( aTHX_ "Wx::Colour", RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__ListCtrl_GetItemBackgroundColour); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ListCtrl_GetItemBackgroundColour)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, item");
    {
	long	item = (long)SvIV(ST(1))
;
	wxListCtrl *    THIS = (wxListCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::ListCtrl" )
;
	wxColour *	RETVAL;
    RETVAL = new wxColour( THIS->GetItemBackgroundColour( item ) );
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_non_object_2_sv( aTHX_ RETVALSV, RETVAL, "Wx::Colour" );
    wxPli_thread_sv_register( aTHX_ "Wx::Colour", RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__ListCtrl_SetItemTextColour); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ListCtrl_SetItemTextColour)
{
    dVAR; dXSARGS;
    if (items != 3)
       croak_xs_usage(cv,  "THIS, item, colour");
    {
	long	item = (long)SvIV(ST(1))
;
	wxColour*    colour = (wxColour *) wxPli_sv_2_object( aTHX_ ST(2), "Wx::Colour" )
;
	wxListCtrl *    THIS = (wxListCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::ListCtrl" )
;
    THIS->SetItemTextColour( item, *colour );
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__ListCtrl_SetItemBackgroundColour); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ListCtrl_SetItemBackgroundColour)
{
    dVAR; dXSARGS;
    if (items != 3)
       croak_xs_usage(cv,  "THIS, item, colour");
    {
	long	item = (long)SvIV(ST(1))
;
	wxColour*    colour = (wxColour *) wxPli_sv_2_object( aTHX_ ST(2), "Wx::Colour" )
;
	wxListCtrl *    THIS = (wxListCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::ListCtrl" )
;
    THIS->SetItemBackgroundColour( item, *colour );
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__ListCtrl_GetNextItem); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ListCtrl_GetNextItem)
{
    dVAR; dXSARGS;
    if (items < 2 || items > 4)
       croak_xs_usage(cv,  "THIS, item, geometry = wxLIST_NEXT_ALL, state = wxLIST_STATE_DONTCARE");
    {
	long	item = (long)SvIV(ST(1))
;
	int	geometry;
	int	state;
	wxListCtrl *    THIS = (wxListCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::ListCtrl" )
;
	long	RETVAL;
	dXSTARG;

	if (items < 3)
	    geometry = wxLIST_NEXT_ALL;
	else {
	    geometry = (int)SvIV(ST(2))
;
	}

	if (items < 4)
	    state = wxLIST_STATE_DONTCARE;
	else {
	    state = (int)SvIV(ST(3))
;
	}

	RETVAL = THIS->GetNextItem(item, geometry, state);
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__ListCtrl_GetSelectedItemCount); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ListCtrl_GetSelectedItemCount)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxListCtrl *    THIS = (wxListCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::ListCtrl" )
;
	int	RETVAL;
	dXSTARG;

	RETVAL = THIS->GetSelectedItemCount();
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__ListCtrl_GetTextColour); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ListCtrl_GetTextColour)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxListCtrl *    THIS = (wxListCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::ListCtrl" )
;
	wxColour *	RETVAL;
    RETVAL = new wxColour( THIS->GetTextColour() );
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_non_object_2_sv( aTHX_ RETVALSV, RETVAL, "Wx::Colour" );
    wxPli_thread_sv_register( aTHX_ "Wx::Colour", RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__ListCtrl_GetTopItem); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ListCtrl_GetTopItem)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxListCtrl *    THIS = (wxListCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::ListCtrl" )
;
	long	RETVAL;
	dXSTARG;

	RETVAL = THIS->GetTopItem();
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}

#if WXPERL_W_VERSION_GE( 2, 5, 1 )
#define XSubPPtmpAAEZ 1


XS_EUPXS(XS_Wx__ListCtrl_GetViewRect); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ListCtrl_GetViewRect)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxListCtrl *    THIS = (wxListCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::ListCtrl" )
;
	wxRect *	RETVAL;
    RETVAL = new wxRect( THIS->GetViewRect() );
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_non_object_2_sv( aTHX_ RETVALSV, RETVAL, "Wx::Rect" );
    wxPli_thread_sv_register( aTHX_ "Wx::Rect", RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}

#endif

XS_EUPXS(XS_Wx__ListCtrl_HitTest); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ListCtrl_HitTest)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, point");
    PERL_UNUSED_VAR(ax); /* -Wall */
    SP -= items;
    {
	wxPoint    point = wxPli_sv_2_wxpoint( aTHX_ ST(1) )
;
    int flags;
    long item;
#if WXPERL_W_VERSION_GE( 2, 7, 2 )
    long subitem;
#endif
	wxListCtrl *    THIS = (wxListCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::ListCtrl" )
;
#if WXPERL_W_VERSION_GE( 2, 7, 2 )
    item = THIS->HitTest( point, flags, &subitem );
#else
    item = THIS->HitTest( point, flags );
#endif
    EXTEND( SP, 3 );
    PUSHs( sv_2mortal( newSViv( item ) ) );
    PUSHs( sv_2mortal( newSViv( flags ) ) );
#if WXPERL_W_VERSION_GE( 2, 7, 2 )
    PUSHs( sv_2mortal( newSViv( subitem ) ) );
#endif
	PUTBACK;
	return;
    }
}


XS_EUPXS(XS_Wx__ListCtrl_InsertColumn); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ListCtrl_InsertColumn)
{
    dVAR; dXSARGS;
    if (items < 1)
       croak_xs_usage(cv,  "THIS, ...");
    PERL_UNUSED_VAR(ax); /* -Wall */
    SP -= items;
    {
	wxListCtrl *    THIS = (wxListCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::ListCtrl" )
;
    BEGIN_OVERLOAD()
        MATCH_REDISP( wxPliOvl_n_wlci, InsertColumnInfo )
        MATCH_REDISP_COUNT_ALLOWMORE( wxPliOvl_n_s_n_n, InsertColumnString, 2 )
    END_OVERLOAD( Wx::ListCtrl::InsertColumn )
	PUTBACK;
	return;
    }
}


XS_EUPXS(XS_Wx__ListCtrl_InsertColumnInfo); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ListCtrl_InsertColumnInfo)
{
    dVAR; dXSARGS;
    if (items != 3)
       croak_xs_usage(cv,  "THIS, col, info");
    {
	int	col = (int)SvIV(ST(1))
;
	wxListItem*    info = (wxListItem *) wxPli_sv_2_object( aTHX_ ST(2), "Wx::ListItem" )
;
	wxListCtrl *    THIS = (wxListCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::ListCtrl" )
;
	long	RETVAL;
	dXSTARG;
    RETVAL = THIS->InsertColumn( col, *info );
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__ListCtrl_InsertColumnString); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ListCtrl_InsertColumnString)
{
    dVAR; dXSARGS;
    if (items < 3 || items > 5)
       croak_xs_usage(cv,  "THIS, col, heading, format = wxLIST_FORMAT_LEFT, width = -1");
    {
	int	col = (int)SvIV(ST(1))
;
	wxString	heading;
	int	format;
	int	width;
	wxListCtrl *    THIS = (wxListCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::ListCtrl" )
;
	long	RETVAL;
	dXSTARG;

    WXSTRING_INPUT( heading, wxString, ST(2) )
;

	if (items < 4)
	    format = wxLIST_FORMAT_LEFT;
	else {
	    format = (int)SvIV(ST(3))
;
	}

	if (items < 5)
	    width = -1;
	else {
	    width = (int)SvIV(ST(4))
;
	}
    RETVAL = THIS->InsertColumn( col, heading, format, width );
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__ListCtrl_InsertItem); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ListCtrl_InsertItem)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, info");
    {
	wxListItem*    info = (wxListItem *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::ListItem" )
;
	wxListCtrl *    THIS = (wxListCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::ListCtrl" )
;
	long	RETVAL;
	dXSTARG;
    RETVAL = THIS->InsertItem( *info );
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__ListCtrl_InsertStringItem); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ListCtrl_InsertStringItem)
{
    dVAR; dXSARGS;
    if (items != 3)
       croak_xs_usage(cv,  "THIS, index, label");
    {
	long	index = (long)SvIV(ST(1))
;
	wxString	label;
	wxListCtrl *    THIS = (wxListCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::ListCtrl" )
;
	long	RETVAL;
	dXSTARG;

    WXSTRING_INPUT( label, wxString, ST(2) )
;
    RETVAL = THIS->InsertItem( index, label );
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__ListCtrl_InsertImageItem); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ListCtrl_InsertImageItem)
{
    dVAR; dXSARGS;
    if (items != 3)
       croak_xs_usage(cv,  "THIS, index, image");
    {
	long	index = (long)SvIV(ST(1))
;
	int	image = (int)SvIV(ST(2))
;
	wxListCtrl *    THIS = (wxListCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::ListCtrl" )
;
	long	RETVAL;
	dXSTARG;
    RETVAL = THIS->InsertItem( index, image );
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__ListCtrl_InsertImageStringItem); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ListCtrl_InsertImageStringItem)
{
    dVAR; dXSARGS;
    if (items != 4)
       croak_xs_usage(cv,  "THIS, index, label, image");
    {
	long	index = (long)SvIV(ST(1))
;
	wxString	label;
	int	image = (int)SvIV(ST(3))
;
	wxListCtrl *    THIS = (wxListCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::ListCtrl" )
;
	long	RETVAL;
	dXSTARG;

    WXSTRING_INPUT( label, wxString, ST(2) )
;
    RETVAL = THIS->InsertItem( index, label, image );
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__ListCtrl_IsVirtual); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ListCtrl_IsVirtual)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxListCtrl *    THIS = (wxListCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::ListCtrl" )
;
	bool	RETVAL;

	RETVAL = THIS->IsVirtual();
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__ListCtrl_RefreshItem); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ListCtrl_RefreshItem)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, item");
    {
	long	item = (long)SvIV(ST(1))
;
	wxListCtrl *    THIS = (wxListCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::ListCtrl" )
;

	THIS->RefreshItem(item);
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__ListCtrl_RefreshItems); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ListCtrl_RefreshItems)
{
    dVAR; dXSARGS;
    if (items != 3)
       croak_xs_usage(cv,  "THIS, itemFrom, itemTo");
    {
	long	itemFrom = (long)SvIV(ST(1))
;
	long	itemTo = (long)SvIV(ST(2))
;
	wxListCtrl *    THIS = (wxListCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::ListCtrl" )
;

	THIS->RefreshItems(itemFrom, itemTo);
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__ListCtrl_ScrollList); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ListCtrl_ScrollList)
{
    dVAR; dXSARGS;
    if (items != 3)
       croak_xs_usage(cv,  "THIS, dx, dy");
    {
	int	dx = (int)SvIV(ST(1))
;
	int	dy = (int)SvIV(ST(2))
;
	wxListCtrl *    THIS = (wxListCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::ListCtrl" )
;
	bool	RETVAL;

	RETVAL = THIS->ScrollList(dx, dy);
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__ListCtrl_SetColumn); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ListCtrl_SetColumn)
{
    dVAR; dXSARGS;
    if (items != 3)
       croak_xs_usage(cv,  "THIS, col, item");
    {
	int	col = (int)SvIV(ST(1))
;
	wxListItem*    item = (wxListItem *) wxPli_sv_2_object( aTHX_ ST(2), "Wx::ListItem" )
;
	wxListCtrl *    THIS = (wxListCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::ListCtrl" )
;
	bool	RETVAL;
    RETVAL = THIS->SetColumn( col, *item );
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__ListCtrl_SetColumnWidth); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ListCtrl_SetColumnWidth)
{
    dVAR; dXSARGS;
    if (items != 3)
       croak_xs_usage(cv,  "THIS, col, width");
    {
	int	col = (int)SvIV(ST(1))
;
	int	width = (int)SvIV(ST(2))
;
	wxListCtrl *    THIS = (wxListCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::ListCtrl" )
;
	bool	RETVAL;

	RETVAL = THIS->SetColumnWidth(col, width);
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__ListCtrl_SetImageList); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ListCtrl_SetImageList)
{
    dVAR; dXSARGS;
    if (items != 3)
       croak_xs_usage(cv,  "THIS, imagelist, which");
    {
	wxImageList*    imagelist = (wxImageList *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::ImageList" )
;
	int	which = (int)SvIV(ST(2))
;
	wxListCtrl *    THIS = (wxListCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::ListCtrl" )
;

	THIS->SetImageList(imagelist, which);
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__ListCtrl_SetItemCount); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ListCtrl_SetItemCount)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, count");
    {
	long	count = (long)SvIV(ST(1))
;
	wxListCtrl *    THIS = (wxListCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::ListCtrl" )
;

	THIS->SetItemCount(count);
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__ListCtrl_SetItem); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ListCtrl_SetItem)
{
    dVAR; dXSARGS;
    if (items < 1)
       croak_xs_usage(cv,  "THIS, ...");
    PERL_UNUSED_VAR(ax); /* -Wall */
    SP -= items;
    {
	wxListCtrl *    THIS = (wxListCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::ListCtrl" )
;
    BEGIN_OVERLOAD()
        MATCH_REDISP( wxPliOvl_wlci, SetItemInfo )
        MATCH_REDISP_COUNT_ALLOWMORE( wxPliOvl_n_n_s_n, SetItemString, 3 )
    END_OVERLOAD( Wx::ListCtrl::SetItem )
	PUTBACK;
	return;
    }
}


XS_EUPXS(XS_Wx__ListCtrl_SetItemInfo); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ListCtrl_SetItemInfo)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, info");
    {
	wxListItem*    info = (wxListItem *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::ListItem" )
;
	wxListCtrl *    THIS = (wxListCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::ListCtrl" )
;
	bool	RETVAL;
    RETVAL = THIS->SetItem( *info );
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__ListCtrl_SetItemString); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ListCtrl_SetItemString)
{
    dVAR; dXSARGS;
    if (items < 4 || items > 5)
       croak_xs_usage(cv,  "THIS, index, col, label, image = -1");
    {
	long	index = (long)SvIV(ST(1))
;
	int	col = (int)SvIV(ST(2))
;
	wxString	label;
	int	image;
	wxListCtrl *    THIS = (wxListCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::ListCtrl" )
;
	bool	RETVAL;

    WXSTRING_INPUT( label, wxString, ST(3) )
;

	if (items < 5)
	    image = -1;
	else {
	    image = (int)SvIV(ST(4))
;
	}
    RETVAL = THIS->SetItem( index, col, label, image );
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__ListCtrl_SetItemImage); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ListCtrl_SetItemImage)
{
    dVAR; dXSARGS;
    if (items != 4)
       croak_xs_usage(cv,  "THIS, item, image, selImage");
    {
	long	item = (long)SvIV(ST(1))
;
	int	image = (int)SvIV(ST(2))
;
	int	selImage = (int)SvIV(ST(3))
;
	wxListCtrl *    THIS = (wxListCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::ListCtrl" )
;
	bool	RETVAL;

	RETVAL = THIS->SetItemImage(item, image, selImage);
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}

#if WXPERL_W_VERSION_GE( 2, 7, 2 )
#define XSubPPtmpAAFA 1


XS_EUPXS(XS_Wx__ListCtrl_SetItemColumnImage); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ListCtrl_SetItemColumnImage)
{
    dVAR; dXSARGS;
    if (items != 4)
       croak_xs_usage(cv,  "THIS, item, column, image");
    {
	long	item = (long)SvIV(ST(1))
;
	long	column = (long)SvIV(ST(2))
;
	int	image = (int)SvIV(ST(3))
;
	wxListCtrl *    THIS = (wxListCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::ListCtrl" )
;
	bool	RETVAL;

	RETVAL = THIS->SetItemColumnImage(item, column, image);
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}

#endif

XS_EUPXS(XS_Wx__ListCtrl_SetItemPosition); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ListCtrl_SetItemPosition)
{
    dVAR; dXSARGS;
    if (items != 3)
       croak_xs_usage(cv,  "THIS, item, pos");
    {
	long	item = (long)SvIV(ST(1))
;
	wxPoint    pos = wxPli_sv_2_wxpoint( aTHX_ ST(2) )
;
	wxListCtrl *    THIS = (wxListCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::ListCtrl" )
;
	bool	RETVAL;

	RETVAL = THIS->SetItemPosition(item, pos);
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__ListCtrl_SetItemState); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ListCtrl_SetItemState)
{
    dVAR; dXSARGS;
    if (items != 4)
       croak_xs_usage(cv,  "THIS, item, state, stateMask");
    {
	long	item = (long)SvIV(ST(1))
;
	long	state = (long)SvIV(ST(2))
;
	long	stateMask = (long)SvIV(ST(3))
;
	wxListCtrl *    THIS = (wxListCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::ListCtrl" )
;
	bool	RETVAL;

	RETVAL = THIS->SetItemState(item, state, stateMask);
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__ListCtrl_SetItemText); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ListCtrl_SetItemText)
{
    dVAR; dXSARGS;
    if (items != 3)
       croak_xs_usage(cv,  "THIS, item, text");
    {
	long	item = (long)SvIV(ST(1))
;
	wxString	text;
	wxListCtrl *    THIS = (wxListCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::ListCtrl" )
;

    WXSTRING_INPUT( text, wxString, ST(2) )
;

	THIS->SetItemText(item, text);
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__ListCtrl_SetItemFont); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ListCtrl_SetItemFont)
{
    dVAR; dXSARGS;
    if (items != 3)
       croak_xs_usage(cv,  "THIS, item, font");
    {
	long	item = (long)SvIV(ST(1))
;
	wxFont*    font = (wxFont *) wxPli_sv_2_object( aTHX_ ST(2), "Wx::Font" )
;
	wxListCtrl *    THIS = (wxListCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::ListCtrl" )
;
    THIS->SetItemFont( item, *font );
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__ListCtrl_SetSingleStyle); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ListCtrl_SetSingleStyle)
{
    dVAR; dXSARGS;
    if (items < 2 || items > 3)
       croak_xs_usage(cv,  "THIS, style, add = true");
    {
	long	style = (long)SvIV(ST(1))
;
	bool	add;
	wxListCtrl *    THIS = (wxListCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::ListCtrl" )
;

	if (items < 3)
	    add = true;
	else {
	    add = (bool)SvTRUE(ST(2))
;
	}

	THIS->SetSingleStyle(style, add);
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__ListCtrl_SetTextColour); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ListCtrl_SetTextColour)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, colour");
    {
	wxColour    colour = *(wxColour *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::Colour" )
;
	wxListCtrl *    THIS = (wxListCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::ListCtrl" )
;

	THIS->SetTextColour(colour);
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__ListCtrl_SetWindowStyleFlag); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ListCtrl_SetWindowStyleFlag)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, style");
    {
	long	style = (long)SvIV(ST(1))
;
	wxListCtrl *    THIS = (wxListCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::ListCtrl" )
;

	THIS->SetWindowStyleFlag(style);
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__ListCtrl_SortItems); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ListCtrl_SortItems)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, function");
    {
	SV*	function = ST(1)
;
	wxListCtrl *    THIS = (wxListCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::ListCtrl" )
;
	bool	RETVAL;
    RETVAL = THIS->SortItems( (wxListCtrlCompare)&ListCtrlCompareFn,
                              PTR2IV( function ) );
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__ListView_new); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ListView_new)
{
    dVAR; dXSARGS;
    PERL_UNUSED_VAR(cv); /* -W */
    PERL_UNUSED_VAR(items); /* -W */
    PERL_UNUSED_VAR(ax); /* -Wall */
    SP -= items;
    {
    BEGIN_OVERLOAD()
        MATCH_VOIDM_REDISP( newDefault )
        MATCH_ANY_REDISP( newFull )
    END_OVERLOAD( "Wx::ListView::new" )
	PUTBACK;
	return;
    }
}


XS_EUPXS(XS_Wx__ListView_newDefault); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ListView_newDefault)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "CLASS");
    {
	PlClassName    CLASS = wxPli_get_class( aTHX_ ST(0) )
;
	wxListView *	RETVAL;
    RETVAL = new wxPliListView( CLASS );
    wxPli_create_evthandler( aTHX_ RETVAL, CLASS );
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_evthandler_2_sv( aTHX_ RETVALSV, RETVAL );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__ListView_newFull); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ListView_newFull)
{
    dVAR; dXSARGS;
    if (items < 2 || items > 8)
       croak_xs_usage(cv,  "CLASS, parent, id = wxID_ANY, pos = wxDefaultPosition, size = wxDefaultSize, style = wxLC_REPORT, validator = (wxValidator*)&wxDefaultValidator, name = wxListCtrlNameStr");
    {
	PlClassName    CLASS = wxPli_get_class( aTHX_ ST(0) )
;
	wxWindow*    parent = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::Window" )
;
	wxWindowID	id;
	wxPoint	pos;
	wxSize	size;
	long	style;
	wxValidator*	validator;
	wxString	name;
	wxListView *	RETVAL;

	if (items < 3)
	    id = wxID_ANY;
	else {
    id = wxPli_get_wxwindowid( aTHX_ ST(2) )
;
	}

	if (items < 4)
	    pos = wxDefaultPosition;
	else {
    pos = wxPli_sv_2_wxpoint( aTHX_ ST(3) )
;
	}

	if (items < 5)
	    size = wxDefaultSize;
	else {
    size = wxPli_sv_2_wxsize( aTHX_ ST(4) )
;
	}

	if (items < 6)
	    style = wxLC_REPORT;
	else {
	    style = (long)SvIV(ST(5))
;
	}

	if (items < 7)
	    validator = (wxValidator*)&wxDefaultValidator;
	else {
    validator = (wxValidator *) wxPli_sv_2_object( aTHX_ ST(6), "Wx::Validator" )
;
	}

	if (items < 8)
	    name = wxListCtrlNameStr;
	else {
    WXSTRING_INPUT( name, wxString, ST(7) )
;
	}
    RETVAL = new wxPliListView( CLASS, parent, id, pos, size, style,
        *validator, name );
    wxPli_create_evthandler( aTHX_ RETVAL, CLASS );
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_evthandler_2_sv( aTHX_ RETVALSV, RETVAL );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__ListView_Create); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ListView_Create)
{
    dVAR; dXSARGS;
    if (items < 2 || items > 8)
       croak_xs_usage(cv,  "THIS, parent, id = wxID_ANY, pos = wxDefaultPosition, size = wxDefaultSize, style = wxLC_REPORT, validator = (wxValidator*)&wxDefaultValidator, name = wxListCtrlNameStr");
    {
	wxWindow*    parent = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::Window" )
;
	wxWindowID	id;
	wxPoint	pos;
	wxSize	size;
	long	style;
	wxValidator*	validator;
	wxString	name;
	wxListView *    THIS = (wxListView *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::ListView" )
;
	bool	RETVAL;

	if (items < 3)
	    id = wxID_ANY;
	else {
    id = wxPli_get_wxwindowid( aTHX_ ST(2) )
;
	}

	if (items < 4)
	    pos = wxDefaultPosition;
	else {
    pos = wxPli_sv_2_wxpoint( aTHX_ ST(3) )
;
	}

	if (items < 5)
	    size = wxDefaultSize;
	else {
    size = wxPli_sv_2_wxsize( aTHX_ ST(4) )
;
	}

	if (items < 6)
	    style = wxLC_REPORT;
	else {
	    style = (long)SvIV(ST(5))
;
	}

	if (items < 7)
	    validator = (wxValidator*)&wxDefaultValidator;
	else {
    validator = (wxValidator *) wxPli_sv_2_object( aTHX_ ST(6), "Wx::Validator" )
;
	}

	if (items < 8)
	    name = wxListCtrlNameStr;
	else {
    WXSTRING_INPUT( name, wxString, ST(7) )
;
	}

	RETVAL = THIS->Create(parent, id, pos, size, style, *validator, name);
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__ListView_Select); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ListView_Select)
{
    dVAR; dXSARGS;
    if (items != 3)
       croak_xs_usage(cv,  "THIS, n, on");
    {
	long	n = (long)SvIV(ST(1))
;
	bool	on = (bool)SvTRUE(ST(2))
;
	wxListView *    THIS = (wxListView *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::ListView" )
;

	THIS->Select(n, on);
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__ListView_SetColumnImage); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ListView_SetColumnImage)
{
    dVAR; dXSARGS;
    if (items != 3)
       croak_xs_usage(cv,  "THIS, col, image");
    {
	int	col = (int)SvIV(ST(1))
;
	int	image = (int)SvIV(ST(2))
;
	wxListView *    THIS = (wxListView *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::ListView" )
;

	THIS->SetColumnImage(col, image);
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__ListView_ClearColumnImage); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ListView_ClearColumnImage)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, col");
    {
	int	col = (int)SvIV(ST(1))
;
	wxListView *    THIS = (wxListView *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::ListView" )
;

	THIS->ClearColumnImage(col);
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__ListView_Focus); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ListView_Focus)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, index");
    {
	long	index = (long)SvIV(ST(1))
;
	wxListView *    THIS = (wxListView *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::ListView" )
;

	THIS->Focus(index);
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__ListView_GetFocusedItem); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ListView_GetFocusedItem)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxListView *    THIS = (wxListView *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::ListView" )
;
	long	RETVAL;
	dXSTARG;

	RETVAL = THIS->GetFocusedItem();
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__ListView_GetFirstSelected); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ListView_GetFirstSelected)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxListView *    THIS = (wxListView *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::ListView" )
;
	long	RETVAL;
	dXSTARG;

	RETVAL = THIS->GetFirstSelected();
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__ListView_GetNextSelected); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ListView_GetNextSelected)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, item");
    {
	long	item = (long)SvIV(ST(1))
;
	wxListView *    THIS = (wxListView *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::ListView" )
;
	long	RETVAL;
	dXSTARG;

	RETVAL = THIS->GetNextSelected(item);
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__ListView_IsSelected); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ListView_IsSelected)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, index");
    {
	long	index = (long)SvIV(ST(1))
;
	wxListView *    THIS = (wxListView *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::ListView" )
;
	bool	RETVAL;

	RETVAL = THIS->IsSelected(index);
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


/* INCLUDE: Returning to 'XS/ListBox.xs' from 'XS/ListCtrl.xs' */

#include <wx/listbox.h>

XS_EUPXS(XS_Wx__ListBox_new); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ListBox_new)
{
    dVAR; dXSARGS;
    PERL_UNUSED_VAR(cv); /* -W */
    PERL_UNUSED_VAR(items); /* -W */
    PERL_UNUSED_VAR(ax); /* -Wall */
    SP -= items;
    {
    BEGIN_OVERLOAD()
        MATCH_VOIDM_REDISP( newDefault )
        MATCH_ANY_REDISP( newFull )
    END_OVERLOAD( "Wx::ListBox::new" )
	PUTBACK;
	return;
    }
}


XS_EUPXS(XS_Wx__ListBox_newDefault); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ListBox_newDefault)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "CLASS");
    {
	PlClassName    CLASS = wxPli_get_class( aTHX_ ST(0) )
;
	wxListBox *	RETVAL;
    RETVAL = new wxListBox();
    wxPli_create_evthandler( aTHX_ RETVAL, CLASS );
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_evthandler_2_sv( aTHX_ RETVALSV, RETVAL );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__ListBox_newFull); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ListBox_newFull)
{
    dVAR; dXSARGS;
    if (items < 2 || items > 9)
       croak_xs_usage(cv,  "CLASS, parent, id = wxID_ANY, pos = wxDefaultPosition, size = wxDefaultSize, choices = 0, style = 0, validator = (wxValidator*)&wxDefaultValidator, name = wxListBoxNameStr");
    {
	PlClassName    CLASS = wxPli_get_class( aTHX_ ST(0) )
;
	wxWindow*    parent = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::Window" )
;
	wxWindowID	id;
	wxPoint	pos;
	wxSize	size;
	SV*	choices;
	long	style;
	wxValidator*	validator;
	wxString	name;
    wxString* chs;
    int n;
	wxListBox *	RETVAL;

	if (items < 3)
	    id = wxID_ANY;
	else {
    id = wxPli_get_wxwindowid( aTHX_ ST(2) )
;
	}

	if (items < 4)
	    pos = wxDefaultPosition;
	else {
    pos = wxPli_sv_2_wxpoint( aTHX_ ST(3) )
;
	}

	if (items < 5)
	    size = wxDefaultSize;
	else {
    size = wxPli_sv_2_wxsize( aTHX_ ST(4) )
;
	}

	if (items < 6)
	    choices = 0;
	else {
	    choices = ST(5)
;
	}

	if (items < 7)
	    style = 0;
	else {
	    style = (long)SvIV(ST(6))
;
	}

	if (items < 8)
	    validator = (wxValidator*)&wxDefaultValidator;
	else {
    validator = (wxValidator *) wxPli_sv_2_object( aTHX_ ST(7), "Wx::Validator" )
;
	}

	if (items < 9)
	    name = wxListBoxNameStr;
	else {
    WXSTRING_INPUT( name, wxString, ST(8) )
;
	}
    if( choices ) 
        n = wxPli_av_2_stringarray( aTHX_ choices, &chs );
    else
    {
        n = 0;
        chs = 0;
    }

    RETVAL = new wxListBox( parent, id, pos, size, n, chs, 
        style, *validator, name );
    wxPli_create_evthandler( aTHX_ RETVAL, CLASS );

    delete[] chs;
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_evthandler_2_sv( aTHX_ RETVALSV, RETVAL );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__ListBox_Create); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ListBox_Create)
{
    dVAR; dXSARGS;
    if (items < 2 || items > 9)
       croak_xs_usage(cv,  "THIS, parent, id = wxID_ANY, pos = wxDefaultPosition, size = wxDefaultSize, choices = 0, style = 0, validator = (wxValidator*)&wxDefaultValidator, name = wxListBoxNameStr");
    {
	wxWindow*    parent = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::Window" )
;
	wxWindowID	id;
	wxPoint	pos;
	wxSize	size;
	SV*	choices;
	long	style;
	wxValidator*	validator;
	wxString	name;
    wxString* chs;
    int n;
	wxListBox *    THIS = (wxListBox *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::ListBox" )
;
	bool	RETVAL;

	if (items < 3)
	    id = wxID_ANY;
	else {
    id = wxPli_get_wxwindowid( aTHX_ ST(2) )
;
	}

	if (items < 4)
	    pos = wxDefaultPosition;
	else {
    pos = wxPli_sv_2_wxpoint( aTHX_ ST(3) )
;
	}

	if (items < 5)
	    size = wxDefaultSize;
	else {
    size = wxPli_sv_2_wxsize( aTHX_ ST(4) )
;
	}

	if (items < 6)
	    choices = 0;
	else {
	    choices = ST(5)
;
	}

	if (items < 7)
	    style = 0;
	else {
	    style = (long)SvIV(ST(6))
;
	}

	if (items < 8)
	    validator = (wxValidator*)&wxDefaultValidator;
	else {
    validator = (wxValidator *) wxPli_sv_2_object( aTHX_ ST(7), "Wx::Validator" )
;
	}

	if (items < 9)
	    name = wxListBoxNameStr;
	else {
    WXSTRING_INPUT( name, wxString, ST(8) )
;
	}
    if( choices ) 
        n = wxPli_av_2_stringarray( aTHX_ choices, &chs );
    else
    {
        n = 0;
        chs = 0;
    }

    RETVAL = THIS->Create( parent, id, pos, size, n, chs, 
        style, *validator, name );

    delete[] chs;
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__ListBox_Deselect); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ListBox_Deselect)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, n");
    {
	int	n = (int)SvIV(ST(1))
;
	wxListBox *    THIS = (wxListBox *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::ListBox" )
;

	THIS->Deselect(n);
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__ListBox_GetSelections); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ListBox_GetSelections)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    PERL_UNUSED_VAR(ax); /* -Wall */
    SP -= items;
    {
    wxArrayInt selections;
	wxListBox *    THIS = (wxListBox *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::ListBox" )
;
    THIS->GetSelections( selections );
    PUTBACK;
    wxPli_intarray_push( aTHX_ selections );
    SPAGAIN;
	PUTBACK;
	return;
    }
}


XS_EUPXS(XS_Wx__ListBox_HitTest); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ListBox_HitTest)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, point");
    {
	wxPoint    point = wxPli_sv_2_wxpoint( aTHX_ ST(1) )
;
	wxListBox *    THIS = (wxListBox *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::ListBox" )
;
	int	RETVAL;
	dXSTARG;

	RETVAL = THIS->HitTest(point);
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}

#if WXPERL_W_VERSION_LT( 2, 9, 0 )
#define XSubPPtmpAAFB 1


XS_EUPXS(XS_Wx__ListBox_InsertItems); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ListBox_InsertItems)
{
    dVAR; dXSARGS;
    if (items != 3)
       croak_xs_usage(cv,  "THIS, items, pos");
    {
	wxArrayString	items;
	int	pos = (int)SvIV(ST(2))
;
	wxListBox *    THIS = (wxListBox *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::ListBox" )
;

    wxPli_av_2_arraystring( aTHX_ ST(1), & items )
;

	THIS->InsertItems(items, pos);
    }
    XSRETURN_EMPTY;
}

#endif

XS_EUPXS(XS_Wx__ListBox_IsSelected); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ListBox_IsSelected)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, n");
    {
	int	n = (int)SvIV(ST(1))
;
	wxListBox *    THIS = (wxListBox *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::ListBox" )
;
	bool	RETVAL;

	RETVAL = THIS->IsSelected(n);
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__ListBox_SetSelection); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ListBox_SetSelection)
{
    dVAR; dXSARGS;
    if (items < 2 || items > 3)
       croak_xs_usage(cv,  "THIS, n, select = true");
    {
	int	n = (int)SvIV(ST(1))
;
	bool	select;
	wxListBox *    THIS = (wxListBox *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::ListBox" )
;

	if (items < 3)
	    select = true;
	else {
	    select = (bool)SvTRUE(ST(2))
;
	}

	THIS->SetSelection(n, select);
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__ListBox_SetStringSelection); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ListBox_SetStringSelection)
{
    dVAR; dXSARGS;
    if (items < 2 || items > 3)
       croak_xs_usage(cv,  "THIS, string, select = true");
    {
	wxString	string;
	bool	select;
	wxListBox *    THIS = (wxListBox *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::ListBox" )
;

    WXSTRING_INPUT( string, wxString, ST(1) )
;

	if (items < 3)
	    select = true;
	else {
	    select = (bool)SvTRUE(ST(2))
;
	}

	THIS->SetStringSelection(string, select);
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__ListBox_SetFirstItem); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ListBox_SetFirstItem)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, n");
    {
	int	n = (int)SvIV(ST(1))
;
	wxListBox *    THIS = (wxListBox *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::ListBox" )
;

	THIS->SetFirstItem(n);
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__ListBox_SetFirstItemString); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ListBox_SetFirstItemString)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, str");
    {
	wxString	str;
	wxListBox *    THIS = (wxListBox *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::ListBox" )
;

    WXSTRING_INPUT( str, wxString, ST(1) )
;
    THIS->SetFirstItem( str );
    }
    XSRETURN_EMPTY;
}

#if WXPERL_W_VERSION_LT( 2, 9, 0 )
#define XSubPPtmpAAFC 1


XS_EUPXS(XS_Wx__ListBox_Set); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ListBox_Set)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, choices");
    {
	wxArrayString	choices;
	wxListBox *    THIS = (wxListBox *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::ListBox" )
;

    wxPli_av_2_arraystring( aTHX_ ST(1), & choices )
;

	THIS->Set(choices);
    }
    XSRETURN_EMPTY;
}

#endif

/* INCLUDE: Returning to 'XS/Gauge.xs' from 'XS/ListBox.xs' */

#include <wx/gauge.h>

XS_EUPXS(XS_Wx__Gauge_new); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Gauge_new)
{
    dVAR; dXSARGS;
    PERL_UNUSED_VAR(cv); /* -W */
    PERL_UNUSED_VAR(items); /* -W */
    PERL_UNUSED_VAR(ax); /* -Wall */
    SP -= items;
    {
    BEGIN_OVERLOAD()
        MATCH_VOIDM_REDISP( newDefault )
        MATCH_ANY_REDISP( newFull )
    END_OVERLOAD( "Wx::Gauge::new" )
	PUTBACK;
	return;
    }
}


XS_EUPXS(XS_Wx__Gauge_newDefault); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Gauge_newDefault)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "CLASS");
    {
	PlClassName    CLASS = wxPli_get_class( aTHX_ ST(0) )
;
	wxGauge *	RETVAL;
    RETVAL = new wxGauge();
    wxPli_create_evthandler( aTHX_ RETVAL, CLASS );
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_evthandler_2_sv( aTHX_ RETVALSV, RETVAL );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__Gauge_newFull); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Gauge_newFull)
{
    dVAR; dXSARGS;
    if (items < 4 || items > 9)
       croak_xs_usage(cv,  "CLASS, parent, id, range, pos = wxDefaultPosition, size = wxDefaultSize, style = wxGA_HORIZONTAL, validator = (wxValidator*)&wxDefaultValidator, name = wxGaugeNameStr");
    {
	PlClassName    CLASS = wxPli_get_class( aTHX_ ST(0) )
;
	wxWindow*    parent = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::Window" )
;
	wxWindowID    id = wxPli_get_wxwindowid( aTHX_ ST(2) )
;
	int	range = (int)SvIV(ST(3))
;
	wxPoint	pos;
	wxSize	size;
	long	style;
	wxValidator*	validator;
	wxString	name;
	wxGauge *	RETVAL;

	if (items < 5)
	    pos = wxDefaultPosition;
	else {
    pos = wxPli_sv_2_wxpoint( aTHX_ ST(4) )
;
	}

	if (items < 6)
	    size = wxDefaultSize;
	else {
    size = wxPli_sv_2_wxsize( aTHX_ ST(5) )
;
	}

	if (items < 7)
	    style = wxGA_HORIZONTAL;
	else {
	    style = (long)SvIV(ST(6))
;
	}

	if (items < 8)
	    validator = (wxValidator*)&wxDefaultValidator;
	else {
    validator = (wxValidator *) wxPli_sv_2_object( aTHX_ ST(7), "Wx::Validator" )
;
	}

	if (items < 9)
	    name = wxGaugeNameStr;
	else {
    WXSTRING_INPUT( name, wxString, ST(8) )
;
	}
    RETVAL = new wxGauge( parent, id, range, pos, size,
        style, *validator, name );
    wxPli_create_evthandler( aTHX_ RETVAL, CLASS );
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_evthandler_2_sv( aTHX_ RETVALSV, RETVAL );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__Gauge_Create); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Gauge_Create)
{
    dVAR; dXSARGS;
    if (items < 4 || items > 9)
       croak_xs_usage(cv,  "THIS, parent, id, range, pos = wxDefaultPosition, size = wxDefaultSize, style = wxGA_HORIZONTAL, validator = (wxValidator*)&wxDefaultValidator, name = wxGaugeNameStr");
    {
	wxWindow*    parent = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::Window" )
;
	wxWindowID    id = wxPli_get_wxwindowid( aTHX_ ST(2) )
;
	int	range = (int)SvIV(ST(3))
;
	wxPoint	pos;
	wxSize	size;
	long	style;
	wxValidator*	validator;
	wxString	name;
	wxGauge *    THIS = (wxGauge *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Gauge" )
;
	bool	RETVAL;

	if (items < 5)
	    pos = wxDefaultPosition;
	else {
    pos = wxPli_sv_2_wxpoint( aTHX_ ST(4) )
;
	}

	if (items < 6)
	    size = wxDefaultSize;
	else {
    size = wxPli_sv_2_wxsize( aTHX_ ST(5) )
;
	}

	if (items < 7)
	    style = wxGA_HORIZONTAL;
	else {
	    style = (long)SvIV(ST(6))
;
	}

	if (items < 8)
	    validator = (wxValidator*)&wxDefaultValidator;
	else {
    validator = (wxValidator *) wxPli_sv_2_object( aTHX_ ST(7), "Wx::Validator" )
;
	}

	if (items < 9)
	    name = wxGaugeNameStr;
	else {
    WXSTRING_INPUT( name, wxString, ST(8) )
;
	}

	RETVAL = THIS->Create(parent, id, range, pos, size, style, *validator, name);
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}

#if defined( __WXMSW__ ) || defined( __WXPERL_FORCE__ )
#define XSubPPtmpAAFD 1


XS_EUPXS(XS_Wx__Gauge_GetBezelFace); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Gauge_GetBezelFace)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxGauge *    THIS = (wxGauge *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Gauge" )
;
	int	RETVAL;
	dXSTARG;

	RETVAL = THIS->GetBezelFace();
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}

#endif

XS_EUPXS(XS_Wx__Gauge_GetRange); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Gauge_GetRange)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxGauge *    THIS = (wxGauge *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Gauge" )
;
	int	RETVAL;
	dXSTARG;

	RETVAL = THIS->GetRange();
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}

#if defined( __WXMSW__ ) || defined( __WXPERL_FORCE__ )
#define XSubPPtmpAAFE 1


XS_EUPXS(XS_Wx__Gauge_GetShadowWidth); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Gauge_GetShadowWidth)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxGauge *    THIS = (wxGauge *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Gauge" )
;
	int	RETVAL;
	dXSTARG;

	RETVAL = THIS->GetShadowWidth();
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}

#endif

XS_EUPXS(XS_Wx__Gauge_GetValue); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Gauge_GetValue)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxGauge *    THIS = (wxGauge *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Gauge" )
;
	int	RETVAL;
	dXSTARG;

	RETVAL = THIS->GetValue();
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}

#if defined( __WXMSW__ ) || defined( __WXPERL_FORCE__ )
#define XSubPPtmpAAFF 1


XS_EUPXS(XS_Wx__Gauge_SetBezelFace); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Gauge_SetBezelFace)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, width");
    {
	int	width = (int)SvIV(ST(1))
;
	wxGauge *    THIS = (wxGauge *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Gauge" )
;

	THIS->SetBezelFace(width);
    }
    XSRETURN_EMPTY;
}

#endif

XS_EUPXS(XS_Wx__Gauge_SetRange); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Gauge_SetRange)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, range");
    {
	int	range = (int)SvIV(ST(1))
;
	wxGauge *    THIS = (wxGauge *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Gauge" )
;

	THIS->SetRange(range);
    }
    XSRETURN_EMPTY;
}

#if defined( __WXMSW__ ) || defined( __WXPERL_FORCE__ )
#define XSubPPtmpAAFG 1


XS_EUPXS(XS_Wx__Gauge_SetShadowWidth); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Gauge_SetShadowWidth)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, width");
    {
	int	width = (int)SvIV(ST(1))
;
	wxGauge *    THIS = (wxGauge *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Gauge" )
;

	THIS->SetShadowWidth(width);
    }
    XSRETURN_EMPTY;
}

#endif

XS_EUPXS(XS_Wx__Gauge_SetValue); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Gauge_SetValue)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, pos");
    {
	int	pos = (int)SvIV(ST(1))
;
	wxGauge *    THIS = (wxGauge *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Gauge" )
;

	THIS->SetValue(pos);
    }
    XSRETURN_EMPTY;
}

#if WXPERL_W_VERSION_GE( 2, 5, 1 )
#define XSubPPtmpAAFH 1


XS_EUPXS(XS_Wx__Gauge_IsVertical); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Gauge_IsVertical)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxGauge *    THIS = (wxGauge *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Gauge" )
;
	bool	RETVAL;

	RETVAL = THIS->IsVertical();
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}

#endif
#if WXPERL_W_VERSION_GE( 2, 7, 1 )
#define XSubPPtmpAAFI 1


XS_EUPXS(XS_Wx__Gauge_Pulse); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Gauge_Pulse)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxGauge *    THIS = (wxGauge *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Gauge" )
;

	THIS->Pulse();
    }
    XSRETURN_EMPTY;
}

#endif

/* INCLUDE: Returning to 'XS/ComboBox.xs' from 'XS/Gauge.xs' */

#include <wx/combobox.h>
#include <wx/textctrl.h>
#include "cpp/overload.h"

XS_EUPXS(XS_Wx__ComboBox_new); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ComboBox_new)
{
    dVAR; dXSARGS;
    PERL_UNUSED_VAR(cv); /* -W */
    PERL_UNUSED_VAR(items); /* -W */
    PERL_UNUSED_VAR(ax); /* -Wall */
    SP -= items;
    {
    BEGIN_OVERLOAD()
        MATCH_VOIDM_REDISP( newDefault )
        MATCH_ANY_REDISP( newFull )
    END_OVERLOAD( "Wx::ComboBox::new" )
	PUTBACK;
	return;
    }
}


XS_EUPXS(XS_Wx__ComboBox_newDefault); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ComboBox_newDefault)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "CLASS");
    {
	PlClassName    CLASS = wxPli_get_class( aTHX_ ST(0) )
;
	wxComboBox *	RETVAL;
    RETVAL = new wxComboBox();
    wxPli_create_evthandler( aTHX_ RETVAL, CLASS );
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_evthandler_2_sv( aTHX_ RETVALSV, RETVAL );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__ComboBox_newFull); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ComboBox_newFull)
{
    dVAR; dXSARGS;
    if (items < 2 || items > 10)
       croak_xs_usage(cv,  "CLASS, parent, id = wxID_ANY, value = wxEmptyString, pos = wxDefaultPosition, size = wxDefaultSize, choices = 0, style = 0, validator = (wxValidator*)&wxDefaultValidator, name = wxComboBoxNameStr");
    {
	PlClassName    CLASS = wxPli_get_class( aTHX_ ST(0) )
;
	wxWindow*    parent = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::Window" )
;
	wxWindowID	id;
	wxString	value;
	wxPoint	pos;
	wxSize	size;
	SV*	choices;
	long	style;
	wxValidator*	validator;
	wxString	name;
    wxString* chs = 0;
    int n = 0;
	wxComboBox *	RETVAL;

	if (items < 3)
	    id = wxID_ANY;
	else {
    id = wxPli_get_wxwindowid( aTHX_ ST(2) )
;
	}

	if (items < 4)
	    value = wxEmptyString;
	else {
    WXSTRING_INPUT( value, wxString, ST(3) )
;
	}

	if (items < 5)
	    pos = wxDefaultPosition;
	else {
    pos = wxPli_sv_2_wxpoint( aTHX_ ST(4) )
;
	}

	if (items < 6)
	    size = wxDefaultSize;
	else {
    size = wxPli_sv_2_wxsize( aTHX_ ST(5) )
;
	}

	if (items < 7)
	    choices = 0;
	else {
	    choices = ST(6)
;
	}

	if (items < 8)
	    style = 0;
	else {
	    style = (long)SvIV(ST(7))
;
	}

	if (items < 9)
	    validator = (wxValidator*)&wxDefaultValidator;
	else {
    validator = (wxValidator *) wxPli_sv_2_object( aTHX_ ST(8), "Wx::Validator" )
;
	}

	if (items < 10)
	    name = wxComboBoxNameStr;
	else {
    WXSTRING_INPUT( name, wxString, ST(9) )
;
	}
    if( choices != 0 )
        n = wxPli_av_2_stringarray( aTHX_ choices, &chs );
    RETVAL = new wxComboBox( parent, id, value, pos, size, n, chs, 
        style, *validator, name );
    wxPli_create_evthandler( aTHX_ RETVAL, CLASS );

    delete[] chs;
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_evthandler_2_sv( aTHX_ RETVALSV, RETVAL );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__ComboBox_Create); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ComboBox_Create)
{
    dVAR; dXSARGS;
    if (items < 2 || items > 10)
       croak_xs_usage(cv,  "THIS, parent, id = wxID_ANY, value = wxEmptyString, pos = wxDefaultPosition, size = wxDefaultSize, choices = 0, style = 0, validator = (wxValidator*)&wxDefaultValidator, name = wxComboBoxNameStr");
    {
	wxWindow*    parent = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::Window" )
;
	wxWindowID	id;
	wxString	value;
	wxPoint	pos;
	wxSize	size;
	SV*	choices;
	long	style;
	wxValidator*	validator;
	wxString	name;
    wxString* chs = 0;
    int n = 0;
	wxComboBox *    THIS = (wxComboBox *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::ComboBox" )
;
	bool	RETVAL;

	if (items < 3)
	    id = wxID_ANY;
	else {
    id = wxPli_get_wxwindowid( aTHX_ ST(2) )
;
	}

	if (items < 4)
	    value = wxEmptyString;
	else {
    WXSTRING_INPUT( value, wxString, ST(3) )
;
	}

	if (items < 5)
	    pos = wxDefaultPosition;
	else {
    pos = wxPli_sv_2_wxpoint( aTHX_ ST(4) )
;
	}

	if (items < 6)
	    size = wxDefaultSize;
	else {
    size = wxPli_sv_2_wxsize( aTHX_ ST(5) )
;
	}

	if (items < 7)
	    choices = 0;
	else {
	    choices = ST(6)
;
	}

	if (items < 8)
	    style = 0;
	else {
	    style = (long)SvIV(ST(7))
;
	}

	if (items < 9)
	    validator = (wxValidator*)&wxDefaultValidator;
	else {
    validator = (wxValidator *) wxPli_sv_2_object( aTHX_ ST(8), "Wx::Validator" )
;
	}

	if (items < 10)
	    name = wxComboBoxNameStr;
	else {
    WXSTRING_INPUT( name, wxString, ST(9) )
;
	}
    if( choices != 0 )
        n = wxPli_av_2_stringarray( aTHX_ choices, &chs );
    RETVAL = THIS->Create( parent, id, value, pos, size, n, chs, 
        style, *validator, name );

    delete[] chs;
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}

#if defined( __WXMAC__ ) || ( defined( __WXGTK__ ) && WXPERL_W_VERSION_LT( 2, 9, 0 ) )
#define WXPERL_IN_COMBOBOX
#define XSubPPtmpAAFJ 1


/* INCLUDE_COMMAND:  Including output of '/usr/bin/perl -pe "s/ItemContainerImmutable/ComboBox/g" XS/ItemContainerImmutable.xs' from 'XS/ComboBox.xs' */

#include <exception>

#undef  xsp_constructor_class
#define xsp_constructor_class(c) (c)

XS_EUPXS(XS_Wx__ComboBox_GetCount); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ComboBox_GetCount)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxComboBox *    THIS = (wxComboBox *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::ComboBox" )
;
	unsigned int	RETVAL;
	dXSTARG;
    try {
      RETVAL = THIS->GetCount();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	XSprePUSH;
	PUSHu((UV)RETVAL );
    }
    XSRETURN(1);
}

#if !defined(WXPERL_IN_COMBOBOX) || WXPERL_W_VERSION_LE( 2, 9, 2 )
#define XSpp_f9ce292b_043796
#define XSubPPtmpAAFK 1


XS_EUPXS(XS_Wx__ComboBox_IsEmpty); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ComboBox_IsEmpty)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxComboBox *    THIS = (wxComboBox *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::ComboBox" )
;
	bool	RETVAL;
    try {
      RETVAL = THIS->IsEmpty();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}

#endif

XS_EUPXS(XS_Wx__ComboBox_GetString); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ComboBox_GetString)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, n");
    {
	wxComboBox *    THIS = (wxComboBox *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::ComboBox" )
;
	wxString	RETVAL;
	unsigned int    n = (unsigned int)SvUV( ST(1) )
;
    try {
      RETVAL = THIS->GetString( n );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    WXSTRING_OUTPUT( RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__ComboBox_GetStrings); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ComboBox_GetStrings)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    PERL_UNUSED_VAR(ax); /* -Wall */
    SP -= items;
    {
	wxComboBox *    THIS = (wxComboBox *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::ComboBox" )
;
    PUTBACK;
    wxPli_stringarray_push( aTHX_ THIS->GetStrings() );
    SPAGAIN;
	PUTBACK;
	return;
    }
}


XS_EUPXS(XS_Wx__ComboBox_SetString); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ComboBox_SetString)
{
    dVAR; dXSARGS;
    if (items != 3)
       croak_xs_usage(cv,  "THIS, n, s");
    {
	wxComboBox *    THIS = (wxComboBox *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::ComboBox" )
;
	unsigned int    n = (unsigned int)SvUV( ST(1) )
;
	wxString	s;

    WXSTRING_INPUT( s, wxString, ST(2) )
;
    try {
      THIS->SetString( n, s );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__ComboBox_FindString); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ComboBox_FindString)
{
    dVAR; dXSARGS;
    if (items < 1)
       croak_xs_usage(cv,  "THIS, ...");
    PERL_UNUSED_VAR(ax); /* -Wall */
    SP -= items;
    {
	wxComboBox *    THIS = (wxComboBox *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::ComboBox" )
;
	int	RETVAL;
	dXSTARG;
    BEGIN_OVERLOAD()
#if WXPERL_W_VERSION_GE( 2, 7, 2 )
        MATCH_REDISP( wxPliOvl_s_b, FindStringCase )
#endif
        MATCH_REDISP( wxPliOvl_s, FindStringNoCase )
    END_OVERLOAD( Wx::ComboBox::FindString )
	PUTBACK;
	return;
    }
}


XS_EUPXS(XS_Wx__ComboBox_FindStringNoCase); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ComboBox_FindStringNoCase)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, s");
    {
	wxComboBox *    THIS = (wxComboBox *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::ComboBox" )
;
	int	RETVAL;
	dXSTARG;
	wxString	s;

    WXSTRING_INPUT( s, wxString, ST(1) )
;
    try {
      RETVAL = THIS->FindString( s );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}

#if WXPERL_W_VERSION_GE( 2, 7, 2 )
#define XSpp_f9ce292b_037748
#define XSubPPtmpAAFL 1


XS_EUPXS(XS_Wx__ComboBox_FindStringCase); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ComboBox_FindStringCase)
{
    dVAR; dXSARGS;
    if (items < 2 || items > 3)
       croak_xs_usage(cv,  "THIS, s, bCase= false");
    {
	wxComboBox *    THIS = (wxComboBox *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::ComboBox" )
;
	int	RETVAL;
	dXSTARG;
	wxString	s;
	bool	bCase;

    WXSTRING_INPUT( s, wxString, ST(1) )
;

	if (items < 3)
	    bCase = false;
	else {
	    bCase = (bool)SvTRUE(ST(2))
;
	}
    try {
      RETVAL = THIS->FindString( s, bCase );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}

#endif
#if !defined(WXPERL_IN_COMBOBOX)
#define XSpp_f9ce292b_078389
#define XSubPPtmpAAFM 1


XS_EUPXS(XS_Wx__ComboBox_SetSelection); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ComboBox_SetSelection)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, n");
    {
	wxComboBox *    THIS = (wxComboBox *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::ComboBox" )
;
	int	n = (int)SvIV(ST(1))
;
    try {
      THIS->SetSelection( n );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__ComboBox_GetSelection); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ComboBox_GetSelection)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxComboBox *    THIS = (wxComboBox *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::ComboBox" )
;
	int	RETVAL;
	dXSTARG;
    try {
      RETVAL = THIS->GetSelection();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}

#endif

XS_EUPXS(XS_Wx__ComboBox_SetStringSelection); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ComboBox_SetStringSelection)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, s");
    {
	wxComboBox *    THIS = (wxComboBox *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::ComboBox" )
;
	bool	RETVAL;
	wxString	s;

    WXSTRING_INPUT( s, wxString, ST(1) )
;
    try {
      RETVAL = THIS->SetStringSelection( s );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__ComboBox_GetStringSelection); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ComboBox_GetStringSelection)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxComboBox *    THIS = (wxComboBox *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::ComboBox" )
;
	wxString	RETVAL;
    try {
      RETVAL = THIS->GetStringSelection();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    WXSTRING_OUTPUT( RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__ComboBox_Select); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ComboBox_Select)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, n");
    {
	wxComboBox *    THIS = (wxComboBox *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::ComboBox" )
;
	int	n = (int)SvIV(ST(1))
;
    try {
      THIS->Select( n );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


/* INCLUDE: Returning to 'XS/ComboBox.xs' from '/usr/bin/perl -pe "s/ItemContainerImmutable/ComboBox/g" XS/ItemContainerImmutable.xs' */


/* INCLUDE_COMMAND:  Including output of '/usr/bin/perl -pe "s/ItemContainer/ComboBox/g;s/->(?=[SG]etClientObject)/->wxItemContainer::/" XS/ItemContainer.xs' from 'XS/ComboBox.xs' */

#include <exception>

#undef  xsp_constructor_class
#define xsp_constructor_class(c) (c)

XS_EUPXS(XS_Wx__ComboBox_Append); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ComboBox_Append)
{
    dVAR; dXSARGS;
    if (items < 1)
       croak_xs_usage(cv,  "THIS, ...");
    PERL_UNUSED_VAR(ax); /* -Wall */
    SP -= items;
    {
	wxComboBox *    THIS = (wxComboBox *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::ComboBox" )
;
    BEGIN_OVERLOAD()
        MATCH_REDISP( wxPliOvl_arr_arr, AppendItemsData )
        MATCH_REDISP( wxPliOvl_arr, AppendItems )
        MATCH_REDISP( wxPliOvl_s_s, AppendData )
        MATCH_REDISP( wxPliOvl_s, AppendString )
    END_OVERLOAD( Wx::ComboBox::Append )
	PUTBACK;
	return;
    }
}


XS_EUPXS(XS_Wx__ComboBox_AppendString); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ComboBox_AppendString)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, item");
    {
	wxComboBox *    THIS = (wxComboBox *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::ComboBox" )
;
	wxString	item;

    WXSTRING_INPUT( item, wxString, ST(1) )
;
    try {
      THIS->Append( item );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__ComboBox_AppendData); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ComboBox_AppendData)
{
    dVAR; dXSARGS;
    if (items != 3)
       croak_xs_usage(cv,  "THIS, item, data");
    {
	wxComboBox *    THIS = (wxComboBox *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::ComboBox" )
;
	wxString	item;
	wxPliUserDataCD*	data;

    WXSTRING_INPUT( item, wxString, ST(1) )
;

    if( SvOK( ST(2) ) )
    {
        data = new wxPliUserDataCD( ST(2) );
    }
    else
        data = 0
;
    try {
      THIS->Append( item, data );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__ComboBox_AppendItems); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ComboBox_AppendItems)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, items");
    {
	wxComboBox *    THIS = (wxComboBox *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::ComboBox" )
;
	wxArrayString	items;

    wxPli_av_2_arraystring( aTHX_ ST(1), & items )
;
    try {
      THIS->Append( items );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}

#if WXPERL_W_VERSION_GE( 2, 9, 0 )
#define XSpp_a2ea7434_096891
#define XSubPPtmpAAFN 1


XS_EUPXS(XS_Wx__ComboBox_AppendItemsData); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ComboBox_AppendItemsData)
{
    dVAR; dXSARGS;
    if (items != 3)
       croak_xs_usage(cv,  "THIS, items, data");
    {
	wxComboBox *    THIS = (wxComboBox *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::ComboBox" )
;
	wxArrayString	items;
	wxPliUserDataCD**	data;

    wxPli_av_2_arraystring( aTHX_ ST(1), & items )
;

    wxPli_av_2_userdatacdarray( aTHX_ ST(2), & data );
    wxPliArrayGuard<wxPliUserDataCD*> guard_data = data
;
     THIS->Append( items, (wxClientData**)data ); 
    }
    XSRETURN_EMPTY;
}

#endif

XS_EUPXS(XS_Wx__ComboBox_Insert); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ComboBox_Insert)
{
    dVAR; dXSARGS;
    if (items < 1)
       croak_xs_usage(cv,  "THIS, ...");
    PERL_UNUSED_VAR(ax); /* -Wall */
    SP -= items;
    {
	wxComboBox *    THIS = (wxComboBox *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::ComboBox" )
;
    BEGIN_OVERLOAD()
        MATCH_REDISP( wxPliOvl_arr_n_arr, InsertItemsData )
        MATCH_REDISP( wxPliOvl_arr_n, InsertItems )
        MATCH_REDISP( wxPliOvl_s_n_s, InsertData )
        MATCH_REDISP( wxPliOvl_s_n, InsertString )
    END_OVERLOAD( Wx::ComboBox::Insert )
	PUTBACK;
	return;
    }
}


XS_EUPXS(XS_Wx__ComboBox_InsertString); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ComboBox_InsertString)
{
    dVAR; dXSARGS;
    if (items != 3)
       croak_xs_usage(cv,  "THIS, item, pos");
    {
	wxComboBox *    THIS = (wxComboBox *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::ComboBox" )
;
	wxString	item;
	unsigned int    pos = (unsigned int)SvUV( ST(2) )
;

    WXSTRING_INPUT( item, wxString, ST(1) )
;
    try {
      THIS->Insert( item, pos );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__ComboBox_InsertData); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ComboBox_InsertData)
{
    dVAR; dXSARGS;
    if (items != 4)
       croak_xs_usage(cv,  "THIS, item, pos, data");
    {
	wxComboBox *    THIS = (wxComboBox *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::ComboBox" )
;
	wxString	item;
	unsigned int    pos = (unsigned int)SvUV( ST(2) )
;
	wxPliUserDataCD*	data;

    WXSTRING_INPUT( item, wxString, ST(1) )
;

    if( SvOK( ST(3) ) )
    {
        data = new wxPliUserDataCD( ST(3) );
    }
    else
        data = 0
;
    try {
      THIS->Insert( item, pos, data );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}

#if WXPERL_W_VERSION_GE( 2, 9, 0 )
#define XSpp_a2ea7434_055796
#define XSubPPtmpAAFO 1


XS_EUPXS(XS_Wx__ComboBox_InsertItems); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ComboBox_InsertItems)
{
    dVAR; dXSARGS;
    if (items != 3)
       croak_xs_usage(cv,  "THIS, items, pos");
    {
	wxComboBox *    THIS = (wxComboBox *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::ComboBox" )
;
	wxArrayString	items;
	unsigned int    pos = (unsigned int)SvUV( ST(2) )
;

    wxPli_av_2_arraystring( aTHX_ ST(1), & items )
;
    try {
      THIS->Insert( items, pos );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__ComboBox_InsertItemsData); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ComboBox_InsertItemsData)
{
    dVAR; dXSARGS;
    if (items != 4)
       croak_xs_usage(cv,  "THIS, items, pos, data");
    {
	wxComboBox *    THIS = (wxComboBox *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::ComboBox" )
;
	wxArrayString	items;
	unsigned int    pos = (unsigned int)SvUV( ST(2) )
;
	wxPliUserDataCD**	data;

    wxPli_av_2_arraystring( aTHX_ ST(1), & items )
;

    wxPli_av_2_userdatacdarray( aTHX_ ST(3), & data );
    wxPliArrayGuard<wxPliUserDataCD*> guard_data = data
;
     THIS->Insert( items, pos, (wxClientData**)data ); 
    }
    XSRETURN_EMPTY;
}

#endif
#if WXPERL_W_VERSION_GE( 2, 9, 0 )
#define XSpp_a2ea7434_019830
#define XSubPPtmpAAFP 1


XS_EUPXS(XS_Wx__ComboBox_Set); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ComboBox_Set)
{
    dVAR; dXSARGS;
    if (items < 1)
       croak_xs_usage(cv,  "THIS, ...");
    PERL_UNUSED_VAR(ax); /* -Wall */
    SP -= items;
    {
	wxComboBox *    THIS = (wxComboBox *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::ComboBox" )
;
    BEGIN_OVERLOAD()
        MATCH_REDISP( wxPliOvl_arr_arr, SetItemsData )
        MATCH_REDISP( wxPliOvl_arr, SetItems )
    END_OVERLOAD( Wx::ComboBox::Set )
	PUTBACK;
	return;
    }
}


XS_EUPXS(XS_Wx__ComboBox_SetItems); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ComboBox_SetItems)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, items");
    {
	wxComboBox *    THIS = (wxComboBox *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::ComboBox" )
;
	wxArrayString	items;

    wxPli_av_2_arraystring( aTHX_ ST(1), & items )
;
    try {
      THIS->Set( items );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__ComboBox_SetItemsData); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ComboBox_SetItemsData)
{
    dVAR; dXSARGS;
    if (items != 3)
       croak_xs_usage(cv,  "THIS, items, data");
    {
	wxComboBox *    THIS = (wxComboBox *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::ComboBox" )
;
	wxArrayString	items;
	wxPliUserDataCD**	data;

    wxPli_av_2_arraystring( aTHX_ ST(1), & items )
;

    wxPli_av_2_userdatacdarray( aTHX_ ST(2), & data );
    wxPliArrayGuard<wxPliUserDataCD*> guard_data = data
;
     THIS->Set( items, (wxClientData**)data ); 
    }
    XSRETURN_EMPTY;
}

#endif

XS_EUPXS(XS_Wx__ComboBox_Clear); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ComboBox_Clear)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxComboBox *    THIS = (wxComboBox *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::ComboBox" )
;
    try {
      THIS->Clear();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__ComboBox_Delete); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ComboBox_Delete)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, n");
    {
	wxComboBox *    THIS = (wxComboBox *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::ComboBox" )
;
	int	n = (int)SvIV(ST(1))
;
    try {
      THIS->Delete( n );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__ComboBox_GetClientData); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ComboBox_GetClientData)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, n");
    {
	wxComboBox *    THIS = (wxComboBox *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::ComboBox" )
;
	wxPliUserDataCD *	RETVAL;
	int	n = (int)SvIV(ST(1))
;
     RETVAL = (wxPliUserDataCD*) THIS->wxItemContainer::GetClientObject( n ); 
	{
	    SV * RETVALSV;
    RETVALSV = ( RETVAL == 0 ) ? &PL_sv_undef : RETVAL->GetData();
    SvREFCNT_inc( RETVALSV ); // xsubpp mortalizes it...
	    RETVALSV = sv_2mortal(RETVALSV);
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__ComboBox_SetClientData); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ComboBox_SetClientData)
{
    dVAR; dXSARGS;
    if (items != 3)
       croak_xs_usage(cv,  "THIS, n, data");
    {
	wxComboBox *    THIS = (wxComboBox *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::ComboBox" )
;
	int	n = (int)SvIV(ST(1))
;
	wxPliUserDataCD*	data;

    if( SvOK( ST(2) ) )
    {
        data = new wxPliUserDataCD( ST(2) );
    }
    else
        data = 0
;
    try {
      THIS->wxItemContainer::SetClientObject( n, data );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}

#if WXPERL_W_VERSION_GE( 2, 9, 0 )
#define XSpp_a2ea7434_093657
#endif

/* INCLUDE: Returning to 'XS/ComboBox.xs' from '/usr/bin/perl -pe "s/ItemContainer/ComboBox/g;s/->(?=[SG]etClientObject)/->wxItemContainer::/" XS/ItemContainer.xs' */

#undef WXPERL_IN_COMBOBOX

XS_EUPXS(XS_Wx__ComboBox_GetCurrentSelection); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ComboBox_GetCurrentSelection)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxComboBox *    THIS = (wxComboBox *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::ComboBox" )
;
	int	RETVAL;
	dXSTARG;

	RETVAL = THIS->GetCurrentSelection();
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}

#endif

XS_EUPXS(XS_Wx__ComboBox_SetEditable); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ComboBox_SetEditable)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, editable");
    {
	wxComboBox *    THIS = (wxComboBox *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::ComboBox" )
;
	bool	editable = (bool)SvTRUE(ST(1))
;

	THIS->SetEditable(editable);
    }
    XSRETURN_EMPTY;
}

#if WXPERL_W_VERSION_GE( 2, 9, 3 )
#define XSubPPtmpAAFQ 1


XS_EUPXS(XS_Wx__ComboBox_IsListEmpty); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ComboBox_IsListEmpty)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxComboBox *    THIS = (wxComboBox *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::ComboBox" )
;
	bool	RETVAL;

	RETVAL = THIS->IsListEmpty();
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__ComboBox_IsTextEmpty); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ComboBox_IsTextEmpty)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxComboBox *    THIS = (wxComboBox *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::ComboBox" )
;
	bool	RETVAL;

	RETVAL = THIS->IsTextEmpty();
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}

#endif

XS_EUPXS(XS_Wx__ComboBox_Copy); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ComboBox_Copy)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxComboBox *    THIS = (wxComboBox *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::ComboBox" )
;

	THIS->Copy();
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__ComboBox_Cut); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ComboBox_Cut)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxComboBox *    THIS = (wxComboBox *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::ComboBox" )
;

	THIS->Cut();
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__ComboBox_CanCopy); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ComboBox_CanCopy)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxComboBox *    THIS = (wxComboBox *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::ComboBox" )
;
	bool	RETVAL;

	RETVAL = THIS->CanCopy();
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__ComboBox_CanCut); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ComboBox_CanCut)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxComboBox *    THIS = (wxComboBox *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::ComboBox" )
;
	bool	RETVAL;

	RETVAL = THIS->CanCut();
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__ComboBox_CanPaste); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ComboBox_CanPaste)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxComboBox *    THIS = (wxComboBox *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::ComboBox" )
;
	bool	RETVAL;

	RETVAL = THIS->CanPaste();
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__ComboBox_Undo); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ComboBox_Undo)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxComboBox *    THIS = (wxComboBox *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::ComboBox" )
;

	THIS->Undo();
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__ComboBox_Redo); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ComboBox_Redo)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxComboBox *    THIS = (wxComboBox *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::ComboBox" )
;

	THIS->Redo();
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__ComboBox_CanUndo); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ComboBox_CanUndo)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxComboBox *    THIS = (wxComboBox *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::ComboBox" )
;
	bool	RETVAL;

	RETVAL = THIS->CanUndo();
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__ComboBox_CanRedo); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ComboBox_CanRedo)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxComboBox *    THIS = (wxComboBox *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::ComboBox" )
;
	bool	RETVAL;

	RETVAL = THIS->CanRedo();
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__ComboBox_GetInsertionPoint); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ComboBox_GetInsertionPoint)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxComboBox *    THIS = (wxComboBox *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::ComboBox" )
;
	long	RETVAL;
	dXSTARG;

	RETVAL = THIS->GetInsertionPoint();
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__ComboBox_GetLastPosition); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ComboBox_GetLastPosition)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxComboBox *    THIS = (wxComboBox *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::ComboBox" )
;
	wxTextPos	RETVAL;
	dXSTARG;

	RETVAL = THIS->GetLastPosition();
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__ComboBox_GetValue); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ComboBox_GetValue)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxComboBox *    THIS = (wxComboBox *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::ComboBox" )
;
	wxString	RETVAL;

	RETVAL = THIS->GetValue();
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    WXSTRING_OUTPUT( RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__ComboBox_Paste); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ComboBox_Paste)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxComboBox *    THIS = (wxComboBox *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::ComboBox" )
;

	THIS->Paste();
    }
    XSRETURN_EMPTY;
}

#if WXPERL_W_VERSION_GE( 2, 9, 1 )
#define XSubPPtmpAAFR 1


XS_EUPXS(XS_Wx__ComboBox_Popup); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ComboBox_Popup)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxComboBox *    THIS = (wxComboBox *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::ComboBox" )
;

	THIS->Popup();
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__ComboBox_Dismiss); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ComboBox_Dismiss)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxComboBox *    THIS = (wxComboBox *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::ComboBox" )
;

	THIS->Dismiss();
    }
    XSRETURN_EMPTY;
}

#endif

XS_EUPXS(XS_Wx__ComboBox_Replace); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ComboBox_Replace)
{
    dVAR; dXSARGS;
    if (items != 4)
       croak_xs_usage(cv,  "THIS, from, to, text");
    {
	long	from = (long)SvIV(ST(1))
;
	long	to = (long)SvIV(ST(2))
;
	wxString	text;
	wxComboBox *    THIS = (wxComboBox *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::ComboBox" )
;

    WXSTRING_INPUT( text, wxString, ST(3) )
;

	THIS->Replace(from, to, text);
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__ComboBox_Remove); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ComboBox_Remove)
{
    dVAR; dXSARGS;
    if (items != 3)
       croak_xs_usage(cv,  "THIS, from, to");
    {
	long	from = (long)SvIV(ST(1))
;
	long	to = (long)SvIV(ST(2))
;
	wxComboBox *    THIS = (wxComboBox *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::ComboBox" )
;

	THIS->Remove(from, to);
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__ComboBox_SetInsertionPoint); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ComboBox_SetInsertionPoint)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, pos");
    {
	long	pos = (long)SvIV(ST(1))
;
	wxComboBox *    THIS = (wxComboBox *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::ComboBox" )
;

	THIS->SetInsertionPoint(pos);
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__ComboBox_SetInsertionPointEnd); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ComboBox_SetInsertionPointEnd)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxComboBox *    THIS = (wxComboBox *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::ComboBox" )
;

	THIS->SetInsertionPointEnd();
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__ComboBox_GetSelection); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ComboBox_GetSelection)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    PERL_UNUSED_VAR(ax); /* -Wall */
    SP -= items;
    {
    long from;
    long to;
    int  selindex;
	wxComboBox *    THIS = (wxComboBox *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::ComboBox" )
;
    if( GIMME_V == G_ARRAY ) {
        THIS->GetSelection( &from, &to );
        EXTEND( SP, 2 );
        PUSHs( sv_2mortal( newSViv( from ) ) );
        PUSHs( sv_2mortal( newSViv( to ) ) );
    } else {
	selindex = THIS->GetSelection();
	EXTEND( SP, 1 );
        PUSHs( sv_2mortal( newSViv( selindex ) ) );
    }
	PUTBACK;
	return;
    }
}


XS_EUPXS(XS_Wx__ComboBox_SetSelection); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ComboBox_SetSelection)
{
    dVAR; dXSARGS;
    if (items < 1)
       croak_xs_usage(cv,  "THIS, ...");
    PERL_UNUSED_VAR(ax); /* -Wall */
    SP -= items;
    {
	wxComboBox *    THIS = (wxComboBox *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::ComboBox" )
;
    BEGIN_OVERLOAD()
        MATCH_REDISP( wxPliOvl_n_n, SetMark )
        MATCH_REDISP( wxPliOvl_n, SetSelectionN )
    END_OVERLOAD( Wx::ComboBox::SetSelection )
	PUTBACK;
	return;
    }
}


XS_EUPXS(XS_Wx__ComboBox_SetSelectionN); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ComboBox_SetSelectionN)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, n");
    {
	int	n = (int)SvIV(ST(1))
;
	wxComboBox *    THIS = (wxComboBox *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::ComboBox" )
;
    THIS->SetSelection( n );
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__ComboBox_SetMark); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ComboBox_SetMark)
{
    dVAR; dXSARGS;
    if (items != 3)
       croak_xs_usage(cv,  "THIS, from, to");
    {
	long	from = (long)SvIV(ST(1))
;
	long	to = (long)SvIV(ST(2))
;
	wxComboBox *    THIS = (wxComboBox *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::ComboBox" )
;
    THIS->SetSelection( from, to );
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__ComboBox_SetValue); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ComboBox_SetValue)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, string");
    {
	wxString	string;
	wxComboBox *    THIS = (wxComboBox *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::ComboBox" )
;

    WXSTRING_INPUT( string, wxString, ST(1) )
;

	THIS->SetValue(string);
    }
    XSRETURN_EMPTY;
}

#if WXPERL_W_VERSION_GE( 2, 9, 2 )
#define XSubPPtmpAAFS 1


XS_EUPXS(XS_Wx__ComboBox_RemoveSelection); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ComboBox_RemoveSelection)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxComboBox *    THIS = (wxComboBox *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::ComboBox" )
;

	THIS->RemoveSelection();
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__ComboBox_ChangeValue); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ComboBox_ChangeValue)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, string");
    {
	wxString	string;
	wxComboBox *    THIS = (wxComboBox *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::ComboBox" )
;

    WXSTRING_INPUT( string, wxString, ST(1) )
;

	THIS->ChangeValue(string);
    }
    XSRETURN_EMPTY;
}

#endif
#if WXPERL_W_VERSION_GE( 2, 9, 3 )
#define XSubPPtmpAAFT 1


XS_EUPXS(XS_Wx__ComboBox_AutoComplete); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ComboBox_AutoComplete)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, choices");
    {
	wxArrayString	choices;
	wxComboBox *    THIS = (wxComboBox *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::ComboBox" )
;
	bool	RETVAL;

    wxPli_av_2_arraystring( aTHX_ ST(1), & choices )
;

	RETVAL = THIS->AutoComplete(choices);
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__ComboBox_AutoCompleteFileNames); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ComboBox_AutoCompleteFileNames)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxComboBox *    THIS = (wxComboBox *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::ComboBox" )
;
	bool	RETVAL;

	RETVAL = THIS->AutoCompleteFileNames();
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__ComboBox_AutoCompleteDirectories); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ComboBox_AutoCompleteDirectories)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxComboBox *    THIS = (wxComboBox *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::ComboBox" )
;
	bool	RETVAL;

	RETVAL = THIS->AutoCompleteDirectories();
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}

#endif

/* INCLUDE: Returning to 'XS/Choice.xs' from 'XS/ComboBox.xs' */

#include <wx/choice.h>

XS_EUPXS(XS_Wx__Choice_new); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Choice_new)
{
    dVAR; dXSARGS;
    PERL_UNUSED_VAR(cv); /* -W */
    PERL_UNUSED_VAR(items); /* -W */
    PERL_UNUSED_VAR(ax); /* -Wall */
    SP -= items;
    {
    BEGIN_OVERLOAD()
        MATCH_VOIDM_REDISP( newDefault )
        MATCH_ANY_REDISP( newFull )
    END_OVERLOAD( "Wx::Choice::new" )
	PUTBACK;
	return;
    }
}


XS_EUPXS(XS_Wx__Choice_newDefault); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Choice_newDefault)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "CLASS");
    {
	PlClassName    CLASS = wxPli_get_class( aTHX_ ST(0) )
;
	wxChoice *	RETVAL;
    RETVAL = new wxChoice();
    wxPli_create_evthandler( aTHX_ RETVAL, CLASS );
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_evthandler_2_sv( aTHX_ RETVALSV, RETVAL );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__Choice_newFull); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Choice_newFull)
{
    dVAR; dXSARGS;
    if (items < 2 || items > 9)
       croak_xs_usage(cv,  "CLASS, parent, id = wxID_ANY, pos = wxDefaultPosition, size = wxDefaultSize, choices = 0, style = 0, validator = (wxValidator*)&wxDefaultValidator, name = wxChoiceNameStr");
    {
	PlClassName    CLASS = wxPli_get_class( aTHX_ ST(0) )
;
	wxWindow*    parent = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::Window" )
;
	wxWindowID	id;
	wxPoint	pos;
	wxSize	size;
	SV*	choices;
	long	style;
	wxValidator*	validator;
	wxString	name;
    int n = 0;
    wxString *chs = 0;
	wxChoice *	RETVAL;

	if (items < 3)
	    id = wxID_ANY;
	else {
    id = wxPli_get_wxwindowid( aTHX_ ST(2) )
;
	}

	if (items < 4)
	    pos = wxDefaultPosition;
	else {
    pos = wxPli_sv_2_wxpoint( aTHX_ ST(3) )
;
	}

	if (items < 5)
	    size = wxDefaultSize;
	else {
    size = wxPli_sv_2_wxsize( aTHX_ ST(4) )
;
	}

	if (items < 6)
	    choices = 0;
	else {
	    choices = ST(5)
;
	}

	if (items < 7)
	    style = 0;
	else {
	    style = (long)SvIV(ST(6))
;
	}

	if (items < 8)
	    validator = (wxValidator*)&wxDefaultValidator;
	else {
    validator = (wxValidator *) wxPli_sv_2_object( aTHX_ ST(7), "Wx::Validator" )
;
	}

	if (items < 9)
	    name = wxChoiceNameStr;
	else {
    WXSTRING_INPUT( name, wxString, ST(8) )
;
	}
    if( choices )
        n = wxPli_av_2_stringarray( aTHX_ choices, &chs );

    RETVAL = new wxChoice( parent, id, pos, size, n, chs, style, 
        *validator, name );
    wxPli_create_evthandler( aTHX_ RETVAL, CLASS );

    delete[] chs;
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_evthandler_2_sv( aTHX_ RETVALSV, RETVAL );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__Choice_Create); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Choice_Create)
{
    dVAR; dXSARGS;
    if (items < 2 || items > 9)
       croak_xs_usage(cv,  "THIS, parent, id = wxID_ANY, pos = wxDefaultPosition, size = wxDefaultSize, choices = 0, style = 0, validator = (wxValidator*)&wxDefaultValidator, name = wxChoiceNameStr");
    {
	wxWindow*    parent = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::Window" )
;
	wxWindowID	id;
	wxPoint	pos;
	wxSize	size;
	SV*	choices;
	long	style;
	wxValidator*	validator;
	wxString	name;
    int n = 0;
    wxString *chs = 0;
	wxChoice *    THIS = (wxChoice *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Choice" )
;
	bool	RETVAL;

	if (items < 3)
	    id = wxID_ANY;
	else {
    id = wxPli_get_wxwindowid( aTHX_ ST(2) )
;
	}

	if (items < 4)
	    pos = wxDefaultPosition;
	else {
    pos = wxPli_sv_2_wxpoint( aTHX_ ST(3) )
;
	}

	if (items < 5)
	    size = wxDefaultSize;
	else {
    size = wxPli_sv_2_wxsize( aTHX_ ST(4) )
;
	}

	if (items < 6)
	    choices = 0;
	else {
	    choices = ST(5)
;
	}

	if (items < 7)
	    style = 0;
	else {
	    style = (long)SvIV(ST(6))
;
	}

	if (items < 8)
	    validator = (wxValidator*)&wxDefaultValidator;
	else {
    validator = (wxValidator *) wxPli_sv_2_object( aTHX_ ST(7), "Wx::Validator" )
;
	}

	if (items < 9)
	    name = wxChoiceNameStr;
	else {
    WXSTRING_INPUT( name, wxString, ST(8) )
;
	}
    if( choices )
        n = wxPli_av_2_stringarray( aTHX_ choices, &chs );

    RETVAL = THIS->Create( parent, id, pos, size, n, chs, style, 
        *validator, name );

    delete[] chs;
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__Choice_Clear); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Choice_Clear)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxChoice *    THIS = (wxChoice *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Choice" )
;

	THIS->Clear();
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__Choice_Delete); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Choice_Delete)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, n");
    {
	int	n = (int)SvIV(ST(1))
;
	wxChoice *    THIS = (wxChoice *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Choice" )
;

	THIS->Delete(n);
    }
    XSRETURN_EMPTY;
}

#if !defined(__WXUNIVERSAL__)
#define XSubPPtmpAAFU 1


XS_EUPXS(XS_Wx__Choice_GetColumns); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Choice_GetColumns)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxChoice *    THIS = (wxChoice *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Choice" )
;
	int	RETVAL;
	dXSTARG;

	RETVAL = THIS->GetColumns();
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__Choice_SetColumns); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Choice_SetColumns)
{
    dVAR; dXSARGS;
    if (items < 1 || items > 2)
       croak_xs_usage(cv,  "THIS, n = 1");
    {
	int	n;
	wxChoice *    THIS = (wxChoice *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Choice" )
;

	if (items < 2)
	    n = 1;
	else {
	    n = (int)SvIV(ST(1))
;
	}

	THIS->SetColumns(n);
    }
    XSRETURN_EMPTY;
}

#endif
#if WXPERL_W_VERSION_GE( 2, 7, 2 )
#define XSubPPtmpAAFV 1


XS_EUPXS(XS_Wx__Choice_GetCurrentSelection); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Choice_GetCurrentSelection)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxChoice *    THIS = (wxChoice *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Choice" )
;
	int	RETVAL;
	dXSTARG;

	RETVAL = THIS->GetCurrentSelection();
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}

#endif

XS_EUPXS(XS_Wx__Choice_SetSelection); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Choice_SetSelection)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, n");
    {
	int	n = (int)SvIV(ST(1))
;
	wxChoice *    THIS = (wxChoice *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Choice" )
;

	THIS->SetSelection(n);
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__Choice_SetStringSelection); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Choice_SetStringSelection)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, string");
    {
	wxString	string;
	wxChoice *    THIS = (wxChoice *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Choice" )
;

    WXSTRING_INPUT( string, wxString, ST(1) )
;

	THIS->SetStringSelection(string);
    }
    XSRETURN_EMPTY;
}


/* INCLUDE: Returning to 'XS/CheckListBox.xs' from 'XS/Choice.xs' */

#include <wx/checklst.h>

XS_EUPXS(XS_Wx__CheckListBox_new); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__CheckListBox_new)
{
    dVAR; dXSARGS;
    PERL_UNUSED_VAR(cv); /* -W */
    PERL_UNUSED_VAR(items); /* -W */
    PERL_UNUSED_VAR(ax); /* -Wall */
    SP -= items;
    {
    BEGIN_OVERLOAD()
        MATCH_VOIDM_REDISP( newDefault )
        MATCH_ANY_REDISP( newFull )
    END_OVERLOAD( "Wx::CheckListBox::new" )
	PUTBACK;
	return;
    }
}


XS_EUPXS(XS_Wx__CheckListBox_newDefault); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__CheckListBox_newDefault)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "CLASS");
    {
	PlClassName    CLASS = wxPli_get_class( aTHX_ ST(0) )
;
	wxCheckListBox *	RETVAL;
    RETVAL = new wxCheckListBox();
    wxPli_create_evthandler( aTHX_ RETVAL, CLASS );
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_evthandler_2_sv( aTHX_ RETVALSV, RETVAL );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__CheckListBox_newFull); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__CheckListBox_newFull)
{
    dVAR; dXSARGS;
    if (items < 2 || items > 9)
       croak_xs_usage(cv,  "CLASS, parent, id = wxID_ANY, pos = wxDefaultPosition, size = wxDefaultSize, choices = 0, style = 0, validator = (wxValidator*)&wxDefaultValidator, name = wxListBoxNameStr");
    {
	PlClassName    CLASS = wxPli_get_class( aTHX_ ST(0) )
;
	wxWindow*    parent = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::Window" )
;
	wxWindowID	id;
	wxPoint	pos;
	wxSize	size;
	SV*	choices;
	long	style;
	wxValidator*	validator;
	wxString	name;
    wxString* chs;
    int n;
	wxCheckListBox *	RETVAL;

	if (items < 3)
	    id = wxID_ANY;
	else {
    id = wxPli_get_wxwindowid( aTHX_ ST(2) )
;
	}

	if (items < 4)
	    pos = wxDefaultPosition;
	else {
    pos = wxPli_sv_2_wxpoint( aTHX_ ST(3) )
;
	}

	if (items < 5)
	    size = wxDefaultSize;
	else {
    size = wxPli_sv_2_wxsize( aTHX_ ST(4) )
;
	}

	if (items < 6)
	    choices = 0;
	else {
	    choices = ST(5)
;
	}

	if (items < 7)
	    style = 0;
	else {
	    style = (long)SvIV(ST(6))
;
	}

	if (items < 8)
	    validator = (wxValidator*)&wxDefaultValidator;
	else {
    validator = (wxValidator *) wxPli_sv_2_object( aTHX_ ST(7), "Wx::Validator" )
;
	}

	if (items < 9)
	    name = wxListBoxNameStr;
	else {
    WXSTRING_INPUT( name, wxString, ST(8) )
;
	}
    if( choices ) 
        n = wxPli_av_2_stringarray( aTHX_ choices, &chs );
    else
    {
        n = 0;
        chs = 0;
    }

    RETVAL = new wxCheckListBox( parent, id, pos, size, n, chs, 
        style|wxLB_OWNERDRAW, *validator, name );
    wxPli_create_evthandler( aTHX_ RETVAL, CLASS );

    delete[] chs;
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_evthandler_2_sv( aTHX_ RETVALSV, RETVAL );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__CheckListBox_Create); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__CheckListBox_Create)
{
    dVAR; dXSARGS;
    if (items < 2 || items > 9)
       croak_xs_usage(cv,  "THIS, parent, id = wxID_ANY, pos = wxDefaultPosition, size = wxDefaultSize, choices = 0, style = 0, validator = (wxValidator*)&wxDefaultValidator, name = wxListBoxNameStr");
    {
	wxWindow*    parent = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::Window" )
;
	wxWindowID	id;
	wxPoint	pos;
	wxSize	size;
	SV*	choices;
	long	style;
	wxValidator*	validator;
	wxString	name;
    wxString* chs;
    int n;
	wxCheckListBox *    THIS = (wxCheckListBox *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::CheckListBox" )
;
	bool	RETVAL;

	if (items < 3)
	    id = wxID_ANY;
	else {
    id = wxPli_get_wxwindowid( aTHX_ ST(2) )
;
	}

	if (items < 4)
	    pos = wxDefaultPosition;
	else {
    pos = wxPli_sv_2_wxpoint( aTHX_ ST(3) )
;
	}

	if (items < 5)
	    size = wxDefaultSize;
	else {
    size = wxPli_sv_2_wxsize( aTHX_ ST(4) )
;
	}

	if (items < 6)
	    choices = 0;
	else {
	    choices = ST(5)
;
	}

	if (items < 7)
	    style = 0;
	else {
	    style = (long)SvIV(ST(6))
;
	}

	if (items < 8)
	    validator = (wxValidator*)&wxDefaultValidator;
	else {
    validator = (wxValidator *) wxPli_sv_2_object( aTHX_ ST(7), "Wx::Validator" )
;
	}

	if (items < 9)
	    name = wxListBoxNameStr;
	else {
    WXSTRING_INPUT( name, wxString, ST(8) )
;
	}
    if( choices ) 
        n = wxPli_av_2_stringarray( aTHX_ choices, &chs );
    else
    {
        n = 0;
        chs = 0;
    }

    RETVAL = THIS->Create( parent, id, pos, size, n, chs, 
        style|wxLB_OWNERDRAW, *validator, name );

    delete[] chs;
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__CheckListBox_Check); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__CheckListBox_Check)
{
    dVAR; dXSARGS;
    if (items < 2 || items > 3)
       croak_xs_usage(cv,  "THIS, item, check = false");
    {
	int	item = (int)SvIV(ST(1))
;
	bool	check;
	wxCheckListBox *    THIS = (wxCheckListBox *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::CheckListBox" )
;

	if (items < 3)
	    check = false;
	else {
	    check = (bool)SvTRUE(ST(2))
;
	}

	THIS->Check(item, check);
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__CheckListBox_IsChecked); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__CheckListBox_IsChecked)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, item");
    {
	int	item = (int)SvIV(ST(1))
;
	wxCheckListBox *    THIS = (wxCheckListBox *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::CheckListBox" )
;
	bool	RETVAL;

	RETVAL = THIS->IsChecked(item);
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


/* INCLUDE: Returning to 'XS/CheckBox.xs' from 'XS/CheckListBox.xs' */

#include <wx/checkbox.h>

XS_EUPXS(XS_Wx__CheckBox_new); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__CheckBox_new)
{
    dVAR; dXSARGS;
    PERL_UNUSED_VAR(cv); /* -W */
    PERL_UNUSED_VAR(items); /* -W */
    PERL_UNUSED_VAR(ax); /* -Wall */
    SP -= items;
    {
    BEGIN_OVERLOAD()
        MATCH_VOIDM_REDISP( newDefault )
        MATCH_ANY_REDISP( newFull )
    END_OVERLOAD( "Wx::CheckBox::new" )
	PUTBACK;
	return;
    }
}


XS_EUPXS(XS_Wx__CheckBox_newDefault); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__CheckBox_newDefault)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "CLASS");
    {
	PlClassName    CLASS = wxPli_get_class( aTHX_ ST(0) )
;
	wxCheckBox *	RETVAL;
    RETVAL = new wxCheckBox();
    wxPli_create_evthandler( aTHX_ RETVAL, CLASS );
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_evthandler_2_sv( aTHX_ RETVALSV, RETVAL );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__CheckBox_newFull); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__CheckBox_newFull)
{
    dVAR; dXSARGS;
    if (items < 4 || items > 9)
       croak_xs_usage(cv,  "CLASS, parent, id, label, pos = wxDefaultPosition, size = wxDefaultSize, style = 0, validator = (wxValidator*)&wxDefaultValidator, name = wxCheckBoxNameStr");
    {
	PlClassName    CLASS = wxPli_get_class( aTHX_ ST(0) )
;
	wxWindow*    parent = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::Window" )
;
	wxWindowID    id = wxPli_get_wxwindowid( aTHX_ ST(2) )
;
	wxString	label;
	wxPoint	pos;
	wxSize	size;
	long	style;
	wxValidator*	validator;
	wxString	name;
	wxCheckBox *	RETVAL;

    WXSTRING_INPUT( label, wxString, ST(3) )
;

	if (items < 5)
	    pos = wxDefaultPosition;
	else {
    pos = wxPli_sv_2_wxpoint( aTHX_ ST(4) )
;
	}

	if (items < 6)
	    size = wxDefaultSize;
	else {
    size = wxPli_sv_2_wxsize( aTHX_ ST(5) )
;
	}

	if (items < 7)
	    style = 0;
	else {
	    style = (long)SvIV(ST(6))
;
	}

	if (items < 8)
	    validator = (wxValidator*)&wxDefaultValidator;
	else {
    validator = (wxValidator *) wxPli_sv_2_object( aTHX_ ST(7), "Wx::Validator" )
;
	}

	if (items < 9)
	    name = wxCheckBoxNameStr;
	else {
    WXSTRING_INPUT( name, wxString, ST(8) )
;
	}
    RETVAL = new wxCheckBox( parent, id, label, pos, size, 
        style, *validator, name );
    wxPli_create_evthandler( aTHX_ RETVAL, CLASS );
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_evthandler_2_sv( aTHX_ RETVALSV, RETVAL );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__CheckBox_Create); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__CheckBox_Create)
{
    dVAR; dXSARGS;
    if (items < 4 || items > 9)
       croak_xs_usage(cv,  "THIS, parent, id, label, pos = wxDefaultPosition, size = wxDefaultSize, style = 0, validator = (wxValidator*)&wxDefaultValidator, name = wxCheckBoxNameStr");
    {
	wxWindow*    parent = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::Window" )
;
	wxWindowID    id = wxPli_get_wxwindowid( aTHX_ ST(2) )
;
	wxString	label;
	wxPoint	pos;
	wxSize	size;
	long	style;
	wxValidator*	validator;
	wxString	name;
	wxCheckBox *    THIS = (wxCheckBox *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::CheckBox" )
;
	bool	RETVAL;

    WXSTRING_INPUT( label, wxString, ST(3) )
;

	if (items < 5)
	    pos = wxDefaultPosition;
	else {
    pos = wxPli_sv_2_wxpoint( aTHX_ ST(4) )
;
	}

	if (items < 6)
	    size = wxDefaultSize;
	else {
    size = wxPli_sv_2_wxsize( aTHX_ ST(5) )
;
	}

	if (items < 7)
	    style = 0;
	else {
	    style = (long)SvIV(ST(6))
;
	}

	if (items < 8)
	    validator = (wxValidator*)&wxDefaultValidator;
	else {
    validator = (wxValidator *) wxPli_sv_2_object( aTHX_ ST(7), "Wx::Validator" )
;
	}

	if (items < 9)
	    name = wxCheckBoxNameStr;
	else {
    WXSTRING_INPUT( name, wxString, ST(8) )
;
	}

	RETVAL = THIS->Create(parent, id, label, pos, size, style, *validator, name);
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__CheckBox_GetValue); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__CheckBox_GetValue)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxCheckBox *    THIS = (wxCheckBox *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::CheckBox" )
;
	bool	RETVAL;

	RETVAL = THIS->GetValue();
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}

#if WXPERL_W_VERSION_GE( 2, 5, 1 )
#define XSubPPtmpAAFW 1


XS_EUPXS(XS_Wx__CheckBox_Get3StateValue); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__CheckBox_Get3StateValue)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxCheckBox *    THIS = (wxCheckBox *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::CheckBox" )
;
	wxCheckBoxState	RETVAL;
	dXSTARG;

	RETVAL = THIS->Get3StateValue();
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__CheckBox_Set3StateValue); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__CheckBox_Set3StateValue)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, state");
    {
	wxCheckBoxState	state = (wxCheckBoxState)SvIV(ST(1))
;
	wxCheckBox *    THIS = (wxCheckBox *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::CheckBox" )
;

	THIS->Set3StateValue(state);
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__CheckBox_Is3State); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__CheckBox_Is3State)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxCheckBox *    THIS = (wxCheckBox *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::CheckBox" )
;
	bool	RETVAL;

	RETVAL = THIS->Is3State();
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__CheckBox_Is3rdStateAllowedForUser); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__CheckBox_Is3rdStateAllowedForUser)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxCheckBox *    THIS = (wxCheckBox *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::CheckBox" )
;
	bool	RETVAL;

	RETVAL = THIS->Is3rdStateAllowedForUser();
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}

#endif

XS_EUPXS(XS_Wx__CheckBox_SetValue); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__CheckBox_SetValue)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, state");
    {
	bool	state = (bool)SvTRUE(ST(1))
;
	wxCheckBox *    THIS = (wxCheckBox *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::CheckBox" )
;

	THIS->SetValue(state);
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__CheckBox_IsChecked); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__CheckBox_IsChecked)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxCheckBox *    THIS = (wxCheckBox *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::CheckBox" )
;
	bool	RETVAL;

	RETVAL = THIS->IsChecked();
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


/* INCLUDE: Returning to 'Controls.xs' from 'XS/CheckBox.xs' */


/* INCLUDE_COMMAND:  Including output of '/usr/bin/perl -I./ -MExtUtils::XSpp::Cmd -e xspp -- -t typemap.xsp XS/TextAttr.xsp' from 'Controls.xs' */

#include <exception>

#undef  xsp_constructor_class
#define xsp_constructor_class(c) (c)
#include <wx/textctrl.h>

XS_EUPXS(XS_Wx__TextAttr_new); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__TextAttr_new)
{
    dVAR; dXSARGS;
    if (items < 1 || items > 4)
       croak_xs_usage(cv,  "CLASS, colText = wxNullColour, colBack = wxNullColour, font = (wxFont*)&wxNullFont");
    {
	wxColour	colText;
	wxColour	colBack;
	wxFont*	font;
	char *	CLASS = (char *)SvPV_nolen(ST(0))
;
	wxTextAttr *	RETVAL;

	if (items < 2)
	    colText = wxNullColour;
	else {
    colText = *(wxColour *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::Colour" )
;
	}

	if (items < 3)
	    colBack = wxNullColour;
	else {
    colBack = *(wxColour *) wxPli_sv_2_object( aTHX_ ST(2), "Wx::Colour" )
;
	}

	if (items < 4)
	    font = (wxFont*)&wxNullFont;
	else {
    font = (wxFont *) wxPli_sv_2_object( aTHX_ ST(3), "Wx::Font" )
;
	}
    if( items == 1 )
        RETVAL = new wxTextAttr();
    else
        RETVAL = new wxTextAttr( colText, colBack, *font );
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_non_object_2_sv( aTHX_ RETVALSV, RETVAL, "Wx::TextAttr" );
    wxPli_thread_sv_register( aTHX_ "Wx::TextAttr", RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__TextAttr_DESTROY); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__TextAttr_DESTROY)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxTextAttr *    THIS = (wxTextAttr *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::TextAttr" )
;
    wxPli_thread_sv_unregister( aTHX_ "Wx::TextAttr", THIS, ST(0) );
    delete THIS;
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__TextAttr_CLONE); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__TextAttr_CLONE)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "CLASS");
    {
	char *	CLASS = (char *)SvPV_nolen(ST(0))
;
    wxPli_thread_sv_clone( aTHX_ CLASS, (wxPliCloneSV)wxPli_detach_object );
    }
    XSRETURN_EMPTY;
}

#if WXPERL_W_VERSION_GE( 2, 9, 0 )
#define XSpp_44769b6a_048896
#define XSubPPtmpAAFX 1


XS_EUPXS(XS_Wx__TextAttr_Apply); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__TextAttr_Apply)
{
    dVAR; dXSARGS;
    if (items < 2 || items > 3)
       croak_xs_usage(cv,  "THIS, style, compareWith= NULL");
    {
	wxTextAttr *    THIS = (wxTextAttr *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::TextAttr" )
;
	bool	RETVAL;
	wxTextAttr*    style = (wxTextAttr *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::TextAttr" )
;
	wxTextAttr*	compareWith;

	if (items < 3)
	    compareWith = NULL;
	else {
    compareWith = (wxTextAttr *) wxPli_sv_2_object( aTHX_ ST(2), "Wx::TextAttr" )
;
	}
    try {
      RETVAL = THIS->Apply( *( style ), compareWith );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}

#endif
#if WXPERL_W_VERSION_GE( 2, 7, 0 )
#define XSpp_44769b6a_040369
#define XSubPPtmpAAFY 1


XS_EUPXS(XS_Wx__TextAttr_Merge); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__TextAttr_Merge)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, overlay");
    {
	wxTextAttr *    THIS = (wxTextAttr *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::TextAttr" )
;
	wxTextAttr*    overlay = (wxTextAttr *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::TextAttr" )
;
    try {
      THIS->Merge( *( overlay ) );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}

#endif

XS_EUPXS(XS_Wx__TextAttr_SetTextColour); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__TextAttr_SetTextColour)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, colText");
    {
	wxTextAttr *    THIS = (wxTextAttr *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::TextAttr" )
;
	wxColour*    colText = (wxColour *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::Colour" )
;
    try {
      THIS->SetTextColour( *( colText ) );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__TextAttr_SetBackgroundColour); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__TextAttr_SetBackgroundColour)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, colBack");
    {
	wxTextAttr *    THIS = (wxTextAttr *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::TextAttr" )
;
	wxColour*    colBack = (wxColour *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::Colour" )
;
    try {
      THIS->SetBackgroundColour( *( colBack ) );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__TextAttr_SetFont); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__TextAttr_SetFont)
{
    dVAR; dXSARGS;
    if (items < 2 || items > 3)
       croak_xs_usage(cv,  "THIS, font, flags= wxTEXT_ATTR_FONT");
    {
	wxTextAttr *    THIS = (wxTextAttr *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::TextAttr" )
;
	wxFont*    font = (wxFont *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::Font" )
;
	long	flags;

	if (items < 3)
	    flags = wxTEXT_ATTR_FONT;
	else {
	    flags = (long)SvIV(ST(2))
;
	}
    try {
      THIS->SetFont( *( font ), flags );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__TextAttr_SetAlignment); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__TextAttr_SetAlignment)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, alignment");
    {
	wxTextAttr *    THIS = (wxTextAttr *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::TextAttr" )
;
	wxTextAttrAlignment	alignment = (wxTextAttrAlignment)SvIV(ST(1))
;
    try {
      THIS->SetAlignment( alignment );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__TextAttr_SetTabs); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__TextAttr_SetTabs)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, tabs");
    {
	wxTextAttr *    THIS = (wxTextAttr *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::TextAttr" )
;
	wxArrayInt	tabs;

    wxPli_av_2_arrayint( aTHX_ ST(1), & tabs )
;
    try {
      THIS->SetTabs( tabs );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__TextAttr_SetLeftIndent); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__TextAttr_SetLeftIndent)
{
    dVAR; dXSARGS;
    if (items < 2 || items > 3)
       croak_xs_usage(cv,  "THIS, indent, subIndent= 0");
    {
	wxTextAttr *    THIS = (wxTextAttr *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::TextAttr" )
;
	int	indent = (int)SvIV(ST(1))
;
	int	subIndent;

	if (items < 3)
	    subIndent = 0;
	else {
	    subIndent = (int)SvIV(ST(2))
;
	}
    try {
      THIS->SetLeftIndent( indent, subIndent );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__TextAttr_SetRightIndent); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__TextAttr_SetRightIndent)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, indent");
    {
	wxTextAttr *    THIS = (wxTextAttr *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::TextAttr" )
;
	int	indent = (int)SvIV(ST(1))
;
    try {
      THIS->SetRightIndent( indent );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__TextAttr_SetFlags); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__TextAttr_SetFlags)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, flags");
    {
	wxTextAttr *    THIS = (wxTextAttr *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::TextAttr" )
;
	long	flags = (long)SvIV(ST(1))
;
    try {
      THIS->SetFlags( flags );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__TextAttr_HasTextColour); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__TextAttr_HasTextColour)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxTextAttr *    THIS = (wxTextAttr *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::TextAttr" )
;
	bool	RETVAL;
    try {
      RETVAL = THIS->HasTextColour();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__TextAttr_HasBackgroundColour); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__TextAttr_HasBackgroundColour)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxTextAttr *    THIS = (wxTextAttr *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::TextAttr" )
;
	bool	RETVAL;
    try {
      RETVAL = THIS->HasBackgroundColour();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__TextAttr_HasFont); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__TextAttr_HasFont)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxTextAttr *    THIS = (wxTextAttr *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::TextAttr" )
;
	bool	RETVAL;
    try {
      RETVAL = THIS->HasFont();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__TextAttr_HasAlignment); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__TextAttr_HasAlignment)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxTextAttr *    THIS = (wxTextAttr *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::TextAttr" )
;
	bool	RETVAL;
    try {
      RETVAL = THIS->HasAlignment();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__TextAttr_HasTabs); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__TextAttr_HasTabs)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxTextAttr *    THIS = (wxTextAttr *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::TextAttr" )
;
	bool	RETVAL;
    try {
      RETVAL = THIS->HasTabs();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__TextAttr_HasLeftIndent); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__TextAttr_HasLeftIndent)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxTextAttr *    THIS = (wxTextAttr *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::TextAttr" )
;
	bool	RETVAL;
    try {
      RETVAL = THIS->HasLeftIndent();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__TextAttr_HasRightIndent); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__TextAttr_HasRightIndent)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxTextAttr *    THIS = (wxTextAttr *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::TextAttr" )
;
	bool	RETVAL;
    try {
      RETVAL = THIS->HasRightIndent();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__TextAttr_HasFlag); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__TextAttr_HasFlag)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, flag");
    {
	wxTextAttr *    THIS = (wxTextAttr *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::TextAttr" )
;
	bool	RETVAL;
	long	flag = (long)SvIV(ST(1))
;
    try {
      RETVAL = THIS->HasFlag( flag );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__TextAttr_GetTextColour); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__TextAttr_GetTextColour)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxTextAttr *    THIS = (wxTextAttr *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::TextAttr" )
;
	wxColour *	RETVAL;
    try {
      RETVAL = new wxColour( THIS->GetTextColour() );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_non_object_2_sv( aTHX_ RETVALSV, RETVAL, "Wx::Colour" );
    wxPli_thread_sv_register( aTHX_ "Wx::Colour", RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__TextAttr_GetBackgroundColour); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__TextAttr_GetBackgroundColour)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxTextAttr *    THIS = (wxTextAttr *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::TextAttr" )
;
	wxColour *	RETVAL;
    try {
      RETVAL = new wxColour( THIS->GetBackgroundColour() );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_non_object_2_sv( aTHX_ RETVALSV, RETVAL, "Wx::Colour" );
    wxPli_thread_sv_register( aTHX_ "Wx::Colour", RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__TextAttr_GetFont); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__TextAttr_GetFont)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxTextAttr *    THIS = (wxTextAttr *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::TextAttr" )
;
	wxFont *	RETVAL;
    try {
      RETVAL = new wxFont( THIS->GetFont() );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_object_2_sv( aTHX_ RETVALSV, RETVAL );
    wxPli_thread_sv_register( aTHX_ "Wx::Font", RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__TextAttr_GetAlignment); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__TextAttr_GetAlignment)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxTextAttr *    THIS = (wxTextAttr *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::TextAttr" )
;
	wxTextAttrAlignment	RETVAL;
	dXSTARG;
    try {
      RETVAL = THIS->GetAlignment();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__TextAttr_GetLeftIndent); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__TextAttr_GetLeftIndent)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxTextAttr *    THIS = (wxTextAttr *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::TextAttr" )
;
	long	RETVAL;
	dXSTARG;
    try {
      RETVAL = THIS->GetLeftIndent();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__TextAttr_GetLeftSubIndent); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__TextAttr_GetLeftSubIndent)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxTextAttr *    THIS = (wxTextAttr *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::TextAttr" )
;
	long	RETVAL;
	dXSTARG;
    try {
      RETVAL = THIS->GetLeftSubIndent();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__TextAttr_GetRightIndent); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__TextAttr_GetRightIndent)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxTextAttr *    THIS = (wxTextAttr *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::TextAttr" )
;
	long	RETVAL;
	dXSTARG;
    try {
      RETVAL = THIS->GetRightIndent();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__TextAttr_GetFlags); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__TextAttr_GetFlags)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxTextAttr *    THIS = (wxTextAttr *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::TextAttr" )
;
	long	RETVAL;
	dXSTARG;
    try {
      RETVAL = THIS->GetFlags();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__TextAttr_IsDefault); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__TextAttr_IsDefault)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxTextAttr *    THIS = (wxTextAttr *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::TextAttr" )
;
	bool	RETVAL;
    try {
      RETVAL = THIS->IsDefault();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__TextAttr_GetTabs); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__TextAttr_GetTabs)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    PERL_UNUSED_VAR(ax); /* -Wall */
    SP -= items;
    {
	wxTextAttr *    THIS = (wxTextAttr *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::TextAttr" )
;
    const wxArrayInt& tabs = THIS->GetTabs();
    PUTBACK;
    wxPli_intarray_push( aTHX_ tabs );
    SPAGAIN;
	PUTBACK;
	return;
    }
}

#if WXPERL_W_VERSION_GE( 2, 9, 0 )
#define XSpp_44769b6a_059847
#define XSubPPtmpAAFZ 1


XS_EUPXS(XS_Wx__TextAttr_GetFontEncoding); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__TextAttr_GetFontEncoding)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxTextAttr *    THIS = (wxTextAttr *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::TextAttr" )
;
	wxFontEncoding	RETVAL;
	dXSTARG;
    try {
      RETVAL = THIS->GetFontEncoding();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__TextAttr_HasFontEncoding); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__TextAttr_HasFontEncoding)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxTextAttr *    THIS = (wxTextAttr *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::TextAttr" )
;
	bool	RETVAL;
    try {
      RETVAL = THIS->HasFontEncoding();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__TextAttr_SetFontEncoding); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__TextAttr_SetFontEncoding)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, encoding");
    {
	wxTextAttr *    THIS = (wxTextAttr *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::TextAttr" )
;
	wxFontEncoding	encoding = (wxFontEncoding)SvIV(ST(1))
;
    try {
      THIS->SetFontEncoding( encoding );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__TextAttr_GetOutlineLevel); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__TextAttr_GetOutlineLevel)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxTextAttr *    THIS = (wxTextAttr *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::TextAttr" )
;
	int	RETVAL;
	dXSTARG;
    try {
      RETVAL = THIS->GetOutlineLevel();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__TextAttr_HasOutlineLevel); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__TextAttr_HasOutlineLevel)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxTextAttr *    THIS = (wxTextAttr *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::TextAttr" )
;
	bool	RETVAL;
    try {
      RETVAL = THIS->HasOutlineLevel();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__TextAttr_SetOutlineLevel); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__TextAttr_SetOutlineLevel)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, level");
    {
	wxTextAttr *    THIS = (wxTextAttr *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::TextAttr" )
;
	int	level = (int)SvIV(ST(1))
;
    try {
      THIS->SetOutlineLevel( level );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__TextAttr_GetTextEffects); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__TextAttr_GetTextEffects)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxTextAttr *    THIS = (wxTextAttr *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::TextAttr" )
;
	int	RETVAL;
	dXSTARG;
    try {
      RETVAL = THIS->GetTextEffects();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__TextAttr_HasTextEffects); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__TextAttr_HasTextEffects)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxTextAttr *    THIS = (wxTextAttr *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::TextAttr" )
;
	bool	RETVAL;
    try {
      RETVAL = THIS->HasTextEffects();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__TextAttr_SetTextEffects); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__TextAttr_SetTextEffects)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, effects");
    {
	wxTextAttr *    THIS = (wxTextAttr *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::TextAttr" )
;
	int	effects = (int)SvIV(ST(1))
;
    try {
      THIS->SetTextEffects( effects );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__TextAttr_GetTextEffectFlags); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__TextAttr_GetTextEffectFlags)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxTextAttr *    THIS = (wxTextAttr *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::TextAttr" )
;
	int	RETVAL;
	dXSTARG;
    try {
      RETVAL = THIS->GetTextEffectFlags();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__TextAttr_HasTextEffect); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__TextAttr_HasTextEffect)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, effect");
    {
	wxTextAttr *    THIS = (wxTextAttr *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::TextAttr" )
;
	bool	RETVAL;
	int	effect = (int)SvIV(ST(1))
;
    try {
      RETVAL = THIS->HasTextEffect( effect );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__TextAttr_SetTextEffectFlags); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__TextAttr_SetTextEffectFlags)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, effects");
    {
	wxTextAttr *    THIS = (wxTextAttr *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::TextAttr" )
;
	int	effects = (int)SvIV(ST(1))
;
    try {
      THIS->SetTextEffectFlags( effects );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}

#endif
#if WXPERL_W_VERSION_GE( 2, 9, 0 )
#define XSpp_44769b6a_086908
#define XSubPPtmpAAGA 1


XS_EUPXS(XS_Wx__TextAttr_SetCharacterStyleName); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__TextAttr_SetCharacterStyleName)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, name");
    {
	wxTextAttr *    THIS = (wxTextAttr *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::TextAttr" )
;
	wxString	name;

    WXSTRING_INPUT( name, wxString, ST(1) )
;
    try {
      THIS->SetCharacterStyleName( name );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__TextAttr_SetParagraphStyleName); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__TextAttr_SetParagraphStyleName)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, name");
    {
	wxTextAttr *    THIS = (wxTextAttr *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::TextAttr" )
;
	wxString	name;

    WXSTRING_INPUT( name, wxString, ST(1) )
;
    try {
      THIS->SetParagraphStyleName( name );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__TextAttr_SetListStyleName); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__TextAttr_SetListStyleName)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, name");
    {
	wxTextAttr *    THIS = (wxTextAttr *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::TextAttr" )
;
	wxString	name;

    WXSTRING_INPUT( name, wxString, ST(1) )
;
    try {
      THIS->SetListStyleName( name );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__TextAttr_SetParagraphSpacingAfter); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__TextAttr_SetParagraphSpacingAfter)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, spacing");
    {
	wxTextAttr *    THIS = (wxTextAttr *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::TextAttr" )
;
	int	spacing = (int)SvIV(ST(1))
;
    try {
      THIS->SetParagraphSpacingAfter( spacing );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__TextAttr_SetParagraphSpacingBefore); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__TextAttr_SetParagraphSpacingBefore)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, spacing");
    {
	wxTextAttr *    THIS = (wxTextAttr *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::TextAttr" )
;
	int	spacing = (int)SvIV(ST(1))
;
    try {
      THIS->SetParagraphSpacingBefore( spacing );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__TextAttr_SetLineSpacing); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__TextAttr_SetLineSpacing)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, spacing");
    {
	wxTextAttr *    THIS = (wxTextAttr *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::TextAttr" )
;
	int	spacing = (int)SvIV(ST(1))
;
    try {
      THIS->SetLineSpacing( spacing );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__TextAttr_SetBulletStyle); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__TextAttr_SetBulletStyle)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, style");
    {
	wxTextAttr *    THIS = (wxTextAttr *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::TextAttr" )
;
	int	style = (int)SvIV(ST(1))
;
    try {
      THIS->SetBulletStyle( style );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__TextAttr_SetBulletNumber); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__TextAttr_SetBulletNumber)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, n");
    {
	wxTextAttr *    THIS = (wxTextAttr *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::TextAttr" )
;
	int	n = (int)SvIV(ST(1))
;
    try {
      THIS->SetBulletNumber( n );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__TextAttr_SetBulletText); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__TextAttr_SetBulletText)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, text");
    {
	wxTextAttr *    THIS = (wxTextAttr *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::TextAttr" )
;
	wxString	text;

    WXSTRING_INPUT( text, wxString, ST(1) )
;
    try {
      THIS->SetBulletText( text );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__TextAttr_SetBulletName); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__TextAttr_SetBulletName)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, name");
    {
	wxTextAttr *    THIS = (wxTextAttr *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::TextAttr" )
;
	wxString	name;

    WXSTRING_INPUT( name, wxString, ST(1) )
;
    try {
      THIS->SetBulletName( name );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__TextAttr_SetBulletFont); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__TextAttr_SetBulletFont)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, bulletFont");
    {
	wxTextAttr *    THIS = (wxTextAttr *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::TextAttr" )
;
	wxString	bulletFont;

    WXSTRING_INPUT( bulletFont, wxString, ST(1) )
;
    try {
      THIS->SetBulletFont( bulletFont );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__TextAttr_SetURL); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__TextAttr_SetURL)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, url");
    {
	wxTextAttr *    THIS = (wxTextAttr *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::TextAttr" )
;
	wxString	url;

    WXSTRING_INPUT( url, wxString, ST(1) )
;
    try {
      THIS->SetURL( url );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__TextAttr_SetPageBreak); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__TextAttr_SetPageBreak)
{
    dVAR; dXSARGS;
    if (items < 1 || items > 2)
       croak_xs_usage(cv,  "THIS, pageBreak= true");
    {
	wxTextAttr *    THIS = (wxTextAttr *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::TextAttr" )
;
	bool	pageBreak;

	if (items < 2)
	    pageBreak = true;
	else {
	    pageBreak = (bool)SvTRUE(ST(1))
;
	}
    try {
      THIS->SetPageBreak( pageBreak );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__TextAttr_GetCharacterStyleName); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__TextAttr_GetCharacterStyleName)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxTextAttr *    THIS = (wxTextAttr *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::TextAttr" )
;
	wxString	RETVAL;
    try {
      RETVAL = THIS->GetCharacterStyleName();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    WXSTRING_OUTPUT( RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__TextAttr_GetParagraphStyleName); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__TextAttr_GetParagraphStyleName)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxTextAttr *    THIS = (wxTextAttr *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::TextAttr" )
;
	wxString	RETVAL;
    try {
      RETVAL = THIS->GetParagraphStyleName();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    WXSTRING_OUTPUT( RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__TextAttr_GetListStyleName); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__TextAttr_GetListStyleName)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxTextAttr *    THIS = (wxTextAttr *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::TextAttr" )
;
	wxString	RETVAL;
    try {
      RETVAL = THIS->GetListStyleName();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    WXSTRING_OUTPUT( RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__TextAttr_GetParagraphSpacingAfter); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__TextAttr_GetParagraphSpacingAfter)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxTextAttr *    THIS = (wxTextAttr *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::TextAttr" )
;
	int	RETVAL;
	dXSTARG;
    try {
      RETVAL = THIS->GetParagraphSpacingAfter();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__TextAttr_GetParagraphSpacingBefore); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__TextAttr_GetParagraphSpacingBefore)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxTextAttr *    THIS = (wxTextAttr *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::TextAttr" )
;
	int	RETVAL;
	dXSTARG;
    try {
      RETVAL = THIS->GetParagraphSpacingBefore();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__TextAttr_GetLineSpacing); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__TextAttr_GetLineSpacing)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxTextAttr *    THIS = (wxTextAttr *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::TextAttr" )
;
	int	RETVAL;
	dXSTARG;
    try {
      RETVAL = THIS->GetLineSpacing();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__TextAttr_GetBulletStyle); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__TextAttr_GetBulletStyle)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxTextAttr *    THIS = (wxTextAttr *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::TextAttr" )
;
	int	RETVAL;
	dXSTARG;
    try {
      RETVAL = THIS->GetBulletStyle();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__TextAttr_GetBulletNumber); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__TextAttr_GetBulletNumber)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxTextAttr *    THIS = (wxTextAttr *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::TextAttr" )
;
	int	RETVAL;
	dXSTARG;
    try {
      RETVAL = THIS->GetBulletNumber();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__TextAttr_GetBulletText); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__TextAttr_GetBulletText)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxTextAttr *    THIS = (wxTextAttr *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::TextAttr" )
;
	wxString	RETVAL;
    try {
      RETVAL = THIS->GetBulletText();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    WXSTRING_OUTPUT( RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__TextAttr_GetBulletName); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__TextAttr_GetBulletName)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxTextAttr *    THIS = (wxTextAttr *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::TextAttr" )
;
	wxString	RETVAL;
    try {
      RETVAL = THIS->GetBulletName();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    WXSTRING_OUTPUT( RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__TextAttr_GetBulletFont); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__TextAttr_GetBulletFont)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxTextAttr *    THIS = (wxTextAttr *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::TextAttr" )
;
	wxString	RETVAL;
    try {
      RETVAL = THIS->GetBulletFont();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    WXSTRING_OUTPUT( RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__TextAttr_GetURL); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__TextAttr_GetURL)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxTextAttr *    THIS = (wxTextAttr *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::TextAttr" )
;
	wxString	RETVAL;
    try {
      RETVAL = THIS->GetURL();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    WXSTRING_OUTPUT( RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__TextAttr_HasParagraphSpacingAfter); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__TextAttr_HasParagraphSpacingAfter)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxTextAttr *    THIS = (wxTextAttr *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::TextAttr" )
;
	bool	RETVAL;
    try {
      RETVAL = THIS->HasParagraphSpacingAfter();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__TextAttr_HasParagraphSpacingBefore); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__TextAttr_HasParagraphSpacingBefore)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxTextAttr *    THIS = (wxTextAttr *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::TextAttr" )
;
	bool	RETVAL;
    try {
      RETVAL = THIS->HasParagraphSpacingBefore();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__TextAttr_HasLineSpacing); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__TextAttr_HasLineSpacing)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxTextAttr *    THIS = (wxTextAttr *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::TextAttr" )
;
	bool	RETVAL;
    try {
      RETVAL = THIS->HasLineSpacing();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__TextAttr_HasCharacterStyleName); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__TextAttr_HasCharacterStyleName)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxTextAttr *    THIS = (wxTextAttr *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::TextAttr" )
;
	bool	RETVAL;
    try {
      RETVAL = THIS->HasCharacterStyleName();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__TextAttr_HasParagraphStyleName); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__TextAttr_HasParagraphStyleName)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxTextAttr *    THIS = (wxTextAttr *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::TextAttr" )
;
	bool	RETVAL;
    try {
      RETVAL = THIS->HasParagraphStyleName();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__TextAttr_HasListStyleName); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__TextAttr_HasListStyleName)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxTextAttr *    THIS = (wxTextAttr *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::TextAttr" )
;
	bool	RETVAL;
    try {
      RETVAL = THIS->HasListStyleName();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__TextAttr_HasBulletStyle); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__TextAttr_HasBulletStyle)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxTextAttr *    THIS = (wxTextAttr *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::TextAttr" )
;
	bool	RETVAL;
    try {
      RETVAL = THIS->HasBulletStyle();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__TextAttr_HasBulletNumber); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__TextAttr_HasBulletNumber)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxTextAttr *    THIS = (wxTextAttr *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::TextAttr" )
;
	bool	RETVAL;
    try {
      RETVAL = THIS->HasBulletNumber();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__TextAttr_HasBulletText); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__TextAttr_HasBulletText)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxTextAttr *    THIS = (wxTextAttr *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::TextAttr" )
;
	bool	RETVAL;
    try {
      RETVAL = THIS->HasBulletText();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__TextAttr_HasBulletName); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__TextAttr_HasBulletName)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxTextAttr *    THIS = (wxTextAttr *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::TextAttr" )
;
	bool	RETVAL;
    try {
      RETVAL = THIS->HasBulletName();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__TextAttr_HasURL); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__TextAttr_HasURL)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxTextAttr *    THIS = (wxTextAttr *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::TextAttr" )
;
	bool	RETVAL;
    try {
      RETVAL = THIS->HasURL();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__TextAttr_HasPageBreak); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__TextAttr_HasPageBreak)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxTextAttr *    THIS = (wxTextAttr *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::TextAttr" )
;
	bool	RETVAL;
    try {
      RETVAL = THIS->HasPageBreak();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__TextAttr_IsCharacterStyle); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__TextAttr_IsCharacterStyle)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxTextAttr *    THIS = (wxTextAttr *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::TextAttr" )
;
	bool	RETVAL;
    try {
      RETVAL = THIS->IsCharacterStyle();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__TextAttr_IsParagraphStyle); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__TextAttr_IsParagraphStyle)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxTextAttr *    THIS = (wxTextAttr *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::TextAttr" )
;
	bool	RETVAL;
    try {
      RETVAL = THIS->IsParagraphStyle();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}

#if WXPERL_W_VERSION_LT( 2, 9, 0 )
#define XSpp_44769b6a_013743
#define XSubPPtmpAAGB 1


XS_EUPXS(XS_Wx__TextAttr_CreateFont); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__TextAttr_CreateFont)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxTextAttr *    THIS = (wxTextAttr *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::TextAttr" )
;
	wxFont *	RETVAL;
    try {
      RETVAL = new wxFont( THIS->CreateFont() );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_object_2_sv( aTHX_ RETVALSV, RETVAL );
    wxPli_thread_sv_register( aTHX_ "Wx::Font", RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}

#endif

XS_EUPXS(XS_Wx__TextAttr_GetFontAttributes); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__TextAttr_GetFontAttributes)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, font");
    {
	wxTextAttr *    THIS = (wxTextAttr *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::TextAttr" )
;
	bool	RETVAL;
	wxFont*    font = (wxFont *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::Font" )
;
    try {
      RETVAL = THIS->GetFontAttributes( *( font ) );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__TextAttr_SetFontSize); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__TextAttr_SetFontSize)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, pointSize");
    {
	wxTextAttr *    THIS = (wxTextAttr *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::TextAttr" )
;
	int	pointSize = (int)SvIV(ST(1))
;
    try {
      THIS->SetFontSize( pointSize );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__TextAttr_SetFontStyle); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__TextAttr_SetFontStyle)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, fontStyle");
    {
	wxTextAttr *    THIS = (wxTextAttr *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::TextAttr" )
;
	wxFontStyle	fontStyle = (wxFontStyle)SvIV(ST(1))
;
    try {
      THIS->SetFontStyle( fontStyle );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__TextAttr_SetFontWeight); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__TextAttr_SetFontWeight)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, fontWeight");
    {
	wxTextAttr *    THIS = (wxTextAttr *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::TextAttr" )
;
	wxFontWeight	fontWeight = (wxFontWeight)SvIV(ST(1))
;
    try {
      THIS->SetFontWeight( fontWeight );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__TextAttr_SetFontFaceName); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__TextAttr_SetFontFaceName)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, faceName");
    {
	wxTextAttr *    THIS = (wxTextAttr *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::TextAttr" )
;
	wxString	faceName;

    WXSTRING_INPUT( faceName, wxString, ST(1) )
;
    try {
      THIS->SetFontFaceName( faceName );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__TextAttr_SetFontUnderlined); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__TextAttr_SetFontUnderlined)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, underlined");
    {
	wxTextAttr *    THIS = (wxTextAttr *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::TextAttr" )
;
	bool	underlined = (bool)SvTRUE(ST(1))
;
    try {
      THIS->SetFontUnderlined( underlined );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__TextAttr_GetFontSize); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__TextAttr_GetFontSize)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxTextAttr *    THIS = (wxTextAttr *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::TextAttr" )
;
	int	RETVAL;
	dXSTARG;
    try {
      RETVAL = THIS->GetFontSize();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__TextAttr_GetFontStyle); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__TextAttr_GetFontStyle)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxTextAttr *    THIS = (wxTextAttr *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::TextAttr" )
;
	wxFontStyle	RETVAL;
	dXSTARG;
    try {
      RETVAL = THIS->GetFontStyle();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__TextAttr_GetFontWeight); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__TextAttr_GetFontWeight)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxTextAttr *    THIS = (wxTextAttr *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::TextAttr" )
;
	wxFontWeight	RETVAL;
	dXSTARG;
    try {
      RETVAL = THIS->GetFontWeight();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__TextAttr_GetFontUnderlined); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__TextAttr_GetFontUnderlined)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxTextAttr *    THIS = (wxTextAttr *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::TextAttr" )
;
	bool	RETVAL;
    try {
      RETVAL = THIS->GetFontUnderlined();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__TextAttr_GetFontFaceName); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__TextAttr_GetFontFaceName)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxTextAttr *    THIS = (wxTextAttr *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::TextAttr" )
;
	wxString	RETVAL;
    try {
      RETVAL = THIS->GetFontFaceName();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    WXSTRING_OUTPUT( RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__TextAttr_HasFontWeight); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__TextAttr_HasFontWeight)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxTextAttr *    THIS = (wxTextAttr *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::TextAttr" )
;
	bool	RETVAL;
    try {
      RETVAL = THIS->HasFontWeight();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__TextAttr_HasFontSize); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__TextAttr_HasFontSize)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxTextAttr *    THIS = (wxTextAttr *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::TextAttr" )
;
	bool	RETVAL;
    try {
      RETVAL = THIS->HasFontSize();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__TextAttr_HasFontItalic); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__TextAttr_HasFontItalic)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxTextAttr *    THIS = (wxTextAttr *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::TextAttr" )
;
	bool	RETVAL;
    try {
      RETVAL = THIS->HasFontItalic();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__TextAttr_HasFontUnderlined); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__TextAttr_HasFontUnderlined)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxTextAttr *    THIS = (wxTextAttr *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::TextAttr" )
;
	bool	RETVAL;
    try {
      RETVAL = THIS->HasFontUnderlined();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__TextAttr_HasFontFaceName); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__TextAttr_HasFontFaceName)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxTextAttr *    THIS = (wxTextAttr *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::TextAttr" )
;
	bool	RETVAL;
    try {
      RETVAL = THIS->HasFontFaceName();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}

#endif

/* INCLUDE: Returning to 'Controls.xs' from '/usr/bin/perl -I./ -MExtUtils::XSpp::Cmd -e xspp -- -t typemap.xsp XS/TextAttr.xsp' */


/* INCLUDE_COMMAND:  Including output of '/usr/bin/perl -I./ -MExtUtils::XSpp::Cmd -e xspp -- -t typemap.xsp XS/TextCtrl.xsp' from 'Controls.xs' */

#include <exception>

#undef  xsp_constructor_class
#define xsp_constructor_class(c) (c)
#include <wx/textctrl.h>

XS_EUPXS(XS_Wx__TextUrlEvent_GetMouseEvent); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__TextUrlEvent_GetMouseEvent)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxTextUrlEvent *    THIS = (wxTextUrlEvent *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::TextUrlEvent" )
;
	wxMouseEvent *	RETVAL;
    try {
      RETVAL = new wxMouseEvent( THIS->GetMouseEvent() );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_object_2_sv( aTHX_ RETVALSV, RETVAL );
    wxPli_thread_sv_register( aTHX_ "Wx::MouseEvent", RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__TextUrlEvent_GetURLStart); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__TextUrlEvent_GetURLStart)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxTextUrlEvent *    THIS = (wxTextUrlEvent *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::TextUrlEvent" )
;
	long	RETVAL;
	dXSTARG;
    try {
      RETVAL = THIS->GetURLStart();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__TextUrlEvent_GetURLEnd); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__TextUrlEvent_GetURLEnd)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxTextUrlEvent *    THIS = (wxTextUrlEvent *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::TextUrlEvent" )
;
	long	RETVAL;
	dXSTARG;
    try {
      RETVAL = THIS->GetURLEnd();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__TextCtrlBase_GetValue); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__TextCtrlBase_GetValue)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxTextCtrlBase *    THIS = (wxTextCtrlBase *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::TextCtrlBase" )
;
	wxString	RETVAL;
    try {
      RETVAL = THIS->GetValue();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    WXSTRING_OUTPUT( RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}

#if WXPERL_W_VERSION_GE( 2, 7, 2 )
#define XSpp_3167bce7_083395
#define XSubPPtmpAAGC 1


XS_EUPXS(XS_Wx__TextCtrlBase_IsEmpty); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__TextCtrlBase_IsEmpty)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxTextCtrlBase *    THIS = (wxTextCtrlBase *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::TextCtrlBase" )
;
	bool	RETVAL;
    try {
      RETVAL = THIS->IsEmpty();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}

#endif

XS_EUPXS(XS_Wx__TextCtrlBase_SetValue); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__TextCtrlBase_SetValue)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, value");
    {
	wxTextCtrlBase *    THIS = (wxTextCtrlBase *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::TextCtrlBase" )
;
	wxString	value;

    WXSTRING_INPUT( value, wxString, ST(1) )
;
    try {
      THIS->SetValue( value );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}

#if WXPERL_W_VERSION_GE( 2, 7, 1 )
#define XSpp_3167bce7_088228
#define XSubPPtmpAAGD 1


XS_EUPXS(XS_Wx__TextCtrlBase_ChangeValue); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__TextCtrlBase_ChangeValue)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, value");
    {
	wxTextCtrlBase *    THIS = (wxTextCtrlBase *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::TextCtrlBase" )
;
	wxString	value;

    WXSTRING_INPUT( value, wxString, ST(1) )
;
    try {
      THIS->ChangeValue( value );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}

#endif

XS_EUPXS(XS_Wx__TextCtrlBase_GetRange); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__TextCtrlBase_GetRange)
{
    dVAR; dXSARGS;
    if (items != 3)
       croak_xs_usage(cv,  "THIS, from, to");
    {
	wxTextCtrlBase *    THIS = (wxTextCtrlBase *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::TextCtrlBase" )
;
	wxString	RETVAL;
	long	from = (long)SvIV(ST(1))
;
	long	to = (long)SvIV(ST(2))
;
    try {
      RETVAL = THIS->GetRange( from, to );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    WXSTRING_OUTPUT( RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__TextCtrlBase_GetLineLength); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__TextCtrlBase_GetLineLength)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, lineNo");
    {
	wxTextCtrlBase *    THIS = (wxTextCtrlBase *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::TextCtrlBase" )
;
	int	RETVAL;
	dXSTARG;
	long	lineNo = (long)SvIV(ST(1))
;
    try {
      RETVAL = THIS->GetLineLength( lineNo );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__TextCtrlBase_GetLineText); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__TextCtrlBase_GetLineText)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, lineNo");
    {
	wxTextCtrlBase *    THIS = (wxTextCtrlBase *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::TextCtrlBase" )
;
	wxString	RETVAL;
	long	lineNo = (long)SvIV(ST(1))
;
    try {
      RETVAL = THIS->GetLineText( lineNo );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    WXSTRING_OUTPUT( RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__TextCtrlBase_GetNumberOfLines); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__TextCtrlBase_GetNumberOfLines)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxTextCtrlBase *    THIS = (wxTextCtrlBase *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::TextCtrlBase" )
;
	int	RETVAL;
	dXSTARG;
    try {
      RETVAL = THIS->GetNumberOfLines();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__TextCtrlBase_IsModified); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__TextCtrlBase_IsModified)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxTextCtrlBase *    THIS = (wxTextCtrlBase *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::TextCtrlBase" )
;
	bool	RETVAL;
    try {
      RETVAL = THIS->IsModified();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__TextCtrlBase_IsEditable); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__TextCtrlBase_IsEditable)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxTextCtrlBase *    THIS = (wxTextCtrlBase *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::TextCtrlBase" )
;
	bool	RETVAL;
    try {
      RETVAL = THIS->IsEditable();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__TextCtrlBase_IsSingleLine); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__TextCtrlBase_IsSingleLine)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxTextCtrlBase *    THIS = (wxTextCtrlBase *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::TextCtrlBase" )
;
	bool	RETVAL;
    try {
      RETVAL = THIS->IsSingleLine();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__TextCtrlBase_IsMultiLine); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__TextCtrlBase_IsMultiLine)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxTextCtrlBase *    THIS = (wxTextCtrlBase *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::TextCtrlBase" )
;
	bool	RETVAL;
    try {
      RETVAL = THIS->IsMultiLine();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__TextCtrlBase_GetStringSelection); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__TextCtrlBase_GetStringSelection)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxTextCtrlBase *    THIS = (wxTextCtrlBase *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::TextCtrlBase" )
;
	wxString	RETVAL;
    try {
      RETVAL = THIS->GetStringSelection();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    WXSTRING_OUTPUT( RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__TextCtrlBase_Clear); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__TextCtrlBase_Clear)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxTextCtrlBase *    THIS = (wxTextCtrlBase *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::TextCtrlBase" )
;
    try {
      THIS->Clear();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__TextCtrlBase_Replace); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__TextCtrlBase_Replace)
{
    dVAR; dXSARGS;
    if (items != 4)
       croak_xs_usage(cv,  "THIS, from, to, value");
    {
	wxTextCtrlBase *    THIS = (wxTextCtrlBase *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::TextCtrlBase" )
;
	long	from = (long)SvIV(ST(1))
;
	long	to = (long)SvIV(ST(2))
;
	wxString	value;

    WXSTRING_INPUT( value, wxString, ST(3) )
;
    try {
      THIS->Replace( from, to, value );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__TextCtrlBase_Remove); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__TextCtrlBase_Remove)
{
    dVAR; dXSARGS;
    if (items != 3)
       croak_xs_usage(cv,  "THIS, from, to");
    {
	wxTextCtrlBase *    THIS = (wxTextCtrlBase *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::TextCtrlBase" )
;
	long	from = (long)SvIV(ST(1))
;
	long	to = (long)SvIV(ST(2))
;
    try {
      THIS->Remove( from, to );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}

#if WXPERL_W_VERSION_GE( 2, 7, 1 )
#define XSpp_3167bce7_067826
#define XSubPPtmpAAGE 1


XS_EUPXS(XS_Wx__TextCtrlBase_LoadFile); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__TextCtrlBase_LoadFile)
{
    dVAR; dXSARGS;
    if (items < 2 || items > 3)
       croak_xs_usage(cv,  "THIS, file, fileType= wxTEXT_TYPE_ANY");
    {
	wxTextCtrlBase *    THIS = (wxTextCtrlBase *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::TextCtrlBase" )
;
	bool	RETVAL;
	wxString	file;
	int	fileType;

    WXSTRING_INPUT( file, wxString, ST(1) )
;

	if (items < 3)
	    fileType = wxTEXT_TYPE_ANY;
	else {
	    fileType = (int)SvIV(ST(2))
;
	}
    try {
      RETVAL = THIS->LoadFile( file, fileType );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__TextCtrlBase_SaveFile); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__TextCtrlBase_SaveFile)
{
    dVAR; dXSARGS;
    if (items < 1 || items > 3)
       croak_xs_usage(cv,  "THIS, file= wxEmptyString, fileType= wxTEXT_TYPE_ANY");
    {
	wxTextCtrlBase *    THIS = (wxTextCtrlBase *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::TextCtrlBase" )
;
	bool	RETVAL;
	wxString	file;
	int	fileType;

	if (items < 2)
	    file = wxEmptyString;
	else {
    WXSTRING_INPUT( file, wxString, ST(1) )
;
	}

	if (items < 3)
	    fileType = wxTEXT_TYPE_ANY;
	else {
	    fileType = (int)SvIV(ST(2))
;
	}
    try {
      RETVAL = THIS->SaveFile( file, fileType );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}

#else
#define XSpp_3167bce7_006476
#define XSubPPtmpAAGF 1


XS_EUPXS(XS_Wx__TextCtrlBase_LoadFile); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__TextCtrlBase_LoadFile)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, file");
    {
	wxTextCtrlBase *    THIS = (wxTextCtrlBase *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::TextCtrlBase" )
;
	bool	RETVAL;
	wxString	file;

    WXSTRING_INPUT( file, wxString, ST(1) )
;
    try {
      RETVAL = THIS->LoadFile( file );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__TextCtrlBase_SaveFile); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__TextCtrlBase_SaveFile)
{
    dVAR; dXSARGS;
    if (items < 1 || items > 2)
       croak_xs_usage(cv,  "THIS, file= wxEmptyString");
    {
	wxTextCtrlBase *    THIS = (wxTextCtrlBase *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::TextCtrlBase" )
;
	bool	RETVAL;
	wxString	file;

	if (items < 2)
	    file = wxEmptyString;
	else {
    WXSTRING_INPUT( file, wxString, ST(1) )
;
	}
    try {
      RETVAL = THIS->SaveFile( file );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}

#endif

XS_EUPXS(XS_Wx__TextCtrlBase_MarkDirty); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__TextCtrlBase_MarkDirty)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxTextCtrlBase *    THIS = (wxTextCtrlBase *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::TextCtrlBase" )
;
    try {
      THIS->MarkDirty();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__TextCtrlBase_DiscardEdits); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__TextCtrlBase_DiscardEdits)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxTextCtrlBase *    THIS = (wxTextCtrlBase *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::TextCtrlBase" )
;
    try {
      THIS->DiscardEdits();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}

#if WXPERL_W_VERSION_GE( 2, 7, 0 )
#define XSpp_3167bce7_027464
#define XSubPPtmpAAGG 1


XS_EUPXS(XS_Wx__TextCtrlBase_SetModified); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__TextCtrlBase_SetModified)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, modified");
    {
	wxTextCtrlBase *    THIS = (wxTextCtrlBase *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::TextCtrlBase" )
;
	bool	modified = (bool)SvTRUE(ST(1))
;
    try {
      THIS->SetModified( modified );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}

#endif

XS_EUPXS(XS_Wx__TextCtrlBase_SetMaxLength); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__TextCtrlBase_SetMaxLength)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, len");
    {
	wxTextCtrlBase *    THIS = (wxTextCtrlBase *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::TextCtrlBase" )
;
	unsigned long    len = (unsigned long)SvUV( ST(1) )
;
    try {
      THIS->SetMaxLength( len );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__TextCtrlBase_WriteText); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__TextCtrlBase_WriteText)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, text");
    {
	wxTextCtrlBase *    THIS = (wxTextCtrlBase *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::TextCtrlBase" )
;
	wxString	text;

    WXSTRING_INPUT( text, wxString, ST(1) )
;
    try {
      THIS->WriteText( text );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__TextCtrlBase_AppendText); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__TextCtrlBase_AppendText)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, text");
    {
	wxTextCtrlBase *    THIS = (wxTextCtrlBase *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::TextCtrlBase" )
;
	wxString	text;

    WXSTRING_INPUT( text, wxString, ST(1) )
;
    try {
      THIS->AppendText( text );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__TextCtrlBase_EmulateKeyPress); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__TextCtrlBase_EmulateKeyPress)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, event");
    {
	wxTextCtrlBase *    THIS = (wxTextCtrlBase *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::TextCtrlBase" )
;
	bool	RETVAL;
	wxKeyEvent*    event = (wxKeyEvent *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::KeyEvent" )
;
    try {
      RETVAL = THIS->EmulateKeyPress( *( event ) );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__TextCtrlBase_SetStyle); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__TextCtrlBase_SetStyle)
{
    dVAR; dXSARGS;
    if (items != 4)
       croak_xs_usage(cv,  "THIS, start, end, style");
    {
	wxTextCtrlBase *    THIS = (wxTextCtrlBase *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::TextCtrlBase" )
;
	bool	RETVAL;
	long	start = (long)SvIV(ST(1))
;
	long	end = (long)SvIV(ST(2))
;
	wxTextAttr*    style = (wxTextAttr *) wxPli_sv_2_object( aTHX_ ST(3), "Wx::TextAttr" )
;
    try {
      RETVAL = THIS->SetStyle( start, end, *( style ) );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__TextCtrlBase_SetDefaultStyle); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__TextCtrlBase_SetDefaultStyle)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, style");
    {
	wxTextCtrlBase *    THIS = (wxTextCtrlBase *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::TextCtrlBase" )
;
	bool	RETVAL;
	wxTextAttr*    style = (wxTextAttr *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::TextAttr" )
;
    try {
      RETVAL = THIS->SetDefaultStyle( *( style ) );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__TextCtrlBase_GetDefaultStyle); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__TextCtrlBase_GetDefaultStyle)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxTextCtrlBase *    THIS = (wxTextCtrlBase *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::TextCtrlBase" )
;
	wxTextAttr *	RETVAL;
    try {
      RETVAL = new wxTextAttr( THIS->GetDefaultStyle() );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_non_object_2_sv( aTHX_ RETVALSV, RETVAL, "Wx::TextAttr" );
    wxPli_thread_sv_register( aTHX_ "Wx::TextAttr", RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__TextCtrlBase_XYToPosition); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__TextCtrlBase_XYToPosition)
{
    dVAR; dXSARGS;
    if (items != 3)
       croak_xs_usage(cv,  "THIS, x, y");
    {
	wxTextCtrlBase *    THIS = (wxTextCtrlBase *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::TextCtrlBase" )
;
	long	RETVAL;
	dXSTARG;
	long	x = (long)SvIV(ST(1))
;
	long	y = (long)SvIV(ST(2))
;
    try {
      RETVAL = THIS->XYToPosition( x, y );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__TextCtrlBase_ShowPosition); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__TextCtrlBase_ShowPosition)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, pos");
    {
	wxTextCtrlBase *    THIS = (wxTextCtrlBase *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::TextCtrlBase" )
;
	long	pos = (long)SvIV(ST(1))
;
    try {
      THIS->ShowPosition( pos );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__TextCtrlBase_Copy); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__TextCtrlBase_Copy)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxTextCtrlBase *    THIS = (wxTextCtrlBase *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::TextCtrlBase" )
;
    try {
      THIS->Copy();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__TextCtrlBase_Cut); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__TextCtrlBase_Cut)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxTextCtrlBase *    THIS = (wxTextCtrlBase *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::TextCtrlBase" )
;
    try {
      THIS->Cut();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__TextCtrlBase_Paste); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__TextCtrlBase_Paste)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxTextCtrlBase *    THIS = (wxTextCtrlBase *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::TextCtrlBase" )
;
    try {
      THIS->Paste();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__TextCtrlBase_CanCopy); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__TextCtrlBase_CanCopy)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxTextCtrlBase *    THIS = (wxTextCtrlBase *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::TextCtrlBase" )
;
	bool	RETVAL;
    try {
      RETVAL = THIS->CanCopy();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__TextCtrlBase_CanCut); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__TextCtrlBase_CanCut)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxTextCtrlBase *    THIS = (wxTextCtrlBase *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::TextCtrlBase" )
;
	bool	RETVAL;
    try {
      RETVAL = THIS->CanCut();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__TextCtrlBase_CanPaste); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__TextCtrlBase_CanPaste)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxTextCtrlBase *    THIS = (wxTextCtrlBase *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::TextCtrlBase" )
;
	bool	RETVAL;
    try {
      RETVAL = THIS->CanPaste();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__TextCtrlBase_Undo); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__TextCtrlBase_Undo)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxTextCtrlBase *    THIS = (wxTextCtrlBase *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::TextCtrlBase" )
;
    try {
      THIS->Undo();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__TextCtrlBase_Redo); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__TextCtrlBase_Redo)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxTextCtrlBase *    THIS = (wxTextCtrlBase *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::TextCtrlBase" )
;
    try {
      THIS->Redo();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__TextCtrlBase_CanUndo); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__TextCtrlBase_CanUndo)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxTextCtrlBase *    THIS = (wxTextCtrlBase *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::TextCtrlBase" )
;
	bool	RETVAL;
    try {
      RETVAL = THIS->CanUndo();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__TextCtrlBase_CanRedo); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__TextCtrlBase_CanRedo)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxTextCtrlBase *    THIS = (wxTextCtrlBase *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::TextCtrlBase" )
;
	bool	RETVAL;
    try {
      RETVAL = THIS->CanRedo();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__TextCtrlBase_SetInsertionPoint); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__TextCtrlBase_SetInsertionPoint)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, pos");
    {
	wxTextCtrlBase *    THIS = (wxTextCtrlBase *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::TextCtrlBase" )
;
	long	pos = (long)SvIV(ST(1))
;
    try {
      THIS->SetInsertionPoint( pos );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__TextCtrlBase_SetInsertionPointEnd); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__TextCtrlBase_SetInsertionPointEnd)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxTextCtrlBase *    THIS = (wxTextCtrlBase *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::TextCtrlBase" )
;
    try {
      THIS->SetInsertionPointEnd();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__TextCtrlBase_GetInsertionPoint); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__TextCtrlBase_GetInsertionPoint)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxTextCtrlBase *    THIS = (wxTextCtrlBase *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::TextCtrlBase" )
;
	long	RETVAL;
	dXSTARG;
    try {
      RETVAL = THIS->GetInsertionPoint();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__TextCtrlBase_GetLastPosition); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__TextCtrlBase_GetLastPosition)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxTextCtrlBase *    THIS = (wxTextCtrlBase *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::TextCtrlBase" )
;
	wxTextPos	RETVAL;
	dXSTARG;
    try {
      RETVAL = THIS->GetLastPosition();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__TextCtrlBase_SetSelection); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__TextCtrlBase_SetSelection)
{
    dVAR; dXSARGS;
    if (items != 3)
       croak_xs_usage(cv,  "THIS, from, to");
    {
	wxTextCtrlBase *    THIS = (wxTextCtrlBase *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::TextCtrlBase" )
;
	long	from = (long)SvIV(ST(1))
;
	long	to = (long)SvIV(ST(2))
;
    try {
      THIS->SetSelection( from, to );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__TextCtrlBase_SelectAll); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__TextCtrlBase_SelectAll)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxTextCtrlBase *    THIS = (wxTextCtrlBase *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::TextCtrlBase" )
;
    try {
      THIS->SelectAll();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__TextCtrlBase_SetEditable); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__TextCtrlBase_SetEditable)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, editable");
    {
	wxTextCtrlBase *    THIS = (wxTextCtrlBase *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::TextCtrlBase" )
;
	bool	editable = (bool)SvTRUE(ST(1))
;
    try {
      THIS->SetEditable( editable );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}

#if WXPERL_W_VERSION_GE( 2, 9, 0 )
#define XSpp_3167bce7_000683
#define XSubPPtmpAAGH 1


XS_EUPXS(XS_Wx__TextCtrlBase_AutoComplete); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__TextCtrlBase_AutoComplete)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, choices");
    {
	wxTextCtrlBase *    THIS = (wxTextCtrlBase *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::TextCtrlBase" )
;
	bool	RETVAL;
	wxArrayString	choices;

    wxPli_av_2_arraystring( aTHX_ ST(1), & choices )
;
    try {
      RETVAL = THIS->AutoComplete( choices );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__TextCtrlBase_AutoCompleteFileNames); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__TextCtrlBase_AutoCompleteFileNames)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxTextCtrlBase *    THIS = (wxTextCtrlBase *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::TextCtrlBase" )
;
	bool	RETVAL;
    try {
      RETVAL = THIS->AutoCompleteFileNames();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}

#endif

XS_EUPXS(XS_Wx__TextCtrlBase_GetSelection); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__TextCtrlBase_GetSelection)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    PERL_UNUSED_VAR(ax); /* -Wall */
    SP -= items;
    {
    long from;
    long to;
	wxTextCtrlBase *    THIS = (wxTextCtrlBase *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::TextCtrlBase" )
;
    THIS->GetSelection( &from, &to );
    EXTEND( SP, 2 );
    PUSHs( sv_2mortal( newSViv( from ) ) );
    PUSHs( sv_2mortal( newSViv( to ) ) );
	PUTBACK;
	return;
    }
}


XS_EUPXS(XS_Wx__TextCtrlBase_PositionToXY); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__TextCtrlBase_PositionToXY)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, pos");
    PERL_UNUSED_VAR(ax); /* -Wall */
    SP -= items;
    {
	long	pos = (long)SvIV(ST(1))
;
    long x;
    long y;
	wxTextCtrlBase *    THIS = (wxTextCtrlBase *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::TextCtrlBase" )
;
    THIS->PositionToXY( pos, &x, &y );
    EXTEND( SP, 2 );
    PUSHs( sv_2mortal( newSViv( x ) ) );
    PUSHs( sv_2mortal( newSViv( y ) ) );
	PUTBACK;
	return;
    }
}


XS_EUPXS(XS_Wx__TextCtrlBase_HitTest); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__TextCtrlBase_HitTest)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, pt");
    PERL_UNUSED_VAR(ax); /* -Wall */
    SP -= items;
    {
	wxPoint    pt = wxPli_sv_2_wxpoint( aTHX_ ST(1) )
;
	wxTextCtrlBase *    THIS = (wxTextCtrlBase *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::TextCtrlBase" )
;
    long col, row;
    wxTextCtrlHitTestResult res = THIS->HitTest( pt, &col, &row );

    EXTEND( SP, 3 );
    PUSHs( sv_2mortal( newSViv( res ) ) );
    PUSHs( sv_2mortal( newSViv( col ) ) );
    PUSHs( sv_2mortal( newSViv( row ) ) );
	PUTBACK;
	return;
    }
}

#if defined( __WXMAC__ ) && WXPERL_W_VERSION_GE( 2, 8, 0 )
#define XSpp_3167bce7_075361
#define XSubPPtmpAAGI 1


XS_EUPXS(XS_Wx__TextCtrl_MacCheckSpelling); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__TextCtrl_MacCheckSpelling)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, check");
    {
	wxTextCtrl *    THIS = (wxTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::TextCtrl" )
;
	bool	check = (bool)SvTRUE(ST(1))
;
    try {
      THIS->MacCheckSpelling( check );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}

#endif

XS_EUPXS(XS_Wx__TextCtrl_new); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__TextCtrl_new)
{
    dVAR; dXSARGS;
    PERL_UNUSED_VAR(cv); /* -W */
    PERL_UNUSED_VAR(items); /* -W */
    PERL_UNUSED_VAR(ax); /* -Wall */
    SP -= items;
    {
    BEGIN_OVERLOAD()
        MATCH_VOIDM_REDISP( newDefault )
        MATCH_ANY_REDISP( newFull )
    END_OVERLOAD( "Wx::TextCtrl::new" )
	PUTBACK;
	return;
    }
}


XS_EUPXS(XS_Wx__TextCtrl_newDefault); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__TextCtrl_newDefault)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "CLASS");
    {
	PlClassName    CLASS = wxPli_get_class( aTHX_ ST(0) )
;
	wxTextCtrl *	RETVAL;
    RETVAL = new wxTextCtrl();
    wxPli_create_evthandler( aTHX_ RETVAL, CLASS );
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_object_2_sv( aTHX_ RETVALSV, RETVAL );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__TextCtrl_newFull); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__TextCtrl_newFull)
{
    dVAR; dXSARGS;
    if (items < 4 || items > 9)
       croak_xs_usage(cv,  "CLASS, parent, id, value, pos = wxDefaultPosition, size = wxDefaultSize, style = 0, validator = (wxValidator*)&wxDefaultValidator, name = wxTextCtrlNameStr");
    {
	PlClassName    CLASS = wxPli_get_class( aTHX_ ST(0) )
;
	wxWindow*    parent = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::Window" )
;
	wxWindowID    id = wxPli_get_wxwindowid( aTHX_ ST(2) )
;
	wxString	value;
	wxPoint	pos;
	wxSize	size;
	long	style;
	wxValidator*	validator;
	wxString	name;
	wxTextCtrl *	RETVAL;

    WXSTRING_INPUT( value, wxString, ST(3) )
;

	if (items < 5)
	    pos = wxDefaultPosition;
	else {
    pos = wxPli_sv_2_wxpoint( aTHX_ ST(4) )
;
	}

	if (items < 6)
	    size = wxDefaultSize;
	else {
    size = wxPli_sv_2_wxsize( aTHX_ ST(5) )
;
	}

	if (items < 7)
	    style = 0;
	else {
	    style = (long)SvIV(ST(6))
;
	}

	if (items < 8)
	    validator = (wxValidator*)&wxDefaultValidator;
	else {
    validator = (wxValidator *) wxPli_sv_2_object( aTHX_ ST(7), "Wx::Validator" )
;
	}

	if (items < 9)
	    name = wxTextCtrlNameStr;
	else {
    WXSTRING_INPUT( name, wxString, ST(8) )
;
	}
    RETVAL = new wxTextCtrl( parent, id, value, pos, size,
                             style, *validator, name );
    wxPli_create_evthandler( aTHX_ RETVAL, CLASS );
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_object_2_sv( aTHX_ RETVALSV, RETVAL );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__TextCtrl_Create); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__TextCtrl_Create)
{
    dVAR; dXSARGS;
    if (items < 4 || items > 9)
       croak_xs_usage(cv,  "THIS, parent, id, value, pos = wxDefaultPosition, size = wxDefaultSize, style = 0, validator = (wxValidator*)&wxDefaultValidator, name = wxTextCtrlNameStr");
    {
	wxWindow*    parent = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::Window" )
;
	wxWindowID    id = wxPli_get_wxwindowid( aTHX_ ST(2) )
;
	wxString	value;
	wxPoint	pos;
	wxSize	size;
	long	style;
	wxValidator*	validator;
	wxString	name;
	wxTextCtrl *    THIS = (wxTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::TextCtrl" )
;
	bool	RETVAL;

    WXSTRING_INPUT( value, wxString, ST(3) )
;

	if (items < 5)
	    pos = wxDefaultPosition;
	else {
    pos = wxPli_sv_2_wxpoint( aTHX_ ST(4) )
;
	}

	if (items < 6)
	    size = wxDefaultSize;
	else {
    size = wxPli_sv_2_wxsize( aTHX_ ST(5) )
;
	}

	if (items < 7)
	    style = 0;
	else {
	    style = (long)SvIV(ST(6))
;
	}

	if (items < 8)
	    validator = (wxValidator*)&wxDefaultValidator;
	else {
    validator = (wxValidator *) wxPli_sv_2_object( aTHX_ ST(7), "Wx::Validator" )
;
	}

	if (items < 9)
	    name = wxTextCtrlNameStr;
	else {
    WXSTRING_INPUT( name, wxString, ST(8) )
;
	}

	RETVAL = THIS->Create(parent, id, value, pos, size, style, *validator, name);
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__TextCtrl_GetStyle); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__TextCtrl_GetStyle)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, position");
    PERL_UNUSED_VAR(ax); /* -Wall */
    SP -= items;
    {
	long	position = (long)SvIV(ST(1))
;
	wxTextCtrl *    THIS = (wxTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::TextCtrl" )
;
    wxTextAttr attr;
    bool retval = THIS->GetStyle( position, attr );
    EXTEND( SP, 2 );
    PUSHs( newSViv( retval ) );
    PUSHs( retval ? wxPli_non_object_2_sv( aTHX_ sv_newmortal(),
                                           new wxTextAttr( attr ),
                                           "Wx::TextAttr" ) :
                    &PL_sv_undef );
	PUTBACK;
	return;
    }
}


XS_EUPXS(XS_Wx__TextCtrl_GetTextAttrStyle); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__TextCtrl_GetTextAttrStyle)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, position");
    PERL_UNUSED_VAR(ax); /* -Wall */
    SP -= items;
    {
	long	position = (long)SvIV(ST(1))
;
	wxTextCtrl *    THIS = (wxTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::TextCtrl" )
;
    wxTextAttr attr;
    bool retval = THIS->GetStyle( position, attr );
    EXTEND( SP, 2 );
    PUSHs( newSViv( retval ) );
    PUSHs( retval ? wxPli_non_object_2_sv( aTHX_ sv_newmortal(),
                                           new wxTextAttr( attr ),
                                           "Wx::TextAttr" ) :
                    &PL_sv_undef );
	PUTBACK;
	return;
    }
}


/* INCLUDE: Returning to 'Controls.xs' from '/usr/bin/perl -I./ -MExtUtils::XSpp::Cmd -e xspp -- -t typemap.xsp XS/TextCtrl.xsp' */


/* INCLUDE_COMMAND:  Including output of '/usr/bin/perl -I./ -MExtUtils::XSpp::Cmd -e xspp -- -t typemap.xsp XS/PickerCtrl.xsp' from 'Controls.xs' */

#include <exception>

#undef  xsp_constructor_class
#define xsp_constructor_class(c) (c)
#if WXPERL_W_VERSION_GE( 2, 7, 0 )
#include <wx/pickerbase.h>
#define XSubPPtmpAAGJ 1


XS_EUPXS(XS_Wx__PickerBase_SetInternalMargin); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__PickerBase_SetInternalMargin)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, newmargin");
    {
	wxPickerBase *    THIS = (wxPickerBase *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::PickerBase" )
;
	int	newmargin = (int)SvIV(ST(1))
;
    try {
      THIS->SetInternalMargin( newmargin );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__PickerBase_GetInternalMargin); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__PickerBase_GetInternalMargin)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxPickerBase *    THIS = (wxPickerBase *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::PickerBase" )
;
	int	RETVAL;
	dXSTARG;
    try {
      RETVAL = THIS->GetInternalMargin();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__PickerBase_SetTextCtrlProportion); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__PickerBase_SetTextCtrlProportion)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, prop");
    {
	wxPickerBase *    THIS = (wxPickerBase *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::PickerBase" )
;
	int	prop = (int)SvIV(ST(1))
;
    try {
      THIS->SetTextCtrlProportion( prop );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__PickerBase_GetTextCtrlProportion); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__PickerBase_GetTextCtrlProportion)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxPickerBase *    THIS = (wxPickerBase *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::PickerBase" )
;
	int	RETVAL;
	dXSTARG;
    try {
      RETVAL = THIS->GetTextCtrlProportion();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__PickerBase_SetPickerCtrlProportion); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__PickerBase_SetPickerCtrlProportion)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, prop");
    {
	wxPickerBase *    THIS = (wxPickerBase *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::PickerBase" )
;
	int	prop = (int)SvIV(ST(1))
;
    try {
      THIS->SetPickerCtrlProportion( prop );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__PickerBase_GetPickerCtrlProportion); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__PickerBase_GetPickerCtrlProportion)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxPickerBase *    THIS = (wxPickerBase *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::PickerBase" )
;
	int	RETVAL;
	dXSTARG;
    try {
      RETVAL = THIS->GetPickerCtrlProportion();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__PickerBase_IsTextCtrlGrowable); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__PickerBase_IsTextCtrlGrowable)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxPickerBase *    THIS = (wxPickerBase *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::PickerBase" )
;
	bool	RETVAL;
    try {
      RETVAL = THIS->IsTextCtrlGrowable();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__PickerBase_SetTextCtrlGrowable); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__PickerBase_SetTextCtrlGrowable)
{
    dVAR; dXSARGS;
    if (items < 1 || items > 2)
       croak_xs_usage(cv,  "THIS, grow= true");
    {
	wxPickerBase *    THIS = (wxPickerBase *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::PickerBase" )
;
	bool	grow;

	if (items < 2)
	    grow = true;
	else {
	    grow = (bool)SvTRUE(ST(1))
;
	}
    try {
      THIS->SetTextCtrlGrowable( grow );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__PickerBase_IsPickerCtrlGrowable); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__PickerBase_IsPickerCtrlGrowable)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxPickerBase *    THIS = (wxPickerBase *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::PickerBase" )
;
	bool	RETVAL;
    try {
      RETVAL = THIS->IsPickerCtrlGrowable();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__PickerBase_SetPickerCtrlGrowable); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__PickerBase_SetPickerCtrlGrowable)
{
    dVAR; dXSARGS;
    if (items < 1 || items > 2)
       croak_xs_usage(cv,  "THIS, grow= true");
    {
	wxPickerBase *    THIS = (wxPickerBase *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::PickerBase" )
;
	bool	grow;

	if (items < 2)
	    grow = true;
	else {
	    grow = (bool)SvTRUE(ST(1))
;
	}
    try {
      THIS->SetPickerCtrlGrowable( grow );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__PickerBase_HasTextCtrl); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__PickerBase_HasTextCtrl)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxPickerBase *    THIS = (wxPickerBase *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::PickerBase" )
;
	bool	RETVAL;
    try {
      RETVAL = THIS->HasTextCtrl();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__PickerBase_GetTextCtrl); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__PickerBase_GetTextCtrl)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxPickerBase *    THIS = (wxPickerBase *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::PickerBase" )
;
	wxTextCtrl *	RETVAL;
    try {
      RETVAL = THIS->GetTextCtrl();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_object_2_sv( aTHX_ RETVALSV, RETVAL );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__PickerBase_GetPickerCtrl); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__PickerBase_GetPickerCtrl)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxPickerBase *    THIS = (wxPickerBase *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::PickerBase" )
;
	wxControl *	RETVAL;
    try {
      RETVAL = THIS->GetPickerCtrl();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_object_2_sv( aTHX_ RETVALSV, RETVAL );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}

#endif

/* INCLUDE: Returning to 'Controls.xs' from '/usr/bin/perl -I./ -MExtUtils::XSpp::Cmd -e xspp -- -t typemap.xsp XS/PickerCtrl.xsp' */


/* INCLUDE_COMMAND:  Including output of '/usr/bin/perl -I./ -MExtUtils::XSpp::Cmd -e xspp -- -t typemap.xsp XS/ColourPickerCtrl.xsp' from 'Controls.xs' */

#include <exception>

#undef  xsp_constructor_class
#define xsp_constructor_class(c) (c)
#if WXPERL_W_VERSION_GE( 2, 7, 0 )
#include <wx/clrpicker.h>
#undef  xsp_constructor_class
#define xsp_constructor_class(c) (CLASS)
#define XSubPPtmpAAGK 1


XS_EUPXS(XS_Wx__ColourPickerCtrl_newDefault); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ColourPickerCtrl_newDefault)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "CLASS");
    {
	char *	CLASS = (char *)SvPV_nolen(ST(0))
;
	wxColourPickerCtrl *	RETVAL;
     RETVAL = new wxColourPickerCtrl;
                wxPli_create_evthandler( aTHX_ RETVAL, CLASS );
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_evthandler_2_sv( aTHX_ RETVALSV, RETVAL );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}

#undef  xsp_constructor_class
#define xsp_constructor_class(c) (c)
#undef  xsp_constructor_class
#define xsp_constructor_class(c) (CLASS)

XS_EUPXS(XS_Wx__ColourPickerCtrl_newFull); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ColourPickerCtrl_newFull)
{
    dVAR; dXSARGS;
    if (items < 2 || items > 9)
       croak_xs_usage(cv,  "CLASS, parent, id= wxID_ANY, col= wxBLACKPtr, pos= wxDefaultPosition, size= wxDefaultSize, style= wxCLRP_DEFAULT_STYLE, validator= wxDefaultValidatorPtr, name= wxButtonNameStr");
    {
	char *	CLASS = (char *)SvPV_nolen(ST(0))
;
	wxColourPickerCtrl *	RETVAL;
	wxWindow*    parent = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::Window" )
;
	wxWindowID	id;
	wxColour*	col;
	wxPoint	pos;
	wxSize	size;
	long	style;
	wxValidator*	validator;
	wxString	name;

	if (items < 3)
	    id = wxID_ANY;
	else {
    id = wxPli_get_wxwindowid( aTHX_ ST(2) )
;
	}

	if (items < 4)
	    col = wxBLACKPtr;
	else {
    col = (wxColour *) wxPli_sv_2_object( aTHX_ ST(3), "Wx::Colour" )
;
	}

	if (items < 5)
	    pos = wxDefaultPosition;
	else {
    pos = wxPli_sv_2_wxpoint( aTHX_ ST(4) )
;
	}

	if (items < 6)
	    size = wxDefaultSize;
	else {
    size = wxPli_sv_2_wxsize( aTHX_ ST(5) )
;
	}

	if (items < 7)
	    style = wxCLRP_DEFAULT_STYLE;
	else {
	    style = (long)SvIV(ST(6))
;
	}

	if (items < 8)
	    validator = wxDefaultValidatorPtr;
	else {
    validator = (wxValidator *) wxPli_sv_2_object( aTHX_ ST(7), "Wx::Validator" )
;
	}

	if (items < 9)
	    name = wxButtonNameStr;
	else {
    WXSTRING_INPUT( name, wxString, ST(8) )
;
	}
     RETVAL = new wxColourPickerCtrl( parent, id, *col, pos, size,
                                                 style, *validator, name );
                wxPli_create_evthandler( aTHX_ RETVAL, CLASS );
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_evthandler_2_sv( aTHX_ RETVALSV, RETVAL );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}

#undef  xsp_constructor_class
#define xsp_constructor_class(c) (c)

XS_EUPXS(XS_Wx__ColourPickerCtrl_Create); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ColourPickerCtrl_Create)
{
    dVAR; dXSARGS;
    if (items < 2 || items > 9)
       croak_xs_usage(cv,  "THIS, parent, id= wxID_ANY, col= wxBLACKPtr, pos= wxDefaultPosition, size= wxDefaultSize, style= wxCLRP_DEFAULT_STYLE, validator= wxDefaultValidatorPtr, name= wxButtonNameStr");
    {
	wxColourPickerCtrl *    THIS = (wxColourPickerCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::ColourPickerCtrl" )
;
	bool	RETVAL;
	wxWindow*    parent = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::Window" )
;
	wxWindowID	id;
	wxColour*	col;
	wxPoint	pos;
	wxSize	size;
	long	style;
	wxValidator*	validator;
	wxString	name;

	if (items < 3)
	    id = wxID_ANY;
	else {
    id = wxPli_get_wxwindowid( aTHX_ ST(2) )
;
	}

	if (items < 4)
	    col = wxBLACKPtr;
	else {
    col = (wxColour *) wxPli_sv_2_object( aTHX_ ST(3), "Wx::Colour" )
;
	}

	if (items < 5)
	    pos = wxDefaultPosition;
	else {
    pos = wxPli_sv_2_wxpoint( aTHX_ ST(4) )
;
	}

	if (items < 6)
	    size = wxDefaultSize;
	else {
    size = wxPli_sv_2_wxsize( aTHX_ ST(5) )
;
	}

	if (items < 7)
	    style = wxCLRP_DEFAULT_STYLE;
	else {
	    style = (long)SvIV(ST(6))
;
	}

	if (items < 8)
	    validator = wxDefaultValidatorPtr;
	else {
    validator = (wxValidator *) wxPli_sv_2_object( aTHX_ ST(7), "Wx::Validator" )
;
	}

	if (items < 9)
	    name = wxButtonNameStr;
	else {
    WXSTRING_INPUT( name, wxString, ST(8) )
;
	}
    try {
      RETVAL = THIS->Create( parent, id, *( col ), pos, size, style, *( validator ), name );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__ColourPickerCtrl_GetColour); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ColourPickerCtrl_GetColour)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxColourPickerCtrl *    THIS = (wxColourPickerCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::ColourPickerCtrl" )
;
	wxColour *	RETVAL;
    try {
      RETVAL = new wxColour( THIS->GetColour() );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_non_object_2_sv( aTHX_ RETVALSV, RETVAL, "Wx::Colour" );
    wxPli_thread_sv_register( aTHX_ "Wx::Colour", RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__ColourPickerCtrl_SetColourColour); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ColourPickerCtrl_SetColourColour)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, col");
    {
	wxColourPickerCtrl *    THIS = (wxColourPickerCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::ColourPickerCtrl" )
;
	wxColour*    col = (wxColour *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::Colour" )
;
    try {
      THIS->SetColour( *( col ) );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__ColourPickerCtrl_SetColourString); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ColourPickerCtrl_SetColourString)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, text");
    {
	wxColourPickerCtrl *    THIS = (wxColourPickerCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::ColourPickerCtrl" )
;
	bool	RETVAL;
	wxString	text;

    WXSTRING_INPUT( text, wxString, ST(1) )
;
    try {
      RETVAL = THIS->SetColour( text );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__ColourPickerCtrl_new); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ColourPickerCtrl_new)
{
    dVAR; dXSARGS;
    PERL_UNUSED_VAR(cv); /* -W */
    PERL_UNUSED_VAR(items); /* -W */
    PERL_UNUSED_VAR(ax); /* -Wall */
    SP -= items;
    {
    BEGIN_OVERLOAD()
        MATCH_VOIDM_REDISP( newDefault )
        MATCH_ANY_REDISP( newFull )
    END_OVERLOAD( "Wx::ColourPickerCtrl::new" )
	PUTBACK;
	return;
    }
}


XS_EUPXS(XS_Wx__ColourPickerCtrl_SetColour); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ColourPickerCtrl_SetColour)
{
    dVAR; dXSARGS;
    PERL_UNUSED_VAR(cv); /* -W */
    PERL_UNUSED_VAR(items); /* -W */
    PERL_UNUSED_VAR(ax); /* -Wall */
    SP -= items;
    {
    BEGIN_OVERLOAD()
        MATCH_REDISP( wxPliOvl_wcol, SetColourColour )
        MATCH_REDISP( wxPliOvl_s, SetColourString )
    END_OVERLOAD( Wx::ColourPickerCtrl::SetColour )
	PUTBACK;
	return;
    }
}


XS_EUPXS(XS_Wx__ColourPickerEvent_GetColour); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ColourPickerEvent_GetColour)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxColourPickerEvent *    THIS = (wxColourPickerEvent *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::ColourPickerEvent" )
;
	wxColour *	RETVAL;
    try {
      RETVAL = new wxColour( THIS->GetColour() );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_non_object_2_sv( aTHX_ RETVALSV, RETVAL, "Wx::Colour" );
    wxPli_thread_sv_register( aTHX_ "Wx::Colour", RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__ColourPickerEvent_SetColour); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ColourPickerEvent_SetColour)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, colour");
    {
	wxColourPickerEvent *    THIS = (wxColourPickerEvent *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::ColourPickerEvent" )
;
	wxColour*    colour = (wxColour *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::Colour" )
;
    try {
      THIS->SetColour( *( colour ) );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}

#endif

/* INCLUDE: Returning to 'Controls.xs' from '/usr/bin/perl -I./ -MExtUtils::XSpp::Cmd -e xspp -- -t typemap.xsp XS/ColourPickerCtrl.xsp' */


/* INCLUDE_COMMAND:  Including output of '/usr/bin/perl -I./ -MExtUtils::XSpp::Cmd -e xspp -- -t typemap.xsp XS/FilePickerCtrl.xsp' from 'Controls.xs' */

#include <exception>

#undef  xsp_constructor_class
#define xsp_constructor_class(c) (c)
#if WXPERL_W_VERSION_GE( 2, 7, 0 )
#include <wx/filepicker.h>
#undef  xsp_constructor_class
#define xsp_constructor_class(c) (CLASS)
#define XSubPPtmpAAGL 1


XS_EUPXS(XS_Wx__FilePickerCtrl_newDefault); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__FilePickerCtrl_newDefault)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "CLASS");
    {
	char *	CLASS = (char *)SvPV_nolen(ST(0))
;
	wxFilePickerCtrl *	RETVAL;
     RETVAL = new wxFilePickerCtrl;
                wxPli_create_evthandler( aTHX_ RETVAL, CLASS );
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_evthandler_2_sv( aTHX_ RETVALSV, RETVAL );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}

#undef  xsp_constructor_class
#define xsp_constructor_class(c) (c)
#undef  xsp_constructor_class
#define xsp_constructor_class(c) (CLASS)

XS_EUPXS(XS_Wx__FilePickerCtrl_newFull); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__FilePickerCtrl_newFull)
{
    dVAR; dXSARGS;
    if (items < 2 || items > 11)
       croak_xs_usage(cv,  "CLASS, parent, id= wxID_ANY, path= wxEmptyString, message= wxFileSelectorPromptStr, wildcard= wxFileSelectorDefaultWildcardStr, pos= wxDefaultPosition, size= wxDefaultSize, style= wxCLRP_DEFAULT_STYLE, validator= wxDefaultValidatorPtr, name= wxFilePickerCtrlNameStr");
    {
	char *	CLASS = (char *)SvPV_nolen(ST(0))
;
	wxFilePickerCtrl *	RETVAL;
	wxWindow*    parent = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::Window" )
;
	wxWindowID	id;
	wxString	path;
	wxString	message;
	wxString	wildcard;
	wxPoint	pos;
	wxSize	size;
	long	style;
	wxValidator*	validator;
	wxString	name;

	if (items < 3)
	    id = wxID_ANY;
	else {
    id = wxPli_get_wxwindowid( aTHX_ ST(2) )
;
	}

	if (items < 4)
	    path = wxEmptyString;
	else {
    WXSTRING_INPUT( path, wxString, ST(3) )
;
	}

	if (items < 5)
	    message = wxFileSelectorPromptStr;
	else {
    WXSTRING_INPUT( message, wxString, ST(4) )
;
	}

	if (items < 6)
	    wildcard = wxFileSelectorDefaultWildcardStr;
	else {
    WXSTRING_INPUT( wildcard, wxString, ST(5) )
;
	}

	if (items < 7)
	    pos = wxDefaultPosition;
	else {
    pos = wxPli_sv_2_wxpoint( aTHX_ ST(6) )
;
	}

	if (items < 8)
	    size = wxDefaultSize;
	else {
    size = wxPli_sv_2_wxsize( aTHX_ ST(7) )
;
	}

	if (items < 9)
	    style = wxCLRP_DEFAULT_STYLE;
	else {
	    style = (long)SvIV(ST(8))
;
	}

	if (items < 10)
	    validator = wxDefaultValidatorPtr;
	else {
    validator = (wxValidator *) wxPli_sv_2_object( aTHX_ ST(9), "Wx::Validator" )
;
	}

	if (items < 11)
	    name = wxFilePickerCtrlNameStr;
	else {
    WXSTRING_INPUT( name, wxString, ST(10) )
;
	}
     RETVAL = new wxFilePickerCtrl( parent, id, path, message,
                                               wildcard, pos, size,
                                               style, *validator, name );
                wxPli_create_evthandler( aTHX_ RETVAL, CLASS );
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_evthandler_2_sv( aTHX_ RETVALSV, RETVAL );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}

#undef  xsp_constructor_class
#define xsp_constructor_class(c) (c)

XS_EUPXS(XS_Wx__FilePickerCtrl_Create); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__FilePickerCtrl_Create)
{
    dVAR; dXSARGS;
    if (items < 2 || items > 11)
       croak_xs_usage(cv,  "THIS, parent, id= wxID_ANY, path= wxEmptyString, message= wxFileSelectorPromptStr, wildcard= wxFileSelectorDefaultWildcardStr, pos= wxDefaultPosition, size= wxDefaultSize, style= wxCLRP_DEFAULT_STYLE, validator= wxDefaultValidatorPtr, name= wxFilePickerCtrlNameStr");
    {
	wxFilePickerCtrl *    THIS = (wxFilePickerCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::FilePickerCtrl" )
;
	bool	RETVAL;
	wxWindow*    parent = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::Window" )
;
	wxWindowID	id;
	wxString	path;
	wxString	message;
	wxString	wildcard;
	wxPoint	pos;
	wxSize	size;
	long	style;
	wxValidator*	validator;
	wxString	name;

	if (items < 3)
	    id = wxID_ANY;
	else {
    id = wxPli_get_wxwindowid( aTHX_ ST(2) )
;
	}

	if (items < 4)
	    path = wxEmptyString;
	else {
    WXSTRING_INPUT( path, wxString, ST(3) )
;
	}

	if (items < 5)
	    message = wxFileSelectorPromptStr;
	else {
    WXSTRING_INPUT( message, wxString, ST(4) )
;
	}

	if (items < 6)
	    wildcard = wxFileSelectorDefaultWildcardStr;
	else {
    WXSTRING_INPUT( wildcard, wxString, ST(5) )
;
	}

	if (items < 7)
	    pos = wxDefaultPosition;
	else {
    pos = wxPli_sv_2_wxpoint( aTHX_ ST(6) )
;
	}

	if (items < 8)
	    size = wxDefaultSize;
	else {
    size = wxPli_sv_2_wxsize( aTHX_ ST(7) )
;
	}

	if (items < 9)
	    style = wxCLRP_DEFAULT_STYLE;
	else {
	    style = (long)SvIV(ST(8))
;
	}

	if (items < 10)
	    validator = wxDefaultValidatorPtr;
	else {
    validator = (wxValidator *) wxPli_sv_2_object( aTHX_ ST(9), "Wx::Validator" )
;
	}

	if (items < 11)
	    name = wxFilePickerCtrlNameStr;
	else {
    WXSTRING_INPUT( name, wxString, ST(10) )
;
	}
    try {
      RETVAL = THIS->Create( parent, id, path, message, wildcard, pos, size, style, *( validator ), name );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__FilePickerCtrl_GetPath); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__FilePickerCtrl_GetPath)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxFilePickerCtrl *    THIS = (wxFilePickerCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::FilePickerCtrl" )
;
	wxString	RETVAL;
    try {
      RETVAL = THIS->GetPath();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    WXSTRING_OUTPUT( RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__FilePickerCtrl_SetPath); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__FilePickerCtrl_SetPath)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, str");
    {
	wxFilePickerCtrl *    THIS = (wxFilePickerCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::FilePickerCtrl" )
;
	wxString	str;

    WXSTRING_INPUT( str, wxString, ST(1) )
;
    try {
      THIS->SetPath( str );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__FilePickerCtrl_new); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__FilePickerCtrl_new)
{
    dVAR; dXSARGS;
    PERL_UNUSED_VAR(cv); /* -W */
    PERL_UNUSED_VAR(items); /* -W */
    PERL_UNUSED_VAR(ax); /* -Wall */
    SP -= items;
    {
    BEGIN_OVERLOAD()
        MATCH_VOIDM_REDISP( newDefault )
        MATCH_ANY_REDISP( newFull )
    END_OVERLOAD( "Wx::FilePickerCtrl::new" )
	PUTBACK;
	return;
    }
}

#undef  xsp_constructor_class
#define xsp_constructor_class(c) (CLASS)

XS_EUPXS(XS_Wx__DirPickerCtrl_newDefault); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__DirPickerCtrl_newDefault)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "CLASS");
    {
	char *	CLASS = (char *)SvPV_nolen(ST(0))
;
	wxDirPickerCtrl *	RETVAL;
     RETVAL = new wxDirPickerCtrl;
                wxPli_create_evthandler( aTHX_ RETVAL, CLASS );
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_evthandler_2_sv( aTHX_ RETVALSV, RETVAL );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}

#undef  xsp_constructor_class
#define xsp_constructor_class(c) (c)
#undef  xsp_constructor_class
#define xsp_constructor_class(c) (CLASS)

XS_EUPXS(XS_Wx__DirPickerCtrl_newFull); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__DirPickerCtrl_newFull)
{
    dVAR; dXSARGS;
    if (items < 2 || items > 10)
       croak_xs_usage(cv,  "CLASS, parent, id= wxID_ANY, path= wxEmptyString, message= wxDirSelectorPromptStr, pos= wxDefaultPosition, size= wxDefaultSize, style= wxCLRP_DEFAULT_STYLE, validator= wxDefaultValidatorPtr, name= wxDirPickerCtrlNameStr");
    {
	char *	CLASS = (char *)SvPV_nolen(ST(0))
;
	wxDirPickerCtrl *	RETVAL;
	wxWindow*    parent = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::Window" )
;
	wxWindowID	id;
	wxString	path;
	wxString	message;
	wxPoint	pos;
	wxSize	size;
	long	style;
	wxValidator*	validator;
	wxString	name;

	if (items < 3)
	    id = wxID_ANY;
	else {
    id = wxPli_get_wxwindowid( aTHX_ ST(2) )
;
	}

	if (items < 4)
	    path = wxEmptyString;
	else {
    WXSTRING_INPUT( path, wxString, ST(3) )
;
	}

	if (items < 5)
	    message = wxDirSelectorPromptStr;
	else {
    WXSTRING_INPUT( message, wxString, ST(4) )
;
	}

	if (items < 6)
	    pos = wxDefaultPosition;
	else {
    pos = wxPli_sv_2_wxpoint( aTHX_ ST(5) )
;
	}

	if (items < 7)
	    size = wxDefaultSize;
	else {
    size = wxPli_sv_2_wxsize( aTHX_ ST(6) )
;
	}

	if (items < 8)
	    style = wxCLRP_DEFAULT_STYLE;
	else {
	    style = (long)SvIV(ST(7))
;
	}

	if (items < 9)
	    validator = wxDefaultValidatorPtr;
	else {
    validator = (wxValidator *) wxPli_sv_2_object( aTHX_ ST(8), "Wx::Validator" )
;
	}

	if (items < 10)
	    name = wxDirPickerCtrlNameStr;
	else {
    WXSTRING_INPUT( name, wxString, ST(9) )
;
	}
     RETVAL = new wxDirPickerCtrl( parent, id, path, message,
                                              pos, size,
                                              style, *validator, name );
                wxPli_create_evthandler( aTHX_ RETVAL, CLASS );
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_evthandler_2_sv( aTHX_ RETVALSV, RETVAL );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}

#undef  xsp_constructor_class
#define xsp_constructor_class(c) (c)

XS_EUPXS(XS_Wx__DirPickerCtrl_Create); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__DirPickerCtrl_Create)
{
    dVAR; dXSARGS;
    if (items < 2 || items > 10)
       croak_xs_usage(cv,  "THIS, parent, id= wxID_ANY, path= wxEmptyString, message= wxDirSelectorPromptStr, pos= wxDefaultPosition, size= wxDefaultSize, style= wxCLRP_DEFAULT_STYLE, validator= wxDefaultValidatorPtr, name= wxDirPickerCtrlNameStr");
    {
	wxDirPickerCtrl *    THIS = (wxDirPickerCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::DirPickerCtrl" )
;
	bool	RETVAL;
	wxWindow*    parent = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::Window" )
;
	wxWindowID	id;
	wxString	path;
	wxString	message;
	wxPoint	pos;
	wxSize	size;
	long	style;
	wxValidator*	validator;
	wxString	name;

	if (items < 3)
	    id = wxID_ANY;
	else {
    id = wxPli_get_wxwindowid( aTHX_ ST(2) )
;
	}

	if (items < 4)
	    path = wxEmptyString;
	else {
    WXSTRING_INPUT( path, wxString, ST(3) )
;
	}

	if (items < 5)
	    message = wxDirSelectorPromptStr;
	else {
    WXSTRING_INPUT( message, wxString, ST(4) )
;
	}

	if (items < 6)
	    pos = wxDefaultPosition;
	else {
    pos = wxPli_sv_2_wxpoint( aTHX_ ST(5) )
;
	}

	if (items < 7)
	    size = wxDefaultSize;
	else {
    size = wxPli_sv_2_wxsize( aTHX_ ST(6) )
;
	}

	if (items < 8)
	    style = wxCLRP_DEFAULT_STYLE;
	else {
	    style = (long)SvIV(ST(7))
;
	}

	if (items < 9)
	    validator = wxDefaultValidatorPtr;
	else {
    validator = (wxValidator *) wxPli_sv_2_object( aTHX_ ST(8), "Wx::Validator" )
;
	}

	if (items < 10)
	    name = wxDirPickerCtrlNameStr;
	else {
    WXSTRING_INPUT( name, wxString, ST(9) )
;
	}
    try {
      RETVAL = THIS->Create( parent, id, path, message, pos, size, style, *( validator ), name );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__DirPickerCtrl_GetPath); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__DirPickerCtrl_GetPath)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxDirPickerCtrl *    THIS = (wxDirPickerCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::DirPickerCtrl" )
;
	wxString	RETVAL;
    try {
      RETVAL = THIS->GetPath();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    WXSTRING_OUTPUT( RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__DirPickerCtrl_SetPath); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__DirPickerCtrl_SetPath)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, str");
    {
	wxDirPickerCtrl *    THIS = (wxDirPickerCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::DirPickerCtrl" )
;
	wxString	str;

    WXSTRING_INPUT( str, wxString, ST(1) )
;
    try {
      THIS->SetPath( str );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__DirPickerCtrl_new); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__DirPickerCtrl_new)
{
    dVAR; dXSARGS;
    PERL_UNUSED_VAR(cv); /* -W */
    PERL_UNUSED_VAR(items); /* -W */
    PERL_UNUSED_VAR(ax); /* -Wall */
    SP -= items;
    {
    BEGIN_OVERLOAD()
        MATCH_VOIDM_REDISP( newDefault )
        MATCH_ANY_REDISP( newFull )
    END_OVERLOAD( "Wx::DirPickerCtrl::new" )
	PUTBACK;
	return;
    }
}


XS_EUPXS(XS_Wx__FileDirPickerEvent_GetPath); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__FileDirPickerEvent_GetPath)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxFileDirPickerEvent *    THIS = (wxFileDirPickerEvent *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::FileDirPickerEvent" )
;
	wxString	RETVAL;
    try {
      RETVAL = THIS->GetPath();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    WXSTRING_OUTPUT( RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__FileDirPickerEvent_SetPath); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__FileDirPickerEvent_SetPath)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, p");
    {
	wxFileDirPickerEvent *    THIS = (wxFileDirPickerEvent *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::FileDirPickerEvent" )
;
	wxString	p;

    WXSTRING_INPUT( p, wxString, ST(1) )
;
    try {
      THIS->SetPath( p );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}

#endif

/* INCLUDE: Returning to 'Controls.xs' from '/usr/bin/perl -I./ -MExtUtils::XSpp::Cmd -e xspp -- -t typemap.xsp XS/FilePickerCtrl.xsp' */


/* INCLUDE_COMMAND:  Including output of '/usr/bin/perl -I./ -MExtUtils::XSpp::Cmd -e xspp -- -t typemap.xsp XS/FontPickerCtrl.xsp' from 'Controls.xs' */

#include <exception>

#undef  xsp_constructor_class
#define xsp_constructor_class(c) (c)
#if WXPERL_W_VERSION_GE( 2, 7, 0 )
#include <wx/fontpicker.h>
#undef  xsp_constructor_class
#define xsp_constructor_class(c) (CLASS)
#define XSubPPtmpAAGM 1


XS_EUPXS(XS_Wx__FontPickerCtrl_newDefault); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__FontPickerCtrl_newDefault)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "CLASS");
    {
	char *	CLASS = (char *)SvPV_nolen(ST(0))
;
	wxFontPickerCtrl *	RETVAL;
     RETVAL = new wxFontPickerCtrl;
                wxPli_create_evthandler( aTHX_ RETVAL, CLASS );
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_evthandler_2_sv( aTHX_ RETVALSV, RETVAL );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}

#undef  xsp_constructor_class
#define xsp_constructor_class(c) (c)
#undef  xsp_constructor_class
#define xsp_constructor_class(c) (CLASS)

XS_EUPXS(XS_Wx__FontPickerCtrl_newFull); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__FontPickerCtrl_newFull)
{
    dVAR; dXSARGS;
    if (items < 2 || items > 9)
       croak_xs_usage(cv,  "CLASS, parent, id= wxID_ANY, font= wxNORMAL_FONTPtr, pos= wxDefaultPosition, size= wxDefaultSize, style= wxCLRP_DEFAULT_STYLE, validator= wxDefaultValidatorPtr, name= wxButtonNameStr");
    {
	char *	CLASS = (char *)SvPV_nolen(ST(0))
;
	wxFontPickerCtrl *	RETVAL;
	wxWindow*    parent = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::Window" )
;
	wxWindowID	id;
	wxFont*	font;
	wxPoint	pos;
	wxSize	size;
	long	style;
	wxValidator*	validator;
	wxString	name;

	if (items < 3)
	    id = wxID_ANY;
	else {
    id = wxPli_get_wxwindowid( aTHX_ ST(2) )
;
	}

	if (items < 4)
	    font = wxNORMAL_FONTPtr;
	else {
    font = (wxFont *) wxPli_sv_2_object( aTHX_ ST(3), "Wx::Font" )
;
	}

	if (items < 5)
	    pos = wxDefaultPosition;
	else {
    pos = wxPli_sv_2_wxpoint( aTHX_ ST(4) )
;
	}

	if (items < 6)
	    size = wxDefaultSize;
	else {
    size = wxPli_sv_2_wxsize( aTHX_ ST(5) )
;
	}

	if (items < 7)
	    style = wxCLRP_DEFAULT_STYLE;
	else {
	    style = (long)SvIV(ST(6))
;
	}

	if (items < 8)
	    validator = wxDefaultValidatorPtr;
	else {
    validator = (wxValidator *) wxPli_sv_2_object( aTHX_ ST(7), "Wx::Validator" )
;
	}

	if (items < 9)
	    name = wxButtonNameStr;
	else {
    WXSTRING_INPUT( name, wxString, ST(8) )
;
	}
     RETVAL = new wxFontPickerCtrl( parent, id, *font, pos, size,
                                                style, *validator, name );
                wxPli_create_evthandler( aTHX_ RETVAL, CLASS );
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_evthandler_2_sv( aTHX_ RETVALSV, RETVAL );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}

#undef  xsp_constructor_class
#define xsp_constructor_class(c) (c)

XS_EUPXS(XS_Wx__FontPickerCtrl_Create); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__FontPickerCtrl_Create)
{
    dVAR; dXSARGS;
    if (items < 2 || items > 9)
       croak_xs_usage(cv,  "THIS, parent, id= wxID_ANY, col= wxNORMAL_FONTPtr, pos= wxDefaultPosition, size= wxDefaultSize, style= wxCLRP_DEFAULT_STYLE, validator= wxDefaultValidatorPtr, name= wxButtonNameStr");
    {
	wxFontPickerCtrl *    THIS = (wxFontPickerCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::FontPickerCtrl" )
;
	bool	RETVAL;
	wxWindow*    parent = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::Window" )
;
	wxWindowID	id;
	wxFont*	col;
	wxPoint	pos;
	wxSize	size;
	long	style;
	wxValidator*	validator;
	wxString	name;

	if (items < 3)
	    id = wxID_ANY;
	else {
    id = wxPli_get_wxwindowid( aTHX_ ST(2) )
;
	}

	if (items < 4)
	    col = wxNORMAL_FONTPtr;
	else {
    col = (wxFont *) wxPli_sv_2_object( aTHX_ ST(3), "Wx::Font" )
;
	}

	if (items < 5)
	    pos = wxDefaultPosition;
	else {
    pos = wxPli_sv_2_wxpoint( aTHX_ ST(4) )
;
	}

	if (items < 6)
	    size = wxDefaultSize;
	else {
    size = wxPli_sv_2_wxsize( aTHX_ ST(5) )
;
	}

	if (items < 7)
	    style = wxCLRP_DEFAULT_STYLE;
	else {
	    style = (long)SvIV(ST(6))
;
	}

	if (items < 8)
	    validator = wxDefaultValidatorPtr;
	else {
    validator = (wxValidator *) wxPli_sv_2_object( aTHX_ ST(7), "Wx::Validator" )
;
	}

	if (items < 9)
	    name = wxButtonNameStr;
	else {
    WXSTRING_INPUT( name, wxString, ST(8) )
;
	}
    try {
      RETVAL = THIS->Create( parent, id, *( col ), pos, size, style, *( validator ), name );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__FontPickerCtrl_GetSelectedFont); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__FontPickerCtrl_GetSelectedFont)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxFontPickerCtrl *    THIS = (wxFontPickerCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::FontPickerCtrl" )
;
	wxFont *	RETVAL;
    try {
      RETVAL = new wxFont( THIS->GetSelectedFont() );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_object_2_sv( aTHX_ RETVALSV, RETVAL );
    wxPli_thread_sv_register( aTHX_ "Wx::Font", RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__FontPickerCtrl_SetSelectedFont); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__FontPickerCtrl_SetSelectedFont)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, f");
    {
	wxFontPickerCtrl *    THIS = (wxFontPickerCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::FontPickerCtrl" )
;
	wxFont*    f = (wxFont *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::Font" )
;
    try {
      THIS->SetSelectedFont( *( f ) );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__FontPickerCtrl_SetMaxPointSize); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__FontPickerCtrl_SetMaxPointSize)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, max");
    {
	wxFontPickerCtrl *    THIS = (wxFontPickerCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::FontPickerCtrl" )
;
	unsigned int    max = (unsigned int)SvUV( ST(1) )
;
    try {
      THIS->SetMaxPointSize( max );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__FontPickerCtrl_GetMaxPointSize); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__FontPickerCtrl_GetMaxPointSize)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxFontPickerCtrl *    THIS = (wxFontPickerCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::FontPickerCtrl" )
;
	unsigned int	RETVAL;
	dXSTARG;
    try {
      RETVAL = THIS->GetMaxPointSize();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	XSprePUSH;
	PUSHu((UV)RETVAL );
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__FontPickerCtrl_new); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__FontPickerCtrl_new)
{
    dVAR; dXSARGS;
    PERL_UNUSED_VAR(cv); /* -W */
    PERL_UNUSED_VAR(items); /* -W */
    PERL_UNUSED_VAR(ax); /* -Wall */
    SP -= items;
    {
    BEGIN_OVERLOAD()
        MATCH_VOIDM_REDISP( newDefault )
        MATCH_ANY_REDISP( newFull )
    END_OVERLOAD( "Wx::FontPickerCtrl::new" )
	PUTBACK;
	return;
    }
}


XS_EUPXS(XS_Wx__FontPickerEvent_GetFont); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__FontPickerEvent_GetFont)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxFontPickerEvent *    THIS = (wxFontPickerEvent *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::FontPickerEvent" )
;
	wxFont *	RETVAL;
    try {
      RETVAL = new wxFont( THIS->GetFont() );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_object_2_sv( aTHX_ RETVALSV, RETVAL );
    wxPli_thread_sv_register( aTHX_ "Wx::Font", RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__FontPickerEvent_SetFont); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__FontPickerEvent_SetFont)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, c");
    {
	wxFontPickerEvent *    THIS = (wxFontPickerEvent *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::FontPickerEvent" )
;
	wxFont*    c = (wxFont *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::Font" )
;
    try {
      THIS->SetFont( *( c ) );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}

#endif

/* INCLUDE: Returning to 'Controls.xs' from '/usr/bin/perl -I./ -MExtUtils::XSpp::Cmd -e xspp -- -t typemap.xsp XS/FontPickerCtrl.xsp' */

#ifdef __cplusplus
extern "C"
#endif
XS_EXTERNAL(boot_Wx_Ctrl); /* prototype to pass -Wmissing-prototypes */
XS_EXTERNAL(boot_Wx_Ctrl)
{
#if PERL_VERSION_LE(5, 21, 5)
    dVAR; dXSARGS;
#else
    dVAR; dXSBOOTARGSXSAPIVERCHK;
#endif
#if PERL_VERSION_LE(5, 8, 999) /* PERL_VERSION_LT is 5.33+ */
    char* file = __FILE__;
#else
    const char* file = __FILE__;
#endif

    PERL_UNUSED_VAR(file);

    PERL_UNUSED_VAR(cv); /* -W */
    PERL_UNUSED_VAR(items); /* -W */
#if PERL_VERSION_LE(5, 21, 5)
    XS_VERSION_BOOTCHECK;
#  ifdef XS_APIVERSION_BOOTCHECK
    XS_APIVERSION_BOOTCHECK;
#  endif
#endif

        newXS_deffile("Wx::Control::Command", XS_Wx__Control_Command);
#if XSubPPtmpAAAA
        newXS_deffile("Wx::Control::GetLabelText", XS_Wx__Control_GetLabelText);
#endif
        newXS_deffile("Wx::ControlWithItems::GetCount", XS_Wx__ControlWithItems_GetCount);
#if XSubPPtmpAAAB
        newXS_deffile("Wx::ControlWithItems::IsEmpty", XS_Wx__ControlWithItems_IsEmpty);
#endif
        newXS_deffile("Wx::ControlWithItems::GetString", XS_Wx__ControlWithItems_GetString);
        newXS_deffile("Wx::ControlWithItems::GetStrings", XS_Wx__ControlWithItems_GetStrings);
        newXS_deffile("Wx::ControlWithItems::SetString", XS_Wx__ControlWithItems_SetString);
        newXS_deffile("Wx::ControlWithItems::FindString", XS_Wx__ControlWithItems_FindString);
        newXS_deffile("Wx::ControlWithItems::FindStringNoCase", XS_Wx__ControlWithItems_FindStringNoCase);
#if XSubPPtmpAAAC
        newXS_deffile("Wx::ControlWithItems::FindStringCase", XS_Wx__ControlWithItems_FindStringCase);
#endif
#if XSubPPtmpAAAD
        newXS_deffile("Wx::ControlWithItems::SetSelection", XS_Wx__ControlWithItems_SetSelection);
        newXS_deffile("Wx::ControlWithItems::GetSelection", XS_Wx__ControlWithItems_GetSelection);
#endif
        newXS_deffile("Wx::ControlWithItems::SetStringSelection", XS_Wx__ControlWithItems_SetStringSelection);
        newXS_deffile("Wx::ControlWithItems::GetStringSelection", XS_Wx__ControlWithItems_GetStringSelection);
        newXS_deffile("Wx::ControlWithItems::Select", XS_Wx__ControlWithItems_Select);
        newXS_deffile("Wx::ControlWithItems::Append", XS_Wx__ControlWithItems_Append);
        newXS_deffile("Wx::ControlWithItems::AppendString", XS_Wx__ControlWithItems_AppendString);
        newXS_deffile("Wx::ControlWithItems::AppendData", XS_Wx__ControlWithItems_AppendData);
        newXS_deffile("Wx::ControlWithItems::AppendItems", XS_Wx__ControlWithItems_AppendItems);
#if XSubPPtmpAAAE
        newXS_deffile("Wx::ControlWithItems::AppendItemsData", XS_Wx__ControlWithItems_AppendItemsData);
#endif
        newXS_deffile("Wx::ControlWithItems::Insert", XS_Wx__ControlWithItems_Insert);
        newXS_deffile("Wx::ControlWithItems::InsertString", XS_Wx__ControlWithItems_InsertString);
        newXS_deffile("Wx::ControlWithItems::InsertData", XS_Wx__ControlWithItems_InsertData);
#if XSubPPtmpAAAF
        newXS_deffile("Wx::ControlWithItems::InsertItems", XS_Wx__ControlWithItems_InsertItems);
        newXS_deffile("Wx::ControlWithItems::InsertItemsData", XS_Wx__ControlWithItems_InsertItemsData);
#endif
#if XSubPPtmpAAAG
        newXS_deffile("Wx::ControlWithItems::Set", XS_Wx__ControlWithItems_Set);
        newXS_deffile("Wx::ControlWithItems::SetItems", XS_Wx__ControlWithItems_SetItems);
        newXS_deffile("Wx::ControlWithItems::SetItemsData", XS_Wx__ControlWithItems_SetItemsData);
#endif
        newXS_deffile("Wx::ControlWithItems::Clear", XS_Wx__ControlWithItems_Clear);
        newXS_deffile("Wx::ControlWithItems::Delete", XS_Wx__ControlWithItems_Delete);
        newXS_deffile("Wx::ControlWithItems::GetClientData", XS_Wx__ControlWithItems_GetClientData);
        newXS_deffile("Wx::ControlWithItems::SetClientData", XS_Wx__ControlWithItems_SetClientData);
#if XSubPPtmpAAAH
        newXS_deffile("Wx::AnimationCtrl::newDefault", XS_Wx__AnimationCtrl_newDefault);
        newXS_deffile("Wx::AnimationCtrl::new", XS_Wx__AnimationCtrl_new);
        newXS_deffile("Wx::AnimationCtrl::Create", XS_Wx__AnimationCtrl_Create);
        newXS_deffile("Wx::AnimationCtrl::LoadFile", XS_Wx__AnimationCtrl_LoadFile);
        newXS_deffile("Wx::AnimationCtrl::SetAnimation", XS_Wx__AnimationCtrl_SetAnimation);
        newXS_deffile("Wx::AnimationCtrl::GetAnimation", XS_Wx__AnimationCtrl_GetAnimation);
        newXS_deffile("Wx::AnimationCtrl::Play", XS_Wx__AnimationCtrl_Play);
        newXS_deffile("Wx::AnimationCtrl::Stop", XS_Wx__AnimationCtrl_Stop);
        newXS_deffile("Wx::AnimationCtrl::IsPlaying", XS_Wx__AnimationCtrl_IsPlaying);
        newXS_deffile("Wx::AnimationCtrl::SetInactiveBitmap", XS_Wx__AnimationCtrl_SetInactiveBitmap);
        newXS_deffile("Wx::AnimationCtrl::GetInactiveBitmap", XS_Wx__AnimationCtrl_GetInactiveBitmap);
#endif
#if XSubPPtmpAAAI
        newXS_deffile("Wx::BitmapButton::NewCloseButton", XS_Wx__BitmapButton_NewCloseButton);
#endif
        newXS_deffile("Wx::BitmapButton::newDefault", XS_Wx__BitmapButton_newDefault);
        newXS_deffile("Wx::BitmapButton::newFull", XS_Wx__BitmapButton_newFull);
        newXS_deffile("Wx::BitmapButton::Create", XS_Wx__BitmapButton_Create);
        newXS_deffile("Wx::BitmapButton::GetBitmapDisabled", XS_Wx__BitmapButton_GetBitmapDisabled);
        newXS_deffile("Wx::BitmapButton::GetBitmapFocus", XS_Wx__BitmapButton_GetBitmapFocus);
#if XSubPPtmpAAAJ
        newXS_deffile("Wx::BitmapButton::GetBitmapHover", XS_Wx__BitmapButton_GetBitmapHover);
#endif
        newXS_deffile("Wx::BitmapButton::GetBitmapLabel", XS_Wx__BitmapButton_GetBitmapLabel);
        newXS_deffile("Wx::BitmapButton::GetBitmapSelected", XS_Wx__BitmapButton_GetBitmapSelected);
        newXS_deffile("Wx::BitmapButton::SetBitmapDisabled", XS_Wx__BitmapButton_SetBitmapDisabled);
        newXS_deffile("Wx::BitmapButton::SetBitmapFocus", XS_Wx__BitmapButton_SetBitmapFocus);
#if XSubPPtmpAAAK
        newXS_deffile("Wx::BitmapButton::SetBitmapHover", XS_Wx__BitmapButton_SetBitmapHover);
#endif
        newXS_deffile("Wx::BitmapButton::SetBitmapLabel", XS_Wx__BitmapButton_SetBitmapLabel);
        newXS_deffile("Wx::BitmapButton::SetBitmapSelected", XS_Wx__BitmapButton_SetBitmapSelected);
#if XSubPPtmpAAAL
        newXS_deffile("Wx::BitmapButton::new", XS_Wx__BitmapButton_new);
#endif
#if XSubPPtmpAAAM
        newXS_deffile("Wx::EditableListBox::new", XS_Wx__EditableListBox_new);
        newXS_deffile("Wx::EditableListBox::newDefault", XS_Wx__EditableListBox_newDefault);
        newXS_deffile("Wx::EditableListBox::newFull", XS_Wx__EditableListBox_newFull);
        newXS_deffile("Wx::EditableListBox::Create", XS_Wx__EditableListBox_Create);
        newXS_deffile("Wx::EditableListBox::SetStrings", XS_Wx__EditableListBox_SetStrings);
        newXS_deffile("Wx::EditableListBox::GetStrings", XS_Wx__EditableListBox_GetStrings);
        newXS_deffile("Wx::EditableListBox::GetListCtrl", XS_Wx__EditableListBox_GetListCtrl);
        newXS_deffile("Wx::EditableListBox::GetDelButton", XS_Wx__EditableListBox_GetDelButton);
        newXS_deffile("Wx::EditableListBox::GetNewButton", XS_Wx__EditableListBox_GetNewButton);
        newXS_deffile("Wx::EditableListBox::GetUpButton", XS_Wx__EditableListBox_GetUpButton);
        newXS_deffile("Wx::EditableListBox::GetDownButton", XS_Wx__EditableListBox_GetDownButton);
        newXS_deffile("Wx::EditableListBox::GetEditButton", XS_Wx__EditableListBox_GetEditButton);
#endif
#if XSubPPtmpAAAN
        newXS_deffile("Wx::BookCtrl::GetPageCount", XS_Wx__BookCtrl_GetPageCount);
        newXS_deffile("Wx::BookCtrl::GetPage", XS_Wx__BookCtrl_GetPage);
        newXS_deffile("Wx::BookCtrl::GetSelection", XS_Wx__BookCtrl_GetSelection);
        newXS_deffile("Wx::BookCtrl::SetPageText", XS_Wx__BookCtrl_SetPageText);
        newXS_deffile("Wx::BookCtrl::GetPageText", XS_Wx__BookCtrl_GetPageText);
        newXS_deffile("Wx::BookCtrl::SetImageList", XS_Wx__BookCtrl_SetImageList);
        newXS_deffile("Wx::BookCtrl::GetPageImage", XS_Wx__BookCtrl_GetPageImage);
        newXS_deffile("Wx::BookCtrl::SetPageImage", XS_Wx__BookCtrl_SetPageImage);
        newXS_deffile("Wx::BookCtrl::SetPageSize", XS_Wx__BookCtrl_SetPageSize);
        newXS_deffile("Wx::BookCtrl::CalcSizeFromPage", XS_Wx__BookCtrl_CalcSizeFromPage);
#if XSubPPtmpAAAO
        newXS_deffile("Wx::BookCtrl::GetInternalBorder", XS_Wx__BookCtrl_GetInternalBorder);
        newXS_deffile("Wx::BookCtrl::SetInternalBorder", XS_Wx__BookCtrl_SetInternalBorder);
        newXS_deffile("Wx::BookCtrl::IsVertical", XS_Wx__BookCtrl_IsVertical);
        newXS_deffile("Wx::BookCtrl::SetFitToCurrentPage", XS_Wx__BookCtrl_SetFitToCurrentPage);
        newXS_deffile("Wx::BookCtrl::GetFitToCurrentPage", XS_Wx__BookCtrl_GetFitToCurrentPage);
        newXS_deffile("Wx::BookCtrl::GetControlSizer", XS_Wx__BookCtrl_GetControlSizer);
#endif
        newXS_deffile("Wx::BookCtrl::DeletePage", XS_Wx__BookCtrl_DeletePage);
        newXS_deffile("Wx::BookCtrl::RemovePage", XS_Wx__BookCtrl_RemovePage);
        newXS_deffile("Wx::BookCtrl::DeleteAllPages", XS_Wx__BookCtrl_DeleteAllPages);
        newXS_deffile("Wx::BookCtrl::AddPage", XS_Wx__BookCtrl_AddPage);
        newXS_deffile("Wx::BookCtrl::InsertPage", XS_Wx__BookCtrl_InsertPage);
        newXS_deffile("Wx::BookCtrl::SetSelection", XS_Wx__BookCtrl_SetSelection);
        newXS_deffile("Wx::BookCtrl::AdvanceSelection", XS_Wx__BookCtrl_AdvanceSelection);
#if XSubPPtmpAAAP
        newXS_deffile("Wx::BookCtrl::ChangeSelection", XS_Wx__BookCtrl_ChangeSelection);
#endif
#if XSubPPtmpAAAQ
        newXS_deffile("Wx::BookCtrl::GetCurrentPage", XS_Wx__BookCtrl_GetCurrentPage);
#endif
        newXS_deffile("Wx::BookCtrl::AssignImageList", XS_Wx__BookCtrl_AssignImageList);
        newXS_deffile("Wx::BookCtrl::GetImageList", XS_Wx__BookCtrl_GetImageList);
#if XSubPPtmpAAAR
        newXS_deffile("Wx::BookCtrl::HitTest", XS_Wx__BookCtrl_HitTest);
#endif
        newXS_deffile("Wx::BookCtrlEvent::GetSelection", XS_Wx__BookCtrlEvent_GetSelection);
        newXS_deffile("Wx::BookCtrlEvent::SetSelection", XS_Wx__BookCtrlEvent_SetSelection);
        newXS_deffile("Wx::BookCtrlEvent::GetOldSelection", XS_Wx__BookCtrlEvent_GetOldSelection);
        newXS_deffile("Wx::BookCtrlEvent::SetOldSelection", XS_Wx__BookCtrlEvent_SetOldSelection);
#endif
#if XSubPPtmpAAAS
        newXS_deffile("Wx::Listbook::newDefault", XS_Wx__Listbook_newDefault);
        newXS_deffile("Wx::Listbook::newFull", XS_Wx__Listbook_newFull);
        newXS_deffile("Wx::Listbook::Create", XS_Wx__Listbook_Create);
#if XSubPPtmpAAAT
        newXS_deffile("Wx::Listbook::GetListView", XS_Wx__Listbook_GetListView);
#endif
        newXS_deffile("Wx::Listbook::new", XS_Wx__Listbook_new);
#endif
#if XSubPPtmpAAAU
        newXS_deffile("Wx::Choicebook::newDefault", XS_Wx__Choicebook_newDefault);
        newXS_deffile("Wx::Choicebook::newFull", XS_Wx__Choicebook_newFull);
        newXS_deffile("Wx::Choicebook::Create", XS_Wx__Choicebook_Create);
        newXS_deffile("Wx::Choicebook::IsVertical", XS_Wx__Choicebook_IsVertical);
#if XSubPPtmpAAAV
        newXS_deffile("Wx::Choicebook::GetChoiceCtrl", XS_Wx__Choicebook_GetChoiceCtrl);
#endif
        newXS_deffile("Wx::Choicebook::new", XS_Wx__Choicebook_new);
#endif
#if XSubPPtmpAAAW
        newXS_deffile("Wx::Toolbook::newDefault", XS_Wx__Toolbook_newDefault);
        newXS_deffile("Wx::Toolbook::newFull", XS_Wx__Toolbook_newFull);
        newXS_deffile("Wx::Toolbook::Create", XS_Wx__Toolbook_Create);
        newXS_deffile("Wx::Toolbook::GetToolBar", XS_Wx__Toolbook_GetToolBar);
        newXS_deffile("Wx::Toolbook::Realize", XS_Wx__Toolbook_Realize);
        newXS_deffile("Wx::Toolbook::new", XS_Wx__Toolbook_new);
#endif
#if XSubPPtmpAAAX
        newXS_deffile("Wx::TreebookEvent::new", XS_Wx__TreebookEvent_new);
        newXS_deffile("Wx::TreebookEvent::GetOldSelection", XS_Wx__TreebookEvent_GetOldSelection);
        newXS_deffile("Wx::TreebookEvent::GetSelection", XS_Wx__TreebookEvent_GetSelection);
        newXS_deffile("Wx::Treebook::newDefault", XS_Wx__Treebook_newDefault);
        newXS_deffile("Wx::Treebook::newFull", XS_Wx__Treebook_newFull);
        newXS_deffile("Wx::Treebook::Create", XS_Wx__Treebook_Create);
        newXS_deffile("Wx::Treebook::InsertSubPage", XS_Wx__Treebook_InsertSubPage);
        newXS_deffile("Wx::Treebook::AddSubPage", XS_Wx__Treebook_AddSubPage);
        newXS_deffile("Wx::Treebook::IsNodeExpanded", XS_Wx__Treebook_IsNodeExpanded);
        newXS_deffile("Wx::Treebook::ExpandNode", XS_Wx__Treebook_ExpandNode);
        newXS_deffile("Wx::Treebook::CollapseNode", XS_Wx__Treebook_CollapseNode);
        newXS_deffile("Wx::Treebook::GetPageParent", XS_Wx__Treebook_GetPageParent);
        newXS_deffile("Wx::Treebook::GetTreeCtrl", XS_Wx__Treebook_GetTreeCtrl);
        newXS_deffile("Wx::Treebook::new", XS_Wx__Treebook_new);
#endif
#if XSubPPtmpAAAY
        newXS_deffile("Wx::HyperlinkCtrl::newDefault", XS_Wx__HyperlinkCtrl_newDefault);
        newXS_deffile("Wx::HyperlinkCtrl::newFull", XS_Wx__HyperlinkCtrl_newFull);
        newXS_deffile("Wx::HyperlinkCtrl::Create", XS_Wx__HyperlinkCtrl_Create);
        newXS_deffile("Wx::HyperlinkCtrl::GetHoverColour", XS_Wx__HyperlinkCtrl_GetHoverColour);
        newXS_deffile("Wx::HyperlinkCtrl::SetHoverColour", XS_Wx__HyperlinkCtrl_SetHoverColour);
        newXS_deffile("Wx::HyperlinkCtrl::GetNormalColour", XS_Wx__HyperlinkCtrl_GetNormalColour);
        newXS_deffile("Wx::HyperlinkCtrl::SetNormalColour", XS_Wx__HyperlinkCtrl_SetNormalColour);
        newXS_deffile("Wx::HyperlinkCtrl::GetVisitedColour", XS_Wx__HyperlinkCtrl_GetVisitedColour);
        newXS_deffile("Wx::HyperlinkCtrl::SetVisitedColour", XS_Wx__HyperlinkCtrl_SetVisitedColour);
        newXS_deffile("Wx::HyperlinkCtrl::GetURL", XS_Wx__HyperlinkCtrl_GetURL);
        newXS_deffile("Wx::HyperlinkCtrl::SetURL", XS_Wx__HyperlinkCtrl_SetURL);
        newXS_deffile("Wx::HyperlinkCtrl::SetVisited", XS_Wx__HyperlinkCtrl_SetVisited);
        newXS_deffile("Wx::HyperlinkCtrl::GetVisited", XS_Wx__HyperlinkCtrl_GetVisited);
        newXS_deffile("Wx::HyperlinkEvent::GetURL", XS_Wx__HyperlinkEvent_GetURL);
        newXS_deffile("Wx::HyperlinkEvent::SetURL", XS_Wx__HyperlinkEvent_SetURL);
        newXS_deffile("Wx::HyperlinkEvent::new", XS_Wx__HyperlinkEvent_new);
#endif
#if XSubPPtmpAAAZ
        newXS_deffile("Wx::VListBox::Create", XS_Wx__VListBox_Create);
        newXS_deffile("Wx::VListBox::GetItemCount", XS_Wx__VListBox_GetItemCount);
        newXS_deffile("Wx::VListBox::HasMultipleSelection", XS_Wx__VListBox_HasMultipleSelection);
        newXS_deffile("Wx::VListBox::IsCurrent", XS_Wx__VListBox_IsCurrent);
        newXS_deffile("Wx::VListBox::IsSelected", XS_Wx__VListBox_IsSelected);
        newXS_deffile("Wx::VListBox::GetSelectedCount", XS_Wx__VListBox_GetSelectedCount);
        newXS_deffile("Wx::VListBox::GetMargins", XS_Wx__VListBox_GetMargins);
        newXS_deffile("Wx::VListBox::GetSelectionBackground", XS_Wx__VListBox_GetSelectionBackground);
        newXS_deffile("Wx::VListBox::SetItemCount", XS_Wx__VListBox_SetItemCount);
        newXS_deffile("Wx::VListBox::Clear", XS_Wx__VListBox_Clear);
        newXS_deffile("Wx::VListBox::GetSelection", XS_Wx__VListBox_GetSelection);
        newXS_deffile("Wx::VListBox::SetSelection", XS_Wx__VListBox_SetSelection);
        newXS_deffile("Wx::VListBox::Select", XS_Wx__VListBox_Select);
        newXS_deffile("Wx::VListBox::SelectRange", XS_Wx__VListBox_SelectRange);
        newXS_deffile("Wx::VListBox::Toggle", XS_Wx__VListBox_Toggle);
        newXS_deffile("Wx::VListBox::SelectAll", XS_Wx__VListBox_SelectAll);
        newXS_deffile("Wx::VListBox::DeselectAll", XS_Wx__VListBox_DeselectAll);
        newXS_deffile("Wx::VListBox::SetMargins", XS_Wx__VListBox_SetMargins);
        newXS_deffile("Wx::VListBox::SetSelectionBackground", XS_Wx__VListBox_SetSelectionBackground);
        newXS_deffile("Wx::VListBox::GetFirstSelected", XS_Wx__VListBox_GetFirstSelected);
        newXS_deffile("Wx::VListBox::GetNextSelected", XS_Wx__VListBox_GetNextSelected);
        newXS_deffile("Wx::PlVListBox::new", XS_Wx__PlVListBox_new);
        newXS_deffile("Wx::PlVListBox::newDefault", XS_Wx__PlVListBox_newDefault);
        newXS_deffile("Wx::PlVListBox::newFull", XS_Wx__PlVListBox_newFull);
#endif
#if XSubPPtmpAABA
        newXS_deffile("Wx::SearchCtrl::new", XS_Wx__SearchCtrl_new);
        newXS_deffile("Wx::SearchCtrl::newDefault", XS_Wx__SearchCtrl_newDefault);
        newXS_deffile("Wx::SearchCtrl::newFull", XS_Wx__SearchCtrl_newFull);
        newXS_deffile("Wx::SearchCtrl::Create", XS_Wx__SearchCtrl_Create);
        newXS_deffile("Wx::SearchCtrl::SetMenu", XS_Wx__SearchCtrl_SetMenu);
        newXS_deffile("Wx::SearchCtrl::GetMenu", XS_Wx__SearchCtrl_GetMenu);
        newXS_deffile("Wx::SearchCtrl::ShowSearchButton", XS_Wx__SearchCtrl_ShowSearchButton);
        newXS_deffile("Wx::SearchCtrl::IsSearchButtonVisible", XS_Wx__SearchCtrl_IsSearchButtonVisible);
        newXS_deffile("Wx::SearchCtrl::ShowCancelButton", XS_Wx__SearchCtrl_ShowCancelButton);
        newXS_deffile("Wx::SearchCtrl::IsCancelButtonVisible", XS_Wx__SearchCtrl_IsCancelButtonVisible);
        newXS_deffile("Wx::SearchCtrl::SetDescriptiveText", XS_Wx__SearchCtrl_SetDescriptiveText);
        newXS_deffile("Wx::SearchCtrl::GetDescriptiveText", XS_Wx__SearchCtrl_GetDescriptiveText);
#if XSubPPtmpAABB
#if XSubPPtmpAABC
        newXS_deffile("Wx::SearchCtrl::GetValue", XS_Wx__SearchCtrl_GetValue);
        newXS_deffile("Wx::SearchCtrl::SetValue", XS_Wx__SearchCtrl_SetValue);
        newXS_deffile("Wx::SearchCtrl::ChangeValue", XS_Wx__SearchCtrl_ChangeValue);
        newXS_deffile("Wx::SearchCtrl::GetRange", XS_Wx__SearchCtrl_GetRange);
        newXS_deffile("Wx::SearchCtrl::WriteText", XS_Wx__SearchCtrl_WriteText);
        newXS_deffile("Wx::SearchCtrl::AppendText", XS_Wx__SearchCtrl_AppendText);
        newXS_deffile("Wx::SearchCtrl::IsEmpty", XS_Wx__SearchCtrl_IsEmpty);
        newXS_deffile("Wx::SearchCtrl::Clear", XS_Wx__SearchCtrl_Clear);
        newXS_deffile("Wx::SearchCtrl::Replace", XS_Wx__SearchCtrl_Replace);
        newXS_deffile("Wx::SearchCtrl::Remove", XS_Wx__SearchCtrl_Remove);
        newXS_deffile("Wx::SearchCtrl::RemoveSelection", XS_Wx__SearchCtrl_RemoveSelection);
        newXS_deffile("Wx::SearchCtrl::Copy", XS_Wx__SearchCtrl_Copy);
        newXS_deffile("Wx::SearchCtrl::Cut", XS_Wx__SearchCtrl_Cut);
        newXS_deffile("Wx::SearchCtrl::Paste", XS_Wx__SearchCtrl_Paste);
        newXS_deffile("Wx::SearchCtrl::CanCopy", XS_Wx__SearchCtrl_CanCopy);
        newXS_deffile("Wx::SearchCtrl::CanCut", XS_Wx__SearchCtrl_CanCut);
        newXS_deffile("Wx::SearchCtrl::CanPaste", XS_Wx__SearchCtrl_CanPaste);
        newXS_deffile("Wx::SearchCtrl::Undo", XS_Wx__SearchCtrl_Undo);
        newXS_deffile("Wx::SearchCtrl::Redo", XS_Wx__SearchCtrl_Redo);
        newXS_deffile("Wx::SearchCtrl::CanUndo", XS_Wx__SearchCtrl_CanUndo);
        newXS_deffile("Wx::SearchCtrl::CanRedo", XS_Wx__SearchCtrl_CanRedo);
        newXS_deffile("Wx::SearchCtrl::SetInsertionPoint", XS_Wx__SearchCtrl_SetInsertionPoint);
        newXS_deffile("Wx::SearchCtrl::SetInsertionPointEnd", XS_Wx__SearchCtrl_SetInsertionPointEnd);
        newXS_deffile("Wx::SearchCtrl::GetInsertionPoint", XS_Wx__SearchCtrl_GetInsertionPoint);
        newXS_deffile("Wx::SearchCtrl::GetLastPosition", XS_Wx__SearchCtrl_GetLastPosition);
        newXS_deffile("Wx::SearchCtrl::SetSelection", XS_Wx__SearchCtrl_SetSelection);
        newXS_deffile("Wx::SearchCtrl::SelectAll", XS_Wx__SearchCtrl_SelectAll);
        newXS_deffile("Wx::SearchCtrl::HasSelection", XS_Wx__SearchCtrl_HasSelection);
        newXS_deffile("Wx::SearchCtrl::GetStringSelection", XS_Wx__SearchCtrl_GetStringSelection);
        newXS_deffile("Wx::SearchCtrl::AutoCompleteFileNames", XS_Wx__SearchCtrl_AutoCompleteFileNames);
        newXS_deffile("Wx::SearchCtrl::AutoComplete", XS_Wx__SearchCtrl_AutoComplete);
        newXS_deffile("Wx::SearchCtrl::IsEditable", XS_Wx__SearchCtrl_IsEditable);
        newXS_deffile("Wx::SearchCtrl::SetEditable", XS_Wx__SearchCtrl_SetEditable);
        newXS_deffile("Wx::SearchCtrl::SetMaxLength", XS_Wx__SearchCtrl_SetMaxLength);
        newXS_deffile("Wx::SearchCtrl::SetHint", XS_Wx__SearchCtrl_SetHint);
        newXS_deffile("Wx::SearchCtrl::GetHint", XS_Wx__SearchCtrl_GetHint);
        newXS_deffile("Wx::SearchCtrl::SetMargins", XS_Wx__SearchCtrl_SetMargins);
        newXS_deffile("Wx::SearchCtrl::GetMargins", XS_Wx__SearchCtrl_GetMargins);
        newXS_deffile("Wx::SearchCtrl::GetLineLength", XS_Wx__SearchCtrl_GetLineLength);
        newXS_deffile("Wx::SearchCtrl::GetLineText", XS_Wx__SearchCtrl_GetLineText);
        newXS_deffile("Wx::SearchCtrl::GetNumberOfLines", XS_Wx__SearchCtrl_GetNumberOfLines);
#if XSubPPtmpAABD
        newXS_deffile("Wx::SearchCtrl::LoadFile", XS_Wx__SearchCtrl_LoadFile);
        newXS_deffile("Wx::SearchCtrl::SaveFile", XS_Wx__SearchCtrl_SaveFile);
#endif
        newXS_deffile("Wx::SearchCtrl::IsModified", XS_Wx__SearchCtrl_IsModified);
        newXS_deffile("Wx::SearchCtrl::MarkDirty", XS_Wx__SearchCtrl_MarkDirty);
        newXS_deffile("Wx::SearchCtrl::DiscardEdits", XS_Wx__SearchCtrl_DiscardEdits);
        newXS_deffile("Wx::SearchCtrl::SetModified", XS_Wx__SearchCtrl_SetModified);
#if XSubPPtmpAABE
        newXS_deffile("Wx::SearchCtrl::SetStyle", XS_Wx__SearchCtrl_SetStyle);
#endif
#if XSubPPtmpAABF
        newXS_deffile("Wx::SearchCtrl::SetDefaultStyle", XS_Wx__SearchCtrl_SetDefaultStyle);
#endif
        newXS_deffile("Wx::SearchCtrl::GetDefaultStyle", XS_Wx__SearchCtrl_GetDefaultStyle);
        newXS_deffile("Wx::SearchCtrl::XYToPosition", XS_Wx__SearchCtrl_XYToPosition);
        newXS_deffile("Wx::SearchCtrl::ShowPosition", XS_Wx__SearchCtrl_ShowPosition);
        newXS_deffile("Wx::SearchCtrl::GetSelection", XS_Wx__SearchCtrl_GetSelection);
#if XSubPPtmpAABG
        newXS_deffile("Wx::SearchCtrl::GetStyle", XS_Wx__SearchCtrl_GetStyle);
#endif
        newXS_deffile("Wx::SearchCtrl::PositionToXY", XS_Wx__SearchCtrl_PositionToXY);
        newXS_deffile("Wx::SearchCtrl::HitTest", XS_Wx__SearchCtrl_HitTest);
#endif
#endif
#endif
#if XSubPPtmpAABH
        newXS_deffile("Wx::ComboPopup::new", XS_Wx__ComboPopup_new);
        newXS_deffile("Wx::ComboPopup::OnPopup", XS_Wx__ComboPopup_OnPopup);
        newXS_deffile("Wx::ComboPopup::OnDismiss", XS_Wx__ComboPopup_OnDismiss);
        newXS_deffile("Wx::ComboPopup::SetStringValue", XS_Wx__ComboPopup_SetStringValue);
        newXS_deffile("Wx::ComboPopup::PaintComboControl", XS_Wx__ComboPopup_PaintComboControl);
        newXS_deffile("Wx::ComboPopup::OnComboKeyEvent", XS_Wx__ComboPopup_OnComboKeyEvent);
        newXS_deffile("Wx::ComboPopup::OnComboDoubleClick", XS_Wx__ComboPopup_OnComboDoubleClick);
        newXS_deffile("Wx::ComboPopup::GetAdjustedSize", XS_Wx__ComboPopup_GetAdjustedSize);
        newXS_deffile("Wx::ComboPopup::LazyCreate", XS_Wx__ComboPopup_LazyCreate);
        newXS_deffile("Wx::ComboPopup::Dismiss", XS_Wx__ComboPopup_Dismiss);
        newXS_deffile("Wx::ComboPopup::IsCreated", XS_Wx__ComboPopup_IsCreated);
        newXS_deffile("Wx::ComboPopup::GetComboCtrl", XS_Wx__ComboPopup_GetComboCtrl);
#endif
#if XSubPPtmpAABI
        newXS_deffile("Wx::ComboCtrl::new", XS_Wx__ComboCtrl_new);
        newXS_deffile("Wx::ComboCtrl::newDefault", XS_Wx__ComboCtrl_newDefault);
        newXS_deffile("Wx::ComboCtrl::newFull", XS_Wx__ComboCtrl_newFull);
        newXS_deffile("Wx::ComboCtrl::Create", XS_Wx__ComboCtrl_Create);
        newXS_deffile("Wx::ComboCtrl::ShowPopup", XS_Wx__ComboCtrl_ShowPopup);
        newXS_deffile("Wx::ComboCtrl::HidePopup", XS_Wx__ComboCtrl_HidePopup);
        newXS_deffile("Wx::ComboCtrl::IsPopupShown", XS_Wx__ComboCtrl_IsPopupShown);
        newXS_deffile("Wx::ComboCtrl::SetPopupControl", XS_Wx__ComboCtrl_SetPopupControl);
        newXS_deffile("Wx::ComboCtrl::GetPopupControl", XS_Wx__ComboCtrl_GetPopupControl);
        newXS_deffile("Wx::ComboCtrl::GetPopupWindow", XS_Wx__ComboCtrl_GetPopupWindow);
        newXS_deffile("Wx::ComboCtrl::GetTextCtrl", XS_Wx__ComboCtrl_GetTextCtrl);
        newXS_deffile("Wx::ComboCtrl::GetButton", XS_Wx__ComboCtrl_GetButton);
        newXS_deffile("Wx::ComboCtrl::GetValue", XS_Wx__ComboCtrl_GetValue);
        newXS_deffile("Wx::ComboCtrl::SetValue", XS_Wx__ComboCtrl_SetValue);
        newXS_deffile("Wx::ComboCtrl::Copy", XS_Wx__ComboCtrl_Copy);
        newXS_deffile("Wx::ComboCtrl::Cut", XS_Wx__ComboCtrl_Cut);
        newXS_deffile("Wx::ComboCtrl::Paste", XS_Wx__ComboCtrl_Paste);
        newXS_deffile("Wx::ComboCtrl::SetInsertionPoint", XS_Wx__ComboCtrl_SetInsertionPoint);
        newXS_deffile("Wx::ComboCtrl::SetInsertionPointEnd", XS_Wx__ComboCtrl_SetInsertionPointEnd);
        newXS_deffile("Wx::ComboCtrl::GetInsertionPoint", XS_Wx__ComboCtrl_GetInsertionPoint);
        newXS_deffile("Wx::ComboCtrl::GetLastPosition", XS_Wx__ComboCtrl_GetLastPosition);
        newXS_deffile("Wx::ComboCtrl::Replace", XS_Wx__ComboCtrl_Replace);
        newXS_deffile("Wx::ComboCtrl::Remove", XS_Wx__ComboCtrl_Remove);
        newXS_deffile("Wx::ComboCtrl::SetSelection", XS_Wx__ComboCtrl_SetSelection);
        newXS_deffile("Wx::ComboCtrl::Undo", XS_Wx__ComboCtrl_Undo);
        newXS_deffile("Wx::ComboCtrl::SetText", XS_Wx__ComboCtrl_SetText);
        newXS_deffile("Wx::ComboCtrl::SetPopupMinWidth", XS_Wx__ComboCtrl_SetPopupMinWidth);
        newXS_deffile("Wx::ComboCtrl::SetPopupMaxHeight", XS_Wx__ComboCtrl_SetPopupMaxHeight);
        newXS_deffile("Wx::ComboCtrl::SetPopupExtents", XS_Wx__ComboCtrl_SetPopupExtents);
        newXS_deffile("Wx::ComboCtrl::SetCustomPaintWidth", XS_Wx__ComboCtrl_SetCustomPaintWidth);
        newXS_deffile("Wx::ComboCtrl::GetCustomPaintWidth", XS_Wx__ComboCtrl_GetCustomPaintWidth);
        newXS_deffile("Wx::ComboCtrl::SetPopupAnchor", XS_Wx__ComboCtrl_SetPopupAnchor);
        newXS_deffile("Wx::ComboCtrl::SetButtonPosition", XS_Wx__ComboCtrl_SetButtonPosition);
        newXS_deffile("Wx::ComboCtrl::GetButtonSize", XS_Wx__ComboCtrl_GetButtonSize);
        newXS_deffile("Wx::ComboCtrl::SetButtonBitmaps", XS_Wx__ComboCtrl_SetButtonBitmaps);
#if XSubPPtmpAABJ
        newXS_deffile("Wx::ComboCtrl::SetTextIndent", XS_Wx__ComboCtrl_SetTextIndent);
        newXS_deffile("Wx::ComboCtrl::GetTextIndent", XS_Wx__ComboCtrl_GetTextIndent);
#endif
        newXS_deffile("Wx::ComboCtrl::GetTextRect", XS_Wx__ComboCtrl_GetTextRect);
        newXS_deffile("Wx::ComboCtrl::UseAltPopupWindow", XS_Wx__ComboCtrl_UseAltPopupWindow);
        newXS_deffile("Wx::ComboCtrl::EnablePopupAnimation", XS_Wx__ComboCtrl_EnablePopupAnimation);
        newXS_deffile("Wx::ComboCtrl::GetBitmapNormal", XS_Wx__ComboCtrl_GetBitmapNormal);
        newXS_deffile("Wx::ComboCtrl::GetBitmapPressed", XS_Wx__ComboCtrl_GetBitmapPressed);
        newXS_deffile("Wx::ComboCtrl::GetBitmapHover", XS_Wx__ComboCtrl_GetBitmapHover);
        newXS_deffile("Wx::ComboCtrl::GetBitmapDisabled", XS_Wx__ComboCtrl_GetBitmapDisabled);
#endif
#if XSubPPtmpAABK
        newXS_deffile("Wx::OwnerDrawnComboBox::GetWidestItemWidth", XS_Wx__OwnerDrawnComboBox_GetWidestItemWidth);
        newXS_deffile("Wx::OwnerDrawnComboBox::GetWidestItem", XS_Wx__OwnerDrawnComboBox_GetWidestItem);
        newXS_deffile("Wx::OwnerDrawnComboBox::GetCount", XS_Wx__OwnerDrawnComboBox_GetCount);
#if XSubPPtmpAABL
        newXS_deffile("Wx::OwnerDrawnComboBox::IsEmpty", XS_Wx__OwnerDrawnComboBox_IsEmpty);
#endif
        newXS_deffile("Wx::OwnerDrawnComboBox::GetString", XS_Wx__OwnerDrawnComboBox_GetString);
        newXS_deffile("Wx::OwnerDrawnComboBox::GetStrings", XS_Wx__OwnerDrawnComboBox_GetStrings);
        newXS_deffile("Wx::OwnerDrawnComboBox::SetString", XS_Wx__OwnerDrawnComboBox_SetString);
        newXS_deffile("Wx::OwnerDrawnComboBox::FindString", XS_Wx__OwnerDrawnComboBox_FindString);
        newXS_deffile("Wx::OwnerDrawnComboBox::FindStringNoCase", XS_Wx__OwnerDrawnComboBox_FindStringNoCase);
#if XSubPPtmpAABM
        newXS_deffile("Wx::OwnerDrawnComboBox::FindStringCase", XS_Wx__OwnerDrawnComboBox_FindStringCase);
#endif
#if XSubPPtmpAABN
        newXS_deffile("Wx::OwnerDrawnComboBox::SetSelection", XS_Wx__OwnerDrawnComboBox_SetSelection);
        newXS_deffile("Wx::OwnerDrawnComboBox::GetSelection", XS_Wx__OwnerDrawnComboBox_GetSelection);
#endif
        newXS_deffile("Wx::OwnerDrawnComboBox::SetStringSelection", XS_Wx__OwnerDrawnComboBox_SetStringSelection);
        newXS_deffile("Wx::OwnerDrawnComboBox::GetStringSelection", XS_Wx__OwnerDrawnComboBox_GetStringSelection);
        newXS_deffile("Wx::OwnerDrawnComboBox::Select", XS_Wx__OwnerDrawnComboBox_Select);
        newXS_deffile("Wx::OwnerDrawnComboBox::Append", XS_Wx__OwnerDrawnComboBox_Append);
        newXS_deffile("Wx::OwnerDrawnComboBox::AppendString", XS_Wx__OwnerDrawnComboBox_AppendString);
        newXS_deffile("Wx::OwnerDrawnComboBox::AppendData", XS_Wx__OwnerDrawnComboBox_AppendData);
        newXS_deffile("Wx::OwnerDrawnComboBox::AppendItems", XS_Wx__OwnerDrawnComboBox_AppendItems);
#if XSubPPtmpAABO
        newXS_deffile("Wx::OwnerDrawnComboBox::AppendItemsData", XS_Wx__OwnerDrawnComboBox_AppendItemsData);
#endif
        newXS_deffile("Wx::OwnerDrawnComboBox::Insert", XS_Wx__OwnerDrawnComboBox_Insert);
        newXS_deffile("Wx::OwnerDrawnComboBox::InsertString", XS_Wx__OwnerDrawnComboBox_InsertString);
        newXS_deffile("Wx::OwnerDrawnComboBox::InsertData", XS_Wx__OwnerDrawnComboBox_InsertData);
#if XSubPPtmpAABP
        newXS_deffile("Wx::OwnerDrawnComboBox::InsertItems", XS_Wx__OwnerDrawnComboBox_InsertItems);
        newXS_deffile("Wx::OwnerDrawnComboBox::InsertItemsData", XS_Wx__OwnerDrawnComboBox_InsertItemsData);
#endif
#if XSubPPtmpAABQ
        newXS_deffile("Wx::OwnerDrawnComboBox::Set", XS_Wx__OwnerDrawnComboBox_Set);
        newXS_deffile("Wx::OwnerDrawnComboBox::SetItems", XS_Wx__OwnerDrawnComboBox_SetItems);
        newXS_deffile("Wx::OwnerDrawnComboBox::SetItemsData", XS_Wx__OwnerDrawnComboBox_SetItemsData);
#endif
        newXS_deffile("Wx::OwnerDrawnComboBox::Clear", XS_Wx__OwnerDrawnComboBox_Clear);
        newXS_deffile("Wx::OwnerDrawnComboBox::Delete", XS_Wx__OwnerDrawnComboBox_Delete);
        newXS_deffile("Wx::OwnerDrawnComboBox::GetClientData", XS_Wx__OwnerDrawnComboBox_GetClientData);
        newXS_deffile("Wx::OwnerDrawnComboBox::SetClientData", XS_Wx__OwnerDrawnComboBox_SetClientData);
        newXS_deffile("Wx::PlOwnerDrawnComboBox::new", XS_Wx__PlOwnerDrawnComboBox_new);
        newXS_deffile("Wx::PlOwnerDrawnComboBox::newDefault", XS_Wx__PlOwnerDrawnComboBox_newDefault);
        newXS_deffile("Wx::PlOwnerDrawnComboBox::newFull", XS_Wx__PlOwnerDrawnComboBox_newFull);
        newXS_deffile("Wx::PlOwnerDrawnComboBox::Create", XS_Wx__PlOwnerDrawnComboBox_Create);
#endif
#if XSubPPtmpAABR
        newXS_deffile("Wx::CollapsiblePaneEvent::new", XS_Wx__CollapsiblePaneEvent_new);
        newXS_deffile("Wx::CollapsiblePaneEvent::GetCollapsed", XS_Wx__CollapsiblePaneEvent_GetCollapsed);
        newXS_deffile("Wx::CollapsiblePaneEvent::SetCollapsed", XS_Wx__CollapsiblePaneEvent_SetCollapsed);
        newXS_deffile("Wx::CollapsiblePane::new", XS_Wx__CollapsiblePane_new);
        newXS_deffile("Wx::CollapsiblePane::newDefault", XS_Wx__CollapsiblePane_newDefault);
        newXS_deffile("Wx::CollapsiblePane::newFull", XS_Wx__CollapsiblePane_newFull);
        newXS_deffile("Wx::CollapsiblePane::Create", XS_Wx__CollapsiblePane_Create);
        newXS_deffile("Wx::CollapsiblePane::Collapse", XS_Wx__CollapsiblePane_Collapse);
        newXS_deffile("Wx::CollapsiblePane::Expand", XS_Wx__CollapsiblePane_Expand);
        newXS_deffile("Wx::CollapsiblePane::IsCollapsed", XS_Wx__CollapsiblePane_IsCollapsed);
        newXS_deffile("Wx::CollapsiblePane::IsExpanded", XS_Wx__CollapsiblePane_IsExpanded);
        newXS_deffile("Wx::CollapsiblePane::GetPane", XS_Wx__CollapsiblePane_GetPane);
#endif
#if XSubPPtmpAABS
        newXS_deffile("Wx::BitmapComboBox::new", XS_Wx__BitmapComboBox_new);
        newXS_deffile("Wx::BitmapComboBox::newDefault", XS_Wx__BitmapComboBox_newDefault);
        newXS_deffile("Wx::BitmapComboBox::newFull", XS_Wx__BitmapComboBox_newFull);
        newXS_deffile("Wx::BitmapComboBox::Create", XS_Wx__BitmapComboBox_Create);
        newXS_deffile("Wx::BitmapComboBox::Append", XS_Wx__BitmapComboBox_Append);
        newXS_deffile("Wx::BitmapComboBox::AppendString", XS_Wx__BitmapComboBox_AppendString);
        newXS_deffile("Wx::BitmapComboBox::AppendData", XS_Wx__BitmapComboBox_AppendData);
        newXS_deffile("Wx::BitmapComboBox::Insert", XS_Wx__BitmapComboBox_Insert);
        newXS_deffile("Wx::BitmapComboBox::InsertString", XS_Wx__BitmapComboBox_InsertString);
        newXS_deffile("Wx::BitmapComboBox::InsertData", XS_Wx__BitmapComboBox_InsertData);
        newXS_deffile("Wx::BitmapComboBox::GetItemBitmap", XS_Wx__BitmapComboBox_GetItemBitmap);
        newXS_deffile("Wx::BitmapComboBox::SetItemBitmap", XS_Wx__BitmapComboBox_SetItemBitmap);
        newXS_deffile("Wx::BitmapComboBox::GetBitmapSize", XS_Wx__BitmapComboBox_GetBitmapSize);
#endif
        newXS_deffile("Wx::GenericDirCtrl::new", XS_Wx__GenericDirCtrl_new);
        newXS_deffile("Wx::GenericDirCtrl::newDefault", XS_Wx__GenericDirCtrl_newDefault);
        newXS_deffile("Wx::GenericDirCtrl::newFull", XS_Wx__GenericDirCtrl_newFull);
        newXS_deffile("Wx::GenericDirCtrl::Create", XS_Wx__GenericDirCtrl_Create);
        newXS_deffile("Wx::GenericDirCtrl::ExpandPath", XS_Wx__GenericDirCtrl_ExpandPath);
#if XSubPPtmpAABT
        newXS_deffile("Wx::GenericDirCtrl::CollapsePath", XS_Wx__GenericDirCtrl_CollapsePath);
#endif
        newXS_deffile("Wx::GenericDirCtrl::GetDefaultPath", XS_Wx__GenericDirCtrl_GetDefaultPath);
        newXS_deffile("Wx::GenericDirCtrl::SetDefaultPath", XS_Wx__GenericDirCtrl_SetDefaultPath);
        newXS_deffile("Wx::GenericDirCtrl::GetPath", XS_Wx__GenericDirCtrl_GetPath);
        newXS_deffile("Wx::GenericDirCtrl::GetFilePath", XS_Wx__GenericDirCtrl_GetFilePath);
        newXS_deffile("Wx::GenericDirCtrl::SetPath", XS_Wx__GenericDirCtrl_SetPath);
        newXS_deffile("Wx::GenericDirCtrl::ShowHidden", XS_Wx__GenericDirCtrl_ShowHidden);
        newXS_deffile("Wx::GenericDirCtrl::GetShowHidden", XS_Wx__GenericDirCtrl_GetShowHidden);
        newXS_deffile("Wx::GenericDirCtrl::GetFilter", XS_Wx__GenericDirCtrl_GetFilter);
        newXS_deffile("Wx::GenericDirCtrl::SetFilter", XS_Wx__GenericDirCtrl_SetFilter);
        newXS_deffile("Wx::GenericDirCtrl::GetFilterIndex", XS_Wx__GenericDirCtrl_GetFilterIndex);
        newXS_deffile("Wx::GenericDirCtrl::SetFilterIndex", XS_Wx__GenericDirCtrl_SetFilterIndex);
        newXS_deffile("Wx::GenericDirCtrl::GetRootId", XS_Wx__GenericDirCtrl_GetRootId);
        newXS_deffile("Wx::GenericDirCtrl::GetTreeCtrl", XS_Wx__GenericDirCtrl_GetTreeCtrl);
        newXS_deffile("Wx::GenericDirCtrl::GetFilterListCtrl", XS_Wx__GenericDirCtrl_GetFilterListCtrl);
        newXS_deffile("Wx::GenericDirCtrl::ReCreateTree", XS_Wx__GenericDirCtrl_ReCreateTree);
#if XSubPPtmpAABU
        newXS_deffile("Wx::GenericDirCtrl::CollapseTree", XS_Wx__GenericDirCtrl_CollapseTree);
#endif
#if XSubPPtmpAABV
        newXS_deffile("Wx::FileCtrl::new", XS_Wx__FileCtrl_new);
        newXS_deffile("Wx::FileCtrl::newDefault", XS_Wx__FileCtrl_newDefault);
        newXS_deffile("Wx::FileCtrl::newFull", XS_Wx__FileCtrl_newFull);
        newXS_deffile("Wx::FileCtrl::Create", XS_Wx__FileCtrl_Create);
        newXS_deffile("Wx::FileCtrl::SetWildcard", XS_Wx__FileCtrl_SetWildcard);
        newXS_deffile("Wx::FileCtrl::SetFilterIndex", XS_Wx__FileCtrl_SetFilterIndex);
        newXS_deffile("Wx::FileCtrl::SetDirectory", XS_Wx__FileCtrl_SetDirectory);
        newXS_deffile("Wx::FileCtrl::SetFilename", XS_Wx__FileCtrl_SetFilename);
        newXS_deffile("Wx::FileCtrl::SetPath", XS_Wx__FileCtrl_SetPath);
        newXS_deffile("Wx::FileCtrl::GetFilename", XS_Wx__FileCtrl_GetFilename);
        newXS_deffile("Wx::FileCtrl::GetDirectory", XS_Wx__FileCtrl_GetDirectory);
        newXS_deffile("Wx::FileCtrl::GetWildcard", XS_Wx__FileCtrl_GetWildcard);
        newXS_deffile("Wx::FileCtrl::GetPath", XS_Wx__FileCtrl_GetPath);
        newXS_deffile("Wx::FileCtrl::GetPaths", XS_Wx__FileCtrl_GetPaths);
        newXS_deffile("Wx::FileCtrl::GetFilenames", XS_Wx__FileCtrl_GetFilenames);
        newXS_deffile("Wx::FileCtrl::GetFilterIndex", XS_Wx__FileCtrl_GetFilterIndex);
        newXS_deffile("Wx::FileCtrl::HasMultipleFileSelection", XS_Wx__FileCtrl_HasMultipleFileSelection);
        newXS_deffile("Wx::FileCtrl::ShowHidden", XS_Wx__FileCtrl_ShowHidden);
        newXS_deffile("Wx::FileCtrlEvent::SetFiles", XS_Wx__FileCtrlEvent_SetFiles);
        newXS_deffile("Wx::FileCtrlEvent::SetDirectory", XS_Wx__FileCtrlEvent_SetDirectory);
        newXS_deffile("Wx::FileCtrlEvent::GetFiles", XS_Wx__FileCtrlEvent_GetFiles);
        newXS_deffile("Wx::FileCtrlEvent::GetDirectory", XS_Wx__FileCtrlEvent_GetDirectory);
        newXS_deffile("Wx::FileCtrlEvent::GetFile", XS_Wx__FileCtrlEvent_GetFile);
#endif
#if XSubPPtmpAABW
        newXS_deffile("Wx::SpinCtrlDouble::wxSpinCtrlDouble0", XS_Wx__SpinCtrlDouble_wxSpinCtrlDouble0);
        newXS_deffile("Wx::SpinCtrlDouble::wxSpinCtrlDouble1", XS_Wx__SpinCtrlDouble_wxSpinCtrlDouble1);
        newXS_deffile("Wx::SpinCtrlDouble::Create", XS_Wx__SpinCtrlDouble_Create);
        newXS_deffile("Wx::SpinCtrlDouble::GetDigits", XS_Wx__SpinCtrlDouble_GetDigits);
        newXS_deffile("Wx::SpinCtrlDouble::GetIncrement", XS_Wx__SpinCtrlDouble_GetIncrement);
        newXS_deffile("Wx::SpinCtrlDouble::GetMax", XS_Wx__SpinCtrlDouble_GetMax);
        newXS_deffile("Wx::SpinCtrlDouble::GetMin", XS_Wx__SpinCtrlDouble_GetMin);
        newXS_deffile("Wx::SpinCtrlDouble::GetValue", XS_Wx__SpinCtrlDouble_GetValue);
        newXS_deffile("Wx::SpinCtrlDouble::SetDigits", XS_Wx__SpinCtrlDouble_SetDigits);
        newXS_deffile("Wx::SpinCtrlDouble::SetIncrement", XS_Wx__SpinCtrlDouble_SetIncrement);
        newXS_deffile("Wx::SpinCtrlDouble::SetRange", XS_Wx__SpinCtrlDouble_SetRange);
        newXS_deffile("Wx::SpinCtrlDouble::SetValue0", XS_Wx__SpinCtrlDouble_SetValue0);
        newXS_deffile("Wx::SpinCtrlDouble::SetValue1", XS_Wx__SpinCtrlDouble_SetValue1);
#if XSubPPtmpAABX
        newXS_deffile("Wx::SpinCtrlDouble::new", XS_Wx__SpinCtrlDouble_new);
#endif
#if XSubPPtmpAABY
        newXS_deffile("Wx::SpinCtrlDouble::SetValue", XS_Wx__SpinCtrlDouble_SetValue);
#endif
#endif
#if XSubPPtmpAABZ
        newXS_deffile("Wx::InfoBar::wxInfoBar0", XS_Wx__InfoBar_wxInfoBar0);
        newXS_deffile("Wx::InfoBar::wxInfoBar1", XS_Wx__InfoBar_wxInfoBar1);
        newXS_deffile("Wx::InfoBar::Create", XS_Wx__InfoBar_Create);
        newXS_deffile("Wx::InfoBar::AddButton", XS_Wx__InfoBar_AddButton);
        newXS_deffile("Wx::InfoBar::Dismiss", XS_Wx__InfoBar_Dismiss);
        newXS_deffile("Wx::InfoBar::RemoveButton", XS_Wx__InfoBar_RemoveButton);
        newXS_deffile("Wx::InfoBar::ShowMessage", XS_Wx__InfoBar_ShowMessage);
        newXS_deffile("Wx::InfoBar::SetShowHideEffects", XS_Wx__InfoBar_SetShowHideEffects);
        newXS_deffile("Wx::InfoBar::GetShowEffect", XS_Wx__InfoBar_GetShowEffect);
        newXS_deffile("Wx::InfoBar::GetHideEffect", XS_Wx__InfoBar_GetHideEffect);
        newXS_deffile("Wx::InfoBar::SetEffectDuration", XS_Wx__InfoBar_SetEffectDuration);
        newXS_deffile("Wx::InfoBar::GetEffectDuration", XS_Wx__InfoBar_GetEffectDuration);
        newXS_deffile("Wx::InfoBar::SetFont", XS_Wx__InfoBar_SetFont);
#if XSubPPtmpAACA
        newXS_deffile("Wx::InfoBar::new", XS_Wx__InfoBar_new);
#endif
#endif
#if XSubPPtmpAACB
        newXS_deffile("Wx::HeaderCtrl::Create", XS_Wx__HeaderCtrl_Create);
        newXS_deffile("Wx::HeaderCtrl::SetColumnCount", XS_Wx__HeaderCtrl_SetColumnCount);
        newXS_deffile("Wx::HeaderCtrl::GetColumnCount", XS_Wx__HeaderCtrl_GetColumnCount);
        newXS_deffile("Wx::HeaderCtrl::IsEmpty", XS_Wx__HeaderCtrl_IsEmpty);
        newXS_deffile("Wx::HeaderCtrl::UpdateColumn", XS_Wx__HeaderCtrl_UpdateColumn);
        newXS_deffile("Wx::HeaderCtrl::SetColumnsOrder", XS_Wx__HeaderCtrl_SetColumnsOrder);
        newXS_deffile("Wx::HeaderCtrl::GetColumnsOrder", XS_Wx__HeaderCtrl_GetColumnsOrder);
        newXS_deffile("Wx::HeaderCtrl::GetColumnAt", XS_Wx__HeaderCtrl_GetColumnAt);
        newXS_deffile("Wx::HeaderCtrl::GetColumnPos", XS_Wx__HeaderCtrl_GetColumnPos);
        newXS_deffile("Wx::HeaderCtrl::ResetColumnsOrder", XS_Wx__HeaderCtrl_ResetColumnsOrder);
        newXS_deffile("Wx::HeaderCtrl::MoveColumnInOrderArray", XS_Wx__HeaderCtrl_MoveColumnInOrderArray);
        newXS_deffile("Wx::HeaderCtrl::ShowColumnsMenu", XS_Wx__HeaderCtrl_ShowColumnsMenu);
        newXS_deffile("Wx::HeaderCtrl::AddColumnsItems", XS_Wx__HeaderCtrl_AddColumnsItems);
        newXS_deffile("Wx::HeaderCtrl::ShowCustomizeDialog", XS_Wx__HeaderCtrl_ShowCustomizeDialog);
#if XSubPPtmpAACC
        newXS_deffile("Wx::HeaderCtrl::new", XS_Wx__HeaderCtrl_new);
#endif
        newXS_deffile("Wx::HeaderCtrlSimple::InsertColumn", XS_Wx__HeaderCtrlSimple_InsertColumn);
        newXS_deffile("Wx::HeaderCtrlSimple::AppendColumn", XS_Wx__HeaderCtrlSimple_AppendColumn);
        newXS_deffile("Wx::HeaderCtrlSimple::DeleteColumn", XS_Wx__HeaderCtrlSimple_DeleteColumn);
        newXS_deffile("Wx::HeaderCtrlSimple::ShowColumn", XS_Wx__HeaderCtrlSimple_ShowColumn);
        newXS_deffile("Wx::HeaderCtrlSimple::HideColumn", XS_Wx__HeaderCtrlSimple_HideColumn);
        newXS_deffile("Wx::HeaderCtrlSimple::ShowSortIndicator", XS_Wx__HeaderCtrlSimple_ShowSortIndicator);
        newXS_deffile("Wx::HeaderCtrlSimple::RemoveSortIndicator", XS_Wx__HeaderCtrlSimple_RemoveSortIndicator);
#if XSubPPtmpAACD
        newXS_deffile("Wx::HeaderCtrlSimple::new", XS_Wx__HeaderCtrlSimple_new);
#endif
        newXS_deffile("Wx::HeaderCtrlSimple::wxHeaderCtrlSimple0", XS_Wx__HeaderCtrlSimple_wxHeaderCtrlSimple0);
        newXS_deffile("Wx::HeaderCtrlSimple::wxHeaderCtrlSimple1", XS_Wx__HeaderCtrlSimple_wxHeaderCtrlSimple1);
        newXS_deffile("Wx::HeaderCtrlEvent::GetColumn", XS_Wx__HeaderCtrlEvent_GetColumn);
        newXS_deffile("Wx::HeaderCtrlEvent::GetWidth", XS_Wx__HeaderCtrlEvent_GetWidth);
        newXS_deffile("Wx::HeaderCtrlEvent::GetNewOrder", XS_Wx__HeaderCtrlEvent_GetNewOrder);
#endif
#if XSubPPtmpAACE
        newXS_deffile("Wx::PlHeaderCtrl::wxHeaderCtrl0", XS_Wx__PlHeaderCtrl_wxHeaderCtrl0);
        newXS_deffile("Wx::PlHeaderCtrl::wxHeaderCtrl1", XS_Wx__PlHeaderCtrl_wxHeaderCtrl1);
#endif
#if XSubPPtmpAACF
        newXS_deffile("Wx::HeaderCtrlSimple::GetBestFittingWidth", XS_Wx__HeaderCtrlSimple_GetBestFittingWidth);
#endif
#if XSubPPtmpAACG
#endif
#if XSubPPtmpAACH
        newXS_deffile("Wx::HeaderColumn::GetTitle", XS_Wx__HeaderColumn_GetTitle);
        newXS_deffile("Wx::HeaderColumn::GetBitmap", XS_Wx__HeaderColumn_GetBitmap);
        newXS_deffile("Wx::HeaderColumn::GetWidth", XS_Wx__HeaderColumn_GetWidth);
        newXS_deffile("Wx::HeaderColumn::GetMinWidth", XS_Wx__HeaderColumn_GetMinWidth);
        newXS_deffile("Wx::HeaderColumn::GetAlignment", XS_Wx__HeaderColumn_GetAlignment);
        newXS_deffile("Wx::HeaderColumn::GetFlags", XS_Wx__HeaderColumn_GetFlags);
        newXS_deffile("Wx::HeaderColumn::HasFlag", XS_Wx__HeaderColumn_HasFlag);
        newXS_deffile("Wx::HeaderColumn::IsResizeable", XS_Wx__HeaderColumn_IsResizeable);
        newXS_deffile("Wx::HeaderColumn::IsSortable", XS_Wx__HeaderColumn_IsSortable);
        newXS_deffile("Wx::HeaderColumn::IsReorderable", XS_Wx__HeaderColumn_IsReorderable);
        newXS_deffile("Wx::HeaderColumn::IsHidden", XS_Wx__HeaderColumn_IsHidden);
        newXS_deffile("Wx::HeaderColumn::IsShown", XS_Wx__HeaderColumn_IsShown);
        newXS_deffile("Wx::HeaderColumn::IsSortKey", XS_Wx__HeaderColumn_IsSortKey);
        newXS_deffile("Wx::HeaderColumn::IsSortOrderAscending", XS_Wx__HeaderColumn_IsSortOrderAscending);
        newXS_deffile("Wx::SettableHeaderColumn::SetTitle", XS_Wx__SettableHeaderColumn_SetTitle);
        newXS_deffile("Wx::SettableHeaderColumn::SetBitmap", XS_Wx__SettableHeaderColumn_SetBitmap);
        newXS_deffile("Wx::SettableHeaderColumn::SetWidth", XS_Wx__SettableHeaderColumn_SetWidth);
        newXS_deffile("Wx::SettableHeaderColumn::SetMinWidth", XS_Wx__SettableHeaderColumn_SetMinWidth);
        newXS_deffile("Wx::SettableHeaderColumn::SetAlignment", XS_Wx__SettableHeaderColumn_SetAlignment);
        newXS_deffile("Wx::SettableHeaderColumn::SetFlags", XS_Wx__SettableHeaderColumn_SetFlags);
        newXS_deffile("Wx::SettableHeaderColumn::ChangeFlag", XS_Wx__SettableHeaderColumn_ChangeFlag);
        newXS_deffile("Wx::SettableHeaderColumn::SetFlag", XS_Wx__SettableHeaderColumn_SetFlag);
        newXS_deffile("Wx::SettableHeaderColumn::ClearFlag", XS_Wx__SettableHeaderColumn_ClearFlag);
        newXS_deffile("Wx::SettableHeaderColumn::ToggleFlag", XS_Wx__SettableHeaderColumn_ToggleFlag);
        newXS_deffile("Wx::SettableHeaderColumn::SetResizeable", XS_Wx__SettableHeaderColumn_SetResizeable);
        newXS_deffile("Wx::SettableHeaderColumn::SetSortable", XS_Wx__SettableHeaderColumn_SetSortable);
        newXS_deffile("Wx::SettableHeaderColumn::SetReorderable", XS_Wx__SettableHeaderColumn_SetReorderable);
        newXS_deffile("Wx::SettableHeaderColumn::SetHidden", XS_Wx__SettableHeaderColumn_SetHidden);
#if XSubPPtmpAACI
        newXS_deffile("Wx::SettableHeaderColumn::SetAsSortKey", XS_Wx__SettableHeaderColumn_SetAsSortKey);
#endif
        newXS_deffile("Wx::SettableHeaderColumn::UnsetAsSortKey", XS_Wx__SettableHeaderColumn_UnsetAsSortKey);
        newXS_deffile("Wx::SettableHeaderColumn::SetSortOrder", XS_Wx__SettableHeaderColumn_SetSortOrder);
        newXS_deffile("Wx::SettableHeaderColumn::ToggleSortOrder", XS_Wx__SettableHeaderColumn_ToggleSortOrder);
        newXS_deffile("Wx::HeaderColumnSimple::wxHeaderColumnSimple0", XS_Wx__HeaderColumnSimple_wxHeaderColumnSimple0);
        newXS_deffile("Wx::HeaderColumnSimple::wxHeaderColumnSimple1", XS_Wx__HeaderColumnSimple_wxHeaderColumnSimple1);
        newXS_deffile("Wx::HeaderColumnSimple::SetTitle", XS_Wx__HeaderColumnSimple_SetTitle);
        newXS_deffile("Wx::HeaderColumnSimple::GetTitle", XS_Wx__HeaderColumnSimple_GetTitle);
        newXS_deffile("Wx::HeaderColumnSimple::SetBitmap", XS_Wx__HeaderColumnSimple_SetBitmap);
        newXS_deffile("Wx::HeaderColumnSimple::GetBitmap", XS_Wx__HeaderColumnSimple_GetBitmap);
        newXS_deffile("Wx::HeaderColumnSimple::SetWidth", XS_Wx__HeaderColumnSimple_SetWidth);
        newXS_deffile("Wx::HeaderColumnSimple::GetWidth", XS_Wx__HeaderColumnSimple_GetWidth);
        newXS_deffile("Wx::HeaderColumnSimple::SetMinWidth", XS_Wx__HeaderColumnSimple_SetMinWidth);
        newXS_deffile("Wx::HeaderColumnSimple::GetMinWidth", XS_Wx__HeaderColumnSimple_GetMinWidth);
        newXS_deffile("Wx::HeaderColumnSimple::SetAlignment", XS_Wx__HeaderColumnSimple_SetAlignment);
        newXS_deffile("Wx::HeaderColumnSimple::GetAlignment", XS_Wx__HeaderColumnSimple_GetAlignment);
        newXS_deffile("Wx::HeaderColumnSimple::SetFlags", XS_Wx__HeaderColumnSimple_SetFlags);
        newXS_deffile("Wx::HeaderColumnSimple::GetFlags", XS_Wx__HeaderColumnSimple_GetFlags);
#if XSubPPtmpAACJ
        newXS_deffile("Wx::HeaderColumnSimple::SetAsSortKey", XS_Wx__HeaderColumnSimple_SetAsSortKey);
#endif
        newXS_deffile("Wx::HeaderColumnSimple::IsSortKey", XS_Wx__HeaderColumnSimple_IsSortKey);
        newXS_deffile("Wx::HeaderColumnSimple::SetSortOrder", XS_Wx__HeaderColumnSimple_SetSortOrder);
        newXS_deffile("Wx::HeaderColumnSimple::IsSortOrderAscending", XS_Wx__HeaderColumnSimple_IsSortOrderAscending);
#if XSubPPtmpAACK
        newXS_deffile("Wx::HeaderColumnSimple::new", XS_Wx__HeaderColumnSimple_new);
#endif
#endif
#if XSubPPtmpAACL
        newXS_deffile("Wx::PlHeaderColumn::new", XS_Wx__PlHeaderColumn_new);
#endif
#if XSubPPtmpAACM
        newXS_deffile("Wx::PlSettableHeaderColumn::new", XS_Wx__PlSettableHeaderColumn_new);
#endif
        newXS_deffile("Wx::Button::newDefault", XS_Wx__Button_newDefault);
        newXS_deffile("Wx::Button::newFull", XS_Wx__Button_newFull);
        newXS_deffile("Wx::Button::Create", XS_Wx__Button_Create);
#if XSubPPtmpAACN
        newXS_deffile("Wx::Button::GetAuthNeeded", XS_Wx__Button_GetAuthNeeded);
        newXS_deffile("Wx::Button::GetBitmap", XS_Wx__Button_GetBitmap);
        newXS_deffile("Wx::Button::GetBitmapCurrent", XS_Wx__Button_GetBitmapCurrent);
        newXS_deffile("Wx::Button::GetBitmapDisabled", XS_Wx__Button_GetBitmapDisabled);
        newXS_deffile("Wx::Button::GetBitmapFocus", XS_Wx__Button_GetBitmapFocus);
        newXS_deffile("Wx::Button::GetBitmapLabel", XS_Wx__Button_GetBitmapLabel);
        newXS_deffile("Wx::Button::GetBitmapPressed", XS_Wx__Button_GetBitmapPressed);
        newXS_deffile("Wx::Button::GetBitmapMargins", XS_Wx__Button_GetBitmapMargins);
#endif
        newXS_deffile("Wx::Button::GetDefaultSize", XS_Wx__Button_GetDefaultSize);
        newXS_deffile("Wx::Button::GetLabel", XS_Wx__Button_GetLabel);
#if XSubPPtmpAACO
        newXS_deffile("Wx::Button::SetAuthNeeded", XS_Wx__Button_SetAuthNeeded);
        newXS_deffile("Wx::Button::SetBitmap", XS_Wx__Button_SetBitmap);
        newXS_deffile("Wx::Button::SetBitmapCurrent", XS_Wx__Button_SetBitmapCurrent);
        newXS_deffile("Wx::Button::SetBitmapDisabled", XS_Wx__Button_SetBitmapDisabled);
        newXS_deffile("Wx::Button::SetBitmapFocus", XS_Wx__Button_SetBitmapFocus);
        newXS_deffile("Wx::Button::SetBitmapLabel", XS_Wx__Button_SetBitmapLabel);
        newXS_deffile("Wx::Button::SetBitmapPressed", XS_Wx__Button_SetBitmapPressed);
        newXS_deffile("Wx::Button::SetBitmapMargins0", XS_Wx__Button_SetBitmapMargins0);
        newXS_deffile("Wx::Button::SetBitmapMargins1", XS_Wx__Button_SetBitmapMargins1);
        newXS_deffile("Wx::Button::SetBitmapPosition", XS_Wx__Button_SetBitmapPosition);
#endif
#if XSubPPtmpAACP
        newXS_deffile("Wx::Button::SetDefault0", XS_Wx__Button_SetDefault0);
#endif
#if XSubPPtmpAACQ
        newXS_deffile("Wx::Button::SetDefault1", XS_Wx__Button_SetDefault1);
#endif
        newXS_deffile("Wx::Button::SetLabel", XS_Wx__Button_SetLabel);
#if XSubPPtmpAACR
        newXS_deffile("Wx::Button::SetBitmapMargins", XS_Wx__Button_SetBitmapMargins);
#endif
#if XSubPPtmpAACS
        newXS_deffile("Wx::Button::SetDefault", XS_Wx__Button_SetDefault);
#endif
#if XSubPPtmpAACT
        newXS_deffile("Wx::Button::new", XS_Wx__Button_new);
#endif
#if XSubPPtmpAACU
        newXS_deffile("Wx::CommandLinkButton::newDefault", XS_Wx__CommandLinkButton_newDefault);
        newXS_deffile("Wx::CommandLinkButton::newFull", XS_Wx__CommandLinkButton_newFull);
        newXS_deffile("Wx::CommandLinkButton::Create", XS_Wx__CommandLinkButton_Create);
        newXS_deffile("Wx::CommandLinkButton::SetMainLabelAndNote", XS_Wx__CommandLinkButton_SetMainLabelAndNote);
        newXS_deffile("Wx::CommandLinkButton::SetLabel", XS_Wx__CommandLinkButton_SetLabel);
        newXS_deffile("Wx::CommandLinkButton::GetLabel", XS_Wx__CommandLinkButton_GetLabel);
        newXS_deffile("Wx::CommandLinkButton::SetMainLabel", XS_Wx__CommandLinkButton_SetMainLabel);
        newXS_deffile("Wx::CommandLinkButton::SetNote", XS_Wx__CommandLinkButton_SetNote);
        newXS_deffile("Wx::CommandLinkButton::GetMainLabel", XS_Wx__CommandLinkButton_GetMainLabel);
        newXS_deffile("Wx::CommandLinkButton::GetNote", XS_Wx__CommandLinkButton_GetNote);
#if XSubPPtmpAACV
        newXS_deffile("Wx::CommandLinkButton::new", XS_Wx__CommandLinkButton_new);
#endif
#endif
#if XSubPPtmpAACW
        newXS_deffile("Wx::TreeListItem::CLONE", XS_Wx__TreeListItem_CLONE);
        newXS_deffile("Wx::TreeListItem::DESTROY", XS_Wx__TreeListItem_DESTROY);
        newXS_deffile("Wx::TreeListItem::IsOk", XS_Wx__TreeListItem_IsOk);
        newXS_deffile("Wx::TreeListItemComparator::Compare", XS_Wx__TreeListItemComparator_Compare);
        newXS_deffile("Wx::TreeListCtrl::newDefault", XS_Wx__TreeListCtrl_newDefault);
        newXS_deffile("Wx::TreeListCtrl::newFull", XS_Wx__TreeListCtrl_newFull);
        newXS_deffile("Wx::TreeListCtrl::Create", XS_Wx__TreeListCtrl_Create);
        newXS_deffile("Wx::TreeListCtrl::AssignImageList", XS_Wx__TreeListCtrl_AssignImageList);
        newXS_deffile("Wx::TreeListCtrl::GetImageList", XS_Wx__TreeListCtrl_GetImageList);
        newXS_deffile("Wx::TreeListCtrl::SetImageList", XS_Wx__TreeListCtrl_SetImageList);
        newXS_deffile("Wx::TreeListCtrl::AppendColumn", XS_Wx__TreeListCtrl_AppendColumn);
        newXS_deffile("Wx::TreeListCtrl::GetColumnCount", XS_Wx__TreeListCtrl_GetColumnCount);
        newXS_deffile("Wx::TreeListCtrl::DeleteColumn", XS_Wx__TreeListCtrl_DeleteColumn);
        newXS_deffile("Wx::TreeListCtrl::ClearColumns", XS_Wx__TreeListCtrl_ClearColumns);
        newXS_deffile("Wx::TreeListCtrl::SetColumnWidth", XS_Wx__TreeListCtrl_SetColumnWidth);
        newXS_deffile("Wx::TreeListCtrl::GetColumnWidth", XS_Wx__TreeListCtrl_GetColumnWidth);
        newXS_deffile("Wx::TreeListCtrl::WidthFor", XS_Wx__TreeListCtrl_WidthFor);
        newXS_deffile("Wx::TreeListCtrl::AppendItem", XS_Wx__TreeListCtrl_AppendItem);
        newXS_deffile("Wx::TreeListCtrl::InsertItem", XS_Wx__TreeListCtrl_InsertItem);
        newXS_deffile("Wx::TreeListCtrl::PrependItem", XS_Wx__TreeListCtrl_PrependItem);
        newXS_deffile("Wx::TreeListCtrl::DeleteItem", XS_Wx__TreeListCtrl_DeleteItem);
        newXS_deffile("Wx::TreeListCtrl::DeleteAllItems", XS_Wx__TreeListCtrl_DeleteAllItems);
        newXS_deffile("Wx::TreeListCtrl::GetRootItem", XS_Wx__TreeListCtrl_GetRootItem);
        newXS_deffile("Wx::TreeListCtrl::GetItemParent", XS_Wx__TreeListCtrl_GetItemParent);
        newXS_deffile("Wx::TreeListCtrl::GetFirstChild", XS_Wx__TreeListCtrl_GetFirstChild);
        newXS_deffile("Wx::TreeListCtrl::GetNextSibling", XS_Wx__TreeListCtrl_GetNextSibling);
        newXS_deffile("Wx::TreeListCtrl::GetFirstItem", XS_Wx__TreeListCtrl_GetFirstItem);
        newXS_deffile("Wx::TreeListCtrl::GetNextItem", XS_Wx__TreeListCtrl_GetNextItem);
        newXS_deffile("Wx::TreeListCtrl::GetItemText", XS_Wx__TreeListCtrl_GetItemText);
        newXS_deffile("Wx::TreeListCtrl::SetItemText0", XS_Wx__TreeListCtrl_SetItemText0);
        newXS_deffile("Wx::TreeListCtrl::SetItemText1", XS_Wx__TreeListCtrl_SetItemText1);
        newXS_deffile("Wx::TreeListCtrl::SetItemImage", XS_Wx__TreeListCtrl_SetItemImage);
        newXS_deffile("Wx::TreeListCtrl::GetItemData", XS_Wx__TreeListCtrl_GetItemData);
        newXS_deffile("Wx::TreeListCtrl::SetItemData", XS_Wx__TreeListCtrl_SetItemData);
        newXS_deffile("Wx::TreeListCtrl::Expand", XS_Wx__TreeListCtrl_Expand);
        newXS_deffile("Wx::TreeListCtrl::Collapse", XS_Wx__TreeListCtrl_Collapse);
        newXS_deffile("Wx::TreeListCtrl::IsExpanded", XS_Wx__TreeListCtrl_IsExpanded);
        newXS_deffile("Wx::TreeListCtrl::GetSelection", XS_Wx__TreeListCtrl_GetSelection);
        newXS_deffile("Wx::TreeListCtrl::GetSelections", XS_Wx__TreeListCtrl_GetSelections);
        newXS_deffile("Wx::TreeListCtrl::Select", XS_Wx__TreeListCtrl_Select);
        newXS_deffile("Wx::TreeListCtrl::Unselect", XS_Wx__TreeListCtrl_Unselect);
        newXS_deffile("Wx::TreeListCtrl::IsSelected", XS_Wx__TreeListCtrl_IsSelected);
        newXS_deffile("Wx::TreeListCtrl::SelectAll", XS_Wx__TreeListCtrl_SelectAll);
        newXS_deffile("Wx::TreeListCtrl::UnselectAll", XS_Wx__TreeListCtrl_UnselectAll);
        newXS_deffile("Wx::TreeListCtrl::CheckItem", XS_Wx__TreeListCtrl_CheckItem);
        newXS_deffile("Wx::TreeListCtrl::CheckItemRecursively", XS_Wx__TreeListCtrl_CheckItemRecursively);
        newXS_deffile("Wx::TreeListCtrl::UncheckItem", XS_Wx__TreeListCtrl_UncheckItem);
        newXS_deffile("Wx::TreeListCtrl::UpdateItemParentStateRecursively", XS_Wx__TreeListCtrl_UpdateItemParentStateRecursively);
        newXS_deffile("Wx::TreeListCtrl::GetCheckedState", XS_Wx__TreeListCtrl_GetCheckedState);
        newXS_deffile("Wx::TreeListCtrl::AreAllChildrenInState", XS_Wx__TreeListCtrl_AreAllChildrenInState);
        newXS_deffile("Wx::TreeListCtrl::SetSortColumn", XS_Wx__TreeListCtrl_SetSortColumn);
        newXS_deffile("Wx::TreeListCtrl::GetSortColumn", XS_Wx__TreeListCtrl_GetSortColumn);
        newXS_deffile("Wx::TreeListCtrl::SetItemComparator", XS_Wx__TreeListCtrl_SetItemComparator);
        newXS_deffile("Wx::TreeListCtrl::GetView", XS_Wx__TreeListCtrl_GetView);
#if XSubPPtmpAACX
        newXS_deffile("Wx::TreeListCtrl::SetItemText", XS_Wx__TreeListCtrl_SetItemText);
#endif
#if XSubPPtmpAACY
        newXS_deffile("Wx::TreeListCtrl::new", XS_Wx__TreeListCtrl_new);
#endif
        newXS_deffile("Wx::TreeListEvent::GetItem", XS_Wx__TreeListEvent_GetItem);
        newXS_deffile("Wx::TreeListEvent::GetOldCheckedState", XS_Wx__TreeListEvent_GetOldCheckedState);
        newXS_deffile("Wx::TreeListEvent::GetColumn", XS_Wx__TreeListEvent_GetColumn);
#endif
#if XSubPPtmpAACZ
        newXS_deffile("Wx::PlTreeListItemComparator::new", XS_Wx__PlTreeListItemComparator_new);
#endif
#if XSubPPtmpAADA
#endif
#if XSubPPtmpAADB
        newXS_deffile("Wx::RichToolTip::CLONE", XS_Wx__RichToolTip_CLONE);
        newXS_deffile("Wx::RichToolTip::new", XS_Wx__RichToolTip_new);
        newXS_deffile("Wx::RichToolTip::SetBackgroundColour", XS_Wx__RichToolTip_SetBackgroundColour);
        newXS_deffile("Wx::RichToolTip::SetIconId", XS_Wx__RichToolTip_SetIconId);
        newXS_deffile("Wx::RichToolTip::SetIconIcon", XS_Wx__RichToolTip_SetIconIcon);
        newXS_deffile("Wx::RichToolTip::SetTimeout", XS_Wx__RichToolTip_SetTimeout);
        newXS_deffile("Wx::RichToolTip::SetTipKind", XS_Wx__RichToolTip_SetTipKind);
        newXS_deffile("Wx::RichToolTip::ShowFor", XS_Wx__RichToolTip_ShowFor);
        newXS_deffile("Wx::RichToolTip::DESTROY", XS_Wx__RichToolTip_DESTROY);
#if XSubPPtmpAADC
        newXS_deffile("Wx::RichToolTip::SetIcon", XS_Wx__RichToolTip_SetIcon);
#endif
#endif
#if XSubPPtmpAADD
        newXS_deffile("Wx::BannerWindow::newDefault", XS_Wx__BannerWindow_newDefault);
        newXS_deffile("Wx::BannerWindow::newShort", XS_Wx__BannerWindow_newShort);
        newXS_deffile("Wx::BannerWindow::newFull", XS_Wx__BannerWindow_newFull);
        newXS_deffile("Wx::BannerWindow::Create", XS_Wx__BannerWindow_Create);
        newXS_deffile("Wx::BannerWindow::SetBitmap", XS_Wx__BannerWindow_SetBitmap);
        newXS_deffile("Wx::BannerWindow::SetText", XS_Wx__BannerWindow_SetText);
        newXS_deffile("Wx::BannerWindow::SetGradient", XS_Wx__BannerWindow_SetGradient);
#if XSubPPtmpAADE
        newXS_deffile("Wx::BannerWindow::new", XS_Wx__BannerWindow_new);
#endif
#endif
#if XSubPPtmpAADF
        newXS_deffile("Wx::RearrangeList::newDefault", XS_Wx__RearrangeList_newDefault);
        newXS_deffile("Wx::RearrangeList::newFull", XS_Wx__RearrangeList_newFull);
        newXS_deffile("Wx::RearrangeList::Create", XS_Wx__RearrangeList_Create);
        newXS_deffile("Wx::RearrangeList::GetCurrentOrder", XS_Wx__RearrangeList_GetCurrentOrder);
        newXS_deffile("Wx::RearrangeList::CanMoveCurrentUp", XS_Wx__RearrangeList_CanMoveCurrentUp);
        newXS_deffile("Wx::RearrangeList::CanMoveCurrentDown", XS_Wx__RearrangeList_CanMoveCurrentDown);
        newXS_deffile("Wx::RearrangeList::MoveCurrentUp", XS_Wx__RearrangeList_MoveCurrentUp);
        newXS_deffile("Wx::RearrangeList::MoveCurrentDown", XS_Wx__RearrangeList_MoveCurrentDown);
#if XSubPPtmpAADG
        newXS_deffile("Wx::RearrangeList::new", XS_Wx__RearrangeList_new);
#endif
        newXS_deffile("Wx::RearrangeCtrl::newDefault", XS_Wx__RearrangeCtrl_newDefault);
        newXS_deffile("Wx::RearrangeCtrl::newFull", XS_Wx__RearrangeCtrl_newFull);
        newXS_deffile("Wx::RearrangeCtrl::Create", XS_Wx__RearrangeCtrl_Create);
        newXS_deffile("Wx::RearrangeCtrl::GetList", XS_Wx__RearrangeCtrl_GetList);
#if XSubPPtmpAADH
        newXS_deffile("Wx::RearrangeCtrl::new", XS_Wx__RearrangeCtrl_new);
#endif
        newXS_deffile("Wx::RearrangeDialog::newDefault", XS_Wx__RearrangeDialog_newDefault);
        newXS_deffile("Wx::RearrangeDialog::newFull", XS_Wx__RearrangeDialog_newFull);
        newXS_deffile("Wx::RearrangeDialog::Create", XS_Wx__RearrangeDialog_Create);
        newXS_deffile("Wx::RearrangeDialog::AddExtraControls", XS_Wx__RearrangeDialog_AddExtraControls);
        newXS_deffile("Wx::RearrangeDialog::GetList", XS_Wx__RearrangeDialog_GetList);
        newXS_deffile("Wx::RearrangeDialog::GetOrder", XS_Wx__RearrangeDialog_GetOrder);
#if XSubPPtmpAADI
        newXS_deffile("Wx::RearrangeDialog::new", XS_Wx__RearrangeDialog_new);
#endif
#endif
        newXS_deffile("Wx::TreeItemData::new", XS_Wx__TreeItemData_new);
        newXS_deffile("Wx::TreeItemData::Destroy", XS_Wx__TreeItemData_Destroy);
        newXS_deffile("Wx::TreeItemData::GetData", XS_Wx__TreeItemData_GetData);
        newXS_deffile("Wx::TreeItemData::SetData", XS_Wx__TreeItemData_SetData);
        newXS_deffile("Wx::TreeItemData::GetId", XS_Wx__TreeItemData_GetId);
        newXS_deffile("Wx::TreeItemData::SetId", XS_Wx__TreeItemData_SetId);
        newXS_deffile("Wx::TreeItemId::CLONE", XS_Wx__TreeItemId_CLONE);
        newXS_deffile("Wx::TreeItemId::DESTROY", XS_Wx__TreeItemId_DESTROY);
        newXS_deffile("Wx::TreeItemId::IsOk", XS_Wx__TreeItemId_IsOk);
        newXS_deffile("Wx::TreeItemId::tiid_spaceship", XS_Wx__TreeItemId_tiid_spaceship);
        newXS_deffile("Wx::TreeEvent::new", XS_Wx__TreeEvent_new);
        newXS_deffile("Wx::TreeEvent::GetItem", XS_Wx__TreeEvent_GetItem);
#if XSubPPtmpAADJ
        newXS_deffile("Wx::TreeEvent::SetQuickBestSize", XS_Wx__TreeEvent_SetQuickBestSize);
        newXS_deffile("Wx::TreeEvent::GetQuickBestSize", XS_Wx__TreeEvent_GetQuickBestSize);
#endif
        newXS_deffile("Wx::TreeEvent::GetKeyCode", XS_Wx__TreeEvent_GetKeyCode);
        newXS_deffile("Wx::TreeEvent::GetKeyEvent", XS_Wx__TreeEvent_GetKeyEvent);
        newXS_deffile("Wx::TreeEvent::GetOldItem", XS_Wx__TreeEvent_GetOldItem);
        newXS_deffile("Wx::TreeEvent::GetPoint", XS_Wx__TreeEvent_GetPoint);
        newXS_deffile("Wx::TreeEvent::IsEditCancelled", XS_Wx__TreeEvent_IsEditCancelled);
        newXS_deffile("Wx::TreeEvent::GetLabel", XS_Wx__TreeEvent_GetLabel);
        newXS_deffile("Wx::TreeEvent::SetToolTip", XS_Wx__TreeEvent_SetToolTip);
        newXS_deffile("Wx::TreeCtrl::new", XS_Wx__TreeCtrl_new);
        newXS_deffile("Wx::TreeCtrl::newDefault", XS_Wx__TreeCtrl_newDefault);
        newXS_deffile("Wx::TreeCtrl::newFull", XS_Wx__TreeCtrl_newFull);
        newXS_deffile("Wx::TreeCtrl::Create", XS_Wx__TreeCtrl_Create);
        newXS_deffile("Wx::TreeCtrl::AddRoot", XS_Wx__TreeCtrl_AddRoot);
        newXS_deffile("Wx::TreeCtrl::AppendItem", XS_Wx__TreeCtrl_AppendItem);
        newXS_deffile("Wx::TreeCtrl::Collapse", XS_Wx__TreeCtrl_Collapse);
#if XSubPPtmpAADK
        newXS_deffile("Wx::TreeCtrl::CollapseAll", XS_Wx__TreeCtrl_CollapseAll);
        newXS_deffile("Wx::TreeCtrl::CollapseAllChildren", XS_Wx__TreeCtrl_CollapseAllChildren);
#endif
        newXS_deffile("Wx::TreeCtrl::CollapseAndReset", XS_Wx__TreeCtrl_CollapseAndReset);
        newXS_deffile("Wx::TreeCtrl::Delete", XS_Wx__TreeCtrl_Delete);
        newXS_deffile("Wx::TreeCtrl::DeleteChildren", XS_Wx__TreeCtrl_DeleteChildren);
        newXS_deffile("Wx::TreeCtrl::DeleteAllItems", XS_Wx__TreeCtrl_DeleteAllItems);
        newXS_deffile("Wx::TreeCtrl::EditLabel", XS_Wx__TreeCtrl_EditLabel);
#if XSubPPtmpAADL
        newXS_deffile("Wx::TreeCtrl::EndEditLabel", XS_Wx__TreeCtrl_EndEditLabel);
#endif
#if XSubPPtmpAADM
        newXS_deffile("Wx::TreeCtrl::EndEditLabel", XS_Wx__TreeCtrl_EndEditLabel);
#endif
        newXS_deffile("Wx::TreeCtrl::EnsureVisible", XS_Wx__TreeCtrl_EnsureVisible);
#if XSubPPtmpAADN
        newXS_deffile("Wx::TreeCtrl::ExpandAll", XS_Wx__TreeCtrl_ExpandAll);
#endif
        newXS_deffile("Wx::TreeCtrl::Expand", XS_Wx__TreeCtrl_Expand);
#if XSubPPtmpAADO
        newXS_deffile("Wx::TreeCtrl::ExpandAllChildren", XS_Wx__TreeCtrl_ExpandAllChildren);
#endif
        newXS_deffile("Wx::TreeCtrl::GetBoundingRect", XS_Wx__TreeCtrl_GetBoundingRect);
        newXS_deffile("Wx::TreeCtrl::GetChildrenCount", XS_Wx__TreeCtrl_GetChildrenCount);
        newXS_deffile("Wx::TreeCtrl::GetCount", XS_Wx__TreeCtrl_GetCount);
        newXS_deffile("Wx::TreeCtrl::GetItemData", XS_Wx__TreeCtrl_GetItemData);
        newXS_deffile("Wx::TreeCtrl::GetPlData", XS_Wx__TreeCtrl_GetPlData);
#if XSubPPtmpAADP
        newXS_deffile("Wx::TreeCtrl::GetEditControl", XS_Wx__TreeCtrl_GetEditControl);
#endif
        newXS_deffile("Wx::TreeCtrl::GetFirstChild", XS_Wx__TreeCtrl_GetFirstChild);
        newXS_deffile("Wx::TreeCtrl::GetFirstVisibleItem", XS_Wx__TreeCtrl_GetFirstVisibleItem);
        newXS_deffile("Wx::TreeCtrl::GetImageList", XS_Wx__TreeCtrl_GetImageList);
#if XSubPPtmpAADQ
        newXS_deffile("Wx::TreeCtrl::GetButtonsImageList", XS_Wx__TreeCtrl_GetButtonsImageList);
#endif
        newXS_deffile("Wx::TreeCtrl::GetIndent", XS_Wx__TreeCtrl_GetIndent);
        newXS_deffile("Wx::TreeCtrl::GetItemImage", XS_Wx__TreeCtrl_GetItemImage);
        newXS_deffile("Wx::TreeCtrl::GetItemText", XS_Wx__TreeCtrl_GetItemText);
        newXS_deffile("Wx::TreeCtrl::GetItemBackgroundColour", XS_Wx__TreeCtrl_GetItemBackgroundColour);
        newXS_deffile("Wx::TreeCtrl::GetItemTextColour", XS_Wx__TreeCtrl_GetItemTextColour);
        newXS_deffile("Wx::TreeCtrl::GetItemFont", XS_Wx__TreeCtrl_GetItemFont);
        newXS_deffile("Wx::TreeCtrl::GetLastChild", XS_Wx__TreeCtrl_GetLastChild);
#if XSubPPtmpAADR
        newXS_deffile("Wx::TreeCtrl::GetNextChild", XS_Wx__TreeCtrl_GetNextChild);
#endif
#if XSubPPtmpAADS
        newXS_deffile("Wx::TreeCtrl::GetNextChild", XS_Wx__TreeCtrl_GetNextChild);
#endif
        newXS_deffile("Wx::TreeCtrl::GetNextSibling", XS_Wx__TreeCtrl_GetNextSibling);
        newXS_deffile("Wx::TreeCtrl::GetNextVisible", XS_Wx__TreeCtrl_GetNextVisible);
        newXS_deffile("Wx::TreeCtrl::GetParent", XS_Wx__TreeCtrl_GetParent);
        newXS_deffile("Wx::TreeCtrl::GetItemParent", XS_Wx__TreeCtrl_GetItemParent);
        newXS_deffile("Wx::TreeCtrl::GetPrevSibling", XS_Wx__TreeCtrl_GetPrevSibling);
        newXS_deffile("Wx::TreeCtrl::GetPrevVisible", XS_Wx__TreeCtrl_GetPrevVisible);
        newXS_deffile("Wx::TreeCtrl::GetRootItem", XS_Wx__TreeCtrl_GetRootItem);
        newXS_deffile("Wx::TreeCtrl::GetSelection", XS_Wx__TreeCtrl_GetSelection);
        newXS_deffile("Wx::TreeCtrl::GetSelections", XS_Wx__TreeCtrl_GetSelections);
        newXS_deffile("Wx::TreeCtrl::GetStateImageList", XS_Wx__TreeCtrl_GetStateImageList);
        newXS_deffile("Wx::TreeCtrl::HitTest", XS_Wx__TreeCtrl_HitTest);
        newXS_deffile("Wx::TreeCtrl::InsertItem", XS_Wx__TreeCtrl_InsertItem);
        newXS_deffile("Wx::TreeCtrl::InsertItemPrev", XS_Wx__TreeCtrl_InsertItemPrev);
        newXS_deffile("Wx::TreeCtrl::InsertItemBef", XS_Wx__TreeCtrl_InsertItemBef);
        newXS_deffile("Wx::TreeCtrl::IsBold", XS_Wx__TreeCtrl_IsBold);
        newXS_deffile("Wx::TreeCtrl::IsExpanded", XS_Wx__TreeCtrl_IsExpanded);
        newXS_deffile("Wx::TreeCtrl::IsSelected", XS_Wx__TreeCtrl_IsSelected);
        newXS_deffile("Wx::TreeCtrl::IsVisible", XS_Wx__TreeCtrl_IsVisible);
#if XSubPPtmpAADT
        newXS_deffile("Wx::TreeCtrl::IsEmpty", XS_Wx__TreeCtrl_IsEmpty);
#endif
        newXS_deffile("Wx::TreeCtrl::ItemHasChildren", XS_Wx__TreeCtrl_ItemHasChildren);
        newXS_deffile("Wx::TreeCtrl::OnCompareItems", XS_Wx__TreeCtrl_OnCompareItems);
        newXS_deffile("Wx::TreeCtrl::PrependItem", XS_Wx__TreeCtrl_PrependItem);
        newXS_deffile("Wx::TreeCtrl::ScrollTo", XS_Wx__TreeCtrl_ScrollTo);
#if XSubPPtmpAADU
        newXS_deffile("Wx::TreeCtrl::SelectItem", XS_Wx__TreeCtrl_SelectItem);
#endif
#if XSubPPtmpAADV
        newXS_deffile("Wx::TreeCtrl::SelectItem", XS_Wx__TreeCtrl_SelectItem);
#endif
        newXS_deffile("Wx::TreeCtrl::SetIndent", XS_Wx__TreeCtrl_SetIndent);
        newXS_deffile("Wx::TreeCtrl::SetImageList", XS_Wx__TreeCtrl_SetImageList);
#if XSubPPtmpAADW
        newXS_deffile("Wx::TreeCtrl::SetButtonsImageList", XS_Wx__TreeCtrl_SetButtonsImageList);
#endif
        newXS_deffile("Wx::TreeCtrl::SetStateImageList", XS_Wx__TreeCtrl_SetStateImageList);
        newXS_deffile("Wx::TreeCtrl::AssignImageList", XS_Wx__TreeCtrl_AssignImageList);
        newXS_deffile("Wx::TreeCtrl::AssignButtonsImageList", XS_Wx__TreeCtrl_AssignButtonsImageList);
        newXS_deffile("Wx::TreeCtrl::AssignStateImageList", XS_Wx__TreeCtrl_AssignStateImageList);
        newXS_deffile("Wx::TreeCtrl::SetItemBackgroundColour", XS_Wx__TreeCtrl_SetItemBackgroundColour);
        newXS_deffile("Wx::TreeCtrl::SetItemBold", XS_Wx__TreeCtrl_SetItemBold);
        newXS_deffile("Wx::TreeCtrl::SetItemData", XS_Wx__TreeCtrl_SetItemData);
        newXS_deffile("Wx::TreeCtrl::SetPlData", XS_Wx__TreeCtrl_SetPlData);
#if XSubPPtmpAADX
        newXS_deffile("Wx::TreeCtrl::SetItemDropHighlight", XS_Wx__TreeCtrl_SetItemDropHighlight);
#endif
        newXS_deffile("Wx::TreeCtrl::SetItemFont", XS_Wx__TreeCtrl_SetItemFont);
        newXS_deffile("Wx::TreeCtrl::SetItemHasChildren", XS_Wx__TreeCtrl_SetItemHasChildren);
        newXS_deffile("Wx::TreeCtrl::SetItemImage", XS_Wx__TreeCtrl_SetItemImage);
        newXS_deffile("Wx::TreeCtrl::SetItemText", XS_Wx__TreeCtrl_SetItemText);
        newXS_deffile("Wx::TreeCtrl::SetItemTextColour", XS_Wx__TreeCtrl_SetItemTextColour);
        newXS_deffile("Wx::TreeCtrl::SortChildren", XS_Wx__TreeCtrl_SortChildren);
        newXS_deffile("Wx::TreeCtrl::Toggle", XS_Wx__TreeCtrl_Toggle);
#if XSubPPtmpAADY
        newXS_deffile("Wx::TreeCtrl::UnselectItem", XS_Wx__TreeCtrl_UnselectItem);
        newXS_deffile("Wx::TreeCtrl::ToggleItemSelection", XS_Wx__TreeCtrl_ToggleItemSelection);
#endif
        newXS_deffile("Wx::TreeCtrl::Unselect", XS_Wx__TreeCtrl_Unselect);
        newXS_deffile("Wx::TreeCtrl::UnselectAll", XS_Wx__TreeCtrl_UnselectAll);
#if XSubPPtmpAADZ
        newXS_deffile("Wx::ToggleButton::new", XS_Wx__ToggleButton_new);
        newXS_deffile("Wx::ToggleButton::newDefault", XS_Wx__ToggleButton_newDefault);
        newXS_deffile("Wx::ToggleButton::newFull", XS_Wx__ToggleButton_newFull);
        newXS_deffile("Wx::ToggleButton::Create", XS_Wx__ToggleButton_Create);
        newXS_deffile("Wx::ToggleButton::GetValue", XS_Wx__ToggleButton_GetValue);
        newXS_deffile("Wx::ToggleButton::SetValue", XS_Wx__ToggleButton_SetValue);
#if XSubPPtmpAAEA
        newXS_deffile("Wx::BitmapToggleButton::new", XS_Wx__BitmapToggleButton_new);
        newXS_deffile("Wx::BitmapToggleButton::newDefault", XS_Wx__BitmapToggleButton_newDefault);
        newXS_deffile("Wx::BitmapToggleButton::newFull", XS_Wx__BitmapToggleButton_newFull);
        newXS_deffile("Wx::BitmapToggleButton::Create", XS_Wx__BitmapToggleButton_Create);
        newXS_deffile("Wx::BitmapToggleButton::GetValue", XS_Wx__BitmapToggleButton_GetValue);
        newXS_deffile("Wx::BitmapToggleButton::SetValue", XS_Wx__BitmapToggleButton_SetValue);
#endif
#endif
        newXS_deffile("Wx::StaticText::new", XS_Wx__StaticText_new);
        newXS_deffile("Wx::StaticText::Create", XS_Wx__StaticText_Create);
#if XSubPPtmpAAEB
        newXS_deffile("Wx::StaticText::Wrap", XS_Wx__StaticText_Wrap);
#endif
        newXS_deffile("Wx::StaticLine::new", XS_Wx__StaticLine_new);
        newXS_deffile("Wx::StaticLine::Create", XS_Wx__StaticLine_Create);
        newXS_deffile("Wx::StaticLine::IsVertical", XS_Wx__StaticLine_IsVertical);
        newXS_deffile("Wx::StaticLine::GetDefaultSize", XS_Wx__StaticLine_GetDefaultSize);
        newXS_deffile("Wx::StaticBox::new", XS_Wx__StaticBox_new);
        newXS_deffile("Wx::StaticBox::Create", XS_Wx__StaticBox_Create);
        newXS_deffile("Wx::StaticBitmap::new", XS_Wx__StaticBitmap_new);
        newXS_deffile("Wx::StaticBitmap::newBitmap", XS_Wx__StaticBitmap_newBitmap);
#if XSubPPtmpAAEC
        newXS_deffile("Wx::StaticBitmap::newIcon", XS_Wx__StaticBitmap_newIcon);
#endif
        newXS_deffile("Wx::StaticBitmap::GetBitmap", XS_Wx__StaticBitmap_GetBitmap);
        newXS_deffile("Wx::StaticBitmap::SetBitmap", XS_Wx__StaticBitmap_SetBitmap);
#if XSubPPtmpAAED
        newXS_deffile("Wx::StaticBitmap::GetIcon", XS_Wx__StaticBitmap_GetIcon);
        newXS_deffile("Wx::StaticBitmap::SetIcon", XS_Wx__StaticBitmap_SetIcon);
#endif
        newXS_deffile("Wx::SpinCtrl::new", XS_Wx__SpinCtrl_new);
        newXS_deffile("Wx::SpinCtrl::newDefault", XS_Wx__SpinCtrl_newDefault);
        newXS_deffile("Wx::SpinCtrl::newFull", XS_Wx__SpinCtrl_newFull);
        newXS_deffile("Wx::SpinCtrl::Create", XS_Wx__SpinCtrl_Create);
        newXS_deffile("Wx::SpinCtrl::GetMin", XS_Wx__SpinCtrl_GetMin);
        newXS_deffile("Wx::SpinCtrl::GetMax", XS_Wx__SpinCtrl_GetMax);
        newXS_deffile("Wx::SpinCtrl::GetValue", XS_Wx__SpinCtrl_GetValue);
        newXS_deffile("Wx::SpinCtrl::SetRange", XS_Wx__SpinCtrl_SetRange);
        newXS_deffile("Wx::SpinCtrl::SetValue", XS_Wx__SpinCtrl_SetValue);
#if XSubPPtmpAAEE
        newXS_deffile("Wx::SpinCtrl::SetSelection", XS_Wx__SpinCtrl_SetSelection);
#endif
        newXS_deffile("Wx::SpinEvent::new", XS_Wx__SpinEvent_new);
        newXS_deffile("Wx::SpinEvent::GetPosition", XS_Wx__SpinEvent_GetPosition);
        newXS_deffile("Wx::SpinEvent::SetPosition", XS_Wx__SpinEvent_SetPosition);
        newXS_deffile("Wx::SpinButton::new", XS_Wx__SpinButton_new);
        newXS_deffile("Wx::SpinButton::newDefault", XS_Wx__SpinButton_newDefault);
        newXS_deffile("Wx::SpinButton::newFull", XS_Wx__SpinButton_newFull);
        newXS_deffile("Wx::SpinButton::Create", XS_Wx__SpinButton_Create);
        newXS_deffile("Wx::SpinButton::GetMax", XS_Wx__SpinButton_GetMax);
        newXS_deffile("Wx::SpinButton::GetMin", XS_Wx__SpinButton_GetMin);
        newXS_deffile("Wx::SpinButton::GetValue", XS_Wx__SpinButton_GetValue);
        newXS_deffile("Wx::SpinButton::SetRange", XS_Wx__SpinButton_SetRange);
        newXS_deffile("Wx::SpinButton::SetValue", XS_Wx__SpinButton_SetValue);
        newXS_deffile("Wx::Slider::new", XS_Wx__Slider_new);
        newXS_deffile("Wx::Slider::newDefault", XS_Wx__Slider_newDefault);
        newXS_deffile("Wx::Slider::newFull", XS_Wx__Slider_newFull);
        newXS_deffile("Wx::Slider::Create", XS_Wx__Slider_Create);
#if XSubPPtmpAAEF
        newXS_deffile("Wx::Slider::ClearSel", XS_Wx__Slider_ClearSel);
        newXS_deffile("Wx::Slider::ClearTicks", XS_Wx__Slider_ClearTicks);
#endif
        newXS_deffile("Wx::Slider::GetLineSize", XS_Wx__Slider_GetLineSize);
        newXS_deffile("Wx::Slider::GetMax", XS_Wx__Slider_GetMax);
        newXS_deffile("Wx::Slider::GetMin", XS_Wx__Slider_GetMin);
        newXS_deffile("Wx::Slider::GetPageSize", XS_Wx__Slider_GetPageSize);
#if XSubPPtmpAAEG
        newXS_deffile("Wx::Slider::GetSelEnd", XS_Wx__Slider_GetSelEnd);
        newXS_deffile("Wx::Slider::GetSelStart", XS_Wx__Slider_GetSelStart);
        newXS_deffile("Wx::Slider::GetThumbLength", XS_Wx__Slider_GetThumbLength);
        newXS_deffile("Wx::Slider::GetTickFreq", XS_Wx__Slider_GetTickFreq);
#endif
        newXS_deffile("Wx::Slider::GetValue", XS_Wx__Slider_GetValue);
        newXS_deffile("Wx::Slider::SetRange", XS_Wx__Slider_SetRange);
        newXS_deffile("Wx::Slider::SetTickFreq", XS_Wx__Slider_SetTickFreq);
        newXS_deffile("Wx::Slider::SetLineSize", XS_Wx__Slider_SetLineSize);
        newXS_deffile("Wx::Slider::SetPageSize", XS_Wx__Slider_SetPageSize);
#if XSubPPtmpAAEH
        newXS_deffile("Wx::Slider::StartSelection", XS_Wx__Slider_StartSelection);
#endif
#if XSubPPtmpAAEI
        newXS_deffile("Wx::Slider::SetThumbLength", XS_Wx__Slider_SetThumbLength);
#endif
        newXS_deffile("Wx::Slider::SetValue", XS_Wx__Slider_SetValue);
        newXS_deffile("Wx::ScrollBar::new", XS_Wx__ScrollBar_new);
        newXS_deffile("Wx::ScrollBar::newDefault", XS_Wx__ScrollBar_newDefault);
        newXS_deffile("Wx::ScrollBar::newFull", XS_Wx__ScrollBar_newFull);
        newXS_deffile("Wx::ScrollBar::Create", XS_Wx__ScrollBar_Create);
        newXS_deffile("Wx::ScrollBar::GetRange", XS_Wx__ScrollBar_GetRange);
        newXS_deffile("Wx::ScrollBar::GetPageSize", XS_Wx__ScrollBar_GetPageSize);
        newXS_deffile("Wx::ScrollBar::GetThumbPosition", XS_Wx__ScrollBar_GetThumbPosition);
        newXS_deffile("Wx::ScrollBar::GetThumbSize", XS_Wx__ScrollBar_GetThumbSize);
        newXS_deffile("Wx::ScrollBar::SetThumbPosition", XS_Wx__ScrollBar_SetThumbPosition);
#if XSubPPtmpAAEJ
        newXS_deffile("Wx::ScrollBar::SetPageSize", XS_Wx__ScrollBar_SetPageSize);
#endif
        newXS_deffile("Wx::ScrollBar::SetScrollbar", XS_Wx__ScrollBar_SetScrollbar);
        newXS_deffile("Wx::RadioButton::new", XS_Wx__RadioButton_new);
        newXS_deffile("Wx::RadioButton::newDefault", XS_Wx__RadioButton_newDefault);
        newXS_deffile("Wx::RadioButton::newFull", XS_Wx__RadioButton_newFull);
        newXS_deffile("Wx::RadioButton::Create", XS_Wx__RadioButton_Create);
        newXS_deffile("Wx::RadioButton::GetValue", XS_Wx__RadioButton_GetValue);
        newXS_deffile("Wx::RadioButton::SetValue", XS_Wx__RadioButton_SetValue);
        newXS_deffile("Wx::RadioBox::new", XS_Wx__RadioBox_new);
        newXS_deffile("Wx::RadioBox::newDefault", XS_Wx__RadioBox_newDefault);
        newXS_deffile("Wx::RadioBox::newFull", XS_Wx__RadioBox_newFull);
        newXS_deffile("Wx::RadioBox::Create", XS_Wx__RadioBox_Create);
        newXS_deffile("Wx::RadioBox::EnableItem", XS_Wx__RadioBox_EnableItem);
        newXS_deffile("Wx::RadioBox::FindString", XS_Wx__RadioBox_FindString);
#if XSubPPtmpAAEK
        newXS_deffile("Wx::RadioBox::GetColumnCount", XS_Wx__RadioBox_GetColumnCount);
        newXS_deffile("Wx::RadioBox::GetRowCount", XS_Wx__RadioBox_GetRowCount);
        newXS_deffile("Wx::RadioBox::GetItemFromPoint", XS_Wx__RadioBox_GetItemFromPoint);
#endif
        newXS_deffile("Wx::RadioBox::GetString", XS_Wx__RadioBox_GetString);
        newXS_deffile("Wx::RadioBox::GetItemLabel", XS_Wx__RadioBox_GetItemLabel);
        newXS_deffile("Wx::RadioBox::GetSelection", XS_Wx__RadioBox_GetSelection);
        newXS_deffile("Wx::RadioBox::GetStringSelection", XS_Wx__RadioBox_GetStringSelection);
#if XSubPPtmpAAEL
        newXS_deffile("Wx::RadioBox::IsItemEnabled", XS_Wx__RadioBox_IsItemEnabled);
        newXS_deffile("Wx::RadioBox::IsItemShown", XS_Wx__RadioBox_IsItemShown);
#endif
        newXS_deffile("Wx::RadioBox::SetString", XS_Wx__RadioBox_SetString);
        newXS_deffile("Wx::RadioBox::SetItemLabel", XS_Wx__RadioBox_SetItemLabel);
#if XSubPPtmpAAEM
        newXS_deffile("Wx::RadioBox::SetItemToolTip", XS_Wx__RadioBox_SetItemToolTip);
        newXS_deffile("Wx::RadioBox::GetItemToolTip", XS_Wx__RadioBox_GetItemToolTip);
#endif
#if XSubPPtmpAAEN
        newXS_deffile("Wx::RadioBox::SetItemHelpText", XS_Wx__RadioBox_SetItemHelpText);
        newXS_deffile("Wx::RadioBox::GetItemHelpText", XS_Wx__RadioBox_GetItemHelpText);
#endif
        newXS_deffile("Wx::RadioBox::SetSelection", XS_Wx__RadioBox_SetSelection);
        newXS_deffile("Wx::RadioBox::SetStringSelection", XS_Wx__RadioBox_SetStringSelection);
        newXS_deffile("Wx::RadioBox::ShowItem", XS_Wx__RadioBox_ShowItem);
        newXS_deffile("Wx::NotebookEvent::new", XS_Wx__NotebookEvent_new);
#if XSubPPtmpAAEO
        newXS_deffile("Wx::NotebookEvent::GetOldSelection", XS_Wx__NotebookEvent_GetOldSelection);
        newXS_deffile("Wx::NotebookEvent::GetSelection", XS_Wx__NotebookEvent_GetSelection);
        newXS_deffile("Wx::NotebookEvent::SetOldSelection", XS_Wx__NotebookEvent_SetOldSelection);
        newXS_deffile("Wx::NotebookEvent::SetSelection", XS_Wx__NotebookEvent_SetSelection);
#endif
        newXS_deffile("Wx::Notebook::new", XS_Wx__Notebook_new);
        newXS_deffile("Wx::Notebook::newDefault", XS_Wx__Notebook_newDefault);
        newXS_deffile("Wx::Notebook::newFull", XS_Wx__Notebook_newFull);
        newXS_deffile("Wx::Notebook::Create", XS_Wx__Notebook_Create);
#if XSubPPtmpAAEP
        newXS_deffile("Wx::Notebook::AddPage", XS_Wx__Notebook_AddPage);
        newXS_deffile("Wx::Notebook::AdvanceSelection", XS_Wx__Notebook_AdvanceSelection);
        newXS_deffile("Wx::Notebook::DeleteAllPages", XS_Wx__Notebook_DeleteAllPages);
        newXS_deffile("Wx::Notebook::DeletePage", XS_Wx__Notebook_DeletePage);
        newXS_deffile("Wx::Notebook::GetImageList", XS_Wx__Notebook_GetImageList);
        newXS_deffile("Wx::Notebook::GetPage", XS_Wx__Notebook_GetPage);
        newXS_deffile("Wx::Notebook::GetPageCount", XS_Wx__Notebook_GetPageCount);
        newXS_deffile("Wx::Notebook::GetPageImage", XS_Wx__Notebook_GetPageImage);
        newXS_deffile("Wx::Notebook::GetPageText", XS_Wx__Notebook_GetPageText);
        newXS_deffile("Wx::Notebook::GetSelection", XS_Wx__Notebook_GetSelection);
        newXS_deffile("Wx::Notebook::InsertPage", XS_Wx__Notebook_InsertPage);
        newXS_deffile("Wx::Notebook::RemovePage", XS_Wx__Notebook_RemovePage);
        newXS_deffile("Wx::Notebook::SetImageList", XS_Wx__Notebook_SetImageList);
        newXS_deffile("Wx::Notebook::SetPageImage", XS_Wx__Notebook_SetPageImage);
        newXS_deffile("Wx::Notebook::SetPageText", XS_Wx__Notebook_SetPageText);
        newXS_deffile("Wx::Notebook::SetSelection", XS_Wx__Notebook_SetSelection);
#endif
#if XSubPPtmpAAEQ
        newXS_deffile("Wx::Notebook::HitTest", XS_Wx__Notebook_HitTest);
#endif
        newXS_deffile("Wx::Notebook::GetRowCount", XS_Wx__Notebook_GetRowCount);
#if XSubPPtmpAAER
        newXS_deffile("Wx::Notebook::SetPadding", XS_Wx__Notebook_SetPadding);
        newXS_deffile("Wx::Notebook::SetPageSize", XS_Wx__Notebook_SetPageSize);
#endif
        newXS_deffile("Wx::ListEvent::new", XS_Wx__ListEvent_new);
#if XSubPPtmpAAES
        newXS_deffile("Wx::ListEvent::IsEditCancelled", XS_Wx__ListEvent_IsEditCancelled);
#endif
        newXS_deffile("Wx::ListEvent::GetCacheFrom", XS_Wx__ListEvent_GetCacheFrom);
        newXS_deffile("Wx::ListEvent::GetCacheTo", XS_Wx__ListEvent_GetCacheTo);
        newXS_deffile("Wx::ListEvent::GetIndex", XS_Wx__ListEvent_GetIndex);
        newXS_deffile("Wx::ListEvent::GetColumn", XS_Wx__ListEvent_GetColumn);
        newXS_deffile("Wx::ListEvent::GetKeyCode", XS_Wx__ListEvent_GetKeyCode);
        newXS_deffile("Wx::ListEvent::GetPoint", XS_Wx__ListEvent_GetPoint);
        newXS_deffile("Wx::ListEvent::GetLabel", XS_Wx__ListEvent_GetLabel);
        newXS_deffile("Wx::ListEvent::GetText", XS_Wx__ListEvent_GetText);
        newXS_deffile("Wx::ListEvent::GetImage", XS_Wx__ListEvent_GetImage);
        newXS_deffile("Wx::ListEvent::GetData", XS_Wx__ListEvent_GetData);
        newXS_deffile("Wx::ListEvent::GetMask", XS_Wx__ListEvent_GetMask);
        newXS_deffile("Wx::ListEvent::GetItem", XS_Wx__ListEvent_GetItem);
        newXS_deffile("Wx::ListItem::new", XS_Wx__ListItem_new);
        newXS_deffile("Wx::ListItem::CLONE", XS_Wx__ListItem_CLONE);
        newXS_deffile("Wx::ListItem::DESTROY", XS_Wx__ListItem_DESTROY);
        newXS_deffile("Wx::ListItem::Clear", XS_Wx__ListItem_Clear);
        newXS_deffile("Wx::ListItem::ClearAttributes", XS_Wx__ListItem_ClearAttributes);
        newXS_deffile("Wx::ListItem::SetMask", XS_Wx__ListItem_SetMask);
        newXS_deffile("Wx::ListItem::SetId", XS_Wx__ListItem_SetId);
        newXS_deffile("Wx::ListItem::SetColumn", XS_Wx__ListItem_SetColumn);
        newXS_deffile("Wx::ListItem::SetState", XS_Wx__ListItem_SetState);
        newXS_deffile("Wx::ListItem::SetStateMask", XS_Wx__ListItem_SetStateMask);
        newXS_deffile("Wx::ListItem::SetText", XS_Wx__ListItem_SetText);
        newXS_deffile("Wx::ListItem::SetImage", XS_Wx__ListItem_SetImage);
        newXS_deffile("Wx::ListItem::SetData", XS_Wx__ListItem_SetData);
        newXS_deffile("Wx::ListItem::SetWidth", XS_Wx__ListItem_SetWidth);
        newXS_deffile("Wx::ListItem::SetAlign", XS_Wx__ListItem_SetAlign);
        newXS_deffile("Wx::ListItem::SetTextColour", XS_Wx__ListItem_SetTextColour);
        newXS_deffile("Wx::ListItem::SetBackgroundColour", XS_Wx__ListItem_SetBackgroundColour);
        newXS_deffile("Wx::ListItem::SetFont", XS_Wx__ListItem_SetFont);
        newXS_deffile("Wx::ListItem::GetMask", XS_Wx__ListItem_GetMask);
        newXS_deffile("Wx::ListItem::GetId", XS_Wx__ListItem_GetId);
        newXS_deffile("Wx::ListItem::GetColumn", XS_Wx__ListItem_GetColumn);
        newXS_deffile("Wx::ListItem::GetState", XS_Wx__ListItem_GetState);
        newXS_deffile("Wx::ListItem::GetText", XS_Wx__ListItem_GetText);
        newXS_deffile("Wx::ListItem::GetImage", XS_Wx__ListItem_GetImage);
        newXS_deffile("Wx::ListItem::GetData", XS_Wx__ListItem_GetData);
        newXS_deffile("Wx::ListItem::GetWidth", XS_Wx__ListItem_GetWidth);
        newXS_deffile("Wx::ListItem::GetAlign", XS_Wx__ListItem_GetAlign);
        newXS_deffile("Wx::ListItem::GetTextColour", XS_Wx__ListItem_GetTextColour);
        newXS_deffile("Wx::ListItem::GetBackgroundColour", XS_Wx__ListItem_GetBackgroundColour);
        newXS_deffile("Wx::ListItem::GetFont", XS_Wx__ListItem_GetFont);
        newXS_deffile("Wx::ListItemAttr::new", XS_Wx__ListItemAttr_new);
        newXS_deffile("Wx::ListItemAttr::CLONE", XS_Wx__ListItemAttr_CLONE);
        newXS_deffile("Wx::ListItemAttr::DESTROY", XS_Wx__ListItemAttr_DESTROY);
        newXS_deffile("Wx::ListItemAttr::SetTextColour", XS_Wx__ListItemAttr_SetTextColour);
        newXS_deffile("Wx::ListItemAttr::SetBackgroundColour", XS_Wx__ListItemAttr_SetBackgroundColour);
        newXS_deffile("Wx::ListItemAttr::SetFont", XS_Wx__ListItemAttr_SetFont);
        newXS_deffile("Wx::ListItemAttr::HasTextColour", XS_Wx__ListItemAttr_HasTextColour);
        newXS_deffile("Wx::ListItemAttr::HasBackgroundColour", XS_Wx__ListItemAttr_HasBackgroundColour);
        newXS_deffile("Wx::ListItemAttr::HasFont", XS_Wx__ListItemAttr_HasFont);
        newXS_deffile("Wx::ListItemAttr::GetTextColour", XS_Wx__ListItemAttr_GetTextColour);
        newXS_deffile("Wx::ListItemAttr::GetBackgroundColour", XS_Wx__ListItemAttr_GetBackgroundColour);
        newXS_deffile("Wx::ListItemAttr::GetFont", XS_Wx__ListItemAttr_GetFont);
        newXS_deffile("Wx::ListCtrl::new", XS_Wx__ListCtrl_new);
        newXS_deffile("Wx::ListCtrl::newDefault", XS_Wx__ListCtrl_newDefault);
        newXS_deffile("Wx::ListCtrl::newFull", XS_Wx__ListCtrl_newFull);
        newXS_deffile("Wx::ListCtrl::Create", XS_Wx__ListCtrl_Create);
        newXS_deffile("Wx::ListCtrl::Arrange", XS_Wx__ListCtrl_Arrange);
        newXS_deffile("Wx::ListCtrl::AssignImageList", XS_Wx__ListCtrl_AssignImageList);
        newXS_deffile("Wx::ListCtrl::ClearAll", XS_Wx__ListCtrl_ClearAll);
        newXS_deffile("Wx::ListCtrl::DeleteItem", XS_Wx__ListCtrl_DeleteItem);
        newXS_deffile("Wx::ListCtrl::DeleteAllItems", XS_Wx__ListCtrl_DeleteAllItems);
        newXS_deffile("Wx::ListCtrl::DeleteColumn", XS_Wx__ListCtrl_DeleteColumn);
        newXS_deffile("Wx::ListCtrl::EditLabel", XS_Wx__ListCtrl_EditLabel);
        newXS_deffile("Wx::ListCtrl::EnsureVisible", XS_Wx__ListCtrl_EnsureVisible);
        newXS_deffile("Wx::ListCtrl::FindItem", XS_Wx__ListCtrl_FindItem);
        newXS_deffile("Wx::ListCtrl::FindItemData", XS_Wx__ListCtrl_FindItemData);
        newXS_deffile("Wx::ListCtrl::FindItemAtPos", XS_Wx__ListCtrl_FindItemAtPos);
        newXS_deffile("Wx::ListCtrl::GetColumn", XS_Wx__ListCtrl_GetColumn);
        newXS_deffile("Wx::ListCtrl::GetColumnCount", XS_Wx__ListCtrl_GetColumnCount);
        newXS_deffile("Wx::ListCtrl::GetColumnWidth", XS_Wx__ListCtrl_GetColumnWidth);
        newXS_deffile("Wx::ListCtrl::GetCountPerPage", XS_Wx__ListCtrl_GetCountPerPage);
#if XSubPPtmpAAET
        newXS_deffile("Wx::ListCtrl::GetEditControl", XS_Wx__ListCtrl_GetEditControl);
#endif
        newXS_deffile("Wx::ListCtrl::GetImageList", XS_Wx__ListCtrl_GetImageList);
        newXS_deffile("Wx::ListCtrl::GetItem", XS_Wx__ListCtrl_GetItem);
#if XSubPPtmpAAEU
        newXS_deffile("Wx::ListCtrl::GetItemData", XS_Wx__ListCtrl_GetItemData);
        newXS_deffile("Wx::ListCtrl::SetItemPtrData", XS_Wx__ListCtrl_SetItemPtrData);
        newXS_deffile("Wx::ListCtrl::SetItemData", XS_Wx__ListCtrl_SetItemData);
#endif
#if XSubPPtmpAAEV
        newXS_deffile("Wx::ListCtrl::GetItemData", XS_Wx__ListCtrl_GetItemData);
        newXS_deffile("Wx::ListCtrl::SetItemData", XS_Wx__ListCtrl_SetItemData);
#endif
        newXS_deffile("Wx::ListCtrl::GetItemPosition", XS_Wx__ListCtrl_GetItemPosition);
        newXS_deffile("Wx::ListCtrl::GetItemRect", XS_Wx__ListCtrl_GetItemRect);
#if XSubPPtmpAAEW
        newXS_deffile("Wx::ListCtrl::GetSubItemRect", XS_Wx__ListCtrl_GetSubItemRect);
#endif
        newXS_deffile("Wx::ListCtrl::GetItemState", XS_Wx__ListCtrl_GetItemState);
        newXS_deffile("Wx::ListCtrl::GetItemCount", XS_Wx__ListCtrl_GetItemCount);
#if XSubPPtmpAAEX
        newXS_deffile("Wx::ListCtrl::GetItemSpacing", XS_Wx__ListCtrl_GetItemSpacing);
#endif
#if XSubPPtmpAAEY
        newXS_deffile("Wx::ListCtrl::GetItemSpacing", XS_Wx__ListCtrl_GetItemSpacing);
#endif
        newXS_deffile("Wx::ListCtrl::GetItemText", XS_Wx__ListCtrl_GetItemText);
        newXS_deffile("Wx::ListCtrl::GetItemFont", XS_Wx__ListCtrl_GetItemFont);
        newXS_deffile("Wx::ListCtrl::GetItemTextColour", XS_Wx__ListCtrl_GetItemTextColour);
        newXS_deffile("Wx::ListCtrl::GetItemBackgroundColour", XS_Wx__ListCtrl_GetItemBackgroundColour);
        newXS_deffile("Wx::ListCtrl::SetItemTextColour", XS_Wx__ListCtrl_SetItemTextColour);
        newXS_deffile("Wx::ListCtrl::SetItemBackgroundColour", XS_Wx__ListCtrl_SetItemBackgroundColour);
        newXS_deffile("Wx::ListCtrl::GetNextItem", XS_Wx__ListCtrl_GetNextItem);
        newXS_deffile("Wx::ListCtrl::GetSelectedItemCount", XS_Wx__ListCtrl_GetSelectedItemCount);
        newXS_deffile("Wx::ListCtrl::GetTextColour", XS_Wx__ListCtrl_GetTextColour);
        newXS_deffile("Wx::ListCtrl::GetTopItem", XS_Wx__ListCtrl_GetTopItem);
#if XSubPPtmpAAEZ
        newXS_deffile("Wx::ListCtrl::GetViewRect", XS_Wx__ListCtrl_GetViewRect);
#endif
        newXS_deffile("Wx::ListCtrl::HitTest", XS_Wx__ListCtrl_HitTest);
        newXS_deffile("Wx::ListCtrl::InsertColumn", XS_Wx__ListCtrl_InsertColumn);
        newXS_deffile("Wx::ListCtrl::InsertColumnInfo", XS_Wx__ListCtrl_InsertColumnInfo);
        newXS_deffile("Wx::ListCtrl::InsertColumnString", XS_Wx__ListCtrl_InsertColumnString);
        newXS_deffile("Wx::ListCtrl::InsertItem", XS_Wx__ListCtrl_InsertItem);
        newXS_deffile("Wx::ListCtrl::InsertStringItem", XS_Wx__ListCtrl_InsertStringItem);
        newXS_deffile("Wx::ListCtrl::InsertImageItem", XS_Wx__ListCtrl_InsertImageItem);
        newXS_deffile("Wx::ListCtrl::InsertImageStringItem", XS_Wx__ListCtrl_InsertImageStringItem);
        newXS_deffile("Wx::ListCtrl::IsVirtual", XS_Wx__ListCtrl_IsVirtual);
        newXS_deffile("Wx::ListCtrl::RefreshItem", XS_Wx__ListCtrl_RefreshItem);
        newXS_deffile("Wx::ListCtrl::RefreshItems", XS_Wx__ListCtrl_RefreshItems);
        newXS_deffile("Wx::ListCtrl::ScrollList", XS_Wx__ListCtrl_ScrollList);
        newXS_deffile("Wx::ListCtrl::SetColumn", XS_Wx__ListCtrl_SetColumn);
        newXS_deffile("Wx::ListCtrl::SetColumnWidth", XS_Wx__ListCtrl_SetColumnWidth);
        newXS_deffile("Wx::ListCtrl::SetImageList", XS_Wx__ListCtrl_SetImageList);
        newXS_deffile("Wx::ListCtrl::SetItemCount", XS_Wx__ListCtrl_SetItemCount);
        newXS_deffile("Wx::ListCtrl::SetItem", XS_Wx__ListCtrl_SetItem);
        newXS_deffile("Wx::ListCtrl::SetItemInfo", XS_Wx__ListCtrl_SetItemInfo);
        newXS_deffile("Wx::ListCtrl::SetItemString", XS_Wx__ListCtrl_SetItemString);
        newXS_deffile("Wx::ListCtrl::SetItemImage", XS_Wx__ListCtrl_SetItemImage);
#if XSubPPtmpAAFA
        newXS_deffile("Wx::ListCtrl::SetItemColumnImage", XS_Wx__ListCtrl_SetItemColumnImage);
#endif
        newXS_deffile("Wx::ListCtrl::SetItemPosition", XS_Wx__ListCtrl_SetItemPosition);
        newXS_deffile("Wx::ListCtrl::SetItemState", XS_Wx__ListCtrl_SetItemState);
        newXS_deffile("Wx::ListCtrl::SetItemText", XS_Wx__ListCtrl_SetItemText);
        newXS_deffile("Wx::ListCtrl::SetItemFont", XS_Wx__ListCtrl_SetItemFont);
        newXS_deffile("Wx::ListCtrl::SetSingleStyle", XS_Wx__ListCtrl_SetSingleStyle);
        newXS_deffile("Wx::ListCtrl::SetTextColour", XS_Wx__ListCtrl_SetTextColour);
        newXS_deffile("Wx::ListCtrl::SetWindowStyleFlag", XS_Wx__ListCtrl_SetWindowStyleFlag);
        newXS_deffile("Wx::ListCtrl::SortItems", XS_Wx__ListCtrl_SortItems);
        newXS_deffile("Wx::ListView::new", XS_Wx__ListView_new);
        newXS_deffile("Wx::ListView::newDefault", XS_Wx__ListView_newDefault);
        newXS_deffile("Wx::ListView::newFull", XS_Wx__ListView_newFull);
        newXS_deffile("Wx::ListView::Create", XS_Wx__ListView_Create);
        newXS_deffile("Wx::ListView::Select", XS_Wx__ListView_Select);
        newXS_deffile("Wx::ListView::SetColumnImage", XS_Wx__ListView_SetColumnImage);
        newXS_deffile("Wx::ListView::ClearColumnImage", XS_Wx__ListView_ClearColumnImage);
        newXS_deffile("Wx::ListView::Focus", XS_Wx__ListView_Focus);
        newXS_deffile("Wx::ListView::GetFocusedItem", XS_Wx__ListView_GetFocusedItem);
        newXS_deffile("Wx::ListView::GetFirstSelected", XS_Wx__ListView_GetFirstSelected);
        newXS_deffile("Wx::ListView::GetNextSelected", XS_Wx__ListView_GetNextSelected);
        newXS_deffile("Wx::ListView::IsSelected", XS_Wx__ListView_IsSelected);
        newXS_deffile("Wx::ListBox::new", XS_Wx__ListBox_new);
        newXS_deffile("Wx::ListBox::newDefault", XS_Wx__ListBox_newDefault);
        newXS_deffile("Wx::ListBox::newFull", XS_Wx__ListBox_newFull);
        newXS_deffile("Wx::ListBox::Create", XS_Wx__ListBox_Create);
        newXS_deffile("Wx::ListBox::Deselect", XS_Wx__ListBox_Deselect);
        newXS_deffile("Wx::ListBox::GetSelections", XS_Wx__ListBox_GetSelections);
        newXS_deffile("Wx::ListBox::HitTest", XS_Wx__ListBox_HitTest);
#if XSubPPtmpAAFB
        newXS_deffile("Wx::ListBox::InsertItems", XS_Wx__ListBox_InsertItems);
#endif
        newXS_deffile("Wx::ListBox::IsSelected", XS_Wx__ListBox_IsSelected);
        newXS_deffile("Wx::ListBox::SetSelection", XS_Wx__ListBox_SetSelection);
        newXS_deffile("Wx::ListBox::SetStringSelection", XS_Wx__ListBox_SetStringSelection);
        newXS_deffile("Wx::ListBox::SetFirstItem", XS_Wx__ListBox_SetFirstItem);
        newXS_deffile("Wx::ListBox::SetFirstItemString", XS_Wx__ListBox_SetFirstItemString);
#if XSubPPtmpAAFC
        newXS_deffile("Wx::ListBox::Set", XS_Wx__ListBox_Set);
#endif
        newXS_deffile("Wx::Gauge::new", XS_Wx__Gauge_new);
        newXS_deffile("Wx::Gauge::newDefault", XS_Wx__Gauge_newDefault);
        newXS_deffile("Wx::Gauge::newFull", XS_Wx__Gauge_newFull);
        newXS_deffile("Wx::Gauge::Create", XS_Wx__Gauge_Create);
#if XSubPPtmpAAFD
        newXS_deffile("Wx::Gauge::GetBezelFace", XS_Wx__Gauge_GetBezelFace);
#endif
        newXS_deffile("Wx::Gauge::GetRange", XS_Wx__Gauge_GetRange);
#if XSubPPtmpAAFE
        newXS_deffile("Wx::Gauge::GetShadowWidth", XS_Wx__Gauge_GetShadowWidth);
#endif
        newXS_deffile("Wx::Gauge::GetValue", XS_Wx__Gauge_GetValue);
#if XSubPPtmpAAFF
        newXS_deffile("Wx::Gauge::SetBezelFace", XS_Wx__Gauge_SetBezelFace);
#endif
        newXS_deffile("Wx::Gauge::SetRange", XS_Wx__Gauge_SetRange);
#if XSubPPtmpAAFG
        newXS_deffile("Wx::Gauge::SetShadowWidth", XS_Wx__Gauge_SetShadowWidth);
#endif
        newXS_deffile("Wx::Gauge::SetValue", XS_Wx__Gauge_SetValue);
#if XSubPPtmpAAFH
        newXS_deffile("Wx::Gauge::IsVertical", XS_Wx__Gauge_IsVertical);
#endif
#if XSubPPtmpAAFI
        newXS_deffile("Wx::Gauge::Pulse", XS_Wx__Gauge_Pulse);
#endif
        newXS_deffile("Wx::ComboBox::new", XS_Wx__ComboBox_new);
        newXS_deffile("Wx::ComboBox::newDefault", XS_Wx__ComboBox_newDefault);
        newXS_deffile("Wx::ComboBox::newFull", XS_Wx__ComboBox_newFull);
        newXS_deffile("Wx::ComboBox::Create", XS_Wx__ComboBox_Create);
#if XSubPPtmpAAFJ
        newXS_deffile("Wx::ComboBox::GetCount", XS_Wx__ComboBox_GetCount);
#if XSubPPtmpAAFK
        newXS_deffile("Wx::ComboBox::IsEmpty", XS_Wx__ComboBox_IsEmpty);
#endif
        newXS_deffile("Wx::ComboBox::GetString", XS_Wx__ComboBox_GetString);
        newXS_deffile("Wx::ComboBox::GetStrings", XS_Wx__ComboBox_GetStrings);
        newXS_deffile("Wx::ComboBox::SetString", XS_Wx__ComboBox_SetString);
        newXS_deffile("Wx::ComboBox::FindString", XS_Wx__ComboBox_FindString);
        newXS_deffile("Wx::ComboBox::FindStringNoCase", XS_Wx__ComboBox_FindStringNoCase);
#if XSubPPtmpAAFL
        newXS_deffile("Wx::ComboBox::FindStringCase", XS_Wx__ComboBox_FindStringCase);
#endif
#if XSubPPtmpAAFM
        newXS_deffile("Wx::ComboBox::SetSelection", XS_Wx__ComboBox_SetSelection);
        newXS_deffile("Wx::ComboBox::GetSelection", XS_Wx__ComboBox_GetSelection);
#endif
        newXS_deffile("Wx::ComboBox::SetStringSelection", XS_Wx__ComboBox_SetStringSelection);
        newXS_deffile("Wx::ComboBox::GetStringSelection", XS_Wx__ComboBox_GetStringSelection);
        newXS_deffile("Wx::ComboBox::Select", XS_Wx__ComboBox_Select);
        newXS_deffile("Wx::ComboBox::Append", XS_Wx__ComboBox_Append);
        newXS_deffile("Wx::ComboBox::AppendString", XS_Wx__ComboBox_AppendString);
        newXS_deffile("Wx::ComboBox::AppendData", XS_Wx__ComboBox_AppendData);
        newXS_deffile("Wx::ComboBox::AppendItems", XS_Wx__ComboBox_AppendItems);
#if XSubPPtmpAAFN
        newXS_deffile("Wx::ComboBox::AppendItemsData", XS_Wx__ComboBox_AppendItemsData);
#endif
        newXS_deffile("Wx::ComboBox::Insert", XS_Wx__ComboBox_Insert);
        newXS_deffile("Wx::ComboBox::InsertString", XS_Wx__ComboBox_InsertString);
        newXS_deffile("Wx::ComboBox::InsertData", XS_Wx__ComboBox_InsertData);
#if XSubPPtmpAAFO
        newXS_deffile("Wx::ComboBox::InsertItems", XS_Wx__ComboBox_InsertItems);
        newXS_deffile("Wx::ComboBox::InsertItemsData", XS_Wx__ComboBox_InsertItemsData);
#endif
#if XSubPPtmpAAFP
        newXS_deffile("Wx::ComboBox::Set", XS_Wx__ComboBox_Set);
        newXS_deffile("Wx::ComboBox::SetItems", XS_Wx__ComboBox_SetItems);
        newXS_deffile("Wx::ComboBox::SetItemsData", XS_Wx__ComboBox_SetItemsData);
#endif
        newXS_deffile("Wx::ComboBox::Clear", XS_Wx__ComboBox_Clear);
        newXS_deffile("Wx::ComboBox::Delete", XS_Wx__ComboBox_Delete);
        newXS_deffile("Wx::ComboBox::GetClientData", XS_Wx__ComboBox_GetClientData);
        newXS_deffile("Wx::ComboBox::SetClientData", XS_Wx__ComboBox_SetClientData);
        newXS_deffile("Wx::ComboBox::GetCurrentSelection", XS_Wx__ComboBox_GetCurrentSelection);
#endif
        newXS_deffile("Wx::ComboBox::SetEditable", XS_Wx__ComboBox_SetEditable);
#if XSubPPtmpAAFQ
        newXS_deffile("Wx::ComboBox::IsListEmpty", XS_Wx__ComboBox_IsListEmpty);
        newXS_deffile("Wx::ComboBox::IsTextEmpty", XS_Wx__ComboBox_IsTextEmpty);
#endif
        newXS_deffile("Wx::ComboBox::Copy", XS_Wx__ComboBox_Copy);
        newXS_deffile("Wx::ComboBox::Cut", XS_Wx__ComboBox_Cut);
        newXS_deffile("Wx::ComboBox::CanCopy", XS_Wx__ComboBox_CanCopy);
        newXS_deffile("Wx::ComboBox::CanCut", XS_Wx__ComboBox_CanCut);
        newXS_deffile("Wx::ComboBox::CanPaste", XS_Wx__ComboBox_CanPaste);
        newXS_deffile("Wx::ComboBox::Undo", XS_Wx__ComboBox_Undo);
        newXS_deffile("Wx::ComboBox::Redo", XS_Wx__ComboBox_Redo);
        newXS_deffile("Wx::ComboBox::CanUndo", XS_Wx__ComboBox_CanUndo);
        newXS_deffile("Wx::ComboBox::CanRedo", XS_Wx__ComboBox_CanRedo);
        newXS_deffile("Wx::ComboBox::GetInsertionPoint", XS_Wx__ComboBox_GetInsertionPoint);
        newXS_deffile("Wx::ComboBox::GetLastPosition", XS_Wx__ComboBox_GetLastPosition);
        newXS_deffile("Wx::ComboBox::GetValue", XS_Wx__ComboBox_GetValue);
        newXS_deffile("Wx::ComboBox::Paste", XS_Wx__ComboBox_Paste);
#if XSubPPtmpAAFR
        newXS_deffile("Wx::ComboBox::Popup", XS_Wx__ComboBox_Popup);
        newXS_deffile("Wx::ComboBox::Dismiss", XS_Wx__ComboBox_Dismiss);
#endif
        newXS_deffile("Wx::ComboBox::Replace", XS_Wx__ComboBox_Replace);
        newXS_deffile("Wx::ComboBox::Remove", XS_Wx__ComboBox_Remove);
        newXS_deffile("Wx::ComboBox::SetInsertionPoint", XS_Wx__ComboBox_SetInsertionPoint);
        newXS_deffile("Wx::ComboBox::SetInsertionPointEnd", XS_Wx__ComboBox_SetInsertionPointEnd);
        newXS_deffile("Wx::ComboBox::GetSelection", XS_Wx__ComboBox_GetSelection);
        newXS_deffile("Wx::ComboBox::SetSelection", XS_Wx__ComboBox_SetSelection);
        newXS_deffile("Wx::ComboBox::SetSelectionN", XS_Wx__ComboBox_SetSelectionN);
        newXS_deffile("Wx::ComboBox::SetMark", XS_Wx__ComboBox_SetMark);
        newXS_deffile("Wx::ComboBox::SetValue", XS_Wx__ComboBox_SetValue);
#if XSubPPtmpAAFS
        newXS_deffile("Wx::ComboBox::RemoveSelection", XS_Wx__ComboBox_RemoveSelection);
        newXS_deffile("Wx::ComboBox::ChangeValue", XS_Wx__ComboBox_ChangeValue);
#endif
#if XSubPPtmpAAFT
        newXS_deffile("Wx::ComboBox::AutoComplete", XS_Wx__ComboBox_AutoComplete);
        newXS_deffile("Wx::ComboBox::AutoCompleteFileNames", XS_Wx__ComboBox_AutoCompleteFileNames);
        newXS_deffile("Wx::ComboBox::AutoCompleteDirectories", XS_Wx__ComboBox_AutoCompleteDirectories);
#endif
        newXS_deffile("Wx::Choice::new", XS_Wx__Choice_new);
        newXS_deffile("Wx::Choice::newDefault", XS_Wx__Choice_newDefault);
        newXS_deffile("Wx::Choice::newFull", XS_Wx__Choice_newFull);
        newXS_deffile("Wx::Choice::Create", XS_Wx__Choice_Create);
        newXS_deffile("Wx::Choice::Clear", XS_Wx__Choice_Clear);
        newXS_deffile("Wx::Choice::Delete", XS_Wx__Choice_Delete);
#if XSubPPtmpAAFU
        newXS_deffile("Wx::Choice::GetColumns", XS_Wx__Choice_GetColumns);
        newXS_deffile("Wx::Choice::SetColumns", XS_Wx__Choice_SetColumns);
#endif
#if XSubPPtmpAAFV
        newXS_deffile("Wx::Choice::GetCurrentSelection", XS_Wx__Choice_GetCurrentSelection);
#endif
        newXS_deffile("Wx::Choice::SetSelection", XS_Wx__Choice_SetSelection);
        newXS_deffile("Wx::Choice::SetStringSelection", XS_Wx__Choice_SetStringSelection);
        newXS_deffile("Wx::CheckListBox::new", XS_Wx__CheckListBox_new);
        newXS_deffile("Wx::CheckListBox::newDefault", XS_Wx__CheckListBox_newDefault);
        newXS_deffile("Wx::CheckListBox::newFull", XS_Wx__CheckListBox_newFull);
        newXS_deffile("Wx::CheckListBox::Create", XS_Wx__CheckListBox_Create);
        newXS_deffile("Wx::CheckListBox::Check", XS_Wx__CheckListBox_Check);
        newXS_deffile("Wx::CheckListBox::IsChecked", XS_Wx__CheckListBox_IsChecked);
        newXS_deffile("Wx::CheckBox::new", XS_Wx__CheckBox_new);
        newXS_deffile("Wx::CheckBox::newDefault", XS_Wx__CheckBox_newDefault);
        newXS_deffile("Wx::CheckBox::newFull", XS_Wx__CheckBox_newFull);
        newXS_deffile("Wx::CheckBox::Create", XS_Wx__CheckBox_Create);
        newXS_deffile("Wx::CheckBox::GetValue", XS_Wx__CheckBox_GetValue);
#if XSubPPtmpAAFW
        newXS_deffile("Wx::CheckBox::Get3StateValue", XS_Wx__CheckBox_Get3StateValue);
        newXS_deffile("Wx::CheckBox::Set3StateValue", XS_Wx__CheckBox_Set3StateValue);
        newXS_deffile("Wx::CheckBox::Is3State", XS_Wx__CheckBox_Is3State);
        newXS_deffile("Wx::CheckBox::Is3rdStateAllowedForUser", XS_Wx__CheckBox_Is3rdStateAllowedForUser);
#endif
        newXS_deffile("Wx::CheckBox::SetValue", XS_Wx__CheckBox_SetValue);
        newXS_deffile("Wx::CheckBox::IsChecked", XS_Wx__CheckBox_IsChecked);
        newXS_deffile("Wx::TextAttr::new", XS_Wx__TextAttr_new);
        newXS_deffile("Wx::TextAttr::DESTROY", XS_Wx__TextAttr_DESTROY);
        newXS_deffile("Wx::TextAttr::CLONE", XS_Wx__TextAttr_CLONE);
#if XSubPPtmpAAFX
        newXS_deffile("Wx::TextAttr::Apply", XS_Wx__TextAttr_Apply);
#endif
#if XSubPPtmpAAFY
        newXS_deffile("Wx::TextAttr::Merge", XS_Wx__TextAttr_Merge);
#endif
        newXS_deffile("Wx::TextAttr::SetTextColour", XS_Wx__TextAttr_SetTextColour);
        newXS_deffile("Wx::TextAttr::SetBackgroundColour", XS_Wx__TextAttr_SetBackgroundColour);
        newXS_deffile("Wx::TextAttr::SetFont", XS_Wx__TextAttr_SetFont);
        newXS_deffile("Wx::TextAttr::SetAlignment", XS_Wx__TextAttr_SetAlignment);
        newXS_deffile("Wx::TextAttr::SetTabs", XS_Wx__TextAttr_SetTabs);
        newXS_deffile("Wx::TextAttr::SetLeftIndent", XS_Wx__TextAttr_SetLeftIndent);
        newXS_deffile("Wx::TextAttr::SetRightIndent", XS_Wx__TextAttr_SetRightIndent);
        newXS_deffile("Wx::TextAttr::SetFlags", XS_Wx__TextAttr_SetFlags);
        newXS_deffile("Wx::TextAttr::HasTextColour", XS_Wx__TextAttr_HasTextColour);
        newXS_deffile("Wx::TextAttr::HasBackgroundColour", XS_Wx__TextAttr_HasBackgroundColour);
        newXS_deffile("Wx::TextAttr::HasFont", XS_Wx__TextAttr_HasFont);
        newXS_deffile("Wx::TextAttr::HasAlignment", XS_Wx__TextAttr_HasAlignment);
        newXS_deffile("Wx::TextAttr::HasTabs", XS_Wx__TextAttr_HasTabs);
        newXS_deffile("Wx::TextAttr::HasLeftIndent", XS_Wx__TextAttr_HasLeftIndent);
        newXS_deffile("Wx::TextAttr::HasRightIndent", XS_Wx__TextAttr_HasRightIndent);
        newXS_deffile("Wx::TextAttr::HasFlag", XS_Wx__TextAttr_HasFlag);
        newXS_deffile("Wx::TextAttr::GetTextColour", XS_Wx__TextAttr_GetTextColour);
        newXS_deffile("Wx::TextAttr::GetBackgroundColour", XS_Wx__TextAttr_GetBackgroundColour);
        newXS_deffile("Wx::TextAttr::GetFont", XS_Wx__TextAttr_GetFont);
        newXS_deffile("Wx::TextAttr::GetAlignment", XS_Wx__TextAttr_GetAlignment);
        newXS_deffile("Wx::TextAttr::GetLeftIndent", XS_Wx__TextAttr_GetLeftIndent);
        newXS_deffile("Wx::TextAttr::GetLeftSubIndent", XS_Wx__TextAttr_GetLeftSubIndent);
        newXS_deffile("Wx::TextAttr::GetRightIndent", XS_Wx__TextAttr_GetRightIndent);
        newXS_deffile("Wx::TextAttr::GetFlags", XS_Wx__TextAttr_GetFlags);
        newXS_deffile("Wx::TextAttr::IsDefault", XS_Wx__TextAttr_IsDefault);
        newXS_deffile("Wx::TextAttr::GetTabs", XS_Wx__TextAttr_GetTabs);
#if XSubPPtmpAAFZ
        newXS_deffile("Wx::TextAttr::GetFontEncoding", XS_Wx__TextAttr_GetFontEncoding);
        newXS_deffile("Wx::TextAttr::HasFontEncoding", XS_Wx__TextAttr_HasFontEncoding);
        newXS_deffile("Wx::TextAttr::SetFontEncoding", XS_Wx__TextAttr_SetFontEncoding);
        newXS_deffile("Wx::TextAttr::GetOutlineLevel", XS_Wx__TextAttr_GetOutlineLevel);
        newXS_deffile("Wx::TextAttr::HasOutlineLevel", XS_Wx__TextAttr_HasOutlineLevel);
        newXS_deffile("Wx::TextAttr::SetOutlineLevel", XS_Wx__TextAttr_SetOutlineLevel);
        newXS_deffile("Wx::TextAttr::GetTextEffects", XS_Wx__TextAttr_GetTextEffects);
        newXS_deffile("Wx::TextAttr::HasTextEffects", XS_Wx__TextAttr_HasTextEffects);
        newXS_deffile("Wx::TextAttr::SetTextEffects", XS_Wx__TextAttr_SetTextEffects);
        newXS_deffile("Wx::TextAttr::GetTextEffectFlags", XS_Wx__TextAttr_GetTextEffectFlags);
        newXS_deffile("Wx::TextAttr::HasTextEffect", XS_Wx__TextAttr_HasTextEffect);
        newXS_deffile("Wx::TextAttr::SetTextEffectFlags", XS_Wx__TextAttr_SetTextEffectFlags);
#endif
#if XSubPPtmpAAGA
        newXS_deffile("Wx::TextAttr::SetCharacterStyleName", XS_Wx__TextAttr_SetCharacterStyleName);
        newXS_deffile("Wx::TextAttr::SetParagraphStyleName", XS_Wx__TextAttr_SetParagraphStyleName);
        newXS_deffile("Wx::TextAttr::SetListStyleName", XS_Wx__TextAttr_SetListStyleName);
        newXS_deffile("Wx::TextAttr::SetParagraphSpacingAfter", XS_Wx__TextAttr_SetParagraphSpacingAfter);
        newXS_deffile("Wx::TextAttr::SetParagraphSpacingBefore", XS_Wx__TextAttr_SetParagraphSpacingBefore);
        newXS_deffile("Wx::TextAttr::SetLineSpacing", XS_Wx__TextAttr_SetLineSpacing);
        newXS_deffile("Wx::TextAttr::SetBulletStyle", XS_Wx__TextAttr_SetBulletStyle);
        newXS_deffile("Wx::TextAttr::SetBulletNumber", XS_Wx__TextAttr_SetBulletNumber);
        newXS_deffile("Wx::TextAttr::SetBulletText", XS_Wx__TextAttr_SetBulletText);
        newXS_deffile("Wx::TextAttr::SetBulletName", XS_Wx__TextAttr_SetBulletName);
        newXS_deffile("Wx::TextAttr::SetBulletFont", XS_Wx__TextAttr_SetBulletFont);
        newXS_deffile("Wx::TextAttr::SetURL", XS_Wx__TextAttr_SetURL);
        newXS_deffile("Wx::TextAttr::SetPageBreak", XS_Wx__TextAttr_SetPageBreak);
        newXS_deffile("Wx::TextAttr::GetCharacterStyleName", XS_Wx__TextAttr_GetCharacterStyleName);
        newXS_deffile("Wx::TextAttr::GetParagraphStyleName", XS_Wx__TextAttr_GetParagraphStyleName);
        newXS_deffile("Wx::TextAttr::GetListStyleName", XS_Wx__TextAttr_GetListStyleName);
        newXS_deffile("Wx::TextAttr::GetParagraphSpacingAfter", XS_Wx__TextAttr_GetParagraphSpacingAfter);
        newXS_deffile("Wx::TextAttr::GetParagraphSpacingBefore", XS_Wx__TextAttr_GetParagraphSpacingBefore);
        newXS_deffile("Wx::TextAttr::GetLineSpacing", XS_Wx__TextAttr_GetLineSpacing);
        newXS_deffile("Wx::TextAttr::GetBulletStyle", XS_Wx__TextAttr_GetBulletStyle);
        newXS_deffile("Wx::TextAttr::GetBulletNumber", XS_Wx__TextAttr_GetBulletNumber);
        newXS_deffile("Wx::TextAttr::GetBulletText", XS_Wx__TextAttr_GetBulletText);
        newXS_deffile("Wx::TextAttr::GetBulletName", XS_Wx__TextAttr_GetBulletName);
        newXS_deffile("Wx::TextAttr::GetBulletFont", XS_Wx__TextAttr_GetBulletFont);
        newXS_deffile("Wx::TextAttr::GetURL", XS_Wx__TextAttr_GetURL);
        newXS_deffile("Wx::TextAttr::HasParagraphSpacingAfter", XS_Wx__TextAttr_HasParagraphSpacingAfter);
        newXS_deffile("Wx::TextAttr::HasParagraphSpacingBefore", XS_Wx__TextAttr_HasParagraphSpacingBefore);
        newXS_deffile("Wx::TextAttr::HasLineSpacing", XS_Wx__TextAttr_HasLineSpacing);
        newXS_deffile("Wx::TextAttr::HasCharacterStyleName", XS_Wx__TextAttr_HasCharacterStyleName);
        newXS_deffile("Wx::TextAttr::HasParagraphStyleName", XS_Wx__TextAttr_HasParagraphStyleName);
        newXS_deffile("Wx::TextAttr::HasListStyleName", XS_Wx__TextAttr_HasListStyleName);
        newXS_deffile("Wx::TextAttr::HasBulletStyle", XS_Wx__TextAttr_HasBulletStyle);
        newXS_deffile("Wx::TextAttr::HasBulletNumber", XS_Wx__TextAttr_HasBulletNumber);
        newXS_deffile("Wx::TextAttr::HasBulletText", XS_Wx__TextAttr_HasBulletText);
        newXS_deffile("Wx::TextAttr::HasBulletName", XS_Wx__TextAttr_HasBulletName);
        newXS_deffile("Wx::TextAttr::HasURL", XS_Wx__TextAttr_HasURL);
        newXS_deffile("Wx::TextAttr::HasPageBreak", XS_Wx__TextAttr_HasPageBreak);
        newXS_deffile("Wx::TextAttr::IsCharacterStyle", XS_Wx__TextAttr_IsCharacterStyle);
        newXS_deffile("Wx::TextAttr::IsParagraphStyle", XS_Wx__TextAttr_IsParagraphStyle);
#if XSubPPtmpAAGB
        newXS_deffile("Wx::TextAttr::CreateFont", XS_Wx__TextAttr_CreateFont);
#endif
        newXS_deffile("Wx::TextAttr::GetFontAttributes", XS_Wx__TextAttr_GetFontAttributes);
        newXS_deffile("Wx::TextAttr::SetFontSize", XS_Wx__TextAttr_SetFontSize);
        newXS_deffile("Wx::TextAttr::SetFontStyle", XS_Wx__TextAttr_SetFontStyle);
        newXS_deffile("Wx::TextAttr::SetFontWeight", XS_Wx__TextAttr_SetFontWeight);
        newXS_deffile("Wx::TextAttr::SetFontFaceName", XS_Wx__TextAttr_SetFontFaceName);
        newXS_deffile("Wx::TextAttr::SetFontUnderlined", XS_Wx__TextAttr_SetFontUnderlined);
        newXS_deffile("Wx::TextAttr::GetFontSize", XS_Wx__TextAttr_GetFontSize);
        newXS_deffile("Wx::TextAttr::GetFontStyle", XS_Wx__TextAttr_GetFontStyle);
        newXS_deffile("Wx::TextAttr::GetFontWeight", XS_Wx__TextAttr_GetFontWeight);
        newXS_deffile("Wx::TextAttr::GetFontUnderlined", XS_Wx__TextAttr_GetFontUnderlined);
        newXS_deffile("Wx::TextAttr::GetFontFaceName", XS_Wx__TextAttr_GetFontFaceName);
        newXS_deffile("Wx::TextAttr::HasFontWeight", XS_Wx__TextAttr_HasFontWeight);
        newXS_deffile("Wx::TextAttr::HasFontSize", XS_Wx__TextAttr_HasFontSize);
        newXS_deffile("Wx::TextAttr::HasFontItalic", XS_Wx__TextAttr_HasFontItalic);
        newXS_deffile("Wx::TextAttr::HasFontUnderlined", XS_Wx__TextAttr_HasFontUnderlined);
        newXS_deffile("Wx::TextAttr::HasFontFaceName", XS_Wx__TextAttr_HasFontFaceName);
#endif
        newXS_deffile("Wx::TextUrlEvent::GetMouseEvent", XS_Wx__TextUrlEvent_GetMouseEvent);
        newXS_deffile("Wx::TextUrlEvent::GetURLStart", XS_Wx__TextUrlEvent_GetURLStart);
        newXS_deffile("Wx::TextUrlEvent::GetURLEnd", XS_Wx__TextUrlEvent_GetURLEnd);
        newXS_deffile("Wx::TextCtrlBase::GetValue", XS_Wx__TextCtrlBase_GetValue);
#if XSubPPtmpAAGC
        newXS_deffile("Wx::TextCtrlBase::IsEmpty", XS_Wx__TextCtrlBase_IsEmpty);
#endif
        newXS_deffile("Wx::TextCtrlBase::SetValue", XS_Wx__TextCtrlBase_SetValue);
#if XSubPPtmpAAGD
        newXS_deffile("Wx::TextCtrlBase::ChangeValue", XS_Wx__TextCtrlBase_ChangeValue);
#endif
        newXS_deffile("Wx::TextCtrlBase::GetRange", XS_Wx__TextCtrlBase_GetRange);
        newXS_deffile("Wx::TextCtrlBase::GetLineLength", XS_Wx__TextCtrlBase_GetLineLength);
        newXS_deffile("Wx::TextCtrlBase::GetLineText", XS_Wx__TextCtrlBase_GetLineText);
        newXS_deffile("Wx::TextCtrlBase::GetNumberOfLines", XS_Wx__TextCtrlBase_GetNumberOfLines);
        newXS_deffile("Wx::TextCtrlBase::IsModified", XS_Wx__TextCtrlBase_IsModified);
        newXS_deffile("Wx::TextCtrlBase::IsEditable", XS_Wx__TextCtrlBase_IsEditable);
        newXS_deffile("Wx::TextCtrlBase::IsSingleLine", XS_Wx__TextCtrlBase_IsSingleLine);
        newXS_deffile("Wx::TextCtrlBase::IsMultiLine", XS_Wx__TextCtrlBase_IsMultiLine);
        newXS_deffile("Wx::TextCtrlBase::GetStringSelection", XS_Wx__TextCtrlBase_GetStringSelection);
        newXS_deffile("Wx::TextCtrlBase::Clear", XS_Wx__TextCtrlBase_Clear);
        newXS_deffile("Wx::TextCtrlBase::Replace", XS_Wx__TextCtrlBase_Replace);
        newXS_deffile("Wx::TextCtrlBase::Remove", XS_Wx__TextCtrlBase_Remove);
#if XSubPPtmpAAGE
        newXS_deffile("Wx::TextCtrlBase::LoadFile", XS_Wx__TextCtrlBase_LoadFile);
        newXS_deffile("Wx::TextCtrlBase::SaveFile", XS_Wx__TextCtrlBase_SaveFile);
#endif
#if XSubPPtmpAAGF
        newXS_deffile("Wx::TextCtrlBase::LoadFile", XS_Wx__TextCtrlBase_LoadFile);
        newXS_deffile("Wx::TextCtrlBase::SaveFile", XS_Wx__TextCtrlBase_SaveFile);
#endif
        newXS_deffile("Wx::TextCtrlBase::MarkDirty", XS_Wx__TextCtrlBase_MarkDirty);
        newXS_deffile("Wx::TextCtrlBase::DiscardEdits", XS_Wx__TextCtrlBase_DiscardEdits);
#if XSubPPtmpAAGG
        newXS_deffile("Wx::TextCtrlBase::SetModified", XS_Wx__TextCtrlBase_SetModified);
#endif
        newXS_deffile("Wx::TextCtrlBase::SetMaxLength", XS_Wx__TextCtrlBase_SetMaxLength);
        newXS_deffile("Wx::TextCtrlBase::WriteText", XS_Wx__TextCtrlBase_WriteText);
        newXS_deffile("Wx::TextCtrlBase::AppendText", XS_Wx__TextCtrlBase_AppendText);
        newXS_deffile("Wx::TextCtrlBase::EmulateKeyPress", XS_Wx__TextCtrlBase_EmulateKeyPress);
        newXS_deffile("Wx::TextCtrlBase::SetStyle", XS_Wx__TextCtrlBase_SetStyle);
        newXS_deffile("Wx::TextCtrlBase::SetDefaultStyle", XS_Wx__TextCtrlBase_SetDefaultStyle);
        newXS_deffile("Wx::TextCtrlBase::GetDefaultStyle", XS_Wx__TextCtrlBase_GetDefaultStyle);
        newXS_deffile("Wx::TextCtrlBase::XYToPosition", XS_Wx__TextCtrlBase_XYToPosition);
        newXS_deffile("Wx::TextCtrlBase::ShowPosition", XS_Wx__TextCtrlBase_ShowPosition);
        newXS_deffile("Wx::TextCtrlBase::Copy", XS_Wx__TextCtrlBase_Copy);
        newXS_deffile("Wx::TextCtrlBase::Cut", XS_Wx__TextCtrlBase_Cut);
        newXS_deffile("Wx::TextCtrlBase::Paste", XS_Wx__TextCtrlBase_Paste);
        newXS_deffile("Wx::TextCtrlBase::CanCopy", XS_Wx__TextCtrlBase_CanCopy);
        newXS_deffile("Wx::TextCtrlBase::CanCut", XS_Wx__TextCtrlBase_CanCut);
        newXS_deffile("Wx::TextCtrlBase::CanPaste", XS_Wx__TextCtrlBase_CanPaste);
        newXS_deffile("Wx::TextCtrlBase::Undo", XS_Wx__TextCtrlBase_Undo);
        newXS_deffile("Wx::TextCtrlBase::Redo", XS_Wx__TextCtrlBase_Redo);
        newXS_deffile("Wx::TextCtrlBase::CanUndo", XS_Wx__TextCtrlBase_CanUndo);
        newXS_deffile("Wx::TextCtrlBase::CanRedo", XS_Wx__TextCtrlBase_CanRedo);
        newXS_deffile("Wx::TextCtrlBase::SetInsertionPoint", XS_Wx__TextCtrlBase_SetInsertionPoint);
        newXS_deffile("Wx::TextCtrlBase::SetInsertionPointEnd", XS_Wx__TextCtrlBase_SetInsertionPointEnd);
        newXS_deffile("Wx::TextCtrlBase::GetInsertionPoint", XS_Wx__TextCtrlBase_GetInsertionPoint);
        newXS_deffile("Wx::TextCtrlBase::GetLastPosition", XS_Wx__TextCtrlBase_GetLastPosition);
        newXS_deffile("Wx::TextCtrlBase::SetSelection", XS_Wx__TextCtrlBase_SetSelection);
        newXS_deffile("Wx::TextCtrlBase::SelectAll", XS_Wx__TextCtrlBase_SelectAll);
        newXS_deffile("Wx::TextCtrlBase::SetEditable", XS_Wx__TextCtrlBase_SetEditable);
#if XSubPPtmpAAGH
        newXS_deffile("Wx::TextCtrlBase::AutoComplete", XS_Wx__TextCtrlBase_AutoComplete);
        newXS_deffile("Wx::TextCtrlBase::AutoCompleteFileNames", XS_Wx__TextCtrlBase_AutoCompleteFileNames);
#endif
        newXS_deffile("Wx::TextCtrlBase::GetSelection", XS_Wx__TextCtrlBase_GetSelection);
        newXS_deffile("Wx::TextCtrlBase::PositionToXY", XS_Wx__TextCtrlBase_PositionToXY);
        newXS_deffile("Wx::TextCtrlBase::HitTest", XS_Wx__TextCtrlBase_HitTest);
#if XSubPPtmpAAGI
        newXS_deffile("Wx::TextCtrl::MacCheckSpelling", XS_Wx__TextCtrl_MacCheckSpelling);
#endif
        newXS_deffile("Wx::TextCtrl::new", XS_Wx__TextCtrl_new);
        newXS_deffile("Wx::TextCtrl::newDefault", XS_Wx__TextCtrl_newDefault);
        newXS_deffile("Wx::TextCtrl::newFull", XS_Wx__TextCtrl_newFull);
        newXS_deffile("Wx::TextCtrl::Create", XS_Wx__TextCtrl_Create);
        newXS_deffile("Wx::TextCtrl::GetStyle", XS_Wx__TextCtrl_GetStyle);
        newXS_deffile("Wx::TextCtrl::GetTextAttrStyle", XS_Wx__TextCtrl_GetTextAttrStyle);
#if XSubPPtmpAAGJ
        newXS_deffile("Wx::PickerBase::SetInternalMargin", XS_Wx__PickerBase_SetInternalMargin);
        newXS_deffile("Wx::PickerBase::GetInternalMargin", XS_Wx__PickerBase_GetInternalMargin);
        newXS_deffile("Wx::PickerBase::SetTextCtrlProportion", XS_Wx__PickerBase_SetTextCtrlProportion);
        newXS_deffile("Wx::PickerBase::GetTextCtrlProportion", XS_Wx__PickerBase_GetTextCtrlProportion);
        newXS_deffile("Wx::PickerBase::SetPickerCtrlProportion", XS_Wx__PickerBase_SetPickerCtrlProportion);
        newXS_deffile("Wx::PickerBase::GetPickerCtrlProportion", XS_Wx__PickerBase_GetPickerCtrlProportion);
        newXS_deffile("Wx::PickerBase::IsTextCtrlGrowable", XS_Wx__PickerBase_IsTextCtrlGrowable);
        newXS_deffile("Wx::PickerBase::SetTextCtrlGrowable", XS_Wx__PickerBase_SetTextCtrlGrowable);
        newXS_deffile("Wx::PickerBase::IsPickerCtrlGrowable", XS_Wx__PickerBase_IsPickerCtrlGrowable);
        newXS_deffile("Wx::PickerBase::SetPickerCtrlGrowable", XS_Wx__PickerBase_SetPickerCtrlGrowable);
        newXS_deffile("Wx::PickerBase::HasTextCtrl", XS_Wx__PickerBase_HasTextCtrl);
        newXS_deffile("Wx::PickerBase::GetTextCtrl", XS_Wx__PickerBase_GetTextCtrl);
        newXS_deffile("Wx::PickerBase::GetPickerCtrl", XS_Wx__PickerBase_GetPickerCtrl);
#endif
#if XSubPPtmpAAGK
        newXS_deffile("Wx::ColourPickerCtrl::newDefault", XS_Wx__ColourPickerCtrl_newDefault);
        newXS_deffile("Wx::ColourPickerCtrl::newFull", XS_Wx__ColourPickerCtrl_newFull);
        newXS_deffile("Wx::ColourPickerCtrl::Create", XS_Wx__ColourPickerCtrl_Create);
        newXS_deffile("Wx::ColourPickerCtrl::GetColour", XS_Wx__ColourPickerCtrl_GetColour);
        newXS_deffile("Wx::ColourPickerCtrl::SetColourColour", XS_Wx__ColourPickerCtrl_SetColourColour);
        newXS_deffile("Wx::ColourPickerCtrl::SetColourString", XS_Wx__ColourPickerCtrl_SetColourString);
        newXS_deffile("Wx::ColourPickerCtrl::new", XS_Wx__ColourPickerCtrl_new);
        newXS_deffile("Wx::ColourPickerCtrl::SetColour", XS_Wx__ColourPickerCtrl_SetColour);
        newXS_deffile("Wx::ColourPickerEvent::GetColour", XS_Wx__ColourPickerEvent_GetColour);
        newXS_deffile("Wx::ColourPickerEvent::SetColour", XS_Wx__ColourPickerEvent_SetColour);
#endif
#if XSubPPtmpAAGL
        newXS_deffile("Wx::FilePickerCtrl::newDefault", XS_Wx__FilePickerCtrl_newDefault);
        newXS_deffile("Wx::FilePickerCtrl::newFull", XS_Wx__FilePickerCtrl_newFull);
        newXS_deffile("Wx::FilePickerCtrl::Create", XS_Wx__FilePickerCtrl_Create);
        newXS_deffile("Wx::FilePickerCtrl::GetPath", XS_Wx__FilePickerCtrl_GetPath);
        newXS_deffile("Wx::FilePickerCtrl::SetPath", XS_Wx__FilePickerCtrl_SetPath);
        newXS_deffile("Wx::FilePickerCtrl::new", XS_Wx__FilePickerCtrl_new);
        newXS_deffile("Wx::DirPickerCtrl::newDefault", XS_Wx__DirPickerCtrl_newDefault);
        newXS_deffile("Wx::DirPickerCtrl::newFull", XS_Wx__DirPickerCtrl_newFull);
        newXS_deffile("Wx::DirPickerCtrl::Create", XS_Wx__DirPickerCtrl_Create);
        newXS_deffile("Wx::DirPickerCtrl::GetPath", XS_Wx__DirPickerCtrl_GetPath);
        newXS_deffile("Wx::DirPickerCtrl::SetPath", XS_Wx__DirPickerCtrl_SetPath);
        newXS_deffile("Wx::DirPickerCtrl::new", XS_Wx__DirPickerCtrl_new);
        newXS_deffile("Wx::FileDirPickerEvent::GetPath", XS_Wx__FileDirPickerEvent_GetPath);
        newXS_deffile("Wx::FileDirPickerEvent::SetPath", XS_Wx__FileDirPickerEvent_SetPath);
#endif
#if XSubPPtmpAAGM
        newXS_deffile("Wx::FontPickerCtrl::newDefault", XS_Wx__FontPickerCtrl_newDefault);
        newXS_deffile("Wx::FontPickerCtrl::newFull", XS_Wx__FontPickerCtrl_newFull);
        newXS_deffile("Wx::FontPickerCtrl::Create", XS_Wx__FontPickerCtrl_Create);
        newXS_deffile("Wx::FontPickerCtrl::GetSelectedFont", XS_Wx__FontPickerCtrl_GetSelectedFont);
        newXS_deffile("Wx::FontPickerCtrl::SetSelectedFont", XS_Wx__FontPickerCtrl_SetSelectedFont);
        newXS_deffile("Wx::FontPickerCtrl::SetMaxPointSize", XS_Wx__FontPickerCtrl_SetMaxPointSize);
        newXS_deffile("Wx::FontPickerCtrl::GetMaxPointSize", XS_Wx__FontPickerCtrl_GetMaxPointSize);
        newXS_deffile("Wx::FontPickerCtrl::new", XS_Wx__FontPickerCtrl_new);
        newXS_deffile("Wx::FontPickerEvent::GetFont", XS_Wx__FontPickerEvent_GetFont);
        newXS_deffile("Wx::FontPickerEvent::SetFont", XS_Wx__FontPickerEvent_SetFont);
#endif

    /* Initialisation Section */

#if XSubPPtmpAAAA
#endif
#if XSubPPtmpAAAB
#endif
#if XSubPPtmpAAAC
#endif
#if XSubPPtmpAAAD
#endif
#if XSubPPtmpAAAE
#endif
#if XSubPPtmpAAAF
#endif
#if XSubPPtmpAAAG
#endif
#if XSubPPtmpAAAH
#endif
#if XSubPPtmpAAAI
#endif
#if XSubPPtmpAAAJ
#endif
#if XSubPPtmpAAAK
#endif
#if XSubPPtmpAAAL
#endif
    {
        AV* isa = get_av( "Wx::BitmapButton::ISA", 1 );
        av_store( isa, 0, newSVpv( "Wx::Button", 0 ) );
    } // blank line here is important

#if XSubPPtmpAAAM
#endif
#if XSubPPtmpAAAN
#if XSubPPtmpAAAO
#endif
#if XSubPPtmpAAAP
#endif
#if XSubPPtmpAAAQ
#endif
#if XSubPPtmpAAAR
#endif
#endif
#if XSubPPtmpAAAS
#if XSubPPtmpAAAT
#endif
#endif
#if XSubPPtmpAAAU
#if XSubPPtmpAAAV
#endif
#endif
#if XSubPPtmpAAAW
#endif
#if XSubPPtmpAAAX
#endif
#if XSubPPtmpAAAY
#endif
#if XSubPPtmpAAAZ
#endif
#if XSubPPtmpAABA
#if XSubPPtmpAABB
#if XSubPPtmpAABC
#if XSubPPtmpAABD
#endif
#if XSubPPtmpAABE
#endif
#if XSubPPtmpAABF
#endif
#if XSubPPtmpAABG
#endif
#endif
#endif
#endif
#if XSubPPtmpAABH
#endif
#if XSubPPtmpAABI
#if XSubPPtmpAABJ
#endif
#endif
#if XSubPPtmpAABK
#if XSubPPtmpAABL
#endif
#if XSubPPtmpAABM
#endif
#if XSubPPtmpAABN
#endif
#if XSubPPtmpAABO
#endif
#if XSubPPtmpAABP
#endif
#if XSubPPtmpAABQ
#endif
#endif
#if XSubPPtmpAABR
#endif
#if XSubPPtmpAABS
#endif
#if XSubPPtmpAABT
#endif
#if XSubPPtmpAABU
#endif
#if XSubPPtmpAABV
#endif
#if XSubPPtmpAABW
#if XSubPPtmpAABX
#endif
#if XSubPPtmpAABY
#endif
    {
#ifdef XSpp_bf682a9f_068242
        AV* isa = get_av( "Wx::SpinCtrlDouble::ISA", 1 );
        av_store( isa, 0, newSVpv( "Wx::Control", 0 ) );
#endif // XSpp_bf682a9f_068242
    } // blank line here is important

#endif
#if XSubPPtmpAABZ
#if XSubPPtmpAACA
#endif
    {
#ifdef XSpp_622a4aee_084652
        AV* isa = get_av( "Wx::InfoBar::ISA", 1 );
        av_store( isa, 0, newSVpv( "Wx::Control", 0 ) );
#endif // XSpp_622a4aee_084652
    } // blank line here is important

#endif
#if XSubPPtmpAACB
#if XSubPPtmpAACC
#endif
    {
#ifdef XSpp_11434cd6_087368
        AV* isa = get_av( "Wx::HeaderCtrl::ISA", 1 );
        av_store( isa, 0, newSVpv( "Wx::Control", 0 ) );
#endif // XSpp_11434cd6_087368
    } // blank line here is important

#if XSubPPtmpAACD
#endif
    {
#ifdef XSpp_11434cd6_087368
        AV* isa = get_av( "Wx::HeaderCtrlSimple::ISA", 1 );
        av_store( isa, 0, newSVpv( "Wx::HeaderCtrl", 0 ) );
#endif // XSpp_11434cd6_087368
    } // blank line here is important

    {
#ifdef XSpp_11434cd6_087368
        AV* isa = get_av( "Wx::HeaderCtrlEvent::ISA", 1 );
        av_store( isa, 0, newSVpv( "Wx::NotifyEvent", 0 ) );
#endif // XSpp_11434cd6_087368
    } // blank line here is important

#endif
#if XSubPPtmpAACE
    {
#ifdef XSpp_11434cd6_087368
        AV* isa = get_av( "Wx::PlHeaderCtrl::ISA", 1 );
        av_store( isa, 0, newSVpv( "Wx::HeaderCtrl", 0 ) );
#endif // XSpp_11434cd6_087368
    } // blank line here is important

#endif
#if XSubPPtmpAACF
#endif
#if XSubPPtmpAACG
    wxPli_set_events( headerctrl_h_events );

#endif
#if XSubPPtmpAACH
#if XSubPPtmpAACI
#endif
    {
#ifdef XSpp_512ff718_079351
        AV* isa = get_av( "Wx::SettableHeaderColumn::ISA", 1 );
        av_store( isa, 0, newSVpv( "Wx::HeaderColumn", 0 ) );
#endif // XSpp_512ff718_079351
    } // blank line here is important

#if XSubPPtmpAACJ
#endif
#if XSubPPtmpAACK
#endif
    {
#ifdef XSpp_512ff718_079351
        AV* isa = get_av( "Wx::HeaderColumnSimple::ISA", 1 );
        av_store( isa, 0, newSVpv( "Wx::HeaderColumn", 0 ) );
#endif // XSpp_512ff718_079351
    } // blank line here is important

#endif
#if XSubPPtmpAACL
    {
#ifdef XSpp_512ff718_079351
        AV* isa = get_av( "Wx::PlHeaderColumn::ISA", 1 );
        av_store( isa, 0, newSVpv( "Wx::HeaderColumn", 0 ) );
#endif // XSpp_512ff718_079351
    } // blank line here is important

#endif
#if XSubPPtmpAACM
    {
#ifdef XSpp_512ff718_079351
        AV* isa = get_av( "Wx::PlSettableHeaderColumn::ISA", 1 );
        av_store( isa, 0, newSVpv( "Wx::SettableHeaderColumn", 0 ) );
#endif // XSpp_512ff718_079351
    } // blank line here is important

#endif
#if XSubPPtmpAACN
#endif
#if XSubPPtmpAACO
#endif
#if XSubPPtmpAACP
#endif
#if XSubPPtmpAACQ
#endif
#if XSubPPtmpAACR
#endif
#if XSubPPtmpAACS
#endif
#if XSubPPtmpAACT
#endif
    {
        AV* isa = get_av( "Wx::Button::ISA", 1 );
        av_store( isa, 0, newSVpv( "Wx::Control", 0 ) );
    } // blank line here is important

#if XSubPPtmpAACU
#if XSubPPtmpAACV
#endif
    {
#ifdef XSpp_14221074_058233
        AV* isa = get_av( "Wx::CommandLinkButton::ISA", 1 );
        av_store( isa, 0, newSVpv( "Wx::Button", 0 ) );
#endif // XSpp_14221074_058233
    } // blank line here is important

#endif
#if XSubPPtmpAACW
#if XSubPPtmpAACX
#endif
#if XSubPPtmpAACY
#endif
    {
#ifdef XSpp_9e3a6f40_027014
        AV* isa = get_av( "Wx::TreeListCtrl::ISA", 1 );
        av_store( isa, 0, newSVpv( "Wx::Window", 0 ) );
#endif // XSpp_9e3a6f40_027014
    } // blank line here is important

    {
#ifdef XSpp_9e3a6f40_027014
        AV* isa = get_av( "Wx::TreeListEvent::ISA", 1 );
        av_store( isa, 0, newSVpv( "Wx::NotifyEvent", 0 ) );
#endif // XSpp_9e3a6f40_027014
    } // blank line here is important

#endif
#if XSubPPtmpAACZ
    {
#ifdef XSpp_9e3a6f40_027014
        AV* isa = get_av( "Wx::PlTreeListItemComparator::ISA", 1 );
        av_store( isa, 0, newSVpv( "Wx::TreeListItemComparator", 0 ) );
#endif // XSpp_9e3a6f40_027014
    } // blank line here is important

#endif
#if XSubPPtmpAADA
    wxPli_set_events( treelist_h_events );

#endif
#if XSubPPtmpAADB
#if XSubPPtmpAADC
#endif
#endif
#if XSubPPtmpAADD
#if XSubPPtmpAADE
#endif
    {
#ifdef XSpp_7efdd844_029941
        AV* isa = get_av( "Wx::BannerWindow::ISA", 1 );
        av_store( isa, 0, newSVpv( "Wx::Window", 0 ) );
#endif // XSpp_7efdd844_029941
    } // blank line here is important

#endif
#if XSubPPtmpAADF
#if XSubPPtmpAADG
#endif
    {
#ifdef XSpp_270e2145_033981
        AV* isa = get_av( "Wx::RearrangeList::ISA", 1 );
        av_store( isa, 0, newSVpv( "Wx::CheckListBox", 0 ) );
#endif // XSpp_270e2145_033981
    } // blank line here is important

#if XSubPPtmpAADH
#endif
    {
#ifdef XSpp_270e2145_033981
        AV* isa = get_av( "Wx::RearrangeCtrl::ISA", 1 );
        av_store( isa, 0, newSVpv( "Wx::Panel", 0 ) );
#endif // XSpp_270e2145_033981
    } // blank line here is important

#if XSubPPtmpAADI
#endif
    {
#ifdef XSpp_270e2145_033981
        AV* isa = get_av( "Wx::RearrangeDialog::ISA", 1 );
        av_store( isa, 0, newSVpv( "Wx::Dialog", 0 ) );
#endif // XSpp_270e2145_033981
    } // blank line here is important

#endif
#if XSubPPtmpAADJ
#endif
#if XSubPPtmpAADK
#endif
#if XSubPPtmpAADL
#endif
#if XSubPPtmpAADM
#endif
#if XSubPPtmpAADN
#endif
#if XSubPPtmpAADO
#endif
#if XSubPPtmpAADP
#endif
#if XSubPPtmpAADQ
#endif
#if XSubPPtmpAADR
#endif
#if XSubPPtmpAADS
#endif
#if XSubPPtmpAADT
#endif
#if XSubPPtmpAADU
#endif
#if XSubPPtmpAADV
#endif
#if XSubPPtmpAADW
#endif
#if XSubPPtmpAADX
#endif
#if XSubPPtmpAADY
#endif
#if XSubPPtmpAADZ
#if XSubPPtmpAAEA
#endif
#endif
#if XSubPPtmpAAEB
#endif
#if XSubPPtmpAAEC
#endif
#if XSubPPtmpAAED
#endif
#if XSubPPtmpAAEE
#endif
#if XSubPPtmpAAEF
#endif
#if XSubPPtmpAAEG
#endif
#if XSubPPtmpAAEH
#endif
#if XSubPPtmpAAEI
#endif
#if XSubPPtmpAAEJ
#endif
#if XSubPPtmpAAEK
#endif
#if XSubPPtmpAAEL
#endif
#if XSubPPtmpAAEM
#endif
#if XSubPPtmpAAEN
#endif
#if XSubPPtmpAAEO
#endif
#if XSubPPtmpAAEP
#endif
#if XSubPPtmpAAEQ
#endif
#if XSubPPtmpAAER
#endif
#if XSubPPtmpAAES
#endif
#if XSubPPtmpAAET
#endif
#if XSubPPtmpAAEU
#endif
#if XSubPPtmpAAEV
#endif
#if XSubPPtmpAAEW
#endif
#if XSubPPtmpAAEX
#endif
#if XSubPPtmpAAEY
#endif
#if XSubPPtmpAAEZ
#endif
#if XSubPPtmpAAFA
#endif
#if XSubPPtmpAAFB
#endif
#if XSubPPtmpAAFC
#endif
#if XSubPPtmpAAFD
#endif
#if XSubPPtmpAAFE
#endif
#if XSubPPtmpAAFF
#endif
#if XSubPPtmpAAFG
#endif
#if XSubPPtmpAAFH
#endif
#if XSubPPtmpAAFI
#endif
#if XSubPPtmpAAFJ
#if XSubPPtmpAAFK
#endif
#if XSubPPtmpAAFL
#endif
#if XSubPPtmpAAFM
#endif
#if XSubPPtmpAAFN
#endif
#if XSubPPtmpAAFO
#endif
#if XSubPPtmpAAFP
#endif
#endif
#if XSubPPtmpAAFQ
#endif
#if XSubPPtmpAAFR
#endif
#if XSubPPtmpAAFS
#endif
#if XSubPPtmpAAFT
#endif
#if XSubPPtmpAAFU
#endif
#if XSubPPtmpAAFV
#endif
#if XSubPPtmpAAFW
#endif
#if XSubPPtmpAAFX
#endif
#if XSubPPtmpAAFY
#endif
#if XSubPPtmpAAFZ
#endif
#if XSubPPtmpAAGA
#if XSubPPtmpAAGB
#endif
#endif
#if XSubPPtmpAAGC
#endif
#if XSubPPtmpAAGD
#endif
#if XSubPPtmpAAGE
#endif
#if XSubPPtmpAAGF
#endif
#if XSubPPtmpAAGG
#endif
#if XSubPPtmpAAGH
#endif
#if XSubPPtmpAAGI
#endif
#if XSubPPtmpAAGJ
#endif
#if XSubPPtmpAAGK
#endif
#if XSubPPtmpAAGL
#endif
#if XSubPPtmpAAGM
#endif

    /* End of Initialisation Section */

#if PERL_VERSION_LE(5, 21, 5)
#  if PERL_VERSION_GE(5, 9, 0)
    if (PL_unitcheckav)
        call_list(PL_scopestack_ix, PL_unitcheckav);
#  endif
    XSRETURN_YES;
#else
    Perl_xs_boot_epilog(aTHX_ ax);
#endif
}

