/*
 * This file was generated automatically by ExtUtils::ParseXS version 3.44 from the
 * contents of STC.xs. Do not edit this file, edit STC.xs instead.
 *
 *    ANY CHANGES MADE HERE WILL BE LOST!
 *
 */

/////////////////////////////////////////////////////////////////////////////
// Name:        ext/stc/STC.xs
// Purpose:     XS for Wx::STC
// Author:      Mattia Barbon
// Modified by:
// Created:     23/05/2002
// RCS-ID:      $Id: STC.xs 2935 2010-07-04 11:46:58Z mbarbon $
// Copyright:   (c) 2002-2004, 2006-2010 Mattia Barbon
// Licence:     This program is free software; you can redistribute it and/or
//              modify it under the same terms as Perl itself
/////////////////////////////////////////////////////////////////////////////

#define PERL_NO_GET_CONTEXT

#include "cpp/wxapi.h"

#undef THIS

#ifndef PERL_UNUSED_VAR
#  define PERL_UNUSED_VAR(var) if (0) var = var
#endif

#ifndef dVAR
#  define dVAR		dNOOP
#endif


/* This stuff is not part of the API! You have been warned. */
#ifndef PERL_VERSION_DECIMAL
#  define PERL_VERSION_DECIMAL(r,v,s) (r*1000000 + v*1000 + s)
#endif
#ifndef PERL_DECIMAL_VERSION
#  define PERL_DECIMAL_VERSION \
	  PERL_VERSION_DECIMAL(PERL_REVISION,PERL_VERSION,PERL_SUBVERSION)
#endif
#ifndef PERL_VERSION_GE
#  define PERL_VERSION_GE(r,v,s) \
	  (PERL_DECIMAL_VERSION >= PERL_VERSION_DECIMAL(r,v,s))
#endif
#ifndef PERL_VERSION_LE
#  define PERL_VERSION_LE(r,v,s) \
	  (PERL_DECIMAL_VERSION <= PERL_VERSION_DECIMAL(r,v,s))
#endif

/* XS_INTERNAL is the explicit static-linkage variant of the default
 * XS macro.
 *
 * XS_EXTERNAL is the same as XS_INTERNAL except it does not include
 * "STATIC", ie. it exports XSUB symbols. You probably don't want that
 * for anything but the BOOT XSUB.
 *
 * See XSUB.h in core!
 */


/* TODO: This might be compatible further back than 5.10.0. */
#if PERL_VERSION_GE(5, 10, 0) && PERL_VERSION_LE(5, 15, 1)
#  undef XS_EXTERNAL
#  undef XS_INTERNAL
#  if defined(__CYGWIN__) && defined(USE_DYNAMIC_LOADING)
#    define XS_EXTERNAL(name) __declspec(dllexport) XSPROTO(name)
#    define XS_INTERNAL(name) STATIC XSPROTO(name)
#  endif
#  if defined(__SYMBIAN32__)
#    define XS_EXTERNAL(name) EXPORT_C XSPROTO(name)
#    define XS_INTERNAL(name) EXPORT_C STATIC XSPROTO(name)
#  endif
#  ifndef XS_EXTERNAL
#    if defined(HASATTRIBUTE_UNUSED) && !defined(__cplusplus)
#      define XS_EXTERNAL(name) void name(pTHX_ CV* cv __attribute__unused__)
#      define XS_INTERNAL(name) STATIC void name(pTHX_ CV* cv __attribute__unused__)
#    else
#      ifdef __cplusplus
#        define XS_EXTERNAL(name) extern "C" XSPROTO(name)
#        define XS_INTERNAL(name) static XSPROTO(name)
#      else
#        define XS_EXTERNAL(name) XSPROTO(name)
#        define XS_INTERNAL(name) STATIC XSPROTO(name)
#      endif
#    endif
#  endif
#endif

/* perl >= 5.10.0 && perl <= 5.15.1 */


/* The XS_EXTERNAL macro is used for functions that must not be static
 * like the boot XSUB of a module. If perl didn't have an XS_EXTERNAL
 * macro defined, the best we can do is assume XS is the same.
 * Dito for XS_INTERNAL.
 */
#ifndef XS_EXTERNAL
#  define XS_EXTERNAL(name) XS(name)
#endif
#ifndef XS_INTERNAL
#  define XS_INTERNAL(name) XS(name)
#endif

/* Now, finally, after all this mess, we want an ExtUtils::ParseXS
 * internal macro that we're free to redefine for varying linkage due
 * to the EXPORT_XSUB_SYMBOLS XS keyword. This is internal, use
 * XS_EXTERNAL(name) or XS_INTERNAL(name) in your code if you need to!
 */

#undef XS_EUPXS
#if defined(PERL_EUPXS_ALWAYS_EXPORT)
#  define XS_EUPXS(name) XS_EXTERNAL(name)
#else
   /* default to internal */
#  define XS_EUPXS(name) XS_INTERNAL(name)
#endif

#ifndef PERL_ARGS_ASSERT_CROAK_XS_USAGE
#define PERL_ARGS_ASSERT_CROAK_XS_USAGE assert(cv); assert(params)

/* prototype to pass -Wmissing-prototypes */
STATIC void
S_croak_xs_usage(const CV *const cv, const char *const params);

STATIC void
S_croak_xs_usage(const CV *const cv, const char *const params)
{
    const GV *const gv = CvGV(cv);

    PERL_ARGS_ASSERT_CROAK_XS_USAGE;

    if (gv) {
        const char *const gvname = GvNAME(gv);
        const HV *const stash = GvSTASH(gv);
        const char *const hvname = stash ? HvNAME(stash) : NULL;

        if (hvname)
	    Perl_croak_nocontext("Usage: %s::%s(%s)", hvname, gvname, params);
        else
	    Perl_croak_nocontext("Usage: %s(%s)", gvname, params);
    } else {
        /* Pants. I don't think that it should be possible to get here. */
	Perl_croak_nocontext("Usage: CODE(0x%" UVxf ")(%s)", PTR2UV(cv), params);
    }
}
#undef  PERL_ARGS_ASSERT_CROAK_XS_USAGE

#define croak_xs_usage        S_croak_xs_usage

#endif

/* NOTE: the prototype of newXSproto() is different in versions of perls,
 * so we define a portable version of newXSproto()
 */
#ifdef newXS_flags
#define newXSproto_portable(name, c_impl, file, proto) newXS_flags(name, c_impl, file, proto, 0)
#else
#define newXSproto_portable(name, c_impl, file, proto) (PL_Sv=(SV*)newXS(name, c_impl, file), sv_setpv(PL_Sv, proto), (CV*)PL_Sv)
#endif /* !defined(newXS_flags) */

#if PERL_VERSION_LE(5, 21, 5)
#  define newXS_deffile(a,b) Perl_newXS(aTHX_ a,b,file)
#else
#  define newXS_deffile(a,b) Perl_newXS_deffile(aTHX_ a,b)
#endif


/* INCLUDE_COMMAND:  Including output of '/usr/bin/perl -MExtUtils::XSpp::Cmd -e xspp -- -t ../../typemap.xsp XS/StyledTextCtrl.xsp' from 'STC.xs' */

#include <exception>

#undef  xsp_constructor_class
#define xsp_constructor_class(c) (c)
#undef FindText
#include "wx/stc/stc.h"

XS_EUPXS(XS_Wx__StyledTextCtrl_new); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_new)
{
    dVAR; dXSARGS;
    if (items < 2 || items > 7)
       croak_xs_usage(cv,  "CLASS, parent, id = wxID_ANY, pos = wxDefaultPosition, size = wxDefaultSize, style = 0, name = wxSTCNameStr");
    {
	wxWindow*    parent = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::Window" )
;
	wxWindowID	id;
	wxPoint	pos;
	wxSize	size;
	long	style;
	wxString	name;
	char *	CLASS = (char *)SvPV_nolen(ST(0))
;
	wxStyledTextCtrl *	RETVAL;

	if (items < 3)
	    id = wxID_ANY;
	else {
    id = wxPli_get_wxwindowid( aTHX_ ST(2) )
;
	}

	if (items < 4)
	    pos = wxDefaultPosition;
	else {
    pos = wxPli_sv_2_wxpoint( aTHX_ ST(3) )
;
	}

	if (items < 5)
	    size = wxDefaultSize;
	else {
    size = wxPli_sv_2_wxsize( aTHX_ ST(4) )
;
	}

	if (items < 6)
	    style = 0;
	else {
	    style = (long)SvIV(ST(5))
;
	}

	if (items < 7)
	    name = wxSTCNameStr;
	else {
    WXSTRING_INPUT( name, wxString, ST(6) )
;
	}
    RETVAL = new wxStyledTextCtrl( parent, id, pos, size, style, name );
    wxPli_create_evthandler( aTHX_ RETVAL, CLASS );
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_object_2_sv( aTHX_ RETVALSV, RETVAL );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__StyledTextCtrl_AddText); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_AddText)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, text");
    {
	wxString	text;
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;

    WXSTRING_INPUT( text, wxString, ST(1) )
;

	THIS->AddText(text);
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__StyledTextCtrl_SetLexer); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_SetLexer)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, lexer");
    {
	int	lexer = (int)SvIV(ST(1))
;
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;

	THIS->SetLexer(lexer);
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__StyledTextCtrl_GetLexer); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_GetLexer)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;
	int	RETVAL;
	dXSTARG;

	RETVAL = THIS->GetLexer();
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__StyledTextCtrl_StyleSetSpec); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_StyleSetSpec)
{
    dVAR; dXSARGS;
    if (items != 3)
       croak_xs_usage(cv,  "THIS, style, spec");
    {
	int	style = (int)SvIV(ST(1))
;
	wxString	spec;
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;

    WXSTRING_INPUT( spec, wxString, ST(2) )
;

	THIS->StyleSetSpec(style, spec);
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__StyledTextCtrl_StyleSetFont); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_StyleSetFont)
{
    dVAR; dXSARGS;
    if (items != 3)
       croak_xs_usage(cv,  "THIS, style, font");
    {
	int	style = (int)SvIV(ST(1))
;
	wxFont*    font = (wxFont *) wxPli_sv_2_object( aTHX_ ST(2), "Wx::Font" )
;
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;
    THIS->StyleSetFont( style, *font );
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__StyledTextCtrl_StyleSetFontAttr); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_StyleSetFontAttr)
{
    dVAR; dXSARGS;
    if (items != 7)
       croak_xs_usage(cv,  "THIS, styleNum, size, faceName, bold, italic, underline");
    {
	int	styleNum = (int)SvIV(ST(1))
;
	int	size = (int)SvIV(ST(2))
;
	wxString	faceName;
	bool	bold = (bool)SvTRUE(ST(4))
;
	bool	italic = (bool)SvTRUE(ST(5))
;
	bool	underline = (bool)SvTRUE(ST(6))
;
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;

    WXSTRING_INPUT( faceName, wxString, ST(3) )
;

	THIS->StyleSetFontAttr(styleNum, size, faceName, bold, italic, underline);
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__StyledTextCtrl_StyleClearAll); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_StyleClearAll)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;

	THIS->StyleClearAll();
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__StyledTextCtrl_ClearDocumentStyle); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_ClearDocumentStyle)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;

	THIS->ClearDocumentStyle();
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__StyledTextCtrl_StyleSetForeground); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_StyleSetForeground)
{
    dVAR; dXSARGS;
    if (items != 3)
       croak_xs_usage(cv,  "THIS, style, fore");
    {
	int	style = (int)SvIV(ST(1))
;
	wxColour*    fore = (wxColour *) wxPli_sv_2_object( aTHX_ ST(2), "Wx::Colour" )
;
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;
    THIS->StyleSetForeground( style, *fore );
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__StyledTextCtrl_StyleSetBackground); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_StyleSetBackground)
{
    dVAR; dXSARGS;
    if (items != 3)
       croak_xs_usage(cv,  "THIS, style, back");
    {
	int	style = (int)SvIV(ST(1))
;
	wxColour*    back = (wxColour *) wxPli_sv_2_object( aTHX_ ST(2), "Wx::Colour" )
;
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;
    THIS->StyleSetBackground( style, *back );
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__StyledTextCtrl_StyleSetBold); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_StyleSetBold)
{
    dVAR; dXSARGS;
    if (items != 3)
       croak_xs_usage(cv,  "THIS, style, bold");
    {
	int	style = (int)SvIV(ST(1))
;
	bool	bold = (bool)SvTRUE(ST(2))
;
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;

	THIS->StyleSetBold(style, bold);
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__StyledTextCtrl_StyleSetItalic); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_StyleSetItalic)
{
    dVAR; dXSARGS;
    if (items != 3)
       croak_xs_usage(cv,  "THIS, style, italic");
    {
	int	style = (int)SvIV(ST(1))
;
	bool	italic = (bool)SvTRUE(ST(2))
;
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;

	THIS->StyleSetItalic(style, italic);
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__StyledTextCtrl_StyleSetUnderline); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_StyleSetUnderline)
{
    dVAR; dXSARGS;
    if (items != 3)
       croak_xs_usage(cv,  "THIS, style, underline");
    {
	int	style = (int)SvIV(ST(1))
;
	bool	underline = (bool)SvTRUE(ST(2))
;
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;

	THIS->StyleSetUnderline(style, underline);
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__StyledTextCtrl_InsertText); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_InsertText)
{
    dVAR; dXSARGS;
    if (items != 3)
       croak_xs_usage(cv,  "THIS, pos, text");
    {
	int	pos = (int)SvIV(ST(1))
;
	wxString	text;
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;

    WXSTRING_INPUT( text, wxString, ST(2) )
;

	THIS->InsertText(pos, text);
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__StyledTextCtrl_StyleSetSize); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_StyleSetSize)
{
    dVAR; dXSARGS;
    if (items != 3)
       croak_xs_usage(cv,  "THIS, style, size_points");
    {
	int	style = (int)SvIV(ST(1))
;
	int	size_points = (int)SvIV(ST(2))
;
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;

	THIS->StyleSetSize(style, size_points);
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__StyledTextCtrl_StyleSetFaceName); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_StyleSetFaceName)
{
    dVAR; dXSARGS;
    if (items != 3)
       croak_xs_usage(cv,  "THIS, style, font_name");
    {
	int	style = (int)SvIV(ST(1))
;
	wxString	font_name;
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;

    WXSTRING_INPUT( font_name, wxString, ST(2) )
;

	THIS->StyleSetFaceName(style, font_name);
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__StyledTextCtrl_StyleSetEOLFilled); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_StyleSetEOLFilled)
{
    dVAR; dXSARGS;
    if (items != 3)
       croak_xs_usage(cv,  "THIS, style, filled");
    {
	int	style = (int)SvIV(ST(1))
;
	bool	filled = (bool)SvTRUE(ST(2))
;
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;

	THIS->StyleSetEOLFilled(style, filled);
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__StyledTextCtrl_StyleResetDefault); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_StyleResetDefault)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;

	THIS->StyleResetDefault();
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__StyledTextCtrl_StyleSetCase); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_StyleSetCase)
{
    dVAR; dXSARGS;
    if (items != 3)
       croak_xs_usage(cv,  "THIS, style, caseForce");
    {
	int	style = (int)SvIV(ST(1))
;
	int	caseForce = (int)SvIV(ST(2))
;
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;

	THIS->StyleSetCase(style, caseForce);
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__StyledTextCtrl_StyleSetCharacterSet); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_StyleSetCharacterSet)
{
    dVAR; dXSARGS;
    if (items != 3)
       croak_xs_usage(cv,  "THIS, style, characterSet");
    {
	int	style = (int)SvIV(ST(1))
;
	int	characterSet = (int)SvIV(ST(2))
;
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;

	THIS->StyleSetCharacterSet(style, characterSet);
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__StyledTextCtrl_SetSelForeground); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_SetSelForeground)
{
    dVAR; dXSARGS;
    if (items != 3)
       croak_xs_usage(cv,  "THIS, useSetting, fore");
    {
	bool	useSetting = (bool)SvTRUE(ST(1))
;
	wxColour*    fore = (wxColour *) wxPli_sv_2_object( aTHX_ ST(2), "Wx::Colour" )
;
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;
    THIS->SetSelForeground( useSetting, *fore );
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__StyledTextCtrl_SetSelBackground); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_SetSelBackground)
{
    dVAR; dXSARGS;
    if (items != 3)
       croak_xs_usage(cv,  "THIS, useSetting, back");
    {
	bool	useSetting = (bool)SvTRUE(ST(1))
;
	wxColour*    back = (wxColour *) wxPli_sv_2_object( aTHX_ ST(2), "Wx::Colour" )
;
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;
    THIS->SetSelBackground( useSetting, *back );
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__StyledTextCtrl_SetCaretForeground); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_SetCaretForeground)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, fore");
    {
	wxColour*    fore = (wxColour *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::Colour" )
;
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;
    THIS->SetCaretForeground( *fore );
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__StyledTextCtrl_CmdKeyAssign); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_CmdKeyAssign)
{
    dVAR; dXSARGS;
    if (items != 4)
       croak_xs_usage(cv,  "THIS, key, modifiers, cmd");
    {
	int	key = (int)SvIV(ST(1))
;
	int	modifiers = (int)SvIV(ST(2))
;
	int	cmd = (int)SvIV(ST(3))
;
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;

	THIS->CmdKeyAssign(key, modifiers, cmd);
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__StyledTextCtrl_CmdKeyClear); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_CmdKeyClear)
{
    dVAR; dXSARGS;
    if (items != 3)
       croak_xs_usage(cv,  "THIS, key, modifiers");
    {
	int	key = (int)SvIV(ST(1))
;
	int	modifiers = (int)SvIV(ST(2))
;
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;

	THIS->CmdKeyClear(key, modifiers);
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__StyledTextCtrl_CmdKeyClearAll); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_CmdKeyClearAll)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;

	THIS->CmdKeyClearAll();
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__StyledTextCtrl_SetStyleBytes); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_SetStyleBytes)
{
    dVAR; dXSARGS;
    if (items != 3)
       croak_xs_usage(cv,  "THIS, length, styleBytes");
    {
	int	length = (int)SvIV(ST(1))
;
	char*	styleBytes = (char *)SvPV_nolen(ST(2))
;
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;

	THIS->SetStyleBytes(length, styleBytes);
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__StyledTextCtrl_StyleSetVisible); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_StyleSetVisible)
{
    dVAR; dXSARGS;
    if (items != 3)
       croak_xs_usage(cv,  "THIS, style, visible");
    {
	int	style = (int)SvIV(ST(1))
;
	bool	visible = (bool)SvTRUE(ST(2))
;
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;

	THIS->StyleSetVisible(style, visible);
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__StyledTextCtrl_GetCaretPeriod); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_GetCaretPeriod)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;
	int	RETVAL;
	dXSTARG;

	RETVAL = THIS->GetCaretPeriod();
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__StyledTextCtrl_SetCaretPeriod); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_SetCaretPeriod)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, periodMilliseconds");
    {
	int	periodMilliseconds = (int)SvIV(ST(1))
;
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;

	THIS->SetCaretPeriod(periodMilliseconds);
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__StyledTextCtrl_SetWordChars); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_SetWordChars)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, characters");
    {
	wxString	characters;
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;

    WXSTRING_INPUT( characters, wxString, ST(1) )
;

	THIS->SetWordChars(characters);
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__StyledTextCtrl_BeginUndoAction); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_BeginUndoAction)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;

	THIS->BeginUndoAction();
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__StyledTextCtrl_EndUndoAction); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_EndUndoAction)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;

	THIS->EndUndoAction();
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__StyledTextCtrl_IndicatorSetStyle); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_IndicatorSetStyle)
{
    dVAR; dXSARGS;
    if (items != 3)
       croak_xs_usage(cv,  "THIS, indic, style");
    {
	int	indic = (int)SvIV(ST(1))
;
	int	style = (int)SvIV(ST(2))
;
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;

	THIS->IndicatorSetStyle(indic, style);
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__StyledTextCtrl_IndicatorGetStyle); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_IndicatorGetStyle)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, indic");
    {
	int	indic = (int)SvIV(ST(1))
;
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;
	int	RETVAL;
	dXSTARG;

	RETVAL = THIS->IndicatorGetStyle(indic);
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__StyledTextCtrl_IndicatorSetForeground); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_IndicatorSetForeground)
{
    dVAR; dXSARGS;
    if (items != 3)
       croak_xs_usage(cv,  "THIS, indic, fore");
    {
	int	indic = (int)SvIV(ST(1))
;
	wxColour*    fore = (wxColour *) wxPli_sv_2_object( aTHX_ ST(2), "Wx::Colour" )
;
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;
    THIS->IndicatorSetForeground( indic, *fore );
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__StyledTextCtrl_SetWhitespaceForeground); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_SetWhitespaceForeground)
{
    dVAR; dXSARGS;
    if (items != 3)
       croak_xs_usage(cv,  "THIS, useSetting, fore");
    {
	bool	useSetting = (bool)SvTRUE(ST(1))
;
	wxColour*    fore = (wxColour *) wxPli_sv_2_object( aTHX_ ST(2), "Wx::Colour" )
;
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;
    THIS->SetWhitespaceForeground( useSetting, *fore );
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__StyledTextCtrl_SetWhitespaceBackground); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_SetWhitespaceBackground)
{
    dVAR; dXSARGS;
    if (items != 3)
       croak_xs_usage(cv,  "THIS, useSetting, back");
    {
	bool	useSetting = (bool)SvTRUE(ST(1))
;
	wxColour*    back = (wxColour *) wxPli_sv_2_object( aTHX_ ST(2), "Wx::Colour" )
;
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;
    THIS->SetWhitespaceBackground( useSetting, *back );
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__StyledTextCtrl_SetStyleBits); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_SetStyleBits)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, bits");
    {
	int	bits = (int)SvIV(ST(1))
;
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;

	THIS->SetStyleBits(bits);
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__StyledTextCtrl_GetStyleBits); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_GetStyleBits)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;
	int	RETVAL;
	dXSTARG;

	RETVAL = THIS->GetStyleBits();
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__StyledTextCtrl_SetLineState); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_SetLineState)
{
    dVAR; dXSARGS;
    if (items != 3)
       croak_xs_usage(cv,  "THIS, line, state");
    {
	int	line = (int)SvIV(ST(1))
;
	int	state = (int)SvIV(ST(2))
;
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;

	THIS->SetLineState(line, state);
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__StyledTextCtrl_GetLineState); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_GetLineState)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, line");
    {
	int	line = (int)SvIV(ST(1))
;
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;
	int	RETVAL;
	dXSTARG;

	RETVAL = THIS->GetLineState(line);
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__StyledTextCtrl_GetMaxLineState); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_GetMaxLineState)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;
	int	RETVAL;
	dXSTARG;

	RETVAL = THIS->GetMaxLineState();
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__StyledTextCtrl_GetCaretLineVisible); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_GetCaretLineVisible)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;
	bool	RETVAL;

	RETVAL = THIS->GetCaretLineVisible();
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__StyledTextCtrl_SetCaretLineVisible); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_SetCaretLineVisible)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, show");
    {
	bool	show = (bool)SvTRUE(ST(1))
;
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;

	THIS->SetCaretLineVisible(show);
    }
    XSRETURN_EMPTY;
}

#if WXPERL_W_VERSION_LT( 2, 7, 0 )
#define XSubPPtmpAAAA 1


XS_EUPXS(XS_Wx__StyledTextCtrl_SetCaretLineBack); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_SetCaretLineBack)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, back");
    {
	wxColour*    back = (wxColour *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::Colour" )
;
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;
    THIS->SetCaretLineBack( *back );
    }
    XSRETURN_EMPTY;
}

#else
#define XSubPPtmpAAAB 1


XS_EUPXS(XS_Wx__StyledTextCtrl_SetCaretLineBack); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_SetCaretLineBack)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, back");
    {
	wxColour*    back = (wxColour *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::Colour" )
;
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;
    THIS->SetCaretLineBackground( *back );
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__StyledTextCtrl_SetCaretLineBackground); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_SetCaretLineBackground)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, back");
    {
	wxColour*    back = (wxColour *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::Colour" )
;
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;
    THIS->SetCaretLineBackground( *back );
    }
    XSRETURN_EMPTY;
}

#endif

XS_EUPXS(XS_Wx__StyledTextCtrl_StyleSetChangeable); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_StyleSetChangeable)
{
    dVAR; dXSARGS;
    if (items != 3)
       croak_xs_usage(cv,  "THIS, style, changeable");
    {
	int	style = (int)SvIV(ST(1))
;
	bool	changeable = (bool)SvTRUE(ST(2))
;
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;

	THIS->StyleSetChangeable(style, changeable);
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__StyledTextCtrl_AutoCompShow); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_AutoCompShow)
{
    dVAR; dXSARGS;
    if (items != 3)
       croak_xs_usage(cv,  "THIS, lenEntered, itemList");
    {
	int	lenEntered = (int)SvIV(ST(1))
;
	wxString	itemList;
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;

    WXSTRING_INPUT( itemList, wxString, ST(2) )
;

	THIS->AutoCompShow(lenEntered, itemList);
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__StyledTextCtrl_AutoCompCancel); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_AutoCompCancel)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;

	THIS->AutoCompCancel();
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__StyledTextCtrl_AutoCompActive); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_AutoCompActive)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;
	bool	RETVAL;

	RETVAL = THIS->AutoCompActive();
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__StyledTextCtrl_AutoCompPosStart); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_AutoCompPosStart)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;
	int	RETVAL;
	dXSTARG;

	RETVAL = THIS->AutoCompPosStart();
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__StyledTextCtrl_AutoCompComplete); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_AutoCompComplete)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;

	THIS->AutoCompComplete();
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__StyledTextCtrl_AutoCompStops); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_AutoCompStops)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, characterSet");
    {
	wxString	characterSet;
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;

    WXSTRING_INPUT( characterSet, wxString, ST(1) )
;

	THIS->AutoCompStops(characterSet);
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__StyledTextCtrl_AutoCompSetSeparator); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_AutoCompSetSeparator)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, separatorCharacter");
    {
	int	separatorCharacter = (int)SvIV(ST(1))
;
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;

	THIS->AutoCompSetSeparator(separatorCharacter);
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__StyledTextCtrl_AutoCompGetSeparator); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_AutoCompGetSeparator)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;
	int	RETVAL;
	dXSTARG;

	RETVAL = THIS->AutoCompGetSeparator();
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__StyledTextCtrl_AutoCompSelect); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_AutoCompSelect)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, text");
    {
	wxString	text;
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;

    WXSTRING_INPUT( text, wxString, ST(1) )
;

	THIS->AutoCompSelect(text);
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__StyledTextCtrl_AutoCompSetCancelAtStart); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_AutoCompSetCancelAtStart)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, cancel");
    {
	bool	cancel = (bool)SvTRUE(ST(1))
;
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;

	THIS->AutoCompSetCancelAtStart(cancel);
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__StyledTextCtrl_AutoCompGetCancelAtStart); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_AutoCompGetCancelAtStart)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;
	bool	RETVAL;

	RETVAL = THIS->AutoCompGetCancelAtStart();
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__StyledTextCtrl_AutoCompSetFillUps); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_AutoCompSetFillUps)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, characterSet");
    {
	wxString	characterSet;
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;

    WXSTRING_INPUT( characterSet, wxString, ST(1) )
;

	THIS->AutoCompSetFillUps(characterSet);
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__StyledTextCtrl_AutoCompSetChooseSingle); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_AutoCompSetChooseSingle)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, chooseSingle");
    {
	bool	chooseSingle = (bool)SvTRUE(ST(1))
;
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;

	THIS->AutoCompSetChooseSingle(chooseSingle);
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__StyledTextCtrl_AutoCompGetChooseSingle); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_AutoCompGetChooseSingle)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;
	bool	RETVAL;

	RETVAL = THIS->AutoCompGetChooseSingle();
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__StyledTextCtrl_AutoCompGetIgnoreCase); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_AutoCompGetIgnoreCase)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;
	bool	RETVAL;

	RETVAL = THIS->AutoCompGetIgnoreCase();
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__StyledTextCtrl_UserListShow); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_UserListShow)
{
    dVAR; dXSARGS;
    if (items != 3)
       croak_xs_usage(cv,  "THIS, listType, itemList");
    {
	int	listType = (int)SvIV(ST(1))
;
	wxString	itemList;
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;

    WXSTRING_INPUT( itemList, wxString, ST(2) )
;

	THIS->UserListShow(listType, itemList);
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__StyledTextCtrl_AutoCompSetAutoHide); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_AutoCompSetAutoHide)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, autoHide");
    {
	bool	autoHide = (bool)SvTRUE(ST(1))
;
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;

	THIS->AutoCompSetAutoHide(autoHide);
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__StyledTextCtrl_AutoCompGetAutoHide); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_AutoCompGetAutoHide)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;
	bool	RETVAL;

	RETVAL = THIS->AutoCompGetAutoHide();
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__StyledTextCtrl_AutoCompSetDropRestOfWord); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_AutoCompSetDropRestOfWord)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, dropRestOfWord");
    {
	bool	dropRestOfWord = (bool)SvTRUE(ST(1))
;
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;

	THIS->AutoCompSetDropRestOfWord(dropRestOfWord);
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__StyledTextCtrl_AutoCompGetDropRestOfWord); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_AutoCompGetDropRestOfWord)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;
	bool	RETVAL;

	RETVAL = THIS->AutoCompGetDropRestOfWord();
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__StyledTextCtrl_SetIndent); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_SetIndent)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, indentSize");
    {
	int	indentSize = (int)SvIV(ST(1))
;
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;

	THIS->SetIndent(indentSize);
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__StyledTextCtrl_GetIndent); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_GetIndent)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;
	int	RETVAL;
	dXSTARG;

	RETVAL = THIS->GetIndent();
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__StyledTextCtrl_SetUseTabs); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_SetUseTabs)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, useTabs");
    {
	bool	useTabs = (bool)SvTRUE(ST(1))
;
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;

	THIS->SetUseTabs(useTabs);
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__StyledTextCtrl_GetUseTabs); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_GetUseTabs)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;
	bool	RETVAL;

	RETVAL = THIS->GetUseTabs();
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__StyledTextCtrl_SetLineIndentation); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_SetLineIndentation)
{
    dVAR; dXSARGS;
    if (items != 3)
       croak_xs_usage(cv,  "THIS, line, indentSize");
    {
	int	line = (int)SvIV(ST(1))
;
	int	indentSize = (int)SvIV(ST(2))
;
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;

	THIS->SetLineIndentation(line, indentSize);
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__StyledTextCtrl_GetLineIndentation); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_GetLineIndentation)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, line");
    {
	int	line = (int)SvIV(ST(1))
;
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;
	int	RETVAL;
	dXSTARG;

	RETVAL = THIS->GetLineIndentation(line);
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__StyledTextCtrl_GetLineIndentPosition); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_GetLineIndentPosition)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, line");
    {
	int	line = (int)SvIV(ST(1))
;
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;
	int	RETVAL;
	dXSTARG;

	RETVAL = THIS->GetLineIndentPosition(line);
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__StyledTextCtrl_GetColumn); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_GetColumn)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, pos");
    {
	int	pos = (int)SvIV(ST(1))
;
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;
	int	RETVAL;
	dXSTARG;

	RETVAL = THIS->GetColumn(pos);
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__StyledTextCtrl_SetUseHorizontalScrollBar); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_SetUseHorizontalScrollBar)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, show");
    {
	bool	show = (bool)SvTRUE(ST(1))
;
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;

	THIS->SetUseHorizontalScrollBar(show);
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__StyledTextCtrl_GetUseHorizontalScrollBar); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_GetUseHorizontalScrollBar)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;
	bool	RETVAL;

	RETVAL = THIS->GetUseHorizontalScrollBar();
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__StyledTextCtrl_SetIndentationGuides); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_SetIndentationGuides)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, show");
    {
	bool	show = (bool)SvTRUE(ST(1))
;
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;

	THIS->SetIndentationGuides(show);
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__StyledTextCtrl_GetIndentationGuides); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_GetIndentationGuides)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;
	bool	RETVAL;

	RETVAL = THIS->GetIndentationGuides();
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__StyledTextCtrl_SetHighlightGuide); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_SetHighlightGuide)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, column");
    {
	int	column = (int)SvIV(ST(1))
;
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;

	THIS->SetHighlightGuide(column);
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__StyledTextCtrl_GetHighlightGuide); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_GetHighlightGuide)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;
	int	RETVAL;
	dXSTARG;

	RETVAL = THIS->GetHighlightGuide();
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__StyledTextCtrl_GetLineEndPosition); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_GetLineEndPosition)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, line");
    {
	int	line = (int)SvIV(ST(1))
;
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;
	int	RETVAL;
	dXSTARG;

	RETVAL = THIS->GetLineEndPosition(line);
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__StyledTextCtrl_GetCodePage); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_GetCodePage)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;
	int	RETVAL;
	dXSTARG;

	RETVAL = THIS->GetCodePage();
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__StyledTextCtrl_GetReadOnly); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_GetReadOnly)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;
	bool	RETVAL;

	RETVAL = THIS->GetReadOnly();
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__StyledTextCtrl_SetCurrentPos); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_SetCurrentPos)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, pos");
    {
	int	pos = (int)SvIV(ST(1))
;
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;

	THIS->SetCurrentPos(pos);
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__StyledTextCtrl_SetSelectionStart); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_SetSelectionStart)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, pos");
    {
	int	pos = (int)SvIV(ST(1))
;
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;

	THIS->SetSelectionStart(pos);
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__StyledTextCtrl_GetSelectionStart); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_GetSelectionStart)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;
	int	RETVAL;
	dXSTARG;

	RETVAL = THIS->GetSelectionStart();
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__StyledTextCtrl_SetSelectionEnd); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_SetSelectionEnd)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, pos");
    {
	int	pos = (int)SvIV(ST(1))
;
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;

	THIS->SetSelectionEnd(pos);
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__StyledTextCtrl_GetSelectionEnd); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_GetSelectionEnd)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;
	int	RETVAL;
	dXSTARG;

	RETVAL = THIS->GetSelectionEnd();
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__StyledTextCtrl_SetPrintMagnification); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_SetPrintMagnification)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, magnification");
    {
	int	magnification = (int)SvIV(ST(1))
;
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;

	THIS->SetPrintMagnification(magnification);
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__StyledTextCtrl_GetPrintMagnification); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_GetPrintMagnification)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;
	int	RETVAL;
	dXSTARG;

	RETVAL = THIS->GetPrintMagnification();
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__StyledTextCtrl_SetPrintColourMode); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_SetPrintColourMode)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, mode");
    {
	int	mode = (int)SvIV(ST(1))
;
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;

	THIS->SetPrintColourMode(mode);
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__StyledTextCtrl_GetPrintColourMode); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_GetPrintColourMode)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;
	int	RETVAL;
	dXSTARG;

	RETVAL = THIS->GetPrintColourMode();
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__StyledTextCtrl_FindText); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_FindText)
{
    dVAR; dXSARGS;
    if (items < 4 || items > 5)
       croak_xs_usage(cv,  "THIS, minPos, maxPos, text, flags = 0");
    {
	int	minPos = (int)SvIV(ST(1))
;
	int	maxPos = (int)SvIV(ST(2))
;
	wxString	text;
	int	flags;
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;
	int	RETVAL;
	dXSTARG;

    WXSTRING_INPUT( text, wxString, ST(3) )
;

	if (items < 5)
	    flags = 0;
	else {
	    flags = (int)SvIV(ST(4))
;
	}

	RETVAL = THIS->FindText(minPos, maxPos, text, flags);
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__StyledTextCtrl_GetFirstVisibleLine); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_GetFirstVisibleLine)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;
	int	RETVAL;
	dXSTARG;

	RETVAL = THIS->GetFirstVisibleLine();
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__StyledTextCtrl_GetLineCount); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_GetLineCount)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;
	int	RETVAL;
	dXSTARG;

	RETVAL = THIS->GetLineCount();
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__StyledTextCtrl_SetMarginLeft); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_SetMarginLeft)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, pixelWidth");
    {
	int	pixelWidth = (int)SvIV(ST(1))
;
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;

	THIS->SetMarginLeft(pixelWidth);
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__StyledTextCtrl_GetMarginLeft); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_GetMarginLeft)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;
	int	RETVAL;
	dXSTARG;

	RETVAL = THIS->GetMarginLeft();
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__StyledTextCtrl_SetMarginRight); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_SetMarginRight)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, pixelWidth");
    {
	int	pixelWidth = (int)SvIV(ST(1))
;
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;

	THIS->SetMarginRight(pixelWidth);
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__StyledTextCtrl_GetMarginRight); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_GetMarginRight)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;
	int	RETVAL;
	dXSTARG;

	RETVAL = THIS->GetMarginRight();
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__StyledTextCtrl_GetModify); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_GetModify)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;
	bool	RETVAL;

	RETVAL = THIS->GetModify();
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__StyledTextCtrl_SetSelection); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_SetSelection)
{
    dVAR; dXSARGS;
    if (items != 3)
       croak_xs_usage(cv,  "THIS, start, end");
    {
	int	start = (int)SvIV(ST(1))
;
	int	end = (int)SvIV(ST(2))
;
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;

	THIS->SetSelection(start, end);
    }
    XSRETURN_EMPTY;
}

#if WXPERL_W_VERSION_GE( 2, 6, 0 )
#define XSubPPtmpAAAC 1


XS_EUPXS(XS_Wx__StyledTextCtrl_SetSelectionMode); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_SetSelectionMode)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, mode");
    {
	int	mode = (int)SvIV(ST(1))
;
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;

	THIS->SetSelectionMode(mode);
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__StyledTextCtrl_GetSelectionMode); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_GetSelectionMode)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;
	int	RETVAL;
	dXSTARG;

	RETVAL = THIS->GetSelectionMode();
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}

#endif

XS_EUPXS(XS_Wx__StyledTextCtrl_HideSelection); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_HideSelection)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, normal");
    {
	bool	normal = (bool)SvTRUE(ST(1))
;
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;

	THIS->HideSelection(normal);
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__StyledTextCtrl_LineFromPosition); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_LineFromPosition)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, pos");
    {
	int	pos = (int)SvIV(ST(1))
;
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;
	int	RETVAL;
	dXSTARG;

	RETVAL = THIS->LineFromPosition(pos);
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__StyledTextCtrl_PositionFromLine); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_PositionFromLine)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, line");
    {
	int	line = (int)SvIV(ST(1))
;
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;
	int	RETVAL;
	dXSTARG;

	RETVAL = THIS->PositionFromLine(line);
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__StyledTextCtrl_LineScroll); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_LineScroll)
{
    dVAR; dXSARGS;
    if (items != 3)
       croak_xs_usage(cv,  "THIS, columns, lines");
    {
	int	columns = (int)SvIV(ST(1))
;
	int	lines = (int)SvIV(ST(2))
;
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;

	THIS->LineScroll(columns, lines);
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__StyledTextCtrl_EnsureCaretVisible); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_EnsureCaretVisible)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;

	THIS->EnsureCaretVisible();
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__StyledTextCtrl_ReplaceSelection); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_ReplaceSelection)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, text");
    {
	wxString	text;
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;

    WXSTRING_INPUT( text, wxString, ST(1) )
;

	THIS->ReplaceSelection(text);
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__StyledTextCtrl_SetReadOnly); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_SetReadOnly)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, readOnly");
    {
	bool	readOnly = (bool)SvTRUE(ST(1))
;
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;

	THIS->SetReadOnly(readOnly);
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__StyledTextCtrl_CanPaste); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_CanPaste)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;
	bool	RETVAL;

	RETVAL = THIS->CanPaste();
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__StyledTextCtrl_CanUndo); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_CanUndo)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;
	bool	RETVAL;

	RETVAL = THIS->CanUndo();
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__StyledTextCtrl_EmptyUndoBuffer); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_EmptyUndoBuffer)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;

	THIS->EmptyUndoBuffer();
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__StyledTextCtrl_Undo); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_Undo)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;

	THIS->Undo();
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__StyledTextCtrl_Cut); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_Cut)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;

	THIS->Cut();
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__StyledTextCtrl_Copy); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_Copy)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;

	THIS->Copy();
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__StyledTextCtrl_Paste); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_Paste)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;

	THIS->Paste();
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__StyledTextCtrl_Clear); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_Clear)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;

	THIS->Clear();
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__StyledTextCtrl_GetTextLength); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_GetTextLength)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;
	int	RETVAL;
	dXSTARG;

	RETVAL = THIS->GetTextLength();
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__StyledTextCtrl_SetOvertype); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_SetOvertype)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, overtype");
    {
	bool	overtype = (bool)SvTRUE(ST(1))
;
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;

	THIS->SetOvertype(overtype);
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__StyledTextCtrl_GetOvertype); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_GetOvertype)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;
	bool	RETVAL;

	RETVAL = THIS->GetOvertype();
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__StyledTextCtrl_SetCaretWidth); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_SetCaretWidth)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, pixelWidth");
    {
	int	pixelWidth = (int)SvIV(ST(1))
;
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;

	THIS->SetCaretWidth(pixelWidth);
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__StyledTextCtrl_GetCaretWidth); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_GetCaretWidth)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;
	int	RETVAL;
	dXSTARG;

	RETVAL = THIS->GetCaretWidth();
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__StyledTextCtrl_SetTargetStart); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_SetTargetStart)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, pos");
    {
	int	pos = (int)SvIV(ST(1))
;
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;

	THIS->SetTargetStart(pos);
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__StyledTextCtrl_GetTargetStart); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_GetTargetStart)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;
	int	RETVAL;
	dXSTARG;

	RETVAL = THIS->GetTargetStart();
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__StyledTextCtrl_SetTargetEnd); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_SetTargetEnd)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, pos");
    {
	int	pos = (int)SvIV(ST(1))
;
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;

	THIS->SetTargetEnd(pos);
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__StyledTextCtrl_GetTargetEnd); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_GetTargetEnd)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;
	int	RETVAL;
	dXSTARG;

	RETVAL = THIS->GetTargetEnd();
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__StyledTextCtrl_ReplaceTarget); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_ReplaceTarget)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, text");
    {
	wxString	text;
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;
	int	RETVAL;
	dXSTARG;

    WXSTRING_INPUT( text, wxString, ST(1) )
;

	RETVAL = THIS->ReplaceTarget(text);
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__StyledTextCtrl_ReplaceTargetRE); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_ReplaceTargetRE)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, text");
    {
	wxString	text;
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;
	int	RETVAL;
	dXSTARG;

    WXSTRING_INPUT( text, wxString, ST(1) )
;

	RETVAL = THIS->ReplaceTargetRE(text);
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__StyledTextCtrl_SearchInTarget); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_SearchInTarget)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, text");
    {
	wxString	text;
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;
	int	RETVAL;
	dXSTARG;

    WXSTRING_INPUT( text, wxString, ST(1) )
;

	RETVAL = THIS->SearchInTarget(text);
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__StyledTextCtrl_SetSearchFlags); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_SetSearchFlags)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, flags");
    {
	int	flags = (int)SvIV(ST(1))
;
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;

	THIS->SetSearchFlags(flags);
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__StyledTextCtrl_GetSearchFlags); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_GetSearchFlags)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;
	int	RETVAL;
	dXSTARG;

	RETVAL = THIS->GetSearchFlags();
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__StyledTextCtrl_CallTipShow); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_CallTipShow)
{
    dVAR; dXSARGS;
    if (items != 3)
       croak_xs_usage(cv,  "THIS, pos, definition");
    {
	int	pos = (int)SvIV(ST(1))
;
	wxString	definition;
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;

    WXSTRING_INPUT( definition, wxString, ST(2) )
;

	THIS->CallTipShow(pos, definition);
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__StyledTextCtrl_CallTipCancel); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_CallTipCancel)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;

	THIS->CallTipCancel();
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__StyledTextCtrl_CallTipActive); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_CallTipActive)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;
	bool	RETVAL;

	RETVAL = THIS->CallTipActive();
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__StyledTextCtrl_CallTipPosAtStart); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_CallTipPosAtStart)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;
	int	RETVAL;
	dXSTARG;

	RETVAL = THIS->CallTipPosAtStart();
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__StyledTextCtrl_CallTipSetHighlight); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_CallTipSetHighlight)
{
    dVAR; dXSARGS;
    if (items != 3)
       croak_xs_usage(cv,  "THIS, start, end");
    {
	int	start = (int)SvIV(ST(1))
;
	int	end = (int)SvIV(ST(2))
;
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;

	THIS->CallTipSetHighlight(start, end);
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__StyledTextCtrl_CallTipSetBackground); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_CallTipSetBackground)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, back");
    {
	wxColour*    back = (wxColour *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::Colour" )
;
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;
    THIS->CallTipSetBackground( *back );
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__StyledTextCtrl_VisibleFromDocLine); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_VisibleFromDocLine)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, line");
    {
	int	line = (int)SvIV(ST(1))
;
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;
	int	RETVAL;
	dXSTARG;

	RETVAL = THIS->VisibleFromDocLine(line);
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__StyledTextCtrl_DocLineFromVisible); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_DocLineFromVisible)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, lineDisplay");
    {
	int	lineDisplay = (int)SvIV(ST(1))
;
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;
	int	RETVAL;
	dXSTARG;

	RETVAL = THIS->DocLineFromVisible(lineDisplay);
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__StyledTextCtrl_SetFoldLevel); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_SetFoldLevel)
{
    dVAR; dXSARGS;
    if (items != 3)
       croak_xs_usage(cv,  "THIS, line, level");
    {
	int	line = (int)SvIV(ST(1))
;
	int	level = (int)SvIV(ST(2))
;
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;

	THIS->SetFoldLevel(line, level);
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__StyledTextCtrl_GetFoldLevel); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_GetFoldLevel)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, line");
    {
	int	line = (int)SvIV(ST(1))
;
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;
	int	RETVAL;
	dXSTARG;

	RETVAL = THIS->GetFoldLevel(line);
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__StyledTextCtrl_GetLastChild); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_GetLastChild)
{
    dVAR; dXSARGS;
    if (items != 3)
       croak_xs_usage(cv,  "THIS, line, level");
    {
	int	line = (int)SvIV(ST(1))
;
	int	level = (int)SvIV(ST(2))
;
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;
	int	RETVAL;
	dXSTARG;

	RETVAL = THIS->GetLastChild(line, level);
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__StyledTextCtrl_GetFoldParent); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_GetFoldParent)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, line");
    {
	int	line = (int)SvIV(ST(1))
;
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;
	int	RETVAL;
	dXSTARG;

	RETVAL = THIS->GetFoldParent(line);
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__StyledTextCtrl_ShowLines); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_ShowLines)
{
    dVAR; dXSARGS;
    if (items != 3)
       croak_xs_usage(cv,  "THIS, lineStart, lineEnd");
    {
	int	lineStart = (int)SvIV(ST(1))
;
	int	lineEnd = (int)SvIV(ST(2))
;
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;

	THIS->ShowLines(lineStart, lineEnd);
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__StyledTextCtrl_HideLines); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_HideLines)
{
    dVAR; dXSARGS;
    if (items != 3)
       croak_xs_usage(cv,  "THIS, lineStart, lineEnd");
    {
	int	lineStart = (int)SvIV(ST(1))
;
	int	lineEnd = (int)SvIV(ST(2))
;
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;

	THIS->HideLines(lineStart, lineEnd);
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__StyledTextCtrl_GetLineVisible); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_GetLineVisible)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, line");
    {
	int	line = (int)SvIV(ST(1))
;
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;
	bool	RETVAL;

	RETVAL = THIS->GetLineVisible(line);
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__StyledTextCtrl_SetFoldExpanded); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_SetFoldExpanded)
{
    dVAR; dXSARGS;
    if (items != 3)
       croak_xs_usage(cv,  "THIS, line, expanded");
    {
	int	line = (int)SvIV(ST(1))
;
	bool	expanded = (bool)SvTRUE(ST(2))
;
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;

	THIS->SetFoldExpanded(line, expanded);
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__StyledTextCtrl_GetFoldExpanded); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_GetFoldExpanded)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, line");
    {
	int	line = (int)SvIV(ST(1))
;
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;
	bool	RETVAL;

	RETVAL = THIS->GetFoldExpanded(line);
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__StyledTextCtrl_ToggleFold); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_ToggleFold)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, line");
    {
	int	line = (int)SvIV(ST(1))
;
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;

	THIS->ToggleFold(line);
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__StyledTextCtrl_EnsureVisible); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_EnsureVisible)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, line");
    {
	int	line = (int)SvIV(ST(1))
;
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;

	THIS->EnsureVisible(line);
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__StyledTextCtrl_SetFoldFlags); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_SetFoldFlags)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, flags");
    {
	int	flags = (int)SvIV(ST(1))
;
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;

	THIS->SetFoldFlags(flags);
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__StyledTextCtrl_EnsureVisibleEnforcePolicy); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_EnsureVisibleEnforcePolicy)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, line");
    {
	int	line = (int)SvIV(ST(1))
;
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;

	THIS->EnsureVisibleEnforcePolicy(line);
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__StyledTextCtrl_SetTabIndents); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_SetTabIndents)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, tabIndents");
    {
	bool	tabIndents = (bool)SvTRUE(ST(1))
;
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;

	THIS->SetTabIndents(tabIndents);
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__StyledTextCtrl_GetTabIndents); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_GetTabIndents)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;
	bool	RETVAL;

	RETVAL = THIS->GetTabIndents();
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__StyledTextCtrl_SetBackSpaceUnIndents); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_SetBackSpaceUnIndents)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, bsUnIndents");
    {
	bool	bsUnIndents = (bool)SvTRUE(ST(1))
;
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;

	THIS->SetBackSpaceUnIndents(bsUnIndents);
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__StyledTextCtrl_GetBackSpaceUnIndents); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_GetBackSpaceUnIndents)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;
	bool	RETVAL;

	RETVAL = THIS->GetBackSpaceUnIndents();
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__StyledTextCtrl_SetMouseDwellTime); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_SetMouseDwellTime)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, periodMilliseconds");
    {
	int	periodMilliseconds = (int)SvIV(ST(1))
;
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;

	THIS->SetMouseDwellTime(periodMilliseconds);
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__StyledTextCtrl_GetMouseDwellTime); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_GetMouseDwellTime)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;
	int	RETVAL;
	dXSTARG;

	RETVAL = THIS->GetMouseDwellTime();
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__StyledTextCtrl_WordStartPosition); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_WordStartPosition)
{
    dVAR; dXSARGS;
    if (items != 3)
       croak_xs_usage(cv,  "THIS, pos, onlyWordCharacters");
    {
	int	pos = (int)SvIV(ST(1))
;
	bool	onlyWordCharacters = (bool)SvTRUE(ST(2))
;
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;
	int	RETVAL;
	dXSTARG;

	RETVAL = THIS->WordStartPosition(pos, onlyWordCharacters);
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__StyledTextCtrl_WordEndPosition); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_WordEndPosition)
{
    dVAR; dXSARGS;
    if (items != 3)
       croak_xs_usage(cv,  "THIS, pos, onlyWordCharacters");
    {
	int	pos = (int)SvIV(ST(1))
;
	bool	onlyWordCharacters = (bool)SvTRUE(ST(2))
;
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;
	int	RETVAL;
	dXSTARG;

	RETVAL = THIS->WordEndPosition(pos, onlyWordCharacters);
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__StyledTextCtrl_SetLayoutCache); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_SetLayoutCache)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, mode");
    {
	int	mode = (int)SvIV(ST(1))
;
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;

	THIS->SetLayoutCache(mode);
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__StyledTextCtrl_GetLayoutCache); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_GetLayoutCache)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;
	int	RETVAL;
	dXSTARG;

	RETVAL = THIS->GetLayoutCache();
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__StyledTextCtrl_SetScrollWidth); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_SetScrollWidth)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, pixelWidth");
    {
	int	pixelWidth = (int)SvIV(ST(1))
;
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;

	THIS->SetScrollWidth(pixelWidth);
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__StyledTextCtrl_GetScrollWidth); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_GetScrollWidth)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;
	int	RETVAL;
	dXSTARG;

	RETVAL = THIS->GetScrollWidth();
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__StyledTextCtrl_TextWidth); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_TextWidth)
{
    dVAR; dXSARGS;
    if (items != 3)
       croak_xs_usage(cv,  "THIS, style, text");
    {
	int	style = (int)SvIV(ST(1))
;
	wxString	text;
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;
	int	RETVAL;
	dXSTARG;

    WXSTRING_INPUT( text, wxString, ST(2) )
;

	RETVAL = THIS->TextWidth(style, text);
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__StyledTextCtrl_SetEndAtLastLine); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_SetEndAtLastLine)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, endAtLastLine");
    {
	bool	endAtLastLine = (bool)SvTRUE(ST(1))
;
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;

	THIS->SetEndAtLastLine(endAtLastLine);
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__StyledTextCtrl_GetEndAtLastLine); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_GetEndAtLastLine)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;
	int	RETVAL;
	dXSTARG;

	RETVAL = THIS->GetEndAtLastLine();
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__StyledTextCtrl_TextHeight); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_TextHeight)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, line");
    {
	int	line = (int)SvIV(ST(1))
;
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;
	int	RETVAL;
	dXSTARG;

	RETVAL = THIS->TextHeight(line);
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__StyledTextCtrl_HomeDisplay); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_HomeDisplay)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;

	THIS->HomeDisplay();
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__StyledTextCtrl_HomeDisplayExtend); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_HomeDisplayExtend)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;

	THIS->HomeDisplayExtend();
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__StyledTextCtrl_LineEndDisplay); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_LineEndDisplay)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;

	THIS->LineEndDisplay();
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__StyledTextCtrl_LineEndDisplayExtend); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_LineEndDisplayExtend)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;

	THIS->LineEndDisplayExtend();
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__StyledTextCtrl_MoveCaretInsideView); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_MoveCaretInsideView)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;

	THIS->MoveCaretInsideView();
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__StyledTextCtrl_LineLength); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_LineLength)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, line");
    {
	int	line = (int)SvIV(ST(1))
;
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;
	int	RETVAL;
	dXSTARG;

	RETVAL = THIS->LineLength(line);
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__StyledTextCtrl_BraceHighlight); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_BraceHighlight)
{
    dVAR; dXSARGS;
    if (items != 3)
       croak_xs_usage(cv,  "THIS, pos1, pos2");
    {
	int	pos1 = (int)SvIV(ST(1))
;
	int	pos2 = (int)SvIV(ST(2))
;
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;

	THIS->BraceHighlight(pos1, pos2);
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__StyledTextCtrl_BraceBadLight); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_BraceBadLight)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, pos");
    {
	int	pos = (int)SvIV(ST(1))
;
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;

	THIS->BraceBadLight(pos);
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__StyledTextCtrl_BraceMatch); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_BraceMatch)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, pos");
    {
	int	pos = (int)SvIV(ST(1))
;
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;
	int	RETVAL;
	dXSTARG;

	RETVAL = THIS->BraceMatch(pos);
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__StyledTextCtrl_GetViewEOL); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_GetViewEOL)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;
	bool	RETVAL;

	RETVAL = THIS->GetViewEOL();
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__StyledTextCtrl_SetViewEOL); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_SetViewEOL)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, visible");
    {
	bool	visible = (bool)SvTRUE(ST(1))
;
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;

	THIS->SetViewEOL(visible);
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__StyledTextCtrl_GetDocPointer); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_GetDocPointer)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;
	void *	RETVAL;
	dXSTARG;

	RETVAL = THIS->GetDocPointer();
	XSprePUSH;
	PUSHi(PTR2IV(RETVAL));
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__StyledTextCtrl_SetDocPointer); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_SetDocPointer)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, docPointer");
    {
	void*	docPointer = INT2PTR(void *,SvIV(ST(1)))
;
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;

	THIS->SetDocPointer(docPointer);
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__StyledTextCtrl_SetModEventMask); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_SetModEventMask)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, mask");
    {
	int	mask = (int)SvIV(ST(1))
;
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;

	THIS->SetModEventMask(mask);
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__StyledTextCtrl_GetEdgeColumn); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_GetEdgeColumn)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;
	int	RETVAL;
	dXSTARG;

	RETVAL = THIS->GetEdgeColumn();
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__StyledTextCtrl_SetEdgeColumn); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_SetEdgeColumn)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, column");
    {
	int	column = (int)SvIV(ST(1))
;
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;

	THIS->SetEdgeColumn(column);
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__StyledTextCtrl_GetEdgeMode); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_GetEdgeMode)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;
	int	RETVAL;
	dXSTARG;

	RETVAL = THIS->GetEdgeMode();
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__StyledTextCtrl_SetEdgeMode); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_SetEdgeMode)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, mode");
    {
	int	mode = (int)SvIV(ST(1))
;
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;

	THIS->SetEdgeMode(mode);
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__StyledTextCtrl_SetEdgeColour); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_SetEdgeColour)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, edgeColour");
    {
	wxColour    edgeColour = *(wxColour *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::Colour" )
;
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;

	THIS->SetEdgeColour(edgeColour);
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__StyledTextCtrl_SearchAnchor); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_SearchAnchor)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;

	THIS->SearchAnchor();
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__StyledTextCtrl_SearchNext); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_SearchNext)
{
    dVAR; dXSARGS;
    if (items != 3)
       croak_xs_usage(cv,  "THIS, flags, text");
    {
	int	flags = (int)SvIV(ST(1))
;
	wxString	text;
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;
	int	RETVAL;
	dXSTARG;

    WXSTRING_INPUT( text, wxString, ST(2) )
;

	RETVAL = THIS->SearchNext(flags, text);
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__StyledTextCtrl_SearchPrev); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_SearchPrev)
{
    dVAR; dXSARGS;
    if (items != 3)
       croak_xs_usage(cv,  "THIS, flags, text");
    {
	int	flags = (int)SvIV(ST(1))
;
	wxString	text;
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;
	int	RETVAL;
	dXSTARG;

    WXSTRING_INPUT( text, wxString, ST(2) )
;

	RETVAL = THIS->SearchPrev(flags, text);
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__StyledTextCtrl_LinesOnScreen); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_LinesOnScreen)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;
	int	RETVAL;
	dXSTARG;

	RETVAL = THIS->LinesOnScreen();
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__StyledTextCtrl_UsePopUp); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_UsePopUp)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, allowPopUp");
    {
	bool	allowPopUp = (bool)SvTRUE(ST(1))
;
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;

	THIS->UsePopUp(allowPopUp);
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__StyledTextCtrl_SelectionIsRectangle); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_SelectionIsRectangle)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;
	bool	RETVAL;

	RETVAL = THIS->SelectionIsRectangle();
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__StyledTextCtrl_SetZoom); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_SetZoom)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, zoom");
    {
	int	zoom = (int)SvIV(ST(1))
;
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;

	THIS->SetZoom(zoom);
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__StyledTextCtrl_GetZoom); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_GetZoom)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;
	int	RETVAL;
	dXSTARG;

	RETVAL = THIS->GetZoom();
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__StyledTextCtrl_CreateDocument); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_CreateDocument)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;
	void *	RETVAL;
	dXSTARG;

	RETVAL = THIS->CreateDocument();
	XSprePUSH;
	PUSHi(PTR2IV(RETVAL));
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__StyledTextCtrl_AddRefDocument); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_AddRefDocument)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, docPointer");
    {
	void*	docPointer = INT2PTR(void *,SvIV(ST(1)))
;
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;

	THIS->AddRefDocument(docPointer);
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__StyledTextCtrl_ReleaseDocument); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_ReleaseDocument)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, docPointer");
    {
	void*	docPointer = INT2PTR(void *,SvIV(ST(1)))
;
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;

	THIS->ReleaseDocument(docPointer);
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__StyledTextCtrl_GetModEventMask); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_GetModEventMask)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;
	int	RETVAL;
	dXSTARG;

	RETVAL = THIS->GetModEventMask();
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__StyledTextCtrl_SetSTCFocus); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_SetSTCFocus)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, focus");
    {
	bool	focus = (bool)SvTRUE(ST(1))
;
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;

	THIS->SetSTCFocus(focus);
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__StyledTextCtrl_GetSTCFocus); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_GetSTCFocus)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;
	bool	RETVAL;

	RETVAL = THIS->GetSTCFocus();
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__StyledTextCtrl_SetStatus); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_SetStatus)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, statusCode");
    {
	int	statusCode = (int)SvIV(ST(1))
;
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;

	THIS->SetStatus(statusCode);
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__StyledTextCtrl_GetStatus); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_GetStatus)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;
	int	RETVAL;
	dXSTARG;

	RETVAL = THIS->GetStatus();
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__StyledTextCtrl_SetMouseDownCaptures); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_SetMouseDownCaptures)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, captures");
    {
	bool	captures = (bool)SvTRUE(ST(1))
;
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;

	THIS->SetMouseDownCaptures(captures);
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__StyledTextCtrl_GetMouseDownCaptures); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_GetMouseDownCaptures)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;
	bool	RETVAL;

	RETVAL = THIS->GetMouseDownCaptures();
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__StyledTextCtrl_SetControlCharSymbol); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_SetControlCharSymbol)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, symbol");
    {
	int	symbol = (int)SvIV(ST(1))
;
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;

	THIS->SetControlCharSymbol(symbol);
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__StyledTextCtrl_GetControlCharSymbol); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_GetControlCharSymbol)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;
	int	RETVAL;
	dXSTARG;

	RETVAL = THIS->GetControlCharSymbol();
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__StyledTextCtrl_WordPartLeft); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_WordPartLeft)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;

	THIS->WordPartLeft();
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__StyledTextCtrl_WordPartLeftExtend); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_WordPartLeftExtend)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;

	THIS->WordPartLeftExtend();
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__StyledTextCtrl_WordPartRight); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_WordPartRight)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;

	THIS->WordPartRight();
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__StyledTextCtrl_WordPartRightExtend); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_WordPartRightExtend)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;

	THIS->WordPartRightExtend();
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__StyledTextCtrl_SetVisiblePolicy); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_SetVisiblePolicy)
{
    dVAR; dXSARGS;
    if (items != 3)
       croak_xs_usage(cv,  "THIS, visiblePolicy, visibleSlop");
    {
	int	visiblePolicy = (int)SvIV(ST(1))
;
	int	visibleSlop = (int)SvIV(ST(2))
;
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;

	THIS->SetVisiblePolicy(visiblePolicy, visibleSlop);
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__StyledTextCtrl_DelLineLeft); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_DelLineLeft)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;

	THIS->DelLineLeft();
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__StyledTextCtrl_DelLineRight); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_DelLineRight)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;

	THIS->DelLineRight();
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__StyledTextCtrl_SetXOffset); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_SetXOffset)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, newOffset");
    {
	int	newOffset = (int)SvIV(ST(1))
;
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;

	THIS->SetXOffset(newOffset);
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__StyledTextCtrl_GetXOffset); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_GetXOffset)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;
	int	RETVAL;
	dXSTARG;

	RETVAL = THIS->GetXOffset();
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__StyledTextCtrl_SetXCaretPolicy); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_SetXCaretPolicy)
{
    dVAR; dXSARGS;
    if (items != 3)
       croak_xs_usage(cv,  "THIS, caretPolicy, caretSlop");
    {
	int	caretPolicy = (int)SvIV(ST(1))
;
	int	caretSlop = (int)SvIV(ST(2))
;
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;

	THIS->SetXCaretPolicy(caretPolicy, caretSlop);
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__StyledTextCtrl_SetYCaretPolicy); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_SetYCaretPolicy)
{
    dVAR; dXSARGS;
    if (items != 3)
       croak_xs_usage(cv,  "THIS, caretPolicy, caretSlop");
    {
	int	caretPolicy = (int)SvIV(ST(1))
;
	int	caretSlop = (int)SvIV(ST(2))
;
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;

	THIS->SetYCaretPolicy(caretPolicy, caretSlop);
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__StyledTextCtrl_StartRecord); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_StartRecord)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;

	THIS->StartRecord();
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__StyledTextCtrl_StopRecord); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_StopRecord)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;

	THIS->StopRecord();
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__StyledTextCtrl_Colourise); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_Colourise)
{
    dVAR; dXSARGS;
    if (items != 3)
       croak_xs_usage(cv,  "THIS, start, end");
    {
	int	start = (int)SvIV(ST(1))
;
	int	end = (int)SvIV(ST(2))
;
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;

	THIS->Colourise(start, end);
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__StyledTextCtrl_SetProperty); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_SetProperty)
{
    dVAR; dXSARGS;
    if (items != 3)
       croak_xs_usage(cv,  "THIS, key, value");
    {
	wxString	key;
	wxString	value;
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;

    WXSTRING_INPUT( key, wxString, ST(1) )
;

    WXSTRING_INPUT( value, wxString, ST(2) )
;

	THIS->SetProperty(key, value);
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__StyledTextCtrl_SetKeyWords); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_SetKeyWords)
{
    dVAR; dXSARGS;
    if (items != 3)
       croak_xs_usage(cv,  "THIS, keywordSet, keyWords");
    {
	int	keywordSet = (int)SvIV(ST(1))
;
	wxString	keyWords;
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;

    WXSTRING_INPUT( keyWords, wxString, ST(2) )
;

	THIS->SetKeyWords(keywordSet, keyWords);
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__StyledTextCtrl_SetLexerLanguage); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_SetLexerLanguage)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, language");
    {
	wxString	language;
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;

    WXSTRING_INPUT( language, wxString, ST(1) )
;

	THIS->SetLexerLanguage(language);
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__StyledTextCtrl_GetSelectedText); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_GetSelectedText)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;
	wxString	RETVAL;

	RETVAL = THIS->GetSelectedText();
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    WXSTRING_OUTPUT( RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__StyledTextCtrl_GetTextRange); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_GetTextRange)
{
    dVAR; dXSARGS;
    if (items != 3)
       croak_xs_usage(cv,  "THIS, startPos, endPos");
    {
	int	startPos = (int)SvIV(ST(1))
;
	int	endPos = (int)SvIV(ST(2))
;
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;
	wxString	RETVAL;

	RETVAL = THIS->GetTextRange(startPos, endPos);
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    WXSTRING_OUTPUT( RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__StyledTextCtrl_GetText); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_GetText)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;
	wxString	RETVAL;

	RETVAL = THIS->GetText();
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    WXSTRING_OUTPUT( RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__StyledTextCtrl_GetAnchor); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_GetAnchor)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;
	int	RETVAL;
	dXSTARG;

	RETVAL = THIS->GetAnchor();
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__StyledTextCtrl_GetStyleAt); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_GetStyleAt)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, pos");
    {
	int	pos = (int)SvIV(ST(1))
;
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;
	int	RETVAL;
	dXSTARG;

	RETVAL = THIS->GetStyleAt(pos);
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__StyledTextCtrl_Redo); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_Redo)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;

	THIS->Redo();
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__StyledTextCtrl_SelectAll); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_SelectAll)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;

	THIS->SelectAll();
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__StyledTextCtrl_SetSavePoint); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_SetSavePoint)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;

	THIS->SetSavePoint();
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__StyledTextCtrl_SetText); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_SetText)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, text");
    {
	wxString	text;
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;

    WXSTRING_INPUT( text, wxString, ST(1) )
;

	THIS->SetText(text);
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__StyledTextCtrl_CanRedo); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_CanRedo)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;
	bool	RETVAL;

	RETVAL = THIS->CanRedo();
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__StyledTextCtrl_MarkerLineFromHandle); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_MarkerLineFromHandle)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, handle");
    {
	int	handle = (int)SvIV(ST(1))
;
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;
	int	RETVAL;
	dXSTARG;

	RETVAL = THIS->MarkerLineFromHandle(handle);
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__StyledTextCtrl_MarkerDeleteHandle); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_MarkerDeleteHandle)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, handle");
    {
	int	handle = (int)SvIV(ST(1))
;
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;

	THIS->MarkerDeleteHandle(handle);
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__StyledTextCtrl_GetUndoCollection); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_GetUndoCollection)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;
	bool	RETVAL;

	RETVAL = THIS->GetUndoCollection();
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__StyledTextCtrl_GetViewWhiteSpace); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_GetViewWhiteSpace)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;
	int	RETVAL;
	dXSTARG;

	RETVAL = THIS->GetViewWhiteSpace();
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__StyledTextCtrl_SetViewWhiteSpace); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_SetViewWhiteSpace)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, viewWs");
    {
	int	viewWs = (int)SvIV(ST(1))
;
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;

	THIS->SetViewWhiteSpace(viewWs);
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__StyledTextCtrl_PositionFromPoint); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_PositionFromPoint)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, pt");
    {
	wxPoint    pt = wxPli_sv_2_wxpoint( aTHX_ ST(1) )
;
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;
	int	RETVAL;
	dXSTARG;

	RETVAL = THIS->PositionFromPoint(pt);
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__StyledTextCtrl_PositionFromPointClose); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_PositionFromPointClose)
{
    dVAR; dXSARGS;
    if (items != 3)
       croak_xs_usage(cv,  "THIS, x, y");
    {
	int	x = (int)SvIV(ST(1))
;
	int	y = (int)SvIV(ST(2))
;
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;
	int	RETVAL;
	dXSTARG;

	RETVAL = THIS->PositionFromPointClose(x, y);
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__StyledTextCtrl_GotoLine); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_GotoLine)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, line");
    {
	int	line = (int)SvIV(ST(1))
;
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;

	THIS->GotoLine(line);
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__StyledTextCtrl_GotoPos); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_GotoPos)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, pos");
    {
	int	pos = (int)SvIV(ST(1))
;
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;

	THIS->GotoPos(pos);
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__StyledTextCtrl_SetAnchor); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_SetAnchor)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, posAnchor");
    {
	int	posAnchor = (int)SvIV(ST(1))
;
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;

	THIS->SetAnchor(posAnchor);
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__StyledTextCtrl_GetEndStyled); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_GetEndStyled)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;
	int	RETVAL;
	dXSTARG;

	RETVAL = THIS->GetEndStyled();
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__StyledTextCtrl_ConvertEOLs); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_ConvertEOLs)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, eolMode");
    {
	int	eolMode = (int)SvIV(ST(1))
;
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;

	THIS->ConvertEOLs(eolMode);
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__StyledTextCtrl_GetEOLMode); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_GetEOLMode)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;
	int	RETVAL;
	dXSTARG;

	RETVAL = THIS->GetEOLMode();
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__StyledTextCtrl_SetEOLMode); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_SetEOLMode)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, eolMode");
    {
	int	eolMode = (int)SvIV(ST(1))
;
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;

	THIS->SetEOLMode(eolMode);
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__StyledTextCtrl_StartStyling); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_StartStyling)
{
    dVAR; dXSARGS;
    if (items != 3)
       croak_xs_usage(cv,  "THIS, pos, mask");
    {
	int	pos = (int)SvIV(ST(1))
;
	int	mask = (int)SvIV(ST(2))
;
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;

	THIS->StartStyling(pos, mask);
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__StyledTextCtrl_SetStyling); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_SetStyling)
{
    dVAR; dXSARGS;
    if (items != 3)
       croak_xs_usage(cv,  "THIS, length, style");
    {
	int	length = (int)SvIV(ST(1))
;
	int	style = (int)SvIV(ST(2))
;
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;

	THIS->SetStyling(length, style);
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__StyledTextCtrl_GetBufferedDraw); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_GetBufferedDraw)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;
	bool	RETVAL;

	RETVAL = THIS->GetBufferedDraw();
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__StyledTextCtrl_SetBufferedDraw); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_SetBufferedDraw)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, buffered");
    {
	bool	buffered = (bool)SvTRUE(ST(1))
;
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;

	THIS->SetBufferedDraw(buffered);
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__StyledTextCtrl_SetTabWidth); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_SetTabWidth)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, tabWidth");
    {
	int	tabWidth = (int)SvIV(ST(1))
;
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;

	THIS->SetTabWidth(tabWidth);
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__StyledTextCtrl_GetTabWidth); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_GetTabWidth)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;
	int	RETVAL;
	dXSTARG;

	RETVAL = THIS->GetTabWidth();
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__StyledTextCtrl_SetCodePage); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_SetCodePage)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, codePage");
    {
	int	codePage = (int)SvIV(ST(1))
;
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;

	THIS->SetCodePage(codePage);
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__StyledTextCtrl_MarkerDefine); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_MarkerDefine)
{
    dVAR; dXSARGS;
    if (items != 5)
       croak_xs_usage(cv,  "THIS, markerNumber, markerSymbol, foreground, background");
    {
	int	markerNumber = (int)SvIV(ST(1))
;
	int	markerSymbol = (int)SvIV(ST(2))
;
	wxColour*    foreground = (wxColour *) wxPli_sv_2_object( aTHX_ ST(3), "Wx::Colour" )
;
	wxColour*    background = (wxColour *) wxPli_sv_2_object( aTHX_ ST(4), "Wx::Colour" )
;
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;
    THIS->MarkerDefine( markerNumber, markerSymbol, *foreground, *background );
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__StyledTextCtrl_MarkerDefineBitmap); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_MarkerDefineBitmap)
{
    dVAR; dXSARGS;
    if (items != 3)
       croak_xs_usage(cv,  "THIS, markerNumber, bmp");
    {
	int	markerNumber = (int)SvIV(ST(1))
;
	wxBitmap*    bmp = (wxBitmap *) wxPli_sv_2_object( aTHX_ ST(2), "Wx::Bitmap" )
;
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;

	THIS->MarkerDefineBitmap(markerNumber, *bmp);
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__StyledTextCtrl_MarkerSetForeground); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_MarkerSetForeground)
{
    dVAR; dXSARGS;
    if (items != 3)
       croak_xs_usage(cv,  "THIS, markerNumber, fore");
    {
	int	markerNumber = (int)SvIV(ST(1))
;
	wxColour*    fore = (wxColour *) wxPli_sv_2_object( aTHX_ ST(2), "Wx::Colour" )
;
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;
    THIS->MarkerSetForeground( markerNumber, *fore );
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__StyledTextCtrl_MarkerSetBackground); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_MarkerSetBackground)
{
    dVAR; dXSARGS;
    if (items != 3)
       croak_xs_usage(cv,  "THIS, markerNumber, back");
    {
	int	markerNumber = (int)SvIV(ST(1))
;
	wxColour*    back = (wxColour *) wxPli_sv_2_object( aTHX_ ST(2), "Wx::Colour" )
;
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;
    THIS->MarkerSetBackground( markerNumber, *back );
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__StyledTextCtrl_MarkerAdd); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_MarkerAdd)
{
    dVAR; dXSARGS;
    if (items != 3)
       croak_xs_usage(cv,  "THIS, line, markerNumber");
    {
	int	line = (int)SvIV(ST(1))
;
	int	markerNumber = (int)SvIV(ST(2))
;
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;
	int	RETVAL;
	dXSTARG;

	RETVAL = THIS->MarkerAdd(line, markerNumber);
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__StyledTextCtrl_MarkerDelete); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_MarkerDelete)
{
    dVAR; dXSARGS;
    if (items != 3)
       croak_xs_usage(cv,  "THIS, line, markerNumber");
    {
	int	line = (int)SvIV(ST(1))
;
	int	markerNumber = (int)SvIV(ST(2))
;
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;

	THIS->MarkerDelete(line, markerNumber);
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__StyledTextCtrl_MarkerDeleteAll); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_MarkerDeleteAll)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, markerNumber");
    {
	int	markerNumber = (int)SvIV(ST(1))
;
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;

	THIS->MarkerDeleteAll(markerNumber);
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__StyledTextCtrl_MarkerGet); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_MarkerGet)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, line");
    {
	int	line = (int)SvIV(ST(1))
;
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;
	int	RETVAL;
	dXSTARG;

	RETVAL = THIS->MarkerGet(line);
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__StyledTextCtrl_MarkerNext); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_MarkerNext)
{
    dVAR; dXSARGS;
    if (items != 3)
       croak_xs_usage(cv,  "THIS, lineStart, markerMask");
    {
	int	lineStart = (int)SvIV(ST(1))
;
	int	markerMask = (int)SvIV(ST(2))
;
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;
	int	RETVAL;
	dXSTARG;

	RETVAL = THIS->MarkerNext(lineStart, markerMask);
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__StyledTextCtrl_MarkerPrevious); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_MarkerPrevious)
{
    dVAR; dXSARGS;
    if (items != 3)
       croak_xs_usage(cv,  "THIS, lineStart, markerMask");
    {
	int	lineStart = (int)SvIV(ST(1))
;
	int	markerMask = (int)SvIV(ST(2))
;
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;
	int	RETVAL;
	dXSTARG;

	RETVAL = THIS->MarkerPrevious(lineStart, markerMask);
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__StyledTextCtrl_SetMarginType); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_SetMarginType)
{
    dVAR; dXSARGS;
    if (items != 3)
       croak_xs_usage(cv,  "THIS, margin, marginType");
    {
	int	margin = (int)SvIV(ST(1))
;
	int	marginType = (int)SvIV(ST(2))
;
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;

	THIS->SetMarginType(margin, marginType);
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__StyledTextCtrl_GetMarginType); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_GetMarginType)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, margin");
    {
	int	margin = (int)SvIV(ST(1))
;
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;
	int	RETVAL;
	dXSTARG;

	RETVAL = THIS->GetMarginType(margin);
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__StyledTextCtrl_SetMarginWidth); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_SetMarginWidth)
{
    dVAR; dXSARGS;
    if (items != 3)
       croak_xs_usage(cv,  "THIS, margin, pixelWidth");
    {
	int	margin = (int)SvIV(ST(1))
;
	int	pixelWidth = (int)SvIV(ST(2))
;
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;

	THIS->SetMarginWidth(margin, pixelWidth);
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__StyledTextCtrl_GetMarginWidth); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_GetMarginWidth)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, margin");
    {
	int	margin = (int)SvIV(ST(1))
;
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;
	int	RETVAL;
	dXSTARG;

	RETVAL = THIS->GetMarginWidth(margin);
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__StyledTextCtrl_SetMarginMask); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_SetMarginMask)
{
    dVAR; dXSARGS;
    if (items != 3)
       croak_xs_usage(cv,  "THIS, margin, mask");
    {
	int	margin = (int)SvIV(ST(1))
;
	int	mask = (int)SvIV(ST(2))
;
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;

	THIS->SetMarginMask(margin, mask);
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__StyledTextCtrl_GetMarginMask); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_GetMarginMask)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, margin");
    {
	int	margin = (int)SvIV(ST(1))
;
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;
	int	RETVAL;
	dXSTARG;

	RETVAL = THIS->GetMarginMask(margin);
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__StyledTextCtrl_SetMarginSensitive); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_SetMarginSensitive)
{
    dVAR; dXSARGS;
    if (items != 3)
       croak_xs_usage(cv,  "THIS, margin, sensitive");
    {
	int	margin = (int)SvIV(ST(1))
;
	bool	sensitive = (bool)SvTRUE(ST(2))
;
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;

	THIS->SetMarginSensitive(margin, sensitive);
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__StyledTextCtrl_GetMarginSensitive); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_GetMarginSensitive)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, margin");
    {
	int	margin = (int)SvIV(ST(1))
;
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;
	bool	RETVAL;

	RETVAL = THIS->GetMarginSensitive(margin);
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__StyledTextCtrl_GetCurrentPos); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_GetCurrentPos)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;
	int	RETVAL;
	dXSTARG;

	RETVAL = THIS->GetCurrentPos();
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__StyledTextCtrl_GetLength); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_GetLength)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;
	int	RETVAL;
	dXSTARG;

	RETVAL = THIS->GetLength();
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__StyledTextCtrl_GetCharAt); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_GetCharAt)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, pos");
    {
	int	pos = (int)SvIV(ST(1))
;
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;
	int	RETVAL;
	dXSTARG;

	RETVAL = THIS->GetCharAt(pos);
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__StyledTextCtrl_SetWrapMode); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_SetWrapMode)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, mode");
    {
	int	mode = (int)SvIV(ST(1))
;
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;

	THIS->SetWrapMode(mode);
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__StyledTextCtrl_GetWrapMode); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_GetWrapMode)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;
	int	RETVAL;
	dXSTARG;

	RETVAL = THIS->GetWrapMode();
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__StyledTextCtrl_GetLine); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_GetLine)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, line");
    {
	int	line = (int)SvIV(ST(1))
;
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;
	wxString	RETVAL;

	RETVAL = THIS->GetLine(line);
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    WXSTRING_OUTPUT( RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__StyledTextCtrl_ClearAll); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_ClearAll)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;

	THIS->ClearAll();
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__StyledTextCtrl_GetCurrentLine); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_GetCurrentLine)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;
	int	RETVAL;
	dXSTARG;

	RETVAL = THIS->GetCurrentLine();
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__StyledTextCtrl_CmdKeyExecute); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_CmdKeyExecute)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, cmd");
    {
	int	cmd = (int)SvIV(ST(1))
;
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;

	THIS->CmdKeyExecute(cmd);
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__StyledTextCtrl_SetMargins); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_SetMargins)
{
    dVAR; dXSARGS;
    if (items != 3)
       croak_xs_usage(cv,  "THIS, left, right");
    {
	int	left = (int)SvIV(ST(1))
;
	int	right = (int)SvIV(ST(2))
;
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;

	THIS->SetMargins(left, right);
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__StyledTextCtrl_SetUndoCollection); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_SetUndoCollection)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, collectUndo");
    {
	bool	collectUndo = (bool)SvTRUE(ST(1))
;
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;

	THIS->SetUndoCollection(collectUndo);
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__StyledTextCtrl_IndicatorGetForeground); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_IndicatorGetForeground)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, indic");
    {
	int	indic = (int)SvIV(ST(1))
;
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;
	wxColour *	RETVAL;
    RETVAL = new wxColour( THIS->IndicatorGetForeground( indic ) );
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_non_object_2_sv( aTHX_ RETVALSV, RETVAL, "Wx::Colour" );
    wxPli_thread_sv_register( aTHX_ "Wx::Colour", RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}

#if WXPERL_W_VERSION_LT( 2, 7, 0 )
#define XSubPPtmpAAAD 1


XS_EUPXS(XS_Wx__StyledTextCtrl_GetCaretLineBack); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_GetCaretLineBack)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;
	wxColour *	RETVAL;
    RETVAL = new wxColour( THIS->GetCaretLineBack() );
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_non_object_2_sv( aTHX_ RETVALSV, RETVAL, "Wx::Colour" );
    wxPli_thread_sv_register( aTHX_ "Wx::Colour", RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}

#endif

XS_EUPXS(XS_Wx__StyledTextCtrl_GetCaretForeground); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_GetCaretForeground)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;
	wxColour *	RETVAL;
    RETVAL = new wxColour( THIS->GetCaretForeground() );
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_non_object_2_sv( aTHX_ RETVALSV, RETVAL, "Wx::Colour" );
    wxPli_thread_sv_register( aTHX_ "Wx::Colour", RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__StyledTextCtrl_FormatRange); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_FormatRange)
{
    dVAR; dXSARGS;
    if (items != 8)
       croak_xs_usage(cv,  "THIS, doDraw, startPos, endPos, draw, target, renderRect, pageRect");
    {
	bool	doDraw = (bool)SvTRUE(ST(1))
;
	int	startPos = (int)SvIV(ST(2))
;
	int	endPos = (int)SvIV(ST(3))
;
	wxDC*    draw = (wxDC *) wxPli_sv_2_object( aTHX_ ST(4), "Wx::DC" )
;
	wxDC*    target = (wxDC *) wxPli_sv_2_object( aTHX_ ST(5), "Wx::DC" )
;
	wxRect*    renderRect = (wxRect *) wxPli_sv_2_object( aTHX_ ST(6), "Wx::Rect" )
;
	wxRect*    pageRect = (wxRect *) wxPli_sv_2_object( aTHX_ ST(7), "Wx::Rect" )
;
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;
	int	RETVAL;
	dXSTARG;
    RETVAL = THIS->FormatRange( doDraw, startPos, endPos, draw,
                                target, *renderRect, *pageRect );
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__StyledTextCtrl_GetEdgeColour); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_GetEdgeColour)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;
	wxColour *	RETVAL;
    RETVAL = new wxColour( THIS->GetEdgeColour() );
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_non_object_2_sv( aTHX_ RETVALSV, RETVAL, "Wx::Colour" );
    wxPli_thread_sv_register( aTHX_ "Wx::Colour", RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__StyledTextCtrl_GetLastKeydownProcessed); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_GetLastKeydownProcessed)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;
	bool	RETVAL;

	RETVAL = THIS->GetLastKeydownProcessed();
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__StyledTextCtrl_SetLastKeydownProcessed); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_SetLastKeydownProcessed)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, val");
    {
	bool	val = (bool)SvTRUE(ST(1))
;
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;

	THIS->SetLastKeydownProcessed(val);
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__StyledTextCtrl_PointFromPosition); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_PointFromPosition)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, pos");
    {
	int	pos = (int)SvIV(ST(1))
;
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;
	wxPoint *	RETVAL;
    RETVAL = new wxPoint( THIS->PointFromPosition( pos ) );
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_non_object_2_sv( aTHX_ RETVALSV, RETVAL, "Wx::Point" );
    wxPli_thread_sv_register( aTHX_ "Wx::Point", RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__StyledTextCtrl_ScrollToLine); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_ScrollToLine)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, line");
    {
	int	line = (int)SvIV(ST(1))
;
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;

	THIS->ScrollToLine(line);
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__StyledTextCtrl_SetHScrollBar); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_SetHScrollBar)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, bar");
    {
	wxScrollBar*    bar = (wxScrollBar *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::ScrollBar" )
;
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;

	THIS->SetHScrollBar(bar);
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__StyledTextCtrl_SetVScrollBar); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_SetVScrollBar)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, bar");
    {
	wxScrollBar*    bar = (wxScrollBar *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::ScrollBar" )
;
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;

	THIS->SetVScrollBar(bar);
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__StyledTextCtrl_GetSelection); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_GetSelection)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    PERL_UNUSED_VAR(ax); /* -Wall */
    SP -= items;
    {
    int start, end;
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;
    THIS->GetSelection( &start, &end );
    XPUSHs( newSViv( start ) );
    XPUSHs( newSViv( end ) );
	PUTBACK;
	return;
    }
}


XS_EUPXS(XS_Wx__StyledTextCtrl_SaveFile); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_SaveFile)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, filename");
    {
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;
	bool	RETVAL;
	wxString	filename;

    WXSTRING_INPUT( filename, wxString, ST(1) )
;

	RETVAL = THIS->SaveFile(filename);
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__StyledTextCtrl_LoadFile); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_LoadFile)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, filename");
    {
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;
	bool	RETVAL;
	wxString	filename;

    WXSTRING_INPUT( filename, wxString, ST(1) )
;

	RETVAL = THIS->LoadFile(filename);
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}

#if WXPERL_W_VERSION_GE( 2, 6, 0 ) && WXPERL_W_VERSION_LT( 2, 9, 4 )
#define XSubPPtmpAAAE 1


XS_EUPXS(XS_Wx__StyledTextCtrl_AddTextRaw); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_AddTextRaw)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, text");
    {
	const char*	text = wxUSE_UNICODE ? SvPVutf8( ST(1), PL_na ) : SvPV( ST(1), PL_na );
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;

	THIS->AddTextRaw(text);
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__StyledTextCtrl_InsertTextRaw); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_InsertTextRaw)
{
    dVAR; dXSARGS;
    if (items != 3)
       croak_xs_usage(cv,  "THIS, pos, text");
    {
	int	pos = (int)SvIV(ST(1))
;
	const char*	text = wxUSE_UNICODE ? SvPVutf8( ST(2), PL_na ) : SvPV( ST(2), PL_na );
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;

	THIS->InsertTextRaw(pos, text);
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__StyledTextCtrl_AppendTextRaw); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_AppendTextRaw)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, text");
    {
	const char*	text = wxUSE_UNICODE ? SvPVutf8( ST(1), PL_na ) : SvPV( ST(1), PL_na );
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;

	THIS->AppendTextRaw(text);
    }
    XSRETURN_EMPTY;
}

#endif
#if WXPERL_W_VERSION_GE( 2, 9, 4 )
#define XSubPPtmpAAAF 1


XS_EUPXS(XS_Wx__StyledTextCtrl_AddTextRaw); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_AddTextRaw)
{
    dVAR; dXSARGS;
    if (items < 2 || items > 3)
       croak_xs_usage(cv,  "THIS, text, length = -1");
    {
	const char*	text = SvPVutf8( ST(1), PL_na );
	int	length;
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;

	if (items < 3)
	    length = -1;
	else {
	    length = (int)SvIV(ST(2))
;
	}

	THIS->AddTextRaw(text, length);
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__StyledTextCtrl_InsertTextRaw); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_InsertTextRaw)
{
    dVAR; dXSARGS;
    if (items != 3)
       croak_xs_usage(cv,  "THIS, pos, text");
    {
	int	pos = (int)SvIV(ST(1))
;
	const char*	text = SvPVutf8( ST(2), PL_na );
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;

	THIS->InsertTextRaw(pos, text);
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__StyledTextCtrl_AppendTextRaw); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_AppendTextRaw)
{
    dVAR; dXSARGS;
    if (items < 2 || items > 3)
       croak_xs_usage(cv,  "THIS, text, length = -1");
    {
	const char*	text = SvPVutf8( ST(1), PL_na );
	int	length;
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;

	if (items < 3)
	    length = -1;
	else {
	    length = (int)SvIV(ST(2))
;
	}

	THIS->AppendTextRaw(text, length);
    }
    XSRETURN_EMPTY;
}

#endif

XS_EUPXS(XS_Wx__StyledTextCtrl_Allocate); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_Allocate)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, bytes");
    {
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;
	int	bytes = (int)SvIV(ST(1))
;
    try {
      THIS->Allocate( bytes );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}

#if WXPERL_W_VERSION_GE( 2, 6, 0 )
#define XSpp_9ec081f4_029689
#define XSubPPtmpAAAG 1


XS_EUPXS(XS_Wx__StyledTextCtrl_AppendText); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_AppendText)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, text");
    {
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;
	wxString	text;

    WXSTRING_INPUT( text, wxString, ST(1) )
;
    try {
      THIS->AppendText( text );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}

#endif

XS_EUPXS(XS_Wx__StyledTextCtrl_AutoCompGetCurrent); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_AutoCompGetCurrent)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;
	int	RETVAL;
	dXSTARG;
    try {
      RETVAL = THIS->AutoCompGetCurrent();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__StyledTextCtrl_AutoCompGetTypeSeparator); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_AutoCompGetTypeSeparator)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;
	int	RETVAL;
	dXSTARG;
    try {
      RETVAL = THIS->AutoCompGetTypeSeparator();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__StyledTextCtrl_AutoCompSetTypeSeparator); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_AutoCompSetTypeSeparator)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, separatorCharacter");
    {
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;
	int	separatorCharacter = (int)SvIV(ST(1))
;
    try {
      THIS->AutoCompSetTypeSeparator( separatorCharacter );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}

#if WXPERL_W_VERSION_GE( 2, 7, 2 )
#define XSpp_9ec081f4_068240
#define XSubPPtmpAAAH 1


XS_EUPXS(XS_Wx__StyledTextCtrl_AutoCompSetMaxWidth); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_AutoCompSetMaxWidth)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, characterCount");
    {
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;
	int	characterCount = (int)SvIV(ST(1))
;
    try {
      THIS->AutoCompSetMaxWidth( characterCount );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__StyledTextCtrl_AutoCompGetMaxWidth); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_AutoCompGetMaxWidth)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;
	int	RETVAL;
	dXSTARG;
    try {
      RETVAL = THIS->AutoCompGetMaxWidth();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__StyledTextCtrl_AutoCompSetMaxHeight); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_AutoCompSetMaxHeight)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, rowCount");
    {
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;
	int	rowCount = (int)SvIV(ST(1))
;
    try {
      THIS->AutoCompSetMaxHeight( rowCount );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__StyledTextCtrl_AutoCompGetMaxHeight); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_AutoCompGetMaxHeight)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;
	int	RETVAL;
	dXSTARG;
    try {
      RETVAL = THIS->AutoCompGetMaxHeight();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}

#endif

XS_EUPXS(XS_Wx__StyledTextCtrl_AutoCompSetIgnoreCase); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_AutoCompSetIgnoreCase)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, ignoreCase");
    {
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;
	bool	ignoreCase = (bool)SvTRUE(ST(1))
;
    try {
      THIS->AutoCompSetIgnoreCase( ignoreCase );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__StyledTextCtrl_BackTab); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_BackTab)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;
    try {
      THIS->BackTab();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__StyledTextCtrl_CallTipSetForeground); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_CallTipSetForeground)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, fore");
    {
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;
	wxColour*    fore = (wxColour *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::Colour" )
;
    try {
      THIS->CallTipSetForeground( *( fore ) );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__StyledTextCtrl_CallTipSetForegroundHighlight); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_CallTipSetForegroundHighlight)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, fore");
    {
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;
	wxColour*    fore = (wxColour *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::Colour" )
;
    try {
      THIS->CallTipSetForegroundHighlight( *( fore ) );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}

#if WXPERL_W_VERSION_GE( 2, 7, 2 )
#define XSpp_9ec081f4_002394
#define XSubPPtmpAAAI 1


XS_EUPXS(XS_Wx__StyledTextCtrl_CallTipUseStyle); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_CallTipUseStyle)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, tabSize");
    {
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;
	int	tabSize = (int)SvIV(ST(1))
;
    try {
      THIS->CallTipUseStyle( tabSize );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}

#endif

XS_EUPXS(XS_Wx__StyledTextCtrl_Cancel); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_Cancel)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;
    try {
      THIS->Cancel();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__StyledTextCtrl_CharLeft); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_CharLeft)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;
    try {
      THIS->CharLeft();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__StyledTextCtrl_CharLeftExtend); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_CharLeftExtend)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;
    try {
      THIS->CharLeftExtend();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__StyledTextCtrl_CharRight); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_CharRight)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;
    try {
      THIS->CharRight();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__StyledTextCtrl_CharRightExtend); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_CharRightExtend)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;
    try {
      THIS->CharRightExtend();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__StyledTextCtrl_CharLeftRectExtend); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_CharLeftRectExtend)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;
    try {
      THIS->CharLeftRectExtend();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__StyledTextCtrl_CharRightRectExtend); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_CharRightRectExtend)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;
    try {
      THIS->CharRightRectExtend();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__StyledTextCtrl_ChooseCaretX); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_ChooseCaretX)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;
    try {
      THIS->ChooseCaretX();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__StyledTextCtrl_ClearRegisteredImages); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_ClearRegisteredImages)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;
    try {
      THIS->ClearRegisteredImages();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__StyledTextCtrl_CopyRange); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_CopyRange)
{
    dVAR; dXSARGS;
    if (items != 3)
       croak_xs_usage(cv,  "THIS, start, end");
    {
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;
	int	start = (int)SvIV(ST(1))
;
	int	end = (int)SvIV(ST(2))
;
    try {
      THIS->CopyRange( start, end );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__StyledTextCtrl_CopyText); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_CopyText)
{
    dVAR; dXSARGS;
    if (items != 3)
       croak_xs_usage(cv,  "THIS, length, text");
    {
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;
	int	length = (int)SvIV(ST(1))
;
	wxString	text;

    WXSTRING_INPUT( text, wxString, ST(2) )
;
    try {
      THIS->CopyText( length, text );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__StyledTextCtrl_DelWordLeft); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_DelWordLeft)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;
    try {
      THIS->DelWordLeft();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__StyledTextCtrl_DelWordRight); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_DelWordRight)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;
    try {
      THIS->DelWordRight();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__StyledTextCtrl_DeleteBack); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_DeleteBack)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;
    try {
      THIS->DeleteBack();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__StyledTextCtrl_DeleteBackNotLine); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_DeleteBackNotLine)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;
    try {
      THIS->DeleteBackNotLine();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}

#if wxUSE_DRAG_AND_DROP
#define XSpp_9ec081f4_032459
#define XSubPPtmpAAAJ 1


XS_EUPXS(XS_Wx__StyledTextCtrl_DoDragOver); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_DoDragOver)
{
    dVAR; dXSARGS;
    if (items != 4)
       croak_xs_usage(cv,  "THIS, x, y, def");
    {
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;
	wxDragResult	RETVAL;
	dXSTARG;
	wxCoord	x = (wxCoord)SvIV(ST(1))
;
	wxCoord	y = (wxCoord)SvIV(ST(2))
;
	wxDragResult	def = (wxDragResult)SvIV(ST(3))
;
    try {
      RETVAL = THIS->DoDragOver( x, y, def );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__StyledTextCtrl_DoDropText); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_DoDropText)
{
    dVAR; dXSARGS;
    if (items != 4)
       croak_xs_usage(cv,  "THIS, x, y, data");
    {
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;
	bool	RETVAL;
	long	x = (long)SvIV(ST(1))
;
	long	y = (long)SvIV(ST(2))
;
	wxString	data;

    WXSTRING_INPUT( data, wxString, ST(3) )
;
    try {
      RETVAL = THIS->DoDropText( x, y, data );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}

#endif

XS_EUPXS(XS_Wx__StyledTextCtrl_DocumentStart); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_DocumentStart)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;
    try {
      THIS->DocumentStart();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__StyledTextCtrl_DocumentStartExtend); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_DocumentStartExtend)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;
    try {
      THIS->DocumentStartExtend();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__StyledTextCtrl_DocumentEnd); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_DocumentEnd)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;
    try {
      THIS->DocumentEnd();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__StyledTextCtrl_DocumentEndExtend); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_DocumentEndExtend)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;
    try {
      THIS->DocumentEndExtend();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__StyledTextCtrl_EditToggleOvertype); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_EditToggleOvertype)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;
    try {
      THIS->EditToggleOvertype();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}

#if WXPERL_W_VERSION_GE( 2, 6, 0 )
#define XSpp_9ec081f4_055666
#define XSubPPtmpAAAK 1


XS_EUPXS(XS_Wx__StyledTextCtrl_FindColumn); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_FindColumn)
{
    dVAR; dXSARGS;
    if (items != 3)
       croak_xs_usage(cv,  "THIS, line, column");
    {
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;
	int	RETVAL;
	dXSTARG;
	int	line = (int)SvIV(ST(1))
;
	int	column = (int)SvIV(ST(2))
;
    try {
      RETVAL = THIS->FindColumn( line, column );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}

#endif

XS_EUPXS(XS_Wx__StyledTextCtrl_FormFeed); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_FormFeed)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;
    try {
      THIS->FormFeed();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}

#if WXPERL_W_VERSION_GE( 2, 7, 2 )
#define XSpp_9ec081f4_020161
#define XSubPPtmpAAAL 1


XS_EUPXS(XS_Wx__StyledTextCtrl_SetCaretLineBackAlpha); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_SetCaretLineBackAlpha)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, alpha");
    {
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;
	int	alpha = (int)SvIV(ST(1))
;
    try {
      THIS->SetCaretLineBackAlpha( alpha );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__StyledTextCtrl_GetCaretLineBackAlpha); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_GetCaretLineBackAlpha)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;
	int	RETVAL;
	dXSTARG;
    try {
      RETVAL = THIS->GetCaretLineBackAlpha();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__StyledTextCtrl_GetCaretLineBackground); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_GetCaretLineBackground)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;
	wxColour *	RETVAL;
    try {
      RETVAL = new wxColour( THIS->GetCaretLineBackground() );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_non_object_2_sv( aTHX_ RETVALSV, RETVAL, "Wx::Colour" );
    wxPli_thread_sv_register( aTHX_ "Wx::Colour", RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__StyledTextCtrl_GetCaretSticky); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_GetCaretSticky)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;
	bool	RETVAL;
    try {
      RETVAL = THIS->GetCaretSticky();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__StyledTextCtrl_SetCaretSticky); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_SetCaretSticky)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, useCaretStickyBehaviour");
    {
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;
	bool	useCaretStickyBehaviour = (bool)SvTRUE(ST(1))
;
    try {
      THIS->SetCaretSticky( useCaretStickyBehaviour );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__StyledTextCtrl_ToggleCaretSticky); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_ToggleCaretSticky)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;
    try {
      THIS->ToggleCaretSticky();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}

#endif

XS_EUPXS(XS_Wx__StyledTextCtrl_GetLineSelStartPosition); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_GetLineSelStartPosition)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, line");
    {
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;
	int	RETVAL;
	dXSTARG;
	int	line = (int)SvIV(ST(1))
;
    try {
      RETVAL = THIS->GetLineSelStartPosition( line );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__StyledTextCtrl_GetLineSelEndPosition); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_GetLineSelEndPosition)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, line");
    {
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;
	int	RETVAL;
	dXSTARG;
	int	line = (int)SvIV(ST(1))
;
    try {
      RETVAL = THIS->GetLineSelEndPosition( line );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}

#if WXPERL_W_VERSION_GE( 2, 7, 2 )
#define XSpp_9ec081f4_038980
#define XSubPPtmpAAAM 1


XS_EUPXS(XS_Wx__StyledTextCtrl_SetPasteConvertEndings); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_SetPasteConvertEndings)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, convert");
    {
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;
	bool	convert = (bool)SvTRUE(ST(1))
;
    try {
      THIS->SetPasteConvertEndings( convert );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__StyledTextCtrl_GetPasteConvertEndings); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_GetPasteConvertEndings)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;
	bool	RETVAL;
    try {
      RETVAL = THIS->GetPasteConvertEndings();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}

#endif

XS_EUPXS(XS_Wx__StyledTextCtrl_SetPrintWrapMode); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_SetPrintWrapMode)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, mode");
    {
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;
	int	mode = (int)SvIV(ST(1))
;
    try {
      THIS->SetPrintWrapMode( mode );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__StyledTextCtrl_GetPrintWrapMode); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_GetPrintWrapMode)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;
	int	RETVAL;
	dXSTARG;
    try {
      RETVAL = THIS->GetPrintWrapMode();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}

#if WXPERL_W_VERSION_GE( 2, 7, 2 )
#define XSpp_9ec081f4_005411
#define XSubPPtmpAAAN 1


XS_EUPXS(XS_Wx__StyledTextCtrl_GetProperty); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_GetProperty)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, key");
    {
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;
	wxString	RETVAL;
	wxString	key;

    WXSTRING_INPUT( key, wxString, ST(1) )
;
    try {
      RETVAL = THIS->GetProperty( key );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    WXSTRING_OUTPUT( RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__StyledTextCtrl_GetPropertyExpanded); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_GetPropertyExpanded)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, key");
    {
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;
	wxString	RETVAL;
	wxString	key;

    WXSTRING_INPUT( key, wxString, ST(1) )
;
    try {
      RETVAL = THIS->GetPropertyExpanded( key );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    WXSTRING_OUTPUT( RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__StyledTextCtrl_GetPropertyInt); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_GetPropertyInt)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, key");
    {
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;
	int	RETVAL;
	dXSTARG;
	wxString	key;

    WXSTRING_INPUT( key, wxString, ST(1) )
;
    try {
      RETVAL = THIS->GetPropertyInt( key );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}

#endif

XS_EUPXS(XS_Wx__StyledTextCtrl_GetSTCCursor); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_GetSTCCursor)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;
	int	RETVAL;
	dXSTARG;
    try {
      RETVAL = THIS->GetSTCCursor();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__StyledTextCtrl_SetSTCCursor); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_SetSTCCursor)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, cursorType");
    {
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;
	int	cursorType = (int)SvIV(ST(1))
;
    try {
      THIS->SetSTCCursor( cursorType );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}

#if WXPERL_W_VERSION_GE( 2, 7, 2 )
#define XSpp_9ec081f4_028273
#define XSubPPtmpAAAO 1


XS_EUPXS(XS_Wx__StyledTextCtrl_GetSelAlpha); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_GetSelAlpha)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;
	int	RETVAL;
	dXSTARG;
    try {
      RETVAL = THIS->GetSelAlpha();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__StyledTextCtrl_SetSelAlpha); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_SetSelAlpha)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, alpha");
    {
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;
	int	alpha = (int)SvIV(ST(1))
;
    try {
      THIS->SetSelAlpha( alpha );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__StyledTextCtrl_GetStyleBitsNeeded); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_GetStyleBitsNeeded)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;
	int	RETVAL;
	dXSTARG;
    try {
      RETVAL = THIS->GetStyleBitsNeeded();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}

#endif

XS_EUPXS(XS_Wx__StyledTextCtrl_GetTwoPhaseDraw); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_GetTwoPhaseDraw)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;
	bool	RETVAL;
    try {
      RETVAL = THIS->GetTwoPhaseDraw();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__StyledTextCtrl_SetTwoPhaseDraw); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_SetTwoPhaseDraw)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, twoPhase");
    {
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;
	bool	twoPhase = (bool)SvTRUE(ST(1))
;
    try {
      THIS->SetTwoPhaseDraw( twoPhase );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__StyledTextCtrl_SetUseAntiAliasing); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_SetUseAntiAliasing)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, useAA");
    {
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;
	bool	useAA = (bool)SvTRUE(ST(1))
;
    try {
      THIS->SetUseAntiAliasing( useAA );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__StyledTextCtrl_GetUseAntiAliasing); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_GetUseAntiAliasing)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;
	bool	RETVAL;
    try {
      RETVAL = THIS->GetUseAntiAliasing();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__StyledTextCtrl_SetUseVerticalScrollBar); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_SetUseVerticalScrollBar)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, show");
    {
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;
	bool	show = (bool)SvTRUE(ST(1))
;
    try {
      THIS->SetUseVerticalScrollBar( show );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__StyledTextCtrl_GetUseVerticalScrollBar); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_GetUseVerticalScrollBar)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;
	bool	RETVAL;
    try {
      RETVAL = THIS->GetUseVerticalScrollBar();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__StyledTextCtrl_SetWrapVisualFlags); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_SetWrapVisualFlags)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, wrapVisualFlags");
    {
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;
	int	wrapVisualFlags = (int)SvIV(ST(1))
;
    try {
      THIS->SetWrapVisualFlags( wrapVisualFlags );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__StyledTextCtrl_GetWrapVisualFlags); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_GetWrapVisualFlags)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;
	int	RETVAL;
	dXSTARG;
    try {
      RETVAL = THIS->GetWrapVisualFlags();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__StyledTextCtrl_SetWrapVisualFlagsLocation); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_SetWrapVisualFlagsLocation)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, wrapVisualFlagsLocation");
    {
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;
	int	wrapVisualFlagsLocation = (int)SvIV(ST(1))
;
    try {
      THIS->SetWrapVisualFlagsLocation( wrapVisualFlagsLocation );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__StyledTextCtrl_GetWrapVisualFlagsLocation); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_GetWrapVisualFlagsLocation)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;
	int	RETVAL;
	dXSTARG;
    try {
      RETVAL = THIS->GetWrapVisualFlagsLocation();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__StyledTextCtrl_SetWrapStartIndent); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_SetWrapStartIndent)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, indent");
    {
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;
	int	indent = (int)SvIV(ST(1))
;
    try {
      THIS->SetWrapStartIndent( indent );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__StyledTextCtrl_GetWrapStartIndent); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_GetWrapStartIndent)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;
	int	RETVAL;
	dXSTARG;
    try {
      RETVAL = THIS->GetWrapStartIndent();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__StyledTextCtrl_Home); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_Home)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;
    try {
      THIS->Home();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__StyledTextCtrl_HomeExtend); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_HomeExtend)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;
    try {
      THIS->HomeExtend();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__StyledTextCtrl_HomeRectExtend); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_HomeRectExtend)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;
    try {
      THIS->HomeRectExtend();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__StyledTextCtrl_HomeWrap); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_HomeWrap)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;
    try {
      THIS->HomeWrap();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__StyledTextCtrl_HomeWrapExtend); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_HomeWrapExtend)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;
    try {
      THIS->HomeWrapExtend();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__StyledTextCtrl_LineCopy); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_LineCopy)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;
    try {
      THIS->LineCopy();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__StyledTextCtrl_LineCut); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_LineCut)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;
    try {
      THIS->LineCut();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__StyledTextCtrl_LineDelete); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_LineDelete)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;
    try {
      THIS->LineDelete();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__StyledTextCtrl_LineDownExtend); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_LineDownExtend)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;
    try {
      THIS->LineDownExtend();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__StyledTextCtrl_LineDownRectExtend); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_LineDownRectExtend)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;
    try {
      THIS->LineDownRectExtend();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__StyledTextCtrl_LineDuplicate); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_LineDuplicate)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;
    try {
      THIS->LineDuplicate();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__StyledTextCtrl_LineEnd); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_LineEnd)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;
    try {
      THIS->LineEnd();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__StyledTextCtrl_LineEndExtend); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_LineEndExtend)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;
    try {
      THIS->LineEndExtend();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__StyledTextCtrl_LineEndRectExtend); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_LineEndRectExtend)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;
    try {
      THIS->LineEndRectExtend();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__StyledTextCtrl_LineEndWrap); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_LineEndWrap)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;
    try {
      THIS->LineEndWrap();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__StyledTextCtrl_LineEndWrapExtend); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_LineEndWrapExtend)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;
    try {
      THIS->LineEndWrapExtend();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__StyledTextCtrl_LineScrollDown); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_LineScrollDown)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;
    try {
      THIS->LineScrollDown();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__StyledTextCtrl_LineScrollUp); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_LineScrollUp)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;
    try {
      THIS->LineScrollUp();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__StyledTextCtrl_LineTranspose); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_LineTranspose)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;
    try {
      THIS->LineTranspose();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__StyledTextCtrl_LineUpExtend); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_LineUpExtend)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;
    try {
      THIS->LineUpExtend();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__StyledTextCtrl_LineUpRectExtend); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_LineUpRectExtend)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;
    try {
      THIS->LineUpRectExtend();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__StyledTextCtrl_LineUp); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_LineUp)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;
    try {
      THIS->LineUp();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__StyledTextCtrl_LineDown); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_LineDown)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;
    try {
      THIS->LineDown();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__StyledTextCtrl_LinesJoin); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_LinesJoin)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;
    try {
      THIS->LinesJoin();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__StyledTextCtrl_LinesSplit); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_LinesSplit)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, pixelWidth");
    {
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;
	int	pixelWidth = (int)SvIV(ST(1))
;
    try {
      THIS->LinesSplit( pixelWidth );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__StyledTextCtrl_LowerCase); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_LowerCase)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;
    try {
      THIS->LowerCase();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__StyledTextCtrl_UpperCase); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_UpperCase)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;
    try {
      THIS->UpperCase();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}

#if WXPERL_W_VERSION_GE( 2, 7, 2 )
#define XSpp_9ec081f4_087777
#define XSubPPtmpAAAP 1


XS_EUPXS(XS_Wx__StyledTextCtrl_MarkerAddSet); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_MarkerAddSet)
{
    dVAR; dXSARGS;
    if (items != 3)
       croak_xs_usage(cv,  "THIS, line, set");
    {
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;
	int	line = (int)SvIV(ST(1))
;
	int	set = (int)SvIV(ST(2))
;
    try {
      THIS->MarkerAddSet( line, set );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__StyledTextCtrl_MarkerSetAlpha); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_MarkerSetAlpha)
{
    dVAR; dXSARGS;
    if (items != 3)
       croak_xs_usage(cv,  "THIS, markerNumber, alpha");
    {
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;
	int	markerNumber = (int)SvIV(ST(1))
;
	int	alpha = (int)SvIV(ST(2))
;
    try {
      THIS->MarkerSetAlpha( markerNumber, alpha );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}

#endif

XS_EUPXS(XS_Wx__StyledTextCtrl_NewLine); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_NewLine)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;
    try {
      THIS->NewLine();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__StyledTextCtrl_PageDown); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_PageDown)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;
    try {
      THIS->PageDown();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__StyledTextCtrl_PageDownExtend); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_PageDownExtend)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;
    try {
      THIS->PageDownExtend();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__StyledTextCtrl_PageDownRectExtend); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_PageDownRectExtend)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;
    try {
      THIS->PageDownRectExtend();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__StyledTextCtrl_PageUp); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_PageUp)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;
    try {
      THIS->PageUp();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__StyledTextCtrl_PageUpExtend); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_PageUpExtend)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;
    try {
      THIS->PageUpExtend();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__StyledTextCtrl_PageUpRectExtend); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_PageUpRectExtend)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;
    try {
      THIS->PageUpRectExtend();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__StyledTextCtrl_ParaDown); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_ParaDown)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;
    try {
      THIS->ParaDown();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__StyledTextCtrl_ParaDownExtend); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_ParaDownExtend)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;
    try {
      THIS->ParaDownExtend();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__StyledTextCtrl_ParaUp); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_ParaUp)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;
    try {
      THIS->ParaUp();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__StyledTextCtrl_ParaUpExtend); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_ParaUpExtend)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;
    try {
      THIS->ParaUpExtend();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__StyledTextCtrl_PositionBefore); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_PositionBefore)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, pos");
    {
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;
	int	RETVAL;
	dXSTARG;
	int	pos = (int)SvIV(ST(1))
;
    try {
      RETVAL = THIS->PositionBefore( pos );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__StyledTextCtrl_PositionAfter); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_PositionAfter)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, pos");
    {
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;
	int	RETVAL;
	dXSTARG;
	int	pos = (int)SvIV(ST(1))
;
    try {
      RETVAL = THIS->PositionAfter( pos );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__StyledTextCtrl_RegisterImage); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_RegisterImage)
{
    dVAR; dXSARGS;
    if (items != 3)
       croak_xs_usage(cv,  "THIS, type, bmp");
    {
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;
	int	type = (int)SvIV(ST(1))
;
	wxBitmap*    bmp = (wxBitmap *) wxPli_sv_2_object( aTHX_ ST(2), "Wx::Bitmap" )
;
    try {
      THIS->RegisterImage( type, *( bmp ) );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__StyledTextCtrl_ScrollToColumn); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_ScrollToColumn)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, column");
    {
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;
	int	column = (int)SvIV(ST(1))
;
    try {
      THIS->ScrollToColumn( column );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}

#if WXPERL_W_VERSION_GE( 2, 7, 2 )
#define XSpp_9ec081f4_001878
#define XSubPPtmpAAAQ 1


XS_EUPXS(XS_Wx__StyledTextCtrl_SelectionDuplicate); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_SelectionDuplicate)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;
    try {
      THIS->SelectionDuplicate();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}

#endif

XS_EUPXS(XS_Wx__StyledTextCtrl_SetCharsDefault); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_SetCharsDefault)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;
    try {
      THIS->SetCharsDefault();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__StyledTextCtrl_SetFoldMarginColour); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_SetFoldMarginColour)
{
    dVAR; dXSARGS;
    if (items != 3)
       croak_xs_usage(cv,  "THIS, useSetting, back");
    {
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;
	bool	useSetting = (bool)SvTRUE(ST(1))
;
	wxColour*    back = (wxColour *) wxPli_sv_2_object( aTHX_ ST(2), "Wx::Colour" )
;
    try {
      THIS->SetFoldMarginColour( useSetting, *( back ) );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__StyledTextCtrl_SetFoldMarginHiColour); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_SetFoldMarginHiColour)
{
    dVAR; dXSARGS;
    if (items != 3)
       croak_xs_usage(cv,  "THIS, useSetting, fore");
    {
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;
	bool	useSetting = (bool)SvTRUE(ST(1))
;
	wxColour*    fore = (wxColour *) wxPli_sv_2_object( aTHX_ ST(2), "Wx::Colour" )
;
    try {
      THIS->SetFoldMarginHiColour( useSetting, *( fore ) );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__StyledTextCtrl_SetHotspotActiveForeground); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_SetHotspotActiveForeground)
{
    dVAR; dXSARGS;
    if (items != 3)
       croak_xs_usage(cv,  "THIS, useSetting, fore");
    {
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;
	bool	useSetting = (bool)SvTRUE(ST(1))
;
	wxColour*    fore = (wxColour *) wxPli_sv_2_object( aTHX_ ST(2), "Wx::Colour" )
;
    try {
      THIS->SetHotspotActiveForeground( useSetting, *( fore ) );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__StyledTextCtrl_SetHotspotActiveBackground); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_SetHotspotActiveBackground)
{
    dVAR; dXSARGS;
    if (items != 3)
       croak_xs_usage(cv,  "THIS, useSetting, back");
    {
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;
	bool	useSetting = (bool)SvTRUE(ST(1))
;
	wxColour*    back = (wxColour *) wxPli_sv_2_object( aTHX_ ST(2), "Wx::Colour" )
;
    try {
      THIS->SetHotspotActiveBackground( useSetting, *( back ) );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__StyledTextCtrl_SetHotspotActiveUnderline); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_SetHotspotActiveUnderline)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, underline");
    {
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;
	bool	underline = (bool)SvTRUE(ST(1))
;
    try {
      THIS->SetHotspotActiveUnderline( underline );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__StyledTextCtrl_SetHotspotSingleLine); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_SetHotspotSingleLine)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, singleLine");
    {
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;
	bool	singleLine = (bool)SvTRUE(ST(1))
;
    try {
      THIS->SetHotspotSingleLine( singleLine );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__StyledTextCtrl_SetWhitespaceChars); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_SetWhitespaceChars)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, characters");
    {
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;
	wxString	characters;

    WXSTRING_INPUT( characters, wxString, ST(1) )
;
    try {
      THIS->SetWhitespaceChars( characters );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__StyledTextCtrl_StutteredPageUp); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_StutteredPageUp)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;
    try {
      THIS->StutteredPageUp();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__StyledTextCtrl_StutteredPageUpExtend); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_StutteredPageUpExtend)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;
    try {
      THIS->StutteredPageUpExtend();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__StyledTextCtrl_StutteredPageDown); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_StutteredPageDown)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;
    try {
      THIS->StutteredPageDown();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__StyledTextCtrl_StutteredPageDownExtend); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_StutteredPageDownExtend)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;
    try {
      THIS->StutteredPageDownExtend();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}

#if WXPERL_W_VERSION_GE( 2, 6, 0 )
#define XSpp_9ec081f4_080417
#define XSubPPtmpAAAR 1


XS_EUPXS(XS_Wx__StyledTextCtrl_StyleSetFontEncoding); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_StyleSetFontEncoding)
{
    dVAR; dXSARGS;
    if (items != 3)
       croak_xs_usage(cv,  "THIS, style, encoding");
    {
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;
	int	style = (int)SvIV(ST(1))
;
	wxFontEncoding	encoding = (wxFontEncoding)SvIV(ST(2))
;
    try {
      THIS->StyleSetFontEncoding( style, encoding );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}

#endif

XS_EUPXS(XS_Wx__StyledTextCtrl_StyleSetHotSpot); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_StyleSetHotSpot)
{
    dVAR; dXSARGS;
    if (items != 3)
       croak_xs_usage(cv,  "THIS, style, hotspot");
    {
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;
	int	style = (int)SvIV(ST(1))
;
	bool	hotspot = (bool)SvTRUE(ST(2))
;
    try {
      THIS->StyleSetHotSpot( style, hotspot );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__StyledTextCtrl_Tab); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_Tab)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;
    try {
      THIS->Tab();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__StyledTextCtrl_TargetFromSelection); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_TargetFromSelection)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;
    try {
      THIS->TargetFromSelection();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__StyledTextCtrl_VCHome); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_VCHome)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;
    try {
      THIS->VCHome();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__StyledTextCtrl_VCHomeExtend); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_VCHomeExtend)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;
    try {
      THIS->VCHomeExtend();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__StyledTextCtrl_VCHomeRectExtend); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_VCHomeRectExtend)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;
    try {
      THIS->VCHomeRectExtend();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__StyledTextCtrl_VCHomeWrap); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_VCHomeWrap)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;
    try {
      THIS->VCHomeWrap();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__StyledTextCtrl_VCHomeWrapExtend); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_VCHomeWrapExtend)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;
    try {
      THIS->VCHomeWrapExtend();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__StyledTextCtrl_WordLeft); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_WordLeft)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;
    try {
      THIS->WordLeft();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__StyledTextCtrl_WordLeftEnd); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_WordLeftEnd)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;
    try {
      THIS->WordLeftEnd();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__StyledTextCtrl_WordLeftEndExtend); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_WordLeftEndExtend)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;
    try {
      THIS->WordLeftEndExtend();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__StyledTextCtrl_WordLeftExtend); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_WordLeftExtend)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;
    try {
      THIS->WordLeftExtend();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__StyledTextCtrl_WordRight); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_WordRight)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;
    try {
      THIS->WordRight();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__StyledTextCtrl_WordRightEnd); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_WordRightEnd)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;
    try {
      THIS->WordRightEnd();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__StyledTextCtrl_WordRightEndExtend); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_WordRightEndExtend)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;
    try {
      THIS->WordRightEndExtend();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__StyledTextCtrl_WordRightExtend); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_WordRightExtend)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;
    try {
      THIS->WordRightExtend();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}

#if WXPERL_W_VERSION_GE( 2, 7, 2 )
#define XSpp_9ec081f4_027994
#define XSubPPtmpAAAS 1


XS_EUPXS(XS_Wx__StyledTextCtrl_WrapCount); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_WrapCount)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, line");
    {
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;
	int	RETVAL;
	dXSTARG;
	int	line = (int)SvIV(ST(1))
;
    try {
      RETVAL = THIS->WrapCount( line );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}

#endif

XS_EUPXS(XS_Wx__StyledTextCtrl_ZoomIn); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_ZoomIn)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;
    try {
      THIS->ZoomIn();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__StyledTextCtrl_ZoomOut); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_ZoomOut)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;
    try {
      THIS->ZoomOut();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}

#if WXPERL_W_VERSION_GE( 2, 9, 4 )
#define XSpp_9ec081f4_001463
#define XSubPPtmpAAAT 1


XS_EUPXS(XS_Wx__StyledTextCtrl_SetWhitespaceSize); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_SetWhitespaceSize)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, size");
    {
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;
	int	size = (int)SvIV(ST(1))
;
    try {
      THIS->SetWhitespaceSize( size );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__StyledTextCtrl_GetWhitespaceSize); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_GetWhitespaceSize)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;
	int	RETVAL;
	dXSTARG;
    try {
      RETVAL = THIS->GetWhitespaceSize();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__StyledTextCtrl_SetWrapIndentMode); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_SetWrapIndentMode)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, mode");
    {
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;
	int	mode = (int)SvIV(ST(1))
;
    try {
      THIS->SetWrapIndentMode( mode );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__StyledTextCtrl_GetWrapIndentMode); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_GetWrapIndentMode)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;
	int	RETVAL;
	dXSTARG;
    try {
      RETVAL = THIS->GetWrapIndentMode();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__StyledTextCtrl_SetFirstVisibleLine); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_SetFirstVisibleLine)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, lineDisplay");
    {
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;
	int	lineDisplay = (int)SvIV(ST(1))
;
    try {
      THIS->SetFirstVisibleLine( lineDisplay );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__StyledTextCtrl_CopyAllowLine); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_CopyAllowLine)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;
    try {
      THIS->CopyAllowLine();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__StyledTextCtrl_GetCharacterPointer); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_GetCharacterPointer)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;
	const char *	RETVAL;
	dXSTARG;
    try {
      RETVAL = THIS->GetCharacterPointer();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	sv_setpv(TARG, RETVAL);
	XSprePUSH;
	PUSHTARG;
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__StyledTextCtrl_SetKeysUnicode); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_SetKeysUnicode)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, keysUnicode");
    {
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;
	bool	keysUnicode = (bool)SvTRUE(ST(1))
;
    try {
      THIS->SetKeysUnicode( keysUnicode );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__StyledTextCtrl_GetKeysUnicode); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_GetKeysUnicode)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;
	bool	RETVAL;
    try {
      RETVAL = THIS->GetKeysUnicode();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__StyledTextCtrl_IndicatorSetAlpha); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_IndicatorSetAlpha)
{
    dVAR; dXSARGS;
    if (items != 3)
       croak_xs_usage(cv,  "THIS, indicator, alpha");
    {
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;
	int	indicator = (int)SvIV(ST(1))
;
	int	alpha = (int)SvIV(ST(2))
;
    try {
      THIS->IndicatorSetAlpha( indicator, alpha );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__StyledTextCtrl_IndicatorGetAlpha); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_IndicatorGetAlpha)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, indicator");
    {
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;
	int	RETVAL;
	dXSTARG;
	int	indicator = (int)SvIV(ST(1))
;
    try {
      RETVAL = THIS->IndicatorGetAlpha( indicator );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__StyledTextCtrl_SetExtraAscent); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_SetExtraAscent)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, extraAscent");
    {
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;
	int	extraAscent = (int)SvIV(ST(1))
;
    try {
      THIS->SetExtraAscent( extraAscent );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__StyledTextCtrl_GetExtraAscent); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_GetExtraAscent)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;
	int	RETVAL;
	dXSTARG;
    try {
      RETVAL = THIS->GetExtraAscent();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__StyledTextCtrl_SetExtraDescent); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_SetExtraDescent)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, extraDescent");
    {
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;
	int	extraDescent = (int)SvIV(ST(1))
;
    try {
      THIS->SetExtraDescent( extraDescent );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__StyledTextCtrl_GetExtraDescent); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_GetExtraDescent)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;
	int	RETVAL;
	dXSTARG;
    try {
      RETVAL = THIS->GetExtraDescent();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__StyledTextCtrl_GetMarkerSymbolDefined); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_GetMarkerSymbolDefined)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, markerNumber");
    {
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;
	int	RETVAL;
	dXSTARG;
	int	markerNumber = (int)SvIV(ST(1))
;
    try {
      RETVAL = THIS->GetMarkerSymbolDefined( markerNumber );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__StyledTextCtrl_MarginSetText); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_MarginSetText)
{
    dVAR; dXSARGS;
    if (items != 3)
       croak_xs_usage(cv,  "THIS, line, text");
    {
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;
	int	line = (int)SvIV(ST(1))
;
	wxString	text;

    WXSTRING_INPUT( text, wxString, ST(2) )
;
    try {
      THIS->MarginSetText( line, text );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__StyledTextCtrl_MarginGetText); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_MarginGetText)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, line");
    {
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;
	wxString	RETVAL;
	int	line = (int)SvIV(ST(1))
;
    try {
      RETVAL = THIS->MarginGetText( line );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    WXSTRING_OUTPUT( RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__StyledTextCtrl_MarginSetStyle); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_MarginSetStyle)
{
    dVAR; dXSARGS;
    if (items != 3)
       croak_xs_usage(cv,  "THIS, line, style");
    {
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;
	int	line = (int)SvIV(ST(1))
;
	int	style = (int)SvIV(ST(2))
;
    try {
      THIS->MarginSetStyle( line, style );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__StyledTextCtrl_MarginGetStyle); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_MarginGetStyle)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, line");
    {
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;
	int	RETVAL;
	dXSTARG;
	int	line = (int)SvIV(ST(1))
;
    try {
      RETVAL = THIS->MarginGetStyle( line );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__StyledTextCtrl_MarginSetStyles); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_MarginSetStyles)
{
    dVAR; dXSARGS;
    if (items != 3)
       croak_xs_usage(cv,  "THIS, line, styles");
    {
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;
	int	line = (int)SvIV(ST(1))
;
	wxString	styles;

    WXSTRING_INPUT( styles, wxString, ST(2) )
;
    try {
      THIS->MarginSetStyles( line, styles );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__StyledTextCtrl_MarginGetStyles); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_MarginGetStyles)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, line");
    {
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;
	wxString	RETVAL;
	int	line = (int)SvIV(ST(1))
;
    try {
      RETVAL = THIS->MarginGetStyles( line );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    WXSTRING_OUTPUT( RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__StyledTextCtrl_MarginTextClearAll); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_MarginTextClearAll)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;
    try {
      THIS->MarginTextClearAll();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__StyledTextCtrl_MarginSetStyleOffset); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_MarginSetStyleOffset)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, style");
    {
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;
	int	style = (int)SvIV(ST(1))
;
    try {
      THIS->MarginSetStyleOffset( style );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__StyledTextCtrl_MarginGetStyleOffset); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_MarginGetStyleOffset)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;
	int	RETVAL;
	dXSTARG;
    try {
      RETVAL = THIS->MarginGetStyleOffset();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__StyledTextCtrl_AnnotationSetText); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_AnnotationSetText)
{
    dVAR; dXSARGS;
    if (items != 3)
       croak_xs_usage(cv,  "THIS, line, text");
    {
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;
	int	line = (int)SvIV(ST(1))
;
	wxString	text;

    WXSTRING_INPUT( text, wxString, ST(2) )
;
    try {
      THIS->AnnotationSetText( line, text );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__StyledTextCtrl_AnnotationGetText); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_AnnotationGetText)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, line");
    {
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;
	wxString	RETVAL;
	int	line = (int)SvIV(ST(1))
;
    try {
      RETVAL = THIS->AnnotationGetText( line );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    WXSTRING_OUTPUT( RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__StyledTextCtrl_AnnotationSetStyle); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_AnnotationSetStyle)
{
    dVAR; dXSARGS;
    if (items != 3)
       croak_xs_usage(cv,  "THIS, line, style");
    {
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;
	int	line = (int)SvIV(ST(1))
;
	int	style = (int)SvIV(ST(2))
;
    try {
      THIS->AnnotationSetStyle( line, style );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__StyledTextCtrl_AnnotationGetStyle); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_AnnotationGetStyle)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, line");
    {
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;
	int	RETVAL;
	dXSTARG;
	int	line = (int)SvIV(ST(1))
;
    try {
      RETVAL = THIS->AnnotationGetStyle( line );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__StyledTextCtrl_AnnotationSetStyles); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_AnnotationSetStyles)
{
    dVAR; dXSARGS;
    if (items != 3)
       croak_xs_usage(cv,  "THIS, line, styles");
    {
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;
	int	line = (int)SvIV(ST(1))
;
	wxString	styles;

    WXSTRING_INPUT( styles, wxString, ST(2) )
;
    try {
      THIS->AnnotationSetStyles( line, styles );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__StyledTextCtrl_AnnotationGetStyles); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_AnnotationGetStyles)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, line");
    {
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;
	wxString	RETVAL;
	int	line = (int)SvIV(ST(1))
;
    try {
      RETVAL = THIS->AnnotationGetStyles( line );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    WXSTRING_OUTPUT( RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__StyledTextCtrl_AnnotationGetLines); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_AnnotationGetLines)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, line");
    {
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;
	int	RETVAL;
	dXSTARG;
	int	line = (int)SvIV(ST(1))
;
    try {
      RETVAL = THIS->AnnotationGetLines( line );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__StyledTextCtrl_AnnotationClearAll); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_AnnotationClearAll)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;
    try {
      THIS->AnnotationClearAll();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__StyledTextCtrl_AnnotationSetVisible); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_AnnotationSetVisible)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, visible");
    {
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;
	int	visible = (int)SvIV(ST(1))
;
    try {
      THIS->AnnotationSetVisible( visible );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__StyledTextCtrl_AnnotationGetVisible); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_AnnotationGetVisible)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;
	int	RETVAL;
	dXSTARG;
    try {
      RETVAL = THIS->AnnotationGetVisible();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__StyledTextCtrl_AnnotationSetStyleOffset); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_AnnotationSetStyleOffset)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, style");
    {
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;
	int	style = (int)SvIV(ST(1))
;
    try {
      THIS->AnnotationSetStyleOffset( style );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__StyledTextCtrl_AnnotationGetStyleOffset); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_AnnotationGetStyleOffset)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;
	int	RETVAL;
	dXSTARG;
    try {
      RETVAL = THIS->AnnotationGetStyleOffset();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__StyledTextCtrl_AddUndoAction); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_AddUndoAction)
{
    dVAR; dXSARGS;
    if (items != 3)
       croak_xs_usage(cv,  "THIS, token, flags");
    {
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;
	int	token = (int)SvIV(ST(1))
;
	int	flags = (int)SvIV(ST(2))
;
    try {
      THIS->AddUndoAction( token, flags );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__StyledTextCtrl_CharPositionFromPoint); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_CharPositionFromPoint)
{
    dVAR; dXSARGS;
    if (items != 3)
       croak_xs_usage(cv,  "THIS, x, y");
    {
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;
	int	RETVAL;
	dXSTARG;
	int	x = (int)SvIV(ST(1))
;
	int	y = (int)SvIV(ST(2))
;
    try {
      RETVAL = THIS->CharPositionFromPoint( x, y );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__StyledTextCtrl_CharPositionFromPointClose); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_CharPositionFromPointClose)
{
    dVAR; dXSARGS;
    if (items != 3)
       croak_xs_usage(cv,  "THIS, x, y");
    {
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;
	int	RETVAL;
	dXSTARG;
	int	x = (int)SvIV(ST(1))
;
	int	y = (int)SvIV(ST(2))
;
    try {
      RETVAL = THIS->CharPositionFromPointClose( x, y );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__StyledTextCtrl_SetMultipleSelection); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_SetMultipleSelection)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, multipleSelection");
    {
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;
	bool	multipleSelection = (bool)SvTRUE(ST(1))
;
    try {
      THIS->SetMultipleSelection( multipleSelection );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__StyledTextCtrl_GetMultipleSelection); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_GetMultipleSelection)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;
	bool	RETVAL;
    try {
      RETVAL = THIS->GetMultipleSelection();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__StyledTextCtrl_SetAdditionalSelectionTyping); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_SetAdditionalSelectionTyping)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, additionalSelectionTyping");
    {
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;
	bool	additionalSelectionTyping = (bool)SvTRUE(ST(1))
;
    try {
      THIS->SetAdditionalSelectionTyping( additionalSelectionTyping );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__StyledTextCtrl_GetAdditionalSelectionTyping); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_GetAdditionalSelectionTyping)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;
	bool	RETVAL;
    try {
      RETVAL = THIS->GetAdditionalSelectionTyping();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__StyledTextCtrl_SetAdditionalCaretsBlink); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_SetAdditionalCaretsBlink)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, additionalCaretsBlink");
    {
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;
	bool	additionalCaretsBlink = (bool)SvTRUE(ST(1))
;
    try {
      THIS->SetAdditionalCaretsBlink( additionalCaretsBlink );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__StyledTextCtrl_GetAdditionalCaretsBlink); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_GetAdditionalCaretsBlink)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;
	bool	RETVAL;
    try {
      RETVAL = THIS->GetAdditionalCaretsBlink();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__StyledTextCtrl_SetAdditionalCaretsVisible); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_SetAdditionalCaretsVisible)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, additionalCaretsBlink");
    {
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;
	bool	additionalCaretsBlink = (bool)SvTRUE(ST(1))
;
    try {
      THIS->SetAdditionalCaretsVisible( additionalCaretsBlink );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__StyledTextCtrl_GetAdditionalCaretsVisible); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_GetAdditionalCaretsVisible)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;
	bool	RETVAL;
    try {
      RETVAL = THIS->GetAdditionalCaretsVisible();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__StyledTextCtrl_GetSelections); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_GetSelections)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;
	int	RETVAL;
	dXSTARG;
    try {
      RETVAL = THIS->GetSelections();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__StyledTextCtrl_ClearSelections); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_ClearSelections)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;
    try {
      THIS->ClearSelections();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__StyledTextCtrl_AddSelection); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_AddSelection)
{
    dVAR; dXSARGS;
    if (items != 3)
       croak_xs_usage(cv,  "THIS, caret, anchor");
    {
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;
	int	RETVAL;
	dXSTARG;
	int	caret = (int)SvIV(ST(1))
;
	int	anchor = (int)SvIV(ST(2))
;
    try {
      RETVAL = THIS->AddSelection( caret, anchor );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__StyledTextCtrl_SetMainSelection); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_SetMainSelection)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, selection");
    {
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;
	int	selection = (int)SvIV(ST(1))
;
    try {
      THIS->SetMainSelection( selection );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__StyledTextCtrl_GetMainSelection); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_GetMainSelection)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;
	int	RETVAL;
	dXSTARG;
    try {
      RETVAL = THIS->GetMainSelection();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__StyledTextCtrl_SetSelectionNCaret); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_SetSelectionNCaret)
{
    dVAR; dXSARGS;
    if (items != 3)
       croak_xs_usage(cv,  "THIS, selection, pos");
    {
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;
	int	selection = (int)SvIV(ST(1))
;
	int	pos = (int)SvIV(ST(2))
;
    try {
      THIS->SetSelectionNCaret( selection, pos );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__StyledTextCtrl_GetSelectionNCaret); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_GetSelectionNCaret)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, selection");
    {
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;
	int	RETVAL;
	dXSTARG;
	int	selection = (int)SvIV(ST(1))
;
    try {
      RETVAL = THIS->GetSelectionNCaret( selection );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__StyledTextCtrl_SetSelectionNAnchor); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_SetSelectionNAnchor)
{
    dVAR; dXSARGS;
    if (items != 3)
       croak_xs_usage(cv,  "THIS, selection, posAnchor");
    {
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;
	int	selection = (int)SvIV(ST(1))
;
	int	posAnchor = (int)SvIV(ST(2))
;
    try {
      THIS->SetSelectionNAnchor( selection, posAnchor );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__StyledTextCtrl_GetSelectionNAnchor); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_GetSelectionNAnchor)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, selection");
    {
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;
	int	RETVAL;
	dXSTARG;
	int	selection = (int)SvIV(ST(1))
;
    try {
      RETVAL = THIS->GetSelectionNAnchor( selection );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__StyledTextCtrl_SetSelectionNCaretVirtualSpace); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_SetSelectionNCaretVirtualSpace)
{
    dVAR; dXSARGS;
    if (items != 3)
       croak_xs_usage(cv,  "THIS, selection, space");
    {
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;
	int	selection = (int)SvIV(ST(1))
;
	int	space = (int)SvIV(ST(2))
;
    try {
      THIS->SetSelectionNCaretVirtualSpace( selection, space );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__StyledTextCtrl_GetSelectionNCaretVirtualSpace); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_GetSelectionNCaretVirtualSpace)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, selection");
    {
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;
	int	RETVAL;
	dXSTARG;
	int	selection = (int)SvIV(ST(1))
;
    try {
      RETVAL = THIS->GetSelectionNCaretVirtualSpace( selection );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__StyledTextCtrl_SetSelectionNAnchorVirtualSpace); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_SetSelectionNAnchorVirtualSpace)
{
    dVAR; dXSARGS;
    if (items != 3)
       croak_xs_usage(cv,  "THIS, selection, space");
    {
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;
	int	selection = (int)SvIV(ST(1))
;
	int	space = (int)SvIV(ST(2))
;
    try {
      THIS->SetSelectionNAnchorVirtualSpace( selection, space );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__StyledTextCtrl_GetSelectionNAnchorVirtualSpace); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_GetSelectionNAnchorVirtualSpace)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, selection");
    {
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;
	int	RETVAL;
	dXSTARG;
	int	selection = (int)SvIV(ST(1))
;
    try {
      RETVAL = THIS->GetSelectionNAnchorVirtualSpace( selection );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__StyledTextCtrl_SetSelectionNStart); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_SetSelectionNStart)
{
    dVAR; dXSARGS;
    if (items != 3)
       croak_xs_usage(cv,  "THIS, selection, pos");
    {
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;
	int	selection = (int)SvIV(ST(1))
;
	int	pos = (int)SvIV(ST(2))
;
    try {
      THIS->SetSelectionNStart( selection, pos );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__StyledTextCtrl_GetSelectionNStart); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_GetSelectionNStart)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, selection");
    {
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;
	int	RETVAL;
	dXSTARG;
	int	selection = (int)SvIV(ST(1))
;
    try {
      RETVAL = THIS->GetSelectionNStart( selection );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__StyledTextCtrl_SetSelectionNEnd); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_SetSelectionNEnd)
{
    dVAR; dXSARGS;
    if (items != 3)
       croak_xs_usage(cv,  "THIS, selection, pos");
    {
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;
	int	selection = (int)SvIV(ST(1))
;
	int	pos = (int)SvIV(ST(2))
;
    try {
      THIS->SetSelectionNEnd( selection, pos );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__StyledTextCtrl_GetSelectionNEnd); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_GetSelectionNEnd)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, selection");
    {
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;
	int	RETVAL;
	dXSTARG;
	int	selection = (int)SvIV(ST(1))
;
    try {
      RETVAL = THIS->GetSelectionNEnd( selection );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__StyledTextCtrl_SetRectangularSelectionCaret); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_SetRectangularSelectionCaret)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, pos");
    {
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;
	int	pos = (int)SvIV(ST(1))
;
    try {
      THIS->SetRectangularSelectionCaret( pos );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__StyledTextCtrl_GetRectangularSelectionCaret); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_GetRectangularSelectionCaret)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;
	int	RETVAL;
	dXSTARG;
    try {
      RETVAL = THIS->GetRectangularSelectionCaret();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__StyledTextCtrl_SetRectangularSelectionAnchor); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_SetRectangularSelectionAnchor)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, posAnchor");
    {
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;
	int	posAnchor = (int)SvIV(ST(1))
;
    try {
      THIS->SetRectangularSelectionAnchor( posAnchor );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__StyledTextCtrl_GetRectangularSelectionAnchor); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_GetRectangularSelectionAnchor)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;
	int	RETVAL;
	dXSTARG;
    try {
      RETVAL = THIS->GetRectangularSelectionAnchor();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__StyledTextCtrl_SetRectangularSelectionCaretVirtualSpace); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_SetRectangularSelectionCaretVirtualSpace)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, space");
    {
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;
	int	space = (int)SvIV(ST(1))
;
    try {
      THIS->SetRectangularSelectionCaretVirtualSpace( space );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__StyledTextCtrl_GetRectangularSelectionCaretVirtualSpace); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_GetRectangularSelectionCaretVirtualSpace)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;
	int	RETVAL;
	dXSTARG;
    try {
      RETVAL = THIS->GetRectangularSelectionCaretVirtualSpace();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__StyledTextCtrl_SetRectangularSelectionAnchorVirtualSpace); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_SetRectangularSelectionAnchorVirtualSpace)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, space");
    {
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;
	int	space = (int)SvIV(ST(1))
;
    try {
      THIS->SetRectangularSelectionAnchorVirtualSpace( space );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__StyledTextCtrl_GetRectangularSelectionAnchorVirtualSpace); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_GetRectangularSelectionAnchorVirtualSpace)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;
	int	RETVAL;
	dXSTARG;
    try {
      RETVAL = THIS->GetRectangularSelectionAnchorVirtualSpace();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__StyledTextCtrl_SetVirtualSpaceOptions); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_SetVirtualSpaceOptions)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, virtualSpaceOptions");
    {
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;
	int	virtualSpaceOptions = (int)SvIV(ST(1))
;
    try {
      THIS->SetVirtualSpaceOptions( virtualSpaceOptions );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__StyledTextCtrl_GetVirtualSpaceOptions); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_GetVirtualSpaceOptions)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;
	int	RETVAL;
	dXSTARG;
    try {
      RETVAL = THIS->GetVirtualSpaceOptions();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__StyledTextCtrl_SetRectangularSelectionModifier); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_SetRectangularSelectionModifier)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, modifier");
    {
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;
	int	modifier = (int)SvIV(ST(1))
;
    try {
      THIS->SetRectangularSelectionModifier( modifier );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__StyledTextCtrl_GetRectangularSelectionModifier); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_GetRectangularSelectionModifier)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;
	int	RETVAL;
	dXSTARG;
    try {
      RETVAL = THIS->GetRectangularSelectionModifier();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__StyledTextCtrl_SetAdditionalSelForeground); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_SetAdditionalSelForeground)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, fore");
    {
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;
	wxColour*    fore = (wxColour *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::Colour" )
;
    try {
      THIS->SetAdditionalSelForeground( *( fore ) );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__StyledTextCtrl_SetAdditionalSelBackground); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_SetAdditionalSelBackground)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, back");
    {
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;
	wxColour*    back = (wxColour *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::Colour" )
;
    try {
      THIS->SetAdditionalSelBackground( *( back ) );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__StyledTextCtrl_SetAdditionalSelAlpha); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_SetAdditionalSelAlpha)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, alpha");
    {
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;
	int	alpha = (int)SvIV(ST(1))
;
    try {
      THIS->SetAdditionalSelAlpha( alpha );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__StyledTextCtrl_GetAdditionalSelAlpha); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_GetAdditionalSelAlpha)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;
	int	RETVAL;
	dXSTARG;
    try {
      RETVAL = THIS->GetAdditionalSelAlpha();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__StyledTextCtrl_SetAdditionalCaretForeground); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_SetAdditionalCaretForeground)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, fore");
    {
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;
	wxColour*    fore = (wxColour *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::Colour" )
;
    try {
      THIS->SetAdditionalCaretForeground( *( fore ) );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__StyledTextCtrl_GetAdditionalCaretForeground); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_GetAdditionalCaretForeground)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;
	wxColour *	RETVAL;
    try {
      RETVAL = new wxColour( THIS->GetAdditionalCaretForeground() );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_non_object_2_sv( aTHX_ RETVALSV, RETVAL, "Wx::Colour" );
    wxPli_thread_sv_register( aTHX_ "Wx::Colour", RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__StyledTextCtrl_RotateSelection); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_RotateSelection)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;
    try {
      THIS->RotateSelection();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__StyledTextCtrl_SwapMainAnchorCaret); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextCtrl_SwapMainAnchorCaret)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxStyledTextCtrl *    THIS = (wxStyledTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextCtrl" )
;
    try {
      THIS->SwapMainAnchorCaret();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}

#endif

/* INCLUDE: Returning to 'STC.xs' from '/usr/bin/perl -MExtUtils::XSpp::Cmd -e xspp -- -t ../../typemap.xsp XS/StyledTextCtrl.xsp' */


/* INCLUDE_COMMAND:  Including output of '/usr/bin/perl -MExtUtils::XSpp::Cmd -e xspp -- -t ../../typemap.xsp XS/StyledTextEvent.xsp' from 'STC.xs' */

#include <exception>

#undef  xsp_constructor_class
#define xsp_constructor_class(c) (c)

XS_EUPXS(XS_Wx__StyledTextEvent_SetPosition); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextEvent_SetPosition)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, pos");
    {
	wxStyledTextEvent *    THIS = (wxStyledTextEvent *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextEvent" )
;
	int	pos = (int)SvIV(ST(1))
;
    try {
      THIS->SetPosition( pos );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__StyledTextEvent_SetKey); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextEvent_SetKey)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, k");
    {
	wxStyledTextEvent *    THIS = (wxStyledTextEvent *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextEvent" )
;
	int	k = (int)SvIV(ST(1))
;
    try {
      THIS->SetKey( k );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__StyledTextEvent_SetModifiers); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextEvent_SetModifiers)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, m");
    {
	wxStyledTextEvent *    THIS = (wxStyledTextEvent *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextEvent" )
;
	int	m = (int)SvIV(ST(1))
;
    try {
      THIS->SetModifiers( m );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__StyledTextEvent_SetModificationType); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextEvent_SetModificationType)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, t");
    {
	wxStyledTextEvent *    THIS = (wxStyledTextEvent *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextEvent" )
;
	int	t = (int)SvIV(ST(1))
;
    try {
      THIS->SetModificationType( t );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__StyledTextEvent_SetText); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextEvent_SetText)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, t");
    {
	wxStyledTextEvent *    THIS = (wxStyledTextEvent *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextEvent" )
;
	wxString	t;

    WXSTRING_INPUT( t, wxString, ST(1) )
;
    try {
      THIS->SetText( t );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__StyledTextEvent_SetLength); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextEvent_SetLength)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, len");
    {
	wxStyledTextEvent *    THIS = (wxStyledTextEvent *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextEvent" )
;
	int	len = (int)SvIV(ST(1))
;
    try {
      THIS->SetLength( len );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__StyledTextEvent_SetLinesAdded); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextEvent_SetLinesAdded)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, num");
    {
	wxStyledTextEvent *    THIS = (wxStyledTextEvent *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextEvent" )
;
	int	num = (int)SvIV(ST(1))
;
    try {
      THIS->SetLinesAdded( num );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__StyledTextEvent_SetLine); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextEvent_SetLine)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, val");
    {
	wxStyledTextEvent *    THIS = (wxStyledTextEvent *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextEvent" )
;
	int	val = (int)SvIV(ST(1))
;
    try {
      THIS->SetLine( val );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__StyledTextEvent_SetFoldLevelNow); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextEvent_SetFoldLevelNow)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, val");
    {
	wxStyledTextEvent *    THIS = (wxStyledTextEvent *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextEvent" )
;
	int	val = (int)SvIV(ST(1))
;
    try {
      THIS->SetFoldLevelNow( val );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__StyledTextEvent_SetFoldLevelPrev); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextEvent_SetFoldLevelPrev)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, val");
    {
	wxStyledTextEvent *    THIS = (wxStyledTextEvent *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextEvent" )
;
	int	val = (int)SvIV(ST(1))
;
    try {
      THIS->SetFoldLevelPrev( val );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__StyledTextEvent_SetMargin); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextEvent_SetMargin)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, val");
    {
	wxStyledTextEvent *    THIS = (wxStyledTextEvent *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextEvent" )
;
	int	val = (int)SvIV(ST(1))
;
    try {
      THIS->SetMargin( val );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__StyledTextEvent_SetMessage); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextEvent_SetMessage)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, val");
    {
	wxStyledTextEvent *    THIS = (wxStyledTextEvent *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextEvent" )
;
	int	val = (int)SvIV(ST(1))
;
    try {
      THIS->SetMessage( val );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__StyledTextEvent_SetWParam); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextEvent_SetWParam)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, val");
    {
	wxStyledTextEvent *    THIS = (wxStyledTextEvent *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextEvent" )
;
	int	val = (int)SvIV(ST(1))
;
    try {
      THIS->SetWParam( val );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__StyledTextEvent_SetLParam); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextEvent_SetLParam)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, val");
    {
	wxStyledTextEvent *    THIS = (wxStyledTextEvent *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextEvent" )
;
	int	val = (int)SvIV(ST(1))
;
    try {
      THIS->SetLParam( val );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__StyledTextEvent_SetListType); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextEvent_SetListType)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, val");
    {
	wxStyledTextEvent *    THIS = (wxStyledTextEvent *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextEvent" )
;
	int	val = (int)SvIV(ST(1))
;
    try {
      THIS->SetListType( val );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__StyledTextEvent_SetX); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextEvent_SetX)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, val");
    {
	wxStyledTextEvent *    THIS = (wxStyledTextEvent *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextEvent" )
;
	int	val = (int)SvIV(ST(1))
;
    try {
      THIS->SetX( val );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__StyledTextEvent_SetY); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextEvent_SetY)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, val");
    {
	wxStyledTextEvent *    THIS = (wxStyledTextEvent *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextEvent" )
;
	int	val = (int)SvIV(ST(1))
;
    try {
      THIS->SetY( val );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__StyledTextEvent_SetDragText); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextEvent_SetDragText)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, val");
    {
	wxStyledTextEvent *    THIS = (wxStyledTextEvent *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextEvent" )
;
	wxString	val;

    WXSTRING_INPUT( val, wxString, ST(1) )
;
    try {
      THIS->SetDragText( val );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__StyledTextEvent_SetDragAllowMove); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextEvent_SetDragAllowMove)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, val");
    {
	wxStyledTextEvent *    THIS = (wxStyledTextEvent *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextEvent" )
;
	bool	val = (bool)SvTRUE(ST(1))
;
    try {
      THIS->SetDragAllowMove( val );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}

#ifdef  STC_USE_DND
#define XSpp_f6372dd8_042037
#define XSubPPtmpAAAU 1


XS_EUPXS(XS_Wx__StyledTextEvent_SetDragResult); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextEvent_SetDragResult)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, val");
    {
	wxStyledTextEvent *    THIS = (wxStyledTextEvent *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextEvent" )
;
	wxDragResult	val = (wxDragResult)SvIV(ST(1))
;
    try {
      THIS->SetDragResult( val );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}

#endif

XS_EUPXS(XS_Wx__StyledTextEvent_GetPosition); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextEvent_GetPosition)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxStyledTextEvent *    THIS = (wxStyledTextEvent *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextEvent" )
;
	int	RETVAL;
	dXSTARG;
    try {
      RETVAL = THIS->GetPosition();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__StyledTextEvent_GetKey); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextEvent_GetKey)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxStyledTextEvent *    THIS = (wxStyledTextEvent *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextEvent" )
;
	int	RETVAL;
	dXSTARG;
    try {
      RETVAL = THIS->GetKey();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__StyledTextEvent_GetModifiers); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextEvent_GetModifiers)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxStyledTextEvent *    THIS = (wxStyledTextEvent *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextEvent" )
;
	int	RETVAL;
	dXSTARG;
    try {
      RETVAL = THIS->GetModifiers();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__StyledTextEvent_GetModificationType); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextEvent_GetModificationType)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxStyledTextEvent *    THIS = (wxStyledTextEvent *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextEvent" )
;
	int	RETVAL;
	dXSTARG;
    try {
      RETVAL = THIS->GetModificationType();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__StyledTextEvent_GetText); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextEvent_GetText)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxStyledTextEvent *    THIS = (wxStyledTextEvent *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextEvent" )
;
	wxString	RETVAL;
    try {
      RETVAL = THIS->GetText();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    WXSTRING_OUTPUT( RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__StyledTextEvent_GetLength); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextEvent_GetLength)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxStyledTextEvent *    THIS = (wxStyledTextEvent *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextEvent" )
;
	int	RETVAL;
	dXSTARG;
    try {
      RETVAL = THIS->GetLength();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__StyledTextEvent_GetLinesAdded); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextEvent_GetLinesAdded)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxStyledTextEvent *    THIS = (wxStyledTextEvent *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextEvent" )
;
	int	RETVAL;
	dXSTARG;
    try {
      RETVAL = THIS->GetLinesAdded();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__StyledTextEvent_GetLine); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextEvent_GetLine)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxStyledTextEvent *    THIS = (wxStyledTextEvent *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextEvent" )
;
	int	RETVAL;
	dXSTARG;
    try {
      RETVAL = THIS->GetLine();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__StyledTextEvent_GetFoldLevelNow); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextEvent_GetFoldLevelNow)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxStyledTextEvent *    THIS = (wxStyledTextEvent *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextEvent" )
;
	int	RETVAL;
	dXSTARG;
    try {
      RETVAL = THIS->GetFoldLevelNow();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__StyledTextEvent_GetFoldLevelPrev); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextEvent_GetFoldLevelPrev)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxStyledTextEvent *    THIS = (wxStyledTextEvent *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextEvent" )
;
	int	RETVAL;
	dXSTARG;
    try {
      RETVAL = THIS->GetFoldLevelPrev();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__StyledTextEvent_GetMargin); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextEvent_GetMargin)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxStyledTextEvent *    THIS = (wxStyledTextEvent *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextEvent" )
;
	int	RETVAL;
	dXSTARG;
    try {
      RETVAL = THIS->GetMargin();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__StyledTextEvent_GetMessage); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextEvent_GetMessage)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxStyledTextEvent *    THIS = (wxStyledTextEvent *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextEvent" )
;
	int	RETVAL;
	dXSTARG;
    try {
      RETVAL = THIS->GetMessage();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__StyledTextEvent_GetWParam); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextEvent_GetWParam)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxStyledTextEvent *    THIS = (wxStyledTextEvent *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextEvent" )
;
	int	RETVAL;
	dXSTARG;
    try {
      RETVAL = THIS->GetWParam();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__StyledTextEvent_GetLParam); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextEvent_GetLParam)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxStyledTextEvent *    THIS = (wxStyledTextEvent *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextEvent" )
;
	int	RETVAL;
	dXSTARG;
    try {
      RETVAL = THIS->GetLParam();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__StyledTextEvent_GetListType); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextEvent_GetListType)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxStyledTextEvent *    THIS = (wxStyledTextEvent *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextEvent" )
;
	int	RETVAL;
	dXSTARG;
    try {
      RETVAL = THIS->GetListType();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__StyledTextEvent_GetX); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextEvent_GetX)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxStyledTextEvent *    THIS = (wxStyledTextEvent *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextEvent" )
;
	int	RETVAL;
	dXSTARG;
    try {
      RETVAL = THIS->GetX();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__StyledTextEvent_GetY); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextEvent_GetY)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxStyledTextEvent *    THIS = (wxStyledTextEvent *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextEvent" )
;
	int	RETVAL;
	dXSTARG;
    try {
      RETVAL = THIS->GetY();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__StyledTextEvent_GetDragText); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextEvent_GetDragText)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxStyledTextEvent *    THIS = (wxStyledTextEvent *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextEvent" )
;
	wxString	RETVAL;
    try {
      RETVAL = THIS->GetDragText();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    WXSTRING_OUTPUT( RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__StyledTextEvent_GetDragAllowMove); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextEvent_GetDragAllowMove)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxStyledTextEvent *    THIS = (wxStyledTextEvent *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextEvent" )
;
	bool	RETVAL;
    try {
      RETVAL = THIS->GetDragAllowMove();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}

#ifdef STC_USE_DND
#define XSpp_f6372dd8_083841
#define XSubPPtmpAAAV 1


XS_EUPXS(XS_Wx__StyledTextEvent_GetDragResult); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextEvent_GetDragResult)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxStyledTextEvent *    THIS = (wxStyledTextEvent *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextEvent" )
;
	wxDragResult	RETVAL;
	dXSTARG;
    try {
      RETVAL = THIS->GetDragResult();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}

#endif

XS_EUPXS(XS_Wx__StyledTextEvent_GetShift); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextEvent_GetShift)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxStyledTextEvent *    THIS = (wxStyledTextEvent *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextEvent" )
;
	bool	RETVAL;
    try {
      RETVAL = THIS->GetShift();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__StyledTextEvent_GetControl); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextEvent_GetControl)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxStyledTextEvent *    THIS = (wxStyledTextEvent *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextEvent" )
;
	bool	RETVAL;
    try {
      RETVAL = THIS->GetControl();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__StyledTextEvent_GetAlt); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StyledTextEvent_GetAlt)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxStyledTextEvent *    THIS = (wxStyledTextEvent *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StyledTextEvent" )
;
	bool	RETVAL;
    try {
      RETVAL = THIS->GetAlt();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


/* INCLUDE: Returning to 'STC.xs' from '/usr/bin/perl -MExtUtils::XSpp::Cmd -e xspp -- -t ../../typemap.xsp XS/StyledTextEvent.xsp' */

#include "cpp/st_constants.cpp"
#if defined(__WXMSW__)
#undef XS
#define XS( name ) WXXS( name )
#endif
#ifdef __cplusplus
extern "C"
#endif
XS_EXTERNAL(boot_Wx__STC); /* prototype to pass -Wmissing-prototypes */
XS_EXTERNAL(boot_Wx__STC)
{
#if PERL_VERSION_LE(5, 21, 5)
    dVAR; dXSARGS;
#else
    dVAR; dXSBOOTARGSXSAPIVERCHK;
#endif
#if PERL_VERSION_LE(5, 8, 999) /* PERL_VERSION_LT is 5.33+ */
    char* file = __FILE__;
#else
    const char* file = __FILE__;
#endif

    PERL_UNUSED_VAR(file);

    PERL_UNUSED_VAR(cv); /* -W */
    PERL_UNUSED_VAR(items); /* -W */
#if PERL_VERSION_LE(5, 21, 5)
    XS_VERSION_BOOTCHECK;
#  ifdef XS_APIVERSION_BOOTCHECK
    XS_APIVERSION_BOOTCHECK;
#  endif
#endif

        newXS_deffile("Wx::StyledTextCtrl::new", XS_Wx__StyledTextCtrl_new);
        newXS_deffile("Wx::StyledTextCtrl::AddText", XS_Wx__StyledTextCtrl_AddText);
        newXS_deffile("Wx::StyledTextCtrl::SetLexer", XS_Wx__StyledTextCtrl_SetLexer);
        newXS_deffile("Wx::StyledTextCtrl::GetLexer", XS_Wx__StyledTextCtrl_GetLexer);
        newXS_deffile("Wx::StyledTextCtrl::StyleSetSpec", XS_Wx__StyledTextCtrl_StyleSetSpec);
        newXS_deffile("Wx::StyledTextCtrl::StyleSetFont", XS_Wx__StyledTextCtrl_StyleSetFont);
        newXS_deffile("Wx::StyledTextCtrl::StyleSetFontAttr", XS_Wx__StyledTextCtrl_StyleSetFontAttr);
        newXS_deffile("Wx::StyledTextCtrl::StyleClearAll", XS_Wx__StyledTextCtrl_StyleClearAll);
        newXS_deffile("Wx::StyledTextCtrl::ClearDocumentStyle", XS_Wx__StyledTextCtrl_ClearDocumentStyle);
        newXS_deffile("Wx::StyledTextCtrl::StyleSetForeground", XS_Wx__StyledTextCtrl_StyleSetForeground);
        newXS_deffile("Wx::StyledTextCtrl::StyleSetBackground", XS_Wx__StyledTextCtrl_StyleSetBackground);
        newXS_deffile("Wx::StyledTextCtrl::StyleSetBold", XS_Wx__StyledTextCtrl_StyleSetBold);
        newXS_deffile("Wx::StyledTextCtrl::StyleSetItalic", XS_Wx__StyledTextCtrl_StyleSetItalic);
        newXS_deffile("Wx::StyledTextCtrl::StyleSetUnderline", XS_Wx__StyledTextCtrl_StyleSetUnderline);
        newXS_deffile("Wx::StyledTextCtrl::InsertText", XS_Wx__StyledTextCtrl_InsertText);
        newXS_deffile("Wx::StyledTextCtrl::StyleSetSize", XS_Wx__StyledTextCtrl_StyleSetSize);
        newXS_deffile("Wx::StyledTextCtrl::StyleSetFaceName", XS_Wx__StyledTextCtrl_StyleSetFaceName);
        newXS_deffile("Wx::StyledTextCtrl::StyleSetEOLFilled", XS_Wx__StyledTextCtrl_StyleSetEOLFilled);
        newXS_deffile("Wx::StyledTextCtrl::StyleResetDefault", XS_Wx__StyledTextCtrl_StyleResetDefault);
        newXS_deffile("Wx::StyledTextCtrl::StyleSetCase", XS_Wx__StyledTextCtrl_StyleSetCase);
        newXS_deffile("Wx::StyledTextCtrl::StyleSetCharacterSet", XS_Wx__StyledTextCtrl_StyleSetCharacterSet);
        newXS_deffile("Wx::StyledTextCtrl::SetSelForeground", XS_Wx__StyledTextCtrl_SetSelForeground);
        newXS_deffile("Wx::StyledTextCtrl::SetSelBackground", XS_Wx__StyledTextCtrl_SetSelBackground);
        newXS_deffile("Wx::StyledTextCtrl::SetCaretForeground", XS_Wx__StyledTextCtrl_SetCaretForeground);
        newXS_deffile("Wx::StyledTextCtrl::CmdKeyAssign", XS_Wx__StyledTextCtrl_CmdKeyAssign);
        newXS_deffile("Wx::StyledTextCtrl::CmdKeyClear", XS_Wx__StyledTextCtrl_CmdKeyClear);
        newXS_deffile("Wx::StyledTextCtrl::CmdKeyClearAll", XS_Wx__StyledTextCtrl_CmdKeyClearAll);
        newXS_deffile("Wx::StyledTextCtrl::SetStyleBytes", XS_Wx__StyledTextCtrl_SetStyleBytes);
        newXS_deffile("Wx::StyledTextCtrl::StyleSetVisible", XS_Wx__StyledTextCtrl_StyleSetVisible);
        newXS_deffile("Wx::StyledTextCtrl::GetCaretPeriod", XS_Wx__StyledTextCtrl_GetCaretPeriod);
        newXS_deffile("Wx::StyledTextCtrl::SetCaretPeriod", XS_Wx__StyledTextCtrl_SetCaretPeriod);
        newXS_deffile("Wx::StyledTextCtrl::SetWordChars", XS_Wx__StyledTextCtrl_SetWordChars);
        newXS_deffile("Wx::StyledTextCtrl::BeginUndoAction", XS_Wx__StyledTextCtrl_BeginUndoAction);
        newXS_deffile("Wx::StyledTextCtrl::EndUndoAction", XS_Wx__StyledTextCtrl_EndUndoAction);
        newXS_deffile("Wx::StyledTextCtrl::IndicatorSetStyle", XS_Wx__StyledTextCtrl_IndicatorSetStyle);
        newXS_deffile("Wx::StyledTextCtrl::IndicatorGetStyle", XS_Wx__StyledTextCtrl_IndicatorGetStyle);
        newXS_deffile("Wx::StyledTextCtrl::IndicatorSetForeground", XS_Wx__StyledTextCtrl_IndicatorSetForeground);
        newXS_deffile("Wx::StyledTextCtrl::SetWhitespaceForeground", XS_Wx__StyledTextCtrl_SetWhitespaceForeground);
        newXS_deffile("Wx::StyledTextCtrl::SetWhitespaceBackground", XS_Wx__StyledTextCtrl_SetWhitespaceBackground);
        newXS_deffile("Wx::StyledTextCtrl::SetStyleBits", XS_Wx__StyledTextCtrl_SetStyleBits);
        newXS_deffile("Wx::StyledTextCtrl::GetStyleBits", XS_Wx__StyledTextCtrl_GetStyleBits);
        newXS_deffile("Wx::StyledTextCtrl::SetLineState", XS_Wx__StyledTextCtrl_SetLineState);
        newXS_deffile("Wx::StyledTextCtrl::GetLineState", XS_Wx__StyledTextCtrl_GetLineState);
        newXS_deffile("Wx::StyledTextCtrl::GetMaxLineState", XS_Wx__StyledTextCtrl_GetMaxLineState);
        newXS_deffile("Wx::StyledTextCtrl::GetCaretLineVisible", XS_Wx__StyledTextCtrl_GetCaretLineVisible);
        newXS_deffile("Wx::StyledTextCtrl::SetCaretLineVisible", XS_Wx__StyledTextCtrl_SetCaretLineVisible);
#if XSubPPtmpAAAA
        newXS_deffile("Wx::StyledTextCtrl::SetCaretLineBack", XS_Wx__StyledTextCtrl_SetCaretLineBack);
#endif
#if XSubPPtmpAAAB
        newXS_deffile("Wx::StyledTextCtrl::SetCaretLineBack", XS_Wx__StyledTextCtrl_SetCaretLineBack);
        newXS_deffile("Wx::StyledTextCtrl::SetCaretLineBackground", XS_Wx__StyledTextCtrl_SetCaretLineBackground);
#endif
        newXS_deffile("Wx::StyledTextCtrl::StyleSetChangeable", XS_Wx__StyledTextCtrl_StyleSetChangeable);
        newXS_deffile("Wx::StyledTextCtrl::AutoCompShow", XS_Wx__StyledTextCtrl_AutoCompShow);
        newXS_deffile("Wx::StyledTextCtrl::AutoCompCancel", XS_Wx__StyledTextCtrl_AutoCompCancel);
        newXS_deffile("Wx::StyledTextCtrl::AutoCompActive", XS_Wx__StyledTextCtrl_AutoCompActive);
        newXS_deffile("Wx::StyledTextCtrl::AutoCompPosStart", XS_Wx__StyledTextCtrl_AutoCompPosStart);
        newXS_deffile("Wx::StyledTextCtrl::AutoCompComplete", XS_Wx__StyledTextCtrl_AutoCompComplete);
        newXS_deffile("Wx::StyledTextCtrl::AutoCompStops", XS_Wx__StyledTextCtrl_AutoCompStops);
        newXS_deffile("Wx::StyledTextCtrl::AutoCompSetSeparator", XS_Wx__StyledTextCtrl_AutoCompSetSeparator);
        newXS_deffile("Wx::StyledTextCtrl::AutoCompGetSeparator", XS_Wx__StyledTextCtrl_AutoCompGetSeparator);
        newXS_deffile("Wx::StyledTextCtrl::AutoCompSelect", XS_Wx__StyledTextCtrl_AutoCompSelect);
        newXS_deffile("Wx::StyledTextCtrl::AutoCompSetCancelAtStart", XS_Wx__StyledTextCtrl_AutoCompSetCancelAtStart);
        newXS_deffile("Wx::StyledTextCtrl::AutoCompGetCancelAtStart", XS_Wx__StyledTextCtrl_AutoCompGetCancelAtStart);
        newXS_deffile("Wx::StyledTextCtrl::AutoCompSetFillUps", XS_Wx__StyledTextCtrl_AutoCompSetFillUps);
        newXS_deffile("Wx::StyledTextCtrl::AutoCompSetChooseSingle", XS_Wx__StyledTextCtrl_AutoCompSetChooseSingle);
        newXS_deffile("Wx::StyledTextCtrl::AutoCompGetChooseSingle", XS_Wx__StyledTextCtrl_AutoCompGetChooseSingle);
        newXS_deffile("Wx::StyledTextCtrl::AutoCompGetIgnoreCase", XS_Wx__StyledTextCtrl_AutoCompGetIgnoreCase);
        newXS_deffile("Wx::StyledTextCtrl::UserListShow", XS_Wx__StyledTextCtrl_UserListShow);
        newXS_deffile("Wx::StyledTextCtrl::AutoCompSetAutoHide", XS_Wx__StyledTextCtrl_AutoCompSetAutoHide);
        newXS_deffile("Wx::StyledTextCtrl::AutoCompGetAutoHide", XS_Wx__StyledTextCtrl_AutoCompGetAutoHide);
        newXS_deffile("Wx::StyledTextCtrl::AutoCompSetDropRestOfWord", XS_Wx__StyledTextCtrl_AutoCompSetDropRestOfWord);
        newXS_deffile("Wx::StyledTextCtrl::AutoCompGetDropRestOfWord", XS_Wx__StyledTextCtrl_AutoCompGetDropRestOfWord);
        newXS_deffile("Wx::StyledTextCtrl::SetIndent", XS_Wx__StyledTextCtrl_SetIndent);
        newXS_deffile("Wx::StyledTextCtrl::GetIndent", XS_Wx__StyledTextCtrl_GetIndent);
        newXS_deffile("Wx::StyledTextCtrl::SetUseTabs", XS_Wx__StyledTextCtrl_SetUseTabs);
        newXS_deffile("Wx::StyledTextCtrl::GetUseTabs", XS_Wx__StyledTextCtrl_GetUseTabs);
        newXS_deffile("Wx::StyledTextCtrl::SetLineIndentation", XS_Wx__StyledTextCtrl_SetLineIndentation);
        newXS_deffile("Wx::StyledTextCtrl::GetLineIndentation", XS_Wx__StyledTextCtrl_GetLineIndentation);
        newXS_deffile("Wx::StyledTextCtrl::GetLineIndentPosition", XS_Wx__StyledTextCtrl_GetLineIndentPosition);
        newXS_deffile("Wx::StyledTextCtrl::GetColumn", XS_Wx__StyledTextCtrl_GetColumn);
        newXS_deffile("Wx::StyledTextCtrl::SetUseHorizontalScrollBar", XS_Wx__StyledTextCtrl_SetUseHorizontalScrollBar);
        newXS_deffile("Wx::StyledTextCtrl::GetUseHorizontalScrollBar", XS_Wx__StyledTextCtrl_GetUseHorizontalScrollBar);
        newXS_deffile("Wx::StyledTextCtrl::SetIndentationGuides", XS_Wx__StyledTextCtrl_SetIndentationGuides);
        newXS_deffile("Wx::StyledTextCtrl::GetIndentationGuides", XS_Wx__StyledTextCtrl_GetIndentationGuides);
        newXS_deffile("Wx::StyledTextCtrl::SetHighlightGuide", XS_Wx__StyledTextCtrl_SetHighlightGuide);
        newXS_deffile("Wx::StyledTextCtrl::GetHighlightGuide", XS_Wx__StyledTextCtrl_GetHighlightGuide);
        newXS_deffile("Wx::StyledTextCtrl::GetLineEndPosition", XS_Wx__StyledTextCtrl_GetLineEndPosition);
        newXS_deffile("Wx::StyledTextCtrl::GetCodePage", XS_Wx__StyledTextCtrl_GetCodePage);
        newXS_deffile("Wx::StyledTextCtrl::GetReadOnly", XS_Wx__StyledTextCtrl_GetReadOnly);
        newXS_deffile("Wx::StyledTextCtrl::SetCurrentPos", XS_Wx__StyledTextCtrl_SetCurrentPos);
        newXS_deffile("Wx::StyledTextCtrl::SetSelectionStart", XS_Wx__StyledTextCtrl_SetSelectionStart);
        newXS_deffile("Wx::StyledTextCtrl::GetSelectionStart", XS_Wx__StyledTextCtrl_GetSelectionStart);
        newXS_deffile("Wx::StyledTextCtrl::SetSelectionEnd", XS_Wx__StyledTextCtrl_SetSelectionEnd);
        newXS_deffile("Wx::StyledTextCtrl::GetSelectionEnd", XS_Wx__StyledTextCtrl_GetSelectionEnd);
        newXS_deffile("Wx::StyledTextCtrl::SetPrintMagnification", XS_Wx__StyledTextCtrl_SetPrintMagnification);
        newXS_deffile("Wx::StyledTextCtrl::GetPrintMagnification", XS_Wx__StyledTextCtrl_GetPrintMagnification);
        newXS_deffile("Wx::StyledTextCtrl::SetPrintColourMode", XS_Wx__StyledTextCtrl_SetPrintColourMode);
        newXS_deffile("Wx::StyledTextCtrl::GetPrintColourMode", XS_Wx__StyledTextCtrl_GetPrintColourMode);
        newXS_deffile("Wx::StyledTextCtrl::FindText", XS_Wx__StyledTextCtrl_FindText);
        newXS_deffile("Wx::StyledTextCtrl::GetFirstVisibleLine", XS_Wx__StyledTextCtrl_GetFirstVisibleLine);
        newXS_deffile("Wx::StyledTextCtrl::GetLineCount", XS_Wx__StyledTextCtrl_GetLineCount);
        newXS_deffile("Wx::StyledTextCtrl::SetMarginLeft", XS_Wx__StyledTextCtrl_SetMarginLeft);
        newXS_deffile("Wx::StyledTextCtrl::GetMarginLeft", XS_Wx__StyledTextCtrl_GetMarginLeft);
        newXS_deffile("Wx::StyledTextCtrl::SetMarginRight", XS_Wx__StyledTextCtrl_SetMarginRight);
        newXS_deffile("Wx::StyledTextCtrl::GetMarginRight", XS_Wx__StyledTextCtrl_GetMarginRight);
        newXS_deffile("Wx::StyledTextCtrl::GetModify", XS_Wx__StyledTextCtrl_GetModify);
        newXS_deffile("Wx::StyledTextCtrl::SetSelection", XS_Wx__StyledTextCtrl_SetSelection);
#if XSubPPtmpAAAC
        newXS_deffile("Wx::StyledTextCtrl::SetSelectionMode", XS_Wx__StyledTextCtrl_SetSelectionMode);
        newXS_deffile("Wx::StyledTextCtrl::GetSelectionMode", XS_Wx__StyledTextCtrl_GetSelectionMode);
#endif
        newXS_deffile("Wx::StyledTextCtrl::HideSelection", XS_Wx__StyledTextCtrl_HideSelection);
        newXS_deffile("Wx::StyledTextCtrl::LineFromPosition", XS_Wx__StyledTextCtrl_LineFromPosition);
        newXS_deffile("Wx::StyledTextCtrl::PositionFromLine", XS_Wx__StyledTextCtrl_PositionFromLine);
        newXS_deffile("Wx::StyledTextCtrl::LineScroll", XS_Wx__StyledTextCtrl_LineScroll);
        newXS_deffile("Wx::StyledTextCtrl::EnsureCaretVisible", XS_Wx__StyledTextCtrl_EnsureCaretVisible);
        newXS_deffile("Wx::StyledTextCtrl::ReplaceSelection", XS_Wx__StyledTextCtrl_ReplaceSelection);
        newXS_deffile("Wx::StyledTextCtrl::SetReadOnly", XS_Wx__StyledTextCtrl_SetReadOnly);
        newXS_deffile("Wx::StyledTextCtrl::CanPaste", XS_Wx__StyledTextCtrl_CanPaste);
        newXS_deffile("Wx::StyledTextCtrl::CanUndo", XS_Wx__StyledTextCtrl_CanUndo);
        newXS_deffile("Wx::StyledTextCtrl::EmptyUndoBuffer", XS_Wx__StyledTextCtrl_EmptyUndoBuffer);
        newXS_deffile("Wx::StyledTextCtrl::Undo", XS_Wx__StyledTextCtrl_Undo);
        newXS_deffile("Wx::StyledTextCtrl::Cut", XS_Wx__StyledTextCtrl_Cut);
        newXS_deffile("Wx::StyledTextCtrl::Copy", XS_Wx__StyledTextCtrl_Copy);
        newXS_deffile("Wx::StyledTextCtrl::Paste", XS_Wx__StyledTextCtrl_Paste);
        newXS_deffile("Wx::StyledTextCtrl::Clear", XS_Wx__StyledTextCtrl_Clear);
        newXS_deffile("Wx::StyledTextCtrl::GetTextLength", XS_Wx__StyledTextCtrl_GetTextLength);
        newXS_deffile("Wx::StyledTextCtrl::SetOvertype", XS_Wx__StyledTextCtrl_SetOvertype);
        newXS_deffile("Wx::StyledTextCtrl::GetOvertype", XS_Wx__StyledTextCtrl_GetOvertype);
        newXS_deffile("Wx::StyledTextCtrl::SetCaretWidth", XS_Wx__StyledTextCtrl_SetCaretWidth);
        newXS_deffile("Wx::StyledTextCtrl::GetCaretWidth", XS_Wx__StyledTextCtrl_GetCaretWidth);
        newXS_deffile("Wx::StyledTextCtrl::SetTargetStart", XS_Wx__StyledTextCtrl_SetTargetStart);
        newXS_deffile("Wx::StyledTextCtrl::GetTargetStart", XS_Wx__StyledTextCtrl_GetTargetStart);
        newXS_deffile("Wx::StyledTextCtrl::SetTargetEnd", XS_Wx__StyledTextCtrl_SetTargetEnd);
        newXS_deffile("Wx::StyledTextCtrl::GetTargetEnd", XS_Wx__StyledTextCtrl_GetTargetEnd);
        newXS_deffile("Wx::StyledTextCtrl::ReplaceTarget", XS_Wx__StyledTextCtrl_ReplaceTarget);
        newXS_deffile("Wx::StyledTextCtrl::ReplaceTargetRE", XS_Wx__StyledTextCtrl_ReplaceTargetRE);
        newXS_deffile("Wx::StyledTextCtrl::SearchInTarget", XS_Wx__StyledTextCtrl_SearchInTarget);
        newXS_deffile("Wx::StyledTextCtrl::SetSearchFlags", XS_Wx__StyledTextCtrl_SetSearchFlags);
        newXS_deffile("Wx::StyledTextCtrl::GetSearchFlags", XS_Wx__StyledTextCtrl_GetSearchFlags);
        newXS_deffile("Wx::StyledTextCtrl::CallTipShow", XS_Wx__StyledTextCtrl_CallTipShow);
        newXS_deffile("Wx::StyledTextCtrl::CallTipCancel", XS_Wx__StyledTextCtrl_CallTipCancel);
        newXS_deffile("Wx::StyledTextCtrl::CallTipActive", XS_Wx__StyledTextCtrl_CallTipActive);
        newXS_deffile("Wx::StyledTextCtrl::CallTipPosAtStart", XS_Wx__StyledTextCtrl_CallTipPosAtStart);
        newXS_deffile("Wx::StyledTextCtrl::CallTipSetHighlight", XS_Wx__StyledTextCtrl_CallTipSetHighlight);
        newXS_deffile("Wx::StyledTextCtrl::CallTipSetBackground", XS_Wx__StyledTextCtrl_CallTipSetBackground);
        newXS_deffile("Wx::StyledTextCtrl::VisibleFromDocLine", XS_Wx__StyledTextCtrl_VisibleFromDocLine);
        newXS_deffile("Wx::StyledTextCtrl::DocLineFromVisible", XS_Wx__StyledTextCtrl_DocLineFromVisible);
        newXS_deffile("Wx::StyledTextCtrl::SetFoldLevel", XS_Wx__StyledTextCtrl_SetFoldLevel);
        newXS_deffile("Wx::StyledTextCtrl::GetFoldLevel", XS_Wx__StyledTextCtrl_GetFoldLevel);
        newXS_deffile("Wx::StyledTextCtrl::GetLastChild", XS_Wx__StyledTextCtrl_GetLastChild);
        newXS_deffile("Wx::StyledTextCtrl::GetFoldParent", XS_Wx__StyledTextCtrl_GetFoldParent);
        newXS_deffile("Wx::StyledTextCtrl::ShowLines", XS_Wx__StyledTextCtrl_ShowLines);
        newXS_deffile("Wx::StyledTextCtrl::HideLines", XS_Wx__StyledTextCtrl_HideLines);
        newXS_deffile("Wx::StyledTextCtrl::GetLineVisible", XS_Wx__StyledTextCtrl_GetLineVisible);
        newXS_deffile("Wx::StyledTextCtrl::SetFoldExpanded", XS_Wx__StyledTextCtrl_SetFoldExpanded);
        newXS_deffile("Wx::StyledTextCtrl::GetFoldExpanded", XS_Wx__StyledTextCtrl_GetFoldExpanded);
        newXS_deffile("Wx::StyledTextCtrl::ToggleFold", XS_Wx__StyledTextCtrl_ToggleFold);
        newXS_deffile("Wx::StyledTextCtrl::EnsureVisible", XS_Wx__StyledTextCtrl_EnsureVisible);
        newXS_deffile("Wx::StyledTextCtrl::SetFoldFlags", XS_Wx__StyledTextCtrl_SetFoldFlags);
        newXS_deffile("Wx::StyledTextCtrl::EnsureVisibleEnforcePolicy", XS_Wx__StyledTextCtrl_EnsureVisibleEnforcePolicy);
        newXS_deffile("Wx::StyledTextCtrl::SetTabIndents", XS_Wx__StyledTextCtrl_SetTabIndents);
        newXS_deffile("Wx::StyledTextCtrl::GetTabIndents", XS_Wx__StyledTextCtrl_GetTabIndents);
        newXS_deffile("Wx::StyledTextCtrl::SetBackSpaceUnIndents", XS_Wx__StyledTextCtrl_SetBackSpaceUnIndents);
        newXS_deffile("Wx::StyledTextCtrl::GetBackSpaceUnIndents", XS_Wx__StyledTextCtrl_GetBackSpaceUnIndents);
        newXS_deffile("Wx::StyledTextCtrl::SetMouseDwellTime", XS_Wx__StyledTextCtrl_SetMouseDwellTime);
        newXS_deffile("Wx::StyledTextCtrl::GetMouseDwellTime", XS_Wx__StyledTextCtrl_GetMouseDwellTime);
        newXS_deffile("Wx::StyledTextCtrl::WordStartPosition", XS_Wx__StyledTextCtrl_WordStartPosition);
        newXS_deffile("Wx::StyledTextCtrl::WordEndPosition", XS_Wx__StyledTextCtrl_WordEndPosition);
        newXS_deffile("Wx::StyledTextCtrl::SetLayoutCache", XS_Wx__StyledTextCtrl_SetLayoutCache);
        newXS_deffile("Wx::StyledTextCtrl::GetLayoutCache", XS_Wx__StyledTextCtrl_GetLayoutCache);
        newXS_deffile("Wx::StyledTextCtrl::SetScrollWidth", XS_Wx__StyledTextCtrl_SetScrollWidth);
        newXS_deffile("Wx::StyledTextCtrl::GetScrollWidth", XS_Wx__StyledTextCtrl_GetScrollWidth);
        newXS_deffile("Wx::StyledTextCtrl::TextWidth", XS_Wx__StyledTextCtrl_TextWidth);
        newXS_deffile("Wx::StyledTextCtrl::SetEndAtLastLine", XS_Wx__StyledTextCtrl_SetEndAtLastLine);
        newXS_deffile("Wx::StyledTextCtrl::GetEndAtLastLine", XS_Wx__StyledTextCtrl_GetEndAtLastLine);
        newXS_deffile("Wx::StyledTextCtrl::TextHeight", XS_Wx__StyledTextCtrl_TextHeight);
        newXS_deffile("Wx::StyledTextCtrl::HomeDisplay", XS_Wx__StyledTextCtrl_HomeDisplay);
        newXS_deffile("Wx::StyledTextCtrl::HomeDisplayExtend", XS_Wx__StyledTextCtrl_HomeDisplayExtend);
        newXS_deffile("Wx::StyledTextCtrl::LineEndDisplay", XS_Wx__StyledTextCtrl_LineEndDisplay);
        newXS_deffile("Wx::StyledTextCtrl::LineEndDisplayExtend", XS_Wx__StyledTextCtrl_LineEndDisplayExtend);
        newXS_deffile("Wx::StyledTextCtrl::MoveCaretInsideView", XS_Wx__StyledTextCtrl_MoveCaretInsideView);
        newXS_deffile("Wx::StyledTextCtrl::LineLength", XS_Wx__StyledTextCtrl_LineLength);
        newXS_deffile("Wx::StyledTextCtrl::BraceHighlight", XS_Wx__StyledTextCtrl_BraceHighlight);
        newXS_deffile("Wx::StyledTextCtrl::BraceBadLight", XS_Wx__StyledTextCtrl_BraceBadLight);
        newXS_deffile("Wx::StyledTextCtrl::BraceMatch", XS_Wx__StyledTextCtrl_BraceMatch);
        newXS_deffile("Wx::StyledTextCtrl::GetViewEOL", XS_Wx__StyledTextCtrl_GetViewEOL);
        newXS_deffile("Wx::StyledTextCtrl::SetViewEOL", XS_Wx__StyledTextCtrl_SetViewEOL);
        newXS_deffile("Wx::StyledTextCtrl::GetDocPointer", XS_Wx__StyledTextCtrl_GetDocPointer);
        newXS_deffile("Wx::StyledTextCtrl::SetDocPointer", XS_Wx__StyledTextCtrl_SetDocPointer);
        newXS_deffile("Wx::StyledTextCtrl::SetModEventMask", XS_Wx__StyledTextCtrl_SetModEventMask);
        newXS_deffile("Wx::StyledTextCtrl::GetEdgeColumn", XS_Wx__StyledTextCtrl_GetEdgeColumn);
        newXS_deffile("Wx::StyledTextCtrl::SetEdgeColumn", XS_Wx__StyledTextCtrl_SetEdgeColumn);
        newXS_deffile("Wx::StyledTextCtrl::GetEdgeMode", XS_Wx__StyledTextCtrl_GetEdgeMode);
        newXS_deffile("Wx::StyledTextCtrl::SetEdgeMode", XS_Wx__StyledTextCtrl_SetEdgeMode);
        newXS_deffile("Wx::StyledTextCtrl::SetEdgeColour", XS_Wx__StyledTextCtrl_SetEdgeColour);
        newXS_deffile("Wx::StyledTextCtrl::SearchAnchor", XS_Wx__StyledTextCtrl_SearchAnchor);
        newXS_deffile("Wx::StyledTextCtrl::SearchNext", XS_Wx__StyledTextCtrl_SearchNext);
        newXS_deffile("Wx::StyledTextCtrl::SearchPrev", XS_Wx__StyledTextCtrl_SearchPrev);
        newXS_deffile("Wx::StyledTextCtrl::LinesOnScreen", XS_Wx__StyledTextCtrl_LinesOnScreen);
        newXS_deffile("Wx::StyledTextCtrl::UsePopUp", XS_Wx__StyledTextCtrl_UsePopUp);
        newXS_deffile("Wx::StyledTextCtrl::SelectionIsRectangle", XS_Wx__StyledTextCtrl_SelectionIsRectangle);
        newXS_deffile("Wx::StyledTextCtrl::SetZoom", XS_Wx__StyledTextCtrl_SetZoom);
        newXS_deffile("Wx::StyledTextCtrl::GetZoom", XS_Wx__StyledTextCtrl_GetZoom);
        newXS_deffile("Wx::StyledTextCtrl::CreateDocument", XS_Wx__StyledTextCtrl_CreateDocument);
        newXS_deffile("Wx::StyledTextCtrl::AddRefDocument", XS_Wx__StyledTextCtrl_AddRefDocument);
        newXS_deffile("Wx::StyledTextCtrl::ReleaseDocument", XS_Wx__StyledTextCtrl_ReleaseDocument);
        newXS_deffile("Wx::StyledTextCtrl::GetModEventMask", XS_Wx__StyledTextCtrl_GetModEventMask);
        newXS_deffile("Wx::StyledTextCtrl::SetSTCFocus", XS_Wx__StyledTextCtrl_SetSTCFocus);
        newXS_deffile("Wx::StyledTextCtrl::GetSTCFocus", XS_Wx__StyledTextCtrl_GetSTCFocus);
        newXS_deffile("Wx::StyledTextCtrl::SetStatus", XS_Wx__StyledTextCtrl_SetStatus);
        newXS_deffile("Wx::StyledTextCtrl::GetStatus", XS_Wx__StyledTextCtrl_GetStatus);
        newXS_deffile("Wx::StyledTextCtrl::SetMouseDownCaptures", XS_Wx__StyledTextCtrl_SetMouseDownCaptures);
        newXS_deffile("Wx::StyledTextCtrl::GetMouseDownCaptures", XS_Wx__StyledTextCtrl_GetMouseDownCaptures);
        newXS_deffile("Wx::StyledTextCtrl::SetControlCharSymbol", XS_Wx__StyledTextCtrl_SetControlCharSymbol);
        newXS_deffile("Wx::StyledTextCtrl::GetControlCharSymbol", XS_Wx__StyledTextCtrl_GetControlCharSymbol);
        newXS_deffile("Wx::StyledTextCtrl::WordPartLeft", XS_Wx__StyledTextCtrl_WordPartLeft);
        newXS_deffile("Wx::StyledTextCtrl::WordPartLeftExtend", XS_Wx__StyledTextCtrl_WordPartLeftExtend);
        newXS_deffile("Wx::StyledTextCtrl::WordPartRight", XS_Wx__StyledTextCtrl_WordPartRight);
        newXS_deffile("Wx::StyledTextCtrl::WordPartRightExtend", XS_Wx__StyledTextCtrl_WordPartRightExtend);
        newXS_deffile("Wx::StyledTextCtrl::SetVisiblePolicy", XS_Wx__StyledTextCtrl_SetVisiblePolicy);
        newXS_deffile("Wx::StyledTextCtrl::DelLineLeft", XS_Wx__StyledTextCtrl_DelLineLeft);
        newXS_deffile("Wx::StyledTextCtrl::DelLineRight", XS_Wx__StyledTextCtrl_DelLineRight);
        newXS_deffile("Wx::StyledTextCtrl::SetXOffset", XS_Wx__StyledTextCtrl_SetXOffset);
        newXS_deffile("Wx::StyledTextCtrl::GetXOffset", XS_Wx__StyledTextCtrl_GetXOffset);
        newXS_deffile("Wx::StyledTextCtrl::SetXCaretPolicy", XS_Wx__StyledTextCtrl_SetXCaretPolicy);
        newXS_deffile("Wx::StyledTextCtrl::SetYCaretPolicy", XS_Wx__StyledTextCtrl_SetYCaretPolicy);
        newXS_deffile("Wx::StyledTextCtrl::StartRecord", XS_Wx__StyledTextCtrl_StartRecord);
        newXS_deffile("Wx::StyledTextCtrl::StopRecord", XS_Wx__StyledTextCtrl_StopRecord);
        newXS_deffile("Wx::StyledTextCtrl::Colourise", XS_Wx__StyledTextCtrl_Colourise);
        newXS_deffile("Wx::StyledTextCtrl::SetProperty", XS_Wx__StyledTextCtrl_SetProperty);
        newXS_deffile("Wx::StyledTextCtrl::SetKeyWords", XS_Wx__StyledTextCtrl_SetKeyWords);
        newXS_deffile("Wx::StyledTextCtrl::SetLexerLanguage", XS_Wx__StyledTextCtrl_SetLexerLanguage);
        newXS_deffile("Wx::StyledTextCtrl::GetSelectedText", XS_Wx__StyledTextCtrl_GetSelectedText);
        newXS_deffile("Wx::StyledTextCtrl::GetTextRange", XS_Wx__StyledTextCtrl_GetTextRange);
        newXS_deffile("Wx::StyledTextCtrl::GetText", XS_Wx__StyledTextCtrl_GetText);
        newXS_deffile("Wx::StyledTextCtrl::GetAnchor", XS_Wx__StyledTextCtrl_GetAnchor);
        newXS_deffile("Wx::StyledTextCtrl::GetStyleAt", XS_Wx__StyledTextCtrl_GetStyleAt);
        newXS_deffile("Wx::StyledTextCtrl::Redo", XS_Wx__StyledTextCtrl_Redo);
        newXS_deffile("Wx::StyledTextCtrl::SelectAll", XS_Wx__StyledTextCtrl_SelectAll);
        newXS_deffile("Wx::StyledTextCtrl::SetSavePoint", XS_Wx__StyledTextCtrl_SetSavePoint);
        newXS_deffile("Wx::StyledTextCtrl::SetText", XS_Wx__StyledTextCtrl_SetText);
        newXS_deffile("Wx::StyledTextCtrl::CanRedo", XS_Wx__StyledTextCtrl_CanRedo);
        newXS_deffile("Wx::StyledTextCtrl::MarkerLineFromHandle", XS_Wx__StyledTextCtrl_MarkerLineFromHandle);
        newXS_deffile("Wx::StyledTextCtrl::MarkerDeleteHandle", XS_Wx__StyledTextCtrl_MarkerDeleteHandle);
        newXS_deffile("Wx::StyledTextCtrl::GetUndoCollection", XS_Wx__StyledTextCtrl_GetUndoCollection);
        newXS_deffile("Wx::StyledTextCtrl::GetViewWhiteSpace", XS_Wx__StyledTextCtrl_GetViewWhiteSpace);
        newXS_deffile("Wx::StyledTextCtrl::SetViewWhiteSpace", XS_Wx__StyledTextCtrl_SetViewWhiteSpace);
        newXS_deffile("Wx::StyledTextCtrl::PositionFromPoint", XS_Wx__StyledTextCtrl_PositionFromPoint);
        newXS_deffile("Wx::StyledTextCtrl::PositionFromPointClose", XS_Wx__StyledTextCtrl_PositionFromPointClose);
        newXS_deffile("Wx::StyledTextCtrl::GotoLine", XS_Wx__StyledTextCtrl_GotoLine);
        newXS_deffile("Wx::StyledTextCtrl::GotoPos", XS_Wx__StyledTextCtrl_GotoPos);
        newXS_deffile("Wx::StyledTextCtrl::SetAnchor", XS_Wx__StyledTextCtrl_SetAnchor);
        newXS_deffile("Wx::StyledTextCtrl::GetEndStyled", XS_Wx__StyledTextCtrl_GetEndStyled);
        newXS_deffile("Wx::StyledTextCtrl::ConvertEOLs", XS_Wx__StyledTextCtrl_ConvertEOLs);
        newXS_deffile("Wx::StyledTextCtrl::GetEOLMode", XS_Wx__StyledTextCtrl_GetEOLMode);
        newXS_deffile("Wx::StyledTextCtrl::SetEOLMode", XS_Wx__StyledTextCtrl_SetEOLMode);
        newXS_deffile("Wx::StyledTextCtrl::StartStyling", XS_Wx__StyledTextCtrl_StartStyling);
        newXS_deffile("Wx::StyledTextCtrl::SetStyling", XS_Wx__StyledTextCtrl_SetStyling);
        newXS_deffile("Wx::StyledTextCtrl::GetBufferedDraw", XS_Wx__StyledTextCtrl_GetBufferedDraw);
        newXS_deffile("Wx::StyledTextCtrl::SetBufferedDraw", XS_Wx__StyledTextCtrl_SetBufferedDraw);
        newXS_deffile("Wx::StyledTextCtrl::SetTabWidth", XS_Wx__StyledTextCtrl_SetTabWidth);
        newXS_deffile("Wx::StyledTextCtrl::GetTabWidth", XS_Wx__StyledTextCtrl_GetTabWidth);
        newXS_deffile("Wx::StyledTextCtrl::SetCodePage", XS_Wx__StyledTextCtrl_SetCodePage);
        newXS_deffile("Wx::StyledTextCtrl::MarkerDefine", XS_Wx__StyledTextCtrl_MarkerDefine);
        newXS_deffile("Wx::StyledTextCtrl::MarkerDefineBitmap", XS_Wx__StyledTextCtrl_MarkerDefineBitmap);
        newXS_deffile("Wx::StyledTextCtrl::MarkerSetForeground", XS_Wx__StyledTextCtrl_MarkerSetForeground);
        newXS_deffile("Wx::StyledTextCtrl::MarkerSetBackground", XS_Wx__StyledTextCtrl_MarkerSetBackground);
        newXS_deffile("Wx::StyledTextCtrl::MarkerAdd", XS_Wx__StyledTextCtrl_MarkerAdd);
        newXS_deffile("Wx::StyledTextCtrl::MarkerDelete", XS_Wx__StyledTextCtrl_MarkerDelete);
        newXS_deffile("Wx::StyledTextCtrl::MarkerDeleteAll", XS_Wx__StyledTextCtrl_MarkerDeleteAll);
        newXS_deffile("Wx::StyledTextCtrl::MarkerGet", XS_Wx__StyledTextCtrl_MarkerGet);
        newXS_deffile("Wx::StyledTextCtrl::MarkerNext", XS_Wx__StyledTextCtrl_MarkerNext);
        newXS_deffile("Wx::StyledTextCtrl::MarkerPrevious", XS_Wx__StyledTextCtrl_MarkerPrevious);
        newXS_deffile("Wx::StyledTextCtrl::SetMarginType", XS_Wx__StyledTextCtrl_SetMarginType);
        newXS_deffile("Wx::StyledTextCtrl::GetMarginType", XS_Wx__StyledTextCtrl_GetMarginType);
        newXS_deffile("Wx::StyledTextCtrl::SetMarginWidth", XS_Wx__StyledTextCtrl_SetMarginWidth);
        newXS_deffile("Wx::StyledTextCtrl::GetMarginWidth", XS_Wx__StyledTextCtrl_GetMarginWidth);
        newXS_deffile("Wx::StyledTextCtrl::SetMarginMask", XS_Wx__StyledTextCtrl_SetMarginMask);
        newXS_deffile("Wx::StyledTextCtrl::GetMarginMask", XS_Wx__StyledTextCtrl_GetMarginMask);
        newXS_deffile("Wx::StyledTextCtrl::SetMarginSensitive", XS_Wx__StyledTextCtrl_SetMarginSensitive);
        newXS_deffile("Wx::StyledTextCtrl::GetMarginSensitive", XS_Wx__StyledTextCtrl_GetMarginSensitive);
        newXS_deffile("Wx::StyledTextCtrl::GetCurrentPos", XS_Wx__StyledTextCtrl_GetCurrentPos);
        newXS_deffile("Wx::StyledTextCtrl::GetLength", XS_Wx__StyledTextCtrl_GetLength);
        newXS_deffile("Wx::StyledTextCtrl::GetCharAt", XS_Wx__StyledTextCtrl_GetCharAt);
        newXS_deffile("Wx::StyledTextCtrl::SetWrapMode", XS_Wx__StyledTextCtrl_SetWrapMode);
        newXS_deffile("Wx::StyledTextCtrl::GetWrapMode", XS_Wx__StyledTextCtrl_GetWrapMode);
        newXS_deffile("Wx::StyledTextCtrl::GetLine", XS_Wx__StyledTextCtrl_GetLine);
        newXS_deffile("Wx::StyledTextCtrl::ClearAll", XS_Wx__StyledTextCtrl_ClearAll);
        newXS_deffile("Wx::StyledTextCtrl::GetCurrentLine", XS_Wx__StyledTextCtrl_GetCurrentLine);
        newXS_deffile("Wx::StyledTextCtrl::CmdKeyExecute", XS_Wx__StyledTextCtrl_CmdKeyExecute);
        newXS_deffile("Wx::StyledTextCtrl::SetMargins", XS_Wx__StyledTextCtrl_SetMargins);
        newXS_deffile("Wx::StyledTextCtrl::SetUndoCollection", XS_Wx__StyledTextCtrl_SetUndoCollection);
        newXS_deffile("Wx::StyledTextCtrl::IndicatorGetForeground", XS_Wx__StyledTextCtrl_IndicatorGetForeground);
#if XSubPPtmpAAAD
        newXS_deffile("Wx::StyledTextCtrl::GetCaretLineBack", XS_Wx__StyledTextCtrl_GetCaretLineBack);
#endif
        newXS_deffile("Wx::StyledTextCtrl::GetCaretForeground", XS_Wx__StyledTextCtrl_GetCaretForeground);
        newXS_deffile("Wx::StyledTextCtrl::FormatRange", XS_Wx__StyledTextCtrl_FormatRange);
        newXS_deffile("Wx::StyledTextCtrl::GetEdgeColour", XS_Wx__StyledTextCtrl_GetEdgeColour);
        newXS_deffile("Wx::StyledTextCtrl::GetLastKeydownProcessed", XS_Wx__StyledTextCtrl_GetLastKeydownProcessed);
        newXS_deffile("Wx::StyledTextCtrl::SetLastKeydownProcessed", XS_Wx__StyledTextCtrl_SetLastKeydownProcessed);
        newXS_deffile("Wx::StyledTextCtrl::PointFromPosition", XS_Wx__StyledTextCtrl_PointFromPosition);
        newXS_deffile("Wx::StyledTextCtrl::ScrollToLine", XS_Wx__StyledTextCtrl_ScrollToLine);
        newXS_deffile("Wx::StyledTextCtrl::SetHScrollBar", XS_Wx__StyledTextCtrl_SetHScrollBar);
        newXS_deffile("Wx::StyledTextCtrl::SetVScrollBar", XS_Wx__StyledTextCtrl_SetVScrollBar);
        newXS_deffile("Wx::StyledTextCtrl::GetSelection", XS_Wx__StyledTextCtrl_GetSelection);
        newXS_deffile("Wx::StyledTextCtrl::SaveFile", XS_Wx__StyledTextCtrl_SaveFile);
        newXS_deffile("Wx::StyledTextCtrl::LoadFile", XS_Wx__StyledTextCtrl_LoadFile);
#if XSubPPtmpAAAE
        newXS_deffile("Wx::StyledTextCtrl::AddTextRaw", XS_Wx__StyledTextCtrl_AddTextRaw);
        newXS_deffile("Wx::StyledTextCtrl::InsertTextRaw", XS_Wx__StyledTextCtrl_InsertTextRaw);
        newXS_deffile("Wx::StyledTextCtrl::AppendTextRaw", XS_Wx__StyledTextCtrl_AppendTextRaw);
#endif
#if XSubPPtmpAAAF
        newXS_deffile("Wx::StyledTextCtrl::AddTextRaw", XS_Wx__StyledTextCtrl_AddTextRaw);
        newXS_deffile("Wx::StyledTextCtrl::InsertTextRaw", XS_Wx__StyledTextCtrl_InsertTextRaw);
        newXS_deffile("Wx::StyledTextCtrl::AppendTextRaw", XS_Wx__StyledTextCtrl_AppendTextRaw);
#endif
        newXS_deffile("Wx::StyledTextCtrl::Allocate", XS_Wx__StyledTextCtrl_Allocate);
#if XSubPPtmpAAAG
        newXS_deffile("Wx::StyledTextCtrl::AppendText", XS_Wx__StyledTextCtrl_AppendText);
#endif
        newXS_deffile("Wx::StyledTextCtrl::AutoCompGetCurrent", XS_Wx__StyledTextCtrl_AutoCompGetCurrent);
        newXS_deffile("Wx::StyledTextCtrl::AutoCompGetTypeSeparator", XS_Wx__StyledTextCtrl_AutoCompGetTypeSeparator);
        newXS_deffile("Wx::StyledTextCtrl::AutoCompSetTypeSeparator", XS_Wx__StyledTextCtrl_AutoCompSetTypeSeparator);
#if XSubPPtmpAAAH
        newXS_deffile("Wx::StyledTextCtrl::AutoCompSetMaxWidth", XS_Wx__StyledTextCtrl_AutoCompSetMaxWidth);
        newXS_deffile("Wx::StyledTextCtrl::AutoCompGetMaxWidth", XS_Wx__StyledTextCtrl_AutoCompGetMaxWidth);
        newXS_deffile("Wx::StyledTextCtrl::AutoCompSetMaxHeight", XS_Wx__StyledTextCtrl_AutoCompSetMaxHeight);
        newXS_deffile("Wx::StyledTextCtrl::AutoCompGetMaxHeight", XS_Wx__StyledTextCtrl_AutoCompGetMaxHeight);
#endif
        newXS_deffile("Wx::StyledTextCtrl::AutoCompSetIgnoreCase", XS_Wx__StyledTextCtrl_AutoCompSetIgnoreCase);
        newXS_deffile("Wx::StyledTextCtrl::BackTab", XS_Wx__StyledTextCtrl_BackTab);
        newXS_deffile("Wx::StyledTextCtrl::CallTipSetForeground", XS_Wx__StyledTextCtrl_CallTipSetForeground);
        newXS_deffile("Wx::StyledTextCtrl::CallTipSetForegroundHighlight", XS_Wx__StyledTextCtrl_CallTipSetForegroundHighlight);
#if XSubPPtmpAAAI
        newXS_deffile("Wx::StyledTextCtrl::CallTipUseStyle", XS_Wx__StyledTextCtrl_CallTipUseStyle);
#endif
        newXS_deffile("Wx::StyledTextCtrl::Cancel", XS_Wx__StyledTextCtrl_Cancel);
        newXS_deffile("Wx::StyledTextCtrl::CharLeft", XS_Wx__StyledTextCtrl_CharLeft);
        newXS_deffile("Wx::StyledTextCtrl::CharLeftExtend", XS_Wx__StyledTextCtrl_CharLeftExtend);
        newXS_deffile("Wx::StyledTextCtrl::CharRight", XS_Wx__StyledTextCtrl_CharRight);
        newXS_deffile("Wx::StyledTextCtrl::CharRightExtend", XS_Wx__StyledTextCtrl_CharRightExtend);
        newXS_deffile("Wx::StyledTextCtrl::CharLeftRectExtend", XS_Wx__StyledTextCtrl_CharLeftRectExtend);
        newXS_deffile("Wx::StyledTextCtrl::CharRightRectExtend", XS_Wx__StyledTextCtrl_CharRightRectExtend);
        newXS_deffile("Wx::StyledTextCtrl::ChooseCaretX", XS_Wx__StyledTextCtrl_ChooseCaretX);
        newXS_deffile("Wx::StyledTextCtrl::ClearRegisteredImages", XS_Wx__StyledTextCtrl_ClearRegisteredImages);
        newXS_deffile("Wx::StyledTextCtrl::CopyRange", XS_Wx__StyledTextCtrl_CopyRange);
        newXS_deffile("Wx::StyledTextCtrl::CopyText", XS_Wx__StyledTextCtrl_CopyText);
        newXS_deffile("Wx::StyledTextCtrl::DelWordLeft", XS_Wx__StyledTextCtrl_DelWordLeft);
        newXS_deffile("Wx::StyledTextCtrl::DelWordRight", XS_Wx__StyledTextCtrl_DelWordRight);
        newXS_deffile("Wx::StyledTextCtrl::DeleteBack", XS_Wx__StyledTextCtrl_DeleteBack);
        newXS_deffile("Wx::StyledTextCtrl::DeleteBackNotLine", XS_Wx__StyledTextCtrl_DeleteBackNotLine);
#if XSubPPtmpAAAJ
        newXS_deffile("Wx::StyledTextCtrl::DoDragOver", XS_Wx__StyledTextCtrl_DoDragOver);
        newXS_deffile("Wx::StyledTextCtrl::DoDropText", XS_Wx__StyledTextCtrl_DoDropText);
#endif
        newXS_deffile("Wx::StyledTextCtrl::DocumentStart", XS_Wx__StyledTextCtrl_DocumentStart);
        newXS_deffile("Wx::StyledTextCtrl::DocumentStartExtend", XS_Wx__StyledTextCtrl_DocumentStartExtend);
        newXS_deffile("Wx::StyledTextCtrl::DocumentEnd", XS_Wx__StyledTextCtrl_DocumentEnd);
        newXS_deffile("Wx::StyledTextCtrl::DocumentEndExtend", XS_Wx__StyledTextCtrl_DocumentEndExtend);
        newXS_deffile("Wx::StyledTextCtrl::EditToggleOvertype", XS_Wx__StyledTextCtrl_EditToggleOvertype);
#if XSubPPtmpAAAK
        newXS_deffile("Wx::StyledTextCtrl::FindColumn", XS_Wx__StyledTextCtrl_FindColumn);
#endif
        newXS_deffile("Wx::StyledTextCtrl::FormFeed", XS_Wx__StyledTextCtrl_FormFeed);
#if XSubPPtmpAAAL
        newXS_deffile("Wx::StyledTextCtrl::SetCaretLineBackAlpha", XS_Wx__StyledTextCtrl_SetCaretLineBackAlpha);
        newXS_deffile("Wx::StyledTextCtrl::GetCaretLineBackAlpha", XS_Wx__StyledTextCtrl_GetCaretLineBackAlpha);
        newXS_deffile("Wx::StyledTextCtrl::GetCaretLineBackground", XS_Wx__StyledTextCtrl_GetCaretLineBackground);
        newXS_deffile("Wx::StyledTextCtrl::GetCaretSticky", XS_Wx__StyledTextCtrl_GetCaretSticky);
        newXS_deffile("Wx::StyledTextCtrl::SetCaretSticky", XS_Wx__StyledTextCtrl_SetCaretSticky);
        newXS_deffile("Wx::StyledTextCtrl::ToggleCaretSticky", XS_Wx__StyledTextCtrl_ToggleCaretSticky);
#endif
        newXS_deffile("Wx::StyledTextCtrl::GetLineSelStartPosition", XS_Wx__StyledTextCtrl_GetLineSelStartPosition);
        newXS_deffile("Wx::StyledTextCtrl::GetLineSelEndPosition", XS_Wx__StyledTextCtrl_GetLineSelEndPosition);
#if XSubPPtmpAAAM
        newXS_deffile("Wx::StyledTextCtrl::SetPasteConvertEndings", XS_Wx__StyledTextCtrl_SetPasteConvertEndings);
        newXS_deffile("Wx::StyledTextCtrl::GetPasteConvertEndings", XS_Wx__StyledTextCtrl_GetPasteConvertEndings);
#endif
        newXS_deffile("Wx::StyledTextCtrl::SetPrintWrapMode", XS_Wx__StyledTextCtrl_SetPrintWrapMode);
        newXS_deffile("Wx::StyledTextCtrl::GetPrintWrapMode", XS_Wx__StyledTextCtrl_GetPrintWrapMode);
#if XSubPPtmpAAAN
        newXS_deffile("Wx::StyledTextCtrl::GetProperty", XS_Wx__StyledTextCtrl_GetProperty);
        newXS_deffile("Wx::StyledTextCtrl::GetPropertyExpanded", XS_Wx__StyledTextCtrl_GetPropertyExpanded);
        newXS_deffile("Wx::StyledTextCtrl::GetPropertyInt", XS_Wx__StyledTextCtrl_GetPropertyInt);
#endif
        newXS_deffile("Wx::StyledTextCtrl::GetSTCCursor", XS_Wx__StyledTextCtrl_GetSTCCursor);
        newXS_deffile("Wx::StyledTextCtrl::SetSTCCursor", XS_Wx__StyledTextCtrl_SetSTCCursor);
#if XSubPPtmpAAAO
        newXS_deffile("Wx::StyledTextCtrl::GetSelAlpha", XS_Wx__StyledTextCtrl_GetSelAlpha);
        newXS_deffile("Wx::StyledTextCtrl::SetSelAlpha", XS_Wx__StyledTextCtrl_SetSelAlpha);
        newXS_deffile("Wx::StyledTextCtrl::GetStyleBitsNeeded", XS_Wx__StyledTextCtrl_GetStyleBitsNeeded);
#endif
        newXS_deffile("Wx::StyledTextCtrl::GetTwoPhaseDraw", XS_Wx__StyledTextCtrl_GetTwoPhaseDraw);
        newXS_deffile("Wx::StyledTextCtrl::SetTwoPhaseDraw", XS_Wx__StyledTextCtrl_SetTwoPhaseDraw);
        newXS_deffile("Wx::StyledTextCtrl::SetUseAntiAliasing", XS_Wx__StyledTextCtrl_SetUseAntiAliasing);
        newXS_deffile("Wx::StyledTextCtrl::GetUseAntiAliasing", XS_Wx__StyledTextCtrl_GetUseAntiAliasing);
        newXS_deffile("Wx::StyledTextCtrl::SetUseVerticalScrollBar", XS_Wx__StyledTextCtrl_SetUseVerticalScrollBar);
        newXS_deffile("Wx::StyledTextCtrl::GetUseVerticalScrollBar", XS_Wx__StyledTextCtrl_GetUseVerticalScrollBar);
        newXS_deffile("Wx::StyledTextCtrl::SetWrapVisualFlags", XS_Wx__StyledTextCtrl_SetWrapVisualFlags);
        newXS_deffile("Wx::StyledTextCtrl::GetWrapVisualFlags", XS_Wx__StyledTextCtrl_GetWrapVisualFlags);
        newXS_deffile("Wx::StyledTextCtrl::SetWrapVisualFlagsLocation", XS_Wx__StyledTextCtrl_SetWrapVisualFlagsLocation);
        newXS_deffile("Wx::StyledTextCtrl::GetWrapVisualFlagsLocation", XS_Wx__StyledTextCtrl_GetWrapVisualFlagsLocation);
        newXS_deffile("Wx::StyledTextCtrl::SetWrapStartIndent", XS_Wx__StyledTextCtrl_SetWrapStartIndent);
        newXS_deffile("Wx::StyledTextCtrl::GetWrapStartIndent", XS_Wx__StyledTextCtrl_GetWrapStartIndent);
        newXS_deffile("Wx::StyledTextCtrl::Home", XS_Wx__StyledTextCtrl_Home);
        newXS_deffile("Wx::StyledTextCtrl::HomeExtend", XS_Wx__StyledTextCtrl_HomeExtend);
        newXS_deffile("Wx::StyledTextCtrl::HomeRectExtend", XS_Wx__StyledTextCtrl_HomeRectExtend);
        newXS_deffile("Wx::StyledTextCtrl::HomeWrap", XS_Wx__StyledTextCtrl_HomeWrap);
        newXS_deffile("Wx::StyledTextCtrl::HomeWrapExtend", XS_Wx__StyledTextCtrl_HomeWrapExtend);
        newXS_deffile("Wx::StyledTextCtrl::LineCopy", XS_Wx__StyledTextCtrl_LineCopy);
        newXS_deffile("Wx::StyledTextCtrl::LineCut", XS_Wx__StyledTextCtrl_LineCut);
        newXS_deffile("Wx::StyledTextCtrl::LineDelete", XS_Wx__StyledTextCtrl_LineDelete);
        newXS_deffile("Wx::StyledTextCtrl::LineDownExtend", XS_Wx__StyledTextCtrl_LineDownExtend);
        newXS_deffile("Wx::StyledTextCtrl::LineDownRectExtend", XS_Wx__StyledTextCtrl_LineDownRectExtend);
        newXS_deffile("Wx::StyledTextCtrl::LineDuplicate", XS_Wx__StyledTextCtrl_LineDuplicate);
        newXS_deffile("Wx::StyledTextCtrl::LineEnd", XS_Wx__StyledTextCtrl_LineEnd);
        newXS_deffile("Wx::StyledTextCtrl::LineEndExtend", XS_Wx__StyledTextCtrl_LineEndExtend);
        newXS_deffile("Wx::StyledTextCtrl::LineEndRectExtend", XS_Wx__StyledTextCtrl_LineEndRectExtend);
        newXS_deffile("Wx::StyledTextCtrl::LineEndWrap", XS_Wx__StyledTextCtrl_LineEndWrap);
        newXS_deffile("Wx::StyledTextCtrl::LineEndWrapExtend", XS_Wx__StyledTextCtrl_LineEndWrapExtend);
        newXS_deffile("Wx::StyledTextCtrl::LineScrollDown", XS_Wx__StyledTextCtrl_LineScrollDown);
        newXS_deffile("Wx::StyledTextCtrl::LineScrollUp", XS_Wx__StyledTextCtrl_LineScrollUp);
        newXS_deffile("Wx::StyledTextCtrl::LineTranspose", XS_Wx__StyledTextCtrl_LineTranspose);
        newXS_deffile("Wx::StyledTextCtrl::LineUpExtend", XS_Wx__StyledTextCtrl_LineUpExtend);
        newXS_deffile("Wx::StyledTextCtrl::LineUpRectExtend", XS_Wx__StyledTextCtrl_LineUpRectExtend);
        newXS_deffile("Wx::StyledTextCtrl::LineUp", XS_Wx__StyledTextCtrl_LineUp);
        newXS_deffile("Wx::StyledTextCtrl::LineDown", XS_Wx__StyledTextCtrl_LineDown);
        newXS_deffile("Wx::StyledTextCtrl::LinesJoin", XS_Wx__StyledTextCtrl_LinesJoin);
        newXS_deffile("Wx::StyledTextCtrl::LinesSplit", XS_Wx__StyledTextCtrl_LinesSplit);
        newXS_deffile("Wx::StyledTextCtrl::LowerCase", XS_Wx__StyledTextCtrl_LowerCase);
        newXS_deffile("Wx::StyledTextCtrl::UpperCase", XS_Wx__StyledTextCtrl_UpperCase);
#if XSubPPtmpAAAP
        newXS_deffile("Wx::StyledTextCtrl::MarkerAddSet", XS_Wx__StyledTextCtrl_MarkerAddSet);
        newXS_deffile("Wx::StyledTextCtrl::MarkerSetAlpha", XS_Wx__StyledTextCtrl_MarkerSetAlpha);
#endif
        newXS_deffile("Wx::StyledTextCtrl::NewLine", XS_Wx__StyledTextCtrl_NewLine);
        newXS_deffile("Wx::StyledTextCtrl::PageDown", XS_Wx__StyledTextCtrl_PageDown);
        newXS_deffile("Wx::StyledTextCtrl::PageDownExtend", XS_Wx__StyledTextCtrl_PageDownExtend);
        newXS_deffile("Wx::StyledTextCtrl::PageDownRectExtend", XS_Wx__StyledTextCtrl_PageDownRectExtend);
        newXS_deffile("Wx::StyledTextCtrl::PageUp", XS_Wx__StyledTextCtrl_PageUp);
        newXS_deffile("Wx::StyledTextCtrl::PageUpExtend", XS_Wx__StyledTextCtrl_PageUpExtend);
        newXS_deffile("Wx::StyledTextCtrl::PageUpRectExtend", XS_Wx__StyledTextCtrl_PageUpRectExtend);
        newXS_deffile("Wx::StyledTextCtrl::ParaDown", XS_Wx__StyledTextCtrl_ParaDown);
        newXS_deffile("Wx::StyledTextCtrl::ParaDownExtend", XS_Wx__StyledTextCtrl_ParaDownExtend);
        newXS_deffile("Wx::StyledTextCtrl::ParaUp", XS_Wx__StyledTextCtrl_ParaUp);
        newXS_deffile("Wx::StyledTextCtrl::ParaUpExtend", XS_Wx__StyledTextCtrl_ParaUpExtend);
        newXS_deffile("Wx::StyledTextCtrl::PositionBefore", XS_Wx__StyledTextCtrl_PositionBefore);
        newXS_deffile("Wx::StyledTextCtrl::PositionAfter", XS_Wx__StyledTextCtrl_PositionAfter);
        newXS_deffile("Wx::StyledTextCtrl::RegisterImage", XS_Wx__StyledTextCtrl_RegisterImage);
        newXS_deffile("Wx::StyledTextCtrl::ScrollToColumn", XS_Wx__StyledTextCtrl_ScrollToColumn);
#if XSubPPtmpAAAQ
        newXS_deffile("Wx::StyledTextCtrl::SelectionDuplicate", XS_Wx__StyledTextCtrl_SelectionDuplicate);
#endif
        newXS_deffile("Wx::StyledTextCtrl::SetCharsDefault", XS_Wx__StyledTextCtrl_SetCharsDefault);
        newXS_deffile("Wx::StyledTextCtrl::SetFoldMarginColour", XS_Wx__StyledTextCtrl_SetFoldMarginColour);
        newXS_deffile("Wx::StyledTextCtrl::SetFoldMarginHiColour", XS_Wx__StyledTextCtrl_SetFoldMarginHiColour);
        newXS_deffile("Wx::StyledTextCtrl::SetHotspotActiveForeground", XS_Wx__StyledTextCtrl_SetHotspotActiveForeground);
        newXS_deffile("Wx::StyledTextCtrl::SetHotspotActiveBackground", XS_Wx__StyledTextCtrl_SetHotspotActiveBackground);
        newXS_deffile("Wx::StyledTextCtrl::SetHotspotActiveUnderline", XS_Wx__StyledTextCtrl_SetHotspotActiveUnderline);
        newXS_deffile("Wx::StyledTextCtrl::SetHotspotSingleLine", XS_Wx__StyledTextCtrl_SetHotspotSingleLine);
        newXS_deffile("Wx::StyledTextCtrl::SetWhitespaceChars", XS_Wx__StyledTextCtrl_SetWhitespaceChars);
        newXS_deffile("Wx::StyledTextCtrl::StutteredPageUp", XS_Wx__StyledTextCtrl_StutteredPageUp);
        newXS_deffile("Wx::StyledTextCtrl::StutteredPageUpExtend", XS_Wx__StyledTextCtrl_StutteredPageUpExtend);
        newXS_deffile("Wx::StyledTextCtrl::StutteredPageDown", XS_Wx__StyledTextCtrl_StutteredPageDown);
        newXS_deffile("Wx::StyledTextCtrl::StutteredPageDownExtend", XS_Wx__StyledTextCtrl_StutteredPageDownExtend);
#if XSubPPtmpAAAR
        newXS_deffile("Wx::StyledTextCtrl::StyleSetFontEncoding", XS_Wx__StyledTextCtrl_StyleSetFontEncoding);
#endif
        newXS_deffile("Wx::StyledTextCtrl::StyleSetHotSpot", XS_Wx__StyledTextCtrl_StyleSetHotSpot);
        newXS_deffile("Wx::StyledTextCtrl::Tab", XS_Wx__StyledTextCtrl_Tab);
        newXS_deffile("Wx::StyledTextCtrl::TargetFromSelection", XS_Wx__StyledTextCtrl_TargetFromSelection);
        newXS_deffile("Wx::StyledTextCtrl::VCHome", XS_Wx__StyledTextCtrl_VCHome);
        newXS_deffile("Wx::StyledTextCtrl::VCHomeExtend", XS_Wx__StyledTextCtrl_VCHomeExtend);
        newXS_deffile("Wx::StyledTextCtrl::VCHomeRectExtend", XS_Wx__StyledTextCtrl_VCHomeRectExtend);
        newXS_deffile("Wx::StyledTextCtrl::VCHomeWrap", XS_Wx__StyledTextCtrl_VCHomeWrap);
        newXS_deffile("Wx::StyledTextCtrl::VCHomeWrapExtend", XS_Wx__StyledTextCtrl_VCHomeWrapExtend);
        newXS_deffile("Wx::StyledTextCtrl::WordLeft", XS_Wx__StyledTextCtrl_WordLeft);
        newXS_deffile("Wx::StyledTextCtrl::WordLeftEnd", XS_Wx__StyledTextCtrl_WordLeftEnd);
        newXS_deffile("Wx::StyledTextCtrl::WordLeftEndExtend", XS_Wx__StyledTextCtrl_WordLeftEndExtend);
        newXS_deffile("Wx::StyledTextCtrl::WordLeftExtend", XS_Wx__StyledTextCtrl_WordLeftExtend);
        newXS_deffile("Wx::StyledTextCtrl::WordRight", XS_Wx__StyledTextCtrl_WordRight);
        newXS_deffile("Wx::StyledTextCtrl::WordRightEnd", XS_Wx__StyledTextCtrl_WordRightEnd);
        newXS_deffile("Wx::StyledTextCtrl::WordRightEndExtend", XS_Wx__StyledTextCtrl_WordRightEndExtend);
        newXS_deffile("Wx::StyledTextCtrl::WordRightExtend", XS_Wx__StyledTextCtrl_WordRightExtend);
#if XSubPPtmpAAAS
        newXS_deffile("Wx::StyledTextCtrl::WrapCount", XS_Wx__StyledTextCtrl_WrapCount);
#endif
        newXS_deffile("Wx::StyledTextCtrl::ZoomIn", XS_Wx__StyledTextCtrl_ZoomIn);
        newXS_deffile("Wx::StyledTextCtrl::ZoomOut", XS_Wx__StyledTextCtrl_ZoomOut);
#if XSubPPtmpAAAT
        newXS_deffile("Wx::StyledTextCtrl::SetWhitespaceSize", XS_Wx__StyledTextCtrl_SetWhitespaceSize);
        newXS_deffile("Wx::StyledTextCtrl::GetWhitespaceSize", XS_Wx__StyledTextCtrl_GetWhitespaceSize);
        newXS_deffile("Wx::StyledTextCtrl::SetWrapIndentMode", XS_Wx__StyledTextCtrl_SetWrapIndentMode);
        newXS_deffile("Wx::StyledTextCtrl::GetWrapIndentMode", XS_Wx__StyledTextCtrl_GetWrapIndentMode);
        newXS_deffile("Wx::StyledTextCtrl::SetFirstVisibleLine", XS_Wx__StyledTextCtrl_SetFirstVisibleLine);
        newXS_deffile("Wx::StyledTextCtrl::CopyAllowLine", XS_Wx__StyledTextCtrl_CopyAllowLine);
        newXS_deffile("Wx::StyledTextCtrl::GetCharacterPointer", XS_Wx__StyledTextCtrl_GetCharacterPointer);
        newXS_deffile("Wx::StyledTextCtrl::SetKeysUnicode", XS_Wx__StyledTextCtrl_SetKeysUnicode);
        newXS_deffile("Wx::StyledTextCtrl::GetKeysUnicode", XS_Wx__StyledTextCtrl_GetKeysUnicode);
        newXS_deffile("Wx::StyledTextCtrl::IndicatorSetAlpha", XS_Wx__StyledTextCtrl_IndicatorSetAlpha);
        newXS_deffile("Wx::StyledTextCtrl::IndicatorGetAlpha", XS_Wx__StyledTextCtrl_IndicatorGetAlpha);
        newXS_deffile("Wx::StyledTextCtrl::SetExtraAscent", XS_Wx__StyledTextCtrl_SetExtraAscent);
        newXS_deffile("Wx::StyledTextCtrl::GetExtraAscent", XS_Wx__StyledTextCtrl_GetExtraAscent);
        newXS_deffile("Wx::StyledTextCtrl::SetExtraDescent", XS_Wx__StyledTextCtrl_SetExtraDescent);
        newXS_deffile("Wx::StyledTextCtrl::GetExtraDescent", XS_Wx__StyledTextCtrl_GetExtraDescent);
        newXS_deffile("Wx::StyledTextCtrl::GetMarkerSymbolDefined", XS_Wx__StyledTextCtrl_GetMarkerSymbolDefined);
        newXS_deffile("Wx::StyledTextCtrl::MarginSetText", XS_Wx__StyledTextCtrl_MarginSetText);
        newXS_deffile("Wx::StyledTextCtrl::MarginGetText", XS_Wx__StyledTextCtrl_MarginGetText);
        newXS_deffile("Wx::StyledTextCtrl::MarginSetStyle", XS_Wx__StyledTextCtrl_MarginSetStyle);
        newXS_deffile("Wx::StyledTextCtrl::MarginGetStyle", XS_Wx__StyledTextCtrl_MarginGetStyle);
        newXS_deffile("Wx::StyledTextCtrl::MarginSetStyles", XS_Wx__StyledTextCtrl_MarginSetStyles);
        newXS_deffile("Wx::StyledTextCtrl::MarginGetStyles", XS_Wx__StyledTextCtrl_MarginGetStyles);
        newXS_deffile("Wx::StyledTextCtrl::MarginTextClearAll", XS_Wx__StyledTextCtrl_MarginTextClearAll);
        newXS_deffile("Wx::StyledTextCtrl::MarginSetStyleOffset", XS_Wx__StyledTextCtrl_MarginSetStyleOffset);
        newXS_deffile("Wx::StyledTextCtrl::MarginGetStyleOffset", XS_Wx__StyledTextCtrl_MarginGetStyleOffset);
        newXS_deffile("Wx::StyledTextCtrl::AnnotationSetText", XS_Wx__StyledTextCtrl_AnnotationSetText);
        newXS_deffile("Wx::StyledTextCtrl::AnnotationGetText", XS_Wx__StyledTextCtrl_AnnotationGetText);
        newXS_deffile("Wx::StyledTextCtrl::AnnotationSetStyle", XS_Wx__StyledTextCtrl_AnnotationSetStyle);
        newXS_deffile("Wx::StyledTextCtrl::AnnotationGetStyle", XS_Wx__StyledTextCtrl_AnnotationGetStyle);
        newXS_deffile("Wx::StyledTextCtrl::AnnotationSetStyles", XS_Wx__StyledTextCtrl_AnnotationSetStyles);
        newXS_deffile("Wx::StyledTextCtrl::AnnotationGetStyles", XS_Wx__StyledTextCtrl_AnnotationGetStyles);
        newXS_deffile("Wx::StyledTextCtrl::AnnotationGetLines", XS_Wx__StyledTextCtrl_AnnotationGetLines);
        newXS_deffile("Wx::StyledTextCtrl::AnnotationClearAll", XS_Wx__StyledTextCtrl_AnnotationClearAll);
        newXS_deffile("Wx::StyledTextCtrl::AnnotationSetVisible", XS_Wx__StyledTextCtrl_AnnotationSetVisible);
        newXS_deffile("Wx::StyledTextCtrl::AnnotationGetVisible", XS_Wx__StyledTextCtrl_AnnotationGetVisible);
        newXS_deffile("Wx::StyledTextCtrl::AnnotationSetStyleOffset", XS_Wx__StyledTextCtrl_AnnotationSetStyleOffset);
        newXS_deffile("Wx::StyledTextCtrl::AnnotationGetStyleOffset", XS_Wx__StyledTextCtrl_AnnotationGetStyleOffset);
        newXS_deffile("Wx::StyledTextCtrl::AddUndoAction", XS_Wx__StyledTextCtrl_AddUndoAction);
        newXS_deffile("Wx::StyledTextCtrl::CharPositionFromPoint", XS_Wx__StyledTextCtrl_CharPositionFromPoint);
        newXS_deffile("Wx::StyledTextCtrl::CharPositionFromPointClose", XS_Wx__StyledTextCtrl_CharPositionFromPointClose);
        newXS_deffile("Wx::StyledTextCtrl::SetMultipleSelection", XS_Wx__StyledTextCtrl_SetMultipleSelection);
        newXS_deffile("Wx::StyledTextCtrl::GetMultipleSelection", XS_Wx__StyledTextCtrl_GetMultipleSelection);
        newXS_deffile("Wx::StyledTextCtrl::SetAdditionalSelectionTyping", XS_Wx__StyledTextCtrl_SetAdditionalSelectionTyping);
        newXS_deffile("Wx::StyledTextCtrl::GetAdditionalSelectionTyping", XS_Wx__StyledTextCtrl_GetAdditionalSelectionTyping);
        newXS_deffile("Wx::StyledTextCtrl::SetAdditionalCaretsBlink", XS_Wx__StyledTextCtrl_SetAdditionalCaretsBlink);
        newXS_deffile("Wx::StyledTextCtrl::GetAdditionalCaretsBlink", XS_Wx__StyledTextCtrl_GetAdditionalCaretsBlink);
        newXS_deffile("Wx::StyledTextCtrl::SetAdditionalCaretsVisible", XS_Wx__StyledTextCtrl_SetAdditionalCaretsVisible);
        newXS_deffile("Wx::StyledTextCtrl::GetAdditionalCaretsVisible", XS_Wx__StyledTextCtrl_GetAdditionalCaretsVisible);
        newXS_deffile("Wx::StyledTextCtrl::GetSelections", XS_Wx__StyledTextCtrl_GetSelections);
        newXS_deffile("Wx::StyledTextCtrl::ClearSelections", XS_Wx__StyledTextCtrl_ClearSelections);
        newXS_deffile("Wx::StyledTextCtrl::AddSelection", XS_Wx__StyledTextCtrl_AddSelection);
        newXS_deffile("Wx::StyledTextCtrl::SetMainSelection", XS_Wx__StyledTextCtrl_SetMainSelection);
        newXS_deffile("Wx::StyledTextCtrl::GetMainSelection", XS_Wx__StyledTextCtrl_GetMainSelection);
        newXS_deffile("Wx::StyledTextCtrl::SetSelectionNCaret", XS_Wx__StyledTextCtrl_SetSelectionNCaret);
        newXS_deffile("Wx::StyledTextCtrl::GetSelectionNCaret", XS_Wx__StyledTextCtrl_GetSelectionNCaret);
        newXS_deffile("Wx::StyledTextCtrl::SetSelectionNAnchor", XS_Wx__StyledTextCtrl_SetSelectionNAnchor);
        newXS_deffile("Wx::StyledTextCtrl::GetSelectionNAnchor", XS_Wx__StyledTextCtrl_GetSelectionNAnchor);
        newXS_deffile("Wx::StyledTextCtrl::SetSelectionNCaretVirtualSpace", XS_Wx__StyledTextCtrl_SetSelectionNCaretVirtualSpace);
        newXS_deffile("Wx::StyledTextCtrl::GetSelectionNCaretVirtualSpace", XS_Wx__StyledTextCtrl_GetSelectionNCaretVirtualSpace);
        newXS_deffile("Wx::StyledTextCtrl::SetSelectionNAnchorVirtualSpace", XS_Wx__StyledTextCtrl_SetSelectionNAnchorVirtualSpace);
        newXS_deffile("Wx::StyledTextCtrl::GetSelectionNAnchorVirtualSpace", XS_Wx__StyledTextCtrl_GetSelectionNAnchorVirtualSpace);
        newXS_deffile("Wx::StyledTextCtrl::SetSelectionNStart", XS_Wx__StyledTextCtrl_SetSelectionNStart);
        newXS_deffile("Wx::StyledTextCtrl::GetSelectionNStart", XS_Wx__StyledTextCtrl_GetSelectionNStart);
        newXS_deffile("Wx::StyledTextCtrl::SetSelectionNEnd", XS_Wx__StyledTextCtrl_SetSelectionNEnd);
        newXS_deffile("Wx::StyledTextCtrl::GetSelectionNEnd", XS_Wx__StyledTextCtrl_GetSelectionNEnd);
        newXS_deffile("Wx::StyledTextCtrl::SetRectangularSelectionCaret", XS_Wx__StyledTextCtrl_SetRectangularSelectionCaret);
        newXS_deffile("Wx::StyledTextCtrl::GetRectangularSelectionCaret", XS_Wx__StyledTextCtrl_GetRectangularSelectionCaret);
        newXS_deffile("Wx::StyledTextCtrl::SetRectangularSelectionAnchor", XS_Wx__StyledTextCtrl_SetRectangularSelectionAnchor);
        newXS_deffile("Wx::StyledTextCtrl::GetRectangularSelectionAnchor", XS_Wx__StyledTextCtrl_GetRectangularSelectionAnchor);
        newXS_deffile("Wx::StyledTextCtrl::SetRectangularSelectionCaretVirtualSpace", XS_Wx__StyledTextCtrl_SetRectangularSelectionCaretVirtualSpace);
        newXS_deffile("Wx::StyledTextCtrl::GetRectangularSelectionCaretVirtualSpace", XS_Wx__StyledTextCtrl_GetRectangularSelectionCaretVirtualSpace);
        newXS_deffile("Wx::StyledTextCtrl::SetRectangularSelectionAnchorVirtualSpace", XS_Wx__StyledTextCtrl_SetRectangularSelectionAnchorVirtualSpace);
        newXS_deffile("Wx::StyledTextCtrl::GetRectangularSelectionAnchorVirtualSpace", XS_Wx__StyledTextCtrl_GetRectangularSelectionAnchorVirtualSpace);
        newXS_deffile("Wx::StyledTextCtrl::SetVirtualSpaceOptions", XS_Wx__StyledTextCtrl_SetVirtualSpaceOptions);
        newXS_deffile("Wx::StyledTextCtrl::GetVirtualSpaceOptions", XS_Wx__StyledTextCtrl_GetVirtualSpaceOptions);
        newXS_deffile("Wx::StyledTextCtrl::SetRectangularSelectionModifier", XS_Wx__StyledTextCtrl_SetRectangularSelectionModifier);
        newXS_deffile("Wx::StyledTextCtrl::GetRectangularSelectionModifier", XS_Wx__StyledTextCtrl_GetRectangularSelectionModifier);
        newXS_deffile("Wx::StyledTextCtrl::SetAdditionalSelForeground", XS_Wx__StyledTextCtrl_SetAdditionalSelForeground);
        newXS_deffile("Wx::StyledTextCtrl::SetAdditionalSelBackground", XS_Wx__StyledTextCtrl_SetAdditionalSelBackground);
        newXS_deffile("Wx::StyledTextCtrl::SetAdditionalSelAlpha", XS_Wx__StyledTextCtrl_SetAdditionalSelAlpha);
        newXS_deffile("Wx::StyledTextCtrl::GetAdditionalSelAlpha", XS_Wx__StyledTextCtrl_GetAdditionalSelAlpha);
        newXS_deffile("Wx::StyledTextCtrl::SetAdditionalCaretForeground", XS_Wx__StyledTextCtrl_SetAdditionalCaretForeground);
        newXS_deffile("Wx::StyledTextCtrl::GetAdditionalCaretForeground", XS_Wx__StyledTextCtrl_GetAdditionalCaretForeground);
        newXS_deffile("Wx::StyledTextCtrl::RotateSelection", XS_Wx__StyledTextCtrl_RotateSelection);
        newXS_deffile("Wx::StyledTextCtrl::SwapMainAnchorCaret", XS_Wx__StyledTextCtrl_SwapMainAnchorCaret);
#endif
        newXS_deffile("Wx::StyledTextEvent::SetPosition", XS_Wx__StyledTextEvent_SetPosition);
        newXS_deffile("Wx::StyledTextEvent::SetKey", XS_Wx__StyledTextEvent_SetKey);
        newXS_deffile("Wx::StyledTextEvent::SetModifiers", XS_Wx__StyledTextEvent_SetModifiers);
        newXS_deffile("Wx::StyledTextEvent::SetModificationType", XS_Wx__StyledTextEvent_SetModificationType);
        newXS_deffile("Wx::StyledTextEvent::SetText", XS_Wx__StyledTextEvent_SetText);
        newXS_deffile("Wx::StyledTextEvent::SetLength", XS_Wx__StyledTextEvent_SetLength);
        newXS_deffile("Wx::StyledTextEvent::SetLinesAdded", XS_Wx__StyledTextEvent_SetLinesAdded);
        newXS_deffile("Wx::StyledTextEvent::SetLine", XS_Wx__StyledTextEvent_SetLine);
        newXS_deffile("Wx::StyledTextEvent::SetFoldLevelNow", XS_Wx__StyledTextEvent_SetFoldLevelNow);
        newXS_deffile("Wx::StyledTextEvent::SetFoldLevelPrev", XS_Wx__StyledTextEvent_SetFoldLevelPrev);
        newXS_deffile("Wx::StyledTextEvent::SetMargin", XS_Wx__StyledTextEvent_SetMargin);
        newXS_deffile("Wx::StyledTextEvent::SetMessage", XS_Wx__StyledTextEvent_SetMessage);
        newXS_deffile("Wx::StyledTextEvent::SetWParam", XS_Wx__StyledTextEvent_SetWParam);
        newXS_deffile("Wx::StyledTextEvent::SetLParam", XS_Wx__StyledTextEvent_SetLParam);
        newXS_deffile("Wx::StyledTextEvent::SetListType", XS_Wx__StyledTextEvent_SetListType);
        newXS_deffile("Wx::StyledTextEvent::SetX", XS_Wx__StyledTextEvent_SetX);
        newXS_deffile("Wx::StyledTextEvent::SetY", XS_Wx__StyledTextEvent_SetY);
        newXS_deffile("Wx::StyledTextEvent::SetDragText", XS_Wx__StyledTextEvent_SetDragText);
        newXS_deffile("Wx::StyledTextEvent::SetDragAllowMove", XS_Wx__StyledTextEvent_SetDragAllowMove);
#if XSubPPtmpAAAU
        newXS_deffile("Wx::StyledTextEvent::SetDragResult", XS_Wx__StyledTextEvent_SetDragResult);
#endif
        newXS_deffile("Wx::StyledTextEvent::GetPosition", XS_Wx__StyledTextEvent_GetPosition);
        newXS_deffile("Wx::StyledTextEvent::GetKey", XS_Wx__StyledTextEvent_GetKey);
        newXS_deffile("Wx::StyledTextEvent::GetModifiers", XS_Wx__StyledTextEvent_GetModifiers);
        newXS_deffile("Wx::StyledTextEvent::GetModificationType", XS_Wx__StyledTextEvent_GetModificationType);
        newXS_deffile("Wx::StyledTextEvent::GetText", XS_Wx__StyledTextEvent_GetText);
        newXS_deffile("Wx::StyledTextEvent::GetLength", XS_Wx__StyledTextEvent_GetLength);
        newXS_deffile("Wx::StyledTextEvent::GetLinesAdded", XS_Wx__StyledTextEvent_GetLinesAdded);
        newXS_deffile("Wx::StyledTextEvent::GetLine", XS_Wx__StyledTextEvent_GetLine);
        newXS_deffile("Wx::StyledTextEvent::GetFoldLevelNow", XS_Wx__StyledTextEvent_GetFoldLevelNow);
        newXS_deffile("Wx::StyledTextEvent::GetFoldLevelPrev", XS_Wx__StyledTextEvent_GetFoldLevelPrev);
        newXS_deffile("Wx::StyledTextEvent::GetMargin", XS_Wx__StyledTextEvent_GetMargin);
        newXS_deffile("Wx::StyledTextEvent::GetMessage", XS_Wx__StyledTextEvent_GetMessage);
        newXS_deffile("Wx::StyledTextEvent::GetWParam", XS_Wx__StyledTextEvent_GetWParam);
        newXS_deffile("Wx::StyledTextEvent::GetLParam", XS_Wx__StyledTextEvent_GetLParam);
        newXS_deffile("Wx::StyledTextEvent::GetListType", XS_Wx__StyledTextEvent_GetListType);
        newXS_deffile("Wx::StyledTextEvent::GetX", XS_Wx__StyledTextEvent_GetX);
        newXS_deffile("Wx::StyledTextEvent::GetY", XS_Wx__StyledTextEvent_GetY);
        newXS_deffile("Wx::StyledTextEvent::GetDragText", XS_Wx__StyledTextEvent_GetDragText);
        newXS_deffile("Wx::StyledTextEvent::GetDragAllowMove", XS_Wx__StyledTextEvent_GetDragAllowMove);
#if XSubPPtmpAAAV
        newXS_deffile("Wx::StyledTextEvent::GetDragResult", XS_Wx__StyledTextEvent_GetDragResult);
#endif
        newXS_deffile("Wx::StyledTextEvent::GetShift", XS_Wx__StyledTextEvent_GetShift);
        newXS_deffile("Wx::StyledTextEvent::GetControl", XS_Wx__StyledTextEvent_GetControl);
        newXS_deffile("Wx::StyledTextEvent::GetAlt", XS_Wx__StyledTextEvent_GetAlt);

    /* Initialisation Section */

  INIT_PLI_HELPERS( wx_pli_helpers );

#if XSubPPtmpAAAA
#endif
#if XSubPPtmpAAAB
#endif
#if XSubPPtmpAAAC
#endif
#if XSubPPtmpAAAD
#endif
#if XSubPPtmpAAAE
#endif
#if XSubPPtmpAAAF
#endif
#if XSubPPtmpAAAG
#endif
#if XSubPPtmpAAAH
#endif
#if XSubPPtmpAAAI
#endif
#if XSubPPtmpAAAJ
#endif
#if XSubPPtmpAAAK
#endif
#if XSubPPtmpAAAL
#endif
#if XSubPPtmpAAAM
#endif
#if XSubPPtmpAAAN
#endif
#if XSubPPtmpAAAO
#endif
#if XSubPPtmpAAAP
#endif
#if XSubPPtmpAAAQ
#endif
#if XSubPPtmpAAAR
#endif
#if XSubPPtmpAAAS
#endif
#if XSubPPtmpAAAT
#endif
#if XSubPPtmpAAAU
#endif
#if XSubPPtmpAAAV
#endif

    /* End of Initialisation Section */

#if PERL_VERSION_LE(5, 21, 5)
#  if PERL_VERSION_GE(5, 9, 0)
    if (PL_unitcheckav)
        call_list(PL_scopestack_ix, PL_unitcheckav);
#  endif
    XSRETURN_YES;
#else
    Perl_xs_boot_epilog(aTHX_ ax);
#endif
}

