/*
 * This file was generated automatically by ExtUtils::ParseXS version 3.44 from the
 * contents of Frames.xs. Do not edit this file, edit Frames.xs instead.
 *
 *    ANY CHANGES MADE HERE WILL BE LOST!
 *
 */

/////////////////////////////////////////////////////////////////////////////
// Name:        Frames.xs
// Purpose:     XS for Wx::Frame, Wx::Dialog, Wx::Panel
// Author:      Mattia Barbon
// Modified by:
// Created:     29/10/2000
// RCS-ID:      $Id: Frames.xs 3486 2013-04-16 17:39:27Z mdootson $
// Copyright:   (c) 2000-2003, 2005-2010 Mattia Barbon
// Licence:     This program is free software; you can redistribute it and/or
//              modify it under the same terms as Perl itself
/////////////////////////////////////////////////////////////////////////////

#define PERL_NO_GET_CONTEXT

#include "cpp/wxapi.h"
#include "cpp/v_cback.h"

#undef THIS

WXPLI_BOOT_ONCE(Wx_Wnd);
#define boot_Wx_Wnd wxPli_boot_Wx_Wnd

#ifndef PERL_UNUSED_VAR
#  define PERL_UNUSED_VAR(var) if (0) var = var
#endif

#ifndef dVAR
#  define dVAR		dNOOP
#endif


/* This stuff is not part of the API! You have been warned. */
#ifndef PERL_VERSION_DECIMAL
#  define PERL_VERSION_DECIMAL(r,v,s) (r*1000000 + v*1000 + s)
#endif
#ifndef PERL_DECIMAL_VERSION
#  define PERL_DECIMAL_VERSION \
	  PERL_VERSION_DECIMAL(PERL_REVISION,PERL_VERSION,PERL_SUBVERSION)
#endif
#ifndef PERL_VERSION_GE
#  define PERL_VERSION_GE(r,v,s) \
	  (PERL_DECIMAL_VERSION >= PERL_VERSION_DECIMAL(r,v,s))
#endif
#ifndef PERL_VERSION_LE
#  define PERL_VERSION_LE(r,v,s) \
	  (PERL_DECIMAL_VERSION <= PERL_VERSION_DECIMAL(r,v,s))
#endif

/* XS_INTERNAL is the explicit static-linkage variant of the default
 * XS macro.
 *
 * XS_EXTERNAL is the same as XS_INTERNAL except it does not include
 * "STATIC", ie. it exports XSUB symbols. You probably don't want that
 * for anything but the BOOT XSUB.
 *
 * See XSUB.h in core!
 */


/* TODO: This might be compatible further back than 5.10.0. */
#if PERL_VERSION_GE(5, 10, 0) && PERL_VERSION_LE(5, 15, 1)
#  undef XS_EXTERNAL
#  undef XS_INTERNAL
#  if defined(__CYGWIN__) && defined(USE_DYNAMIC_LOADING)
#    define XS_EXTERNAL(name) __declspec(dllexport) XSPROTO(name)
#    define XS_INTERNAL(name) STATIC XSPROTO(name)
#  endif
#  if defined(__SYMBIAN32__)
#    define XS_EXTERNAL(name) EXPORT_C XSPROTO(name)
#    define XS_INTERNAL(name) EXPORT_C STATIC XSPROTO(name)
#  endif
#  ifndef XS_EXTERNAL
#    if defined(HASATTRIBUTE_UNUSED) && !defined(__cplusplus)
#      define XS_EXTERNAL(name) void name(pTHX_ CV* cv __attribute__unused__)
#      define XS_INTERNAL(name) STATIC void name(pTHX_ CV* cv __attribute__unused__)
#    else
#      ifdef __cplusplus
#        define XS_EXTERNAL(name) extern "C" XSPROTO(name)
#        define XS_INTERNAL(name) static XSPROTO(name)
#      else
#        define XS_EXTERNAL(name) XSPROTO(name)
#        define XS_INTERNAL(name) STATIC XSPROTO(name)
#      endif
#    endif
#  endif
#endif

/* perl >= 5.10.0 && perl <= 5.15.1 */


/* The XS_EXTERNAL macro is used for functions that must not be static
 * like the boot XSUB of a module. If perl didn't have an XS_EXTERNAL
 * macro defined, the best we can do is assume XS is the same.
 * Dito for XS_INTERNAL.
 */
#ifndef XS_EXTERNAL
#  define XS_EXTERNAL(name) XS(name)
#endif
#ifndef XS_INTERNAL
#  define XS_INTERNAL(name) XS(name)
#endif

/* Now, finally, after all this mess, we want an ExtUtils::ParseXS
 * internal macro that we're free to redefine for varying linkage due
 * to the EXPORT_XSUB_SYMBOLS XS keyword. This is internal, use
 * XS_EXTERNAL(name) or XS_INTERNAL(name) in your code if you need to!
 */

#undef XS_EUPXS
#if defined(PERL_EUPXS_ALWAYS_EXPORT)
#  define XS_EUPXS(name) XS_EXTERNAL(name)
#else
   /* default to internal */
#  define XS_EUPXS(name) XS_INTERNAL(name)
#endif

#ifndef PERL_ARGS_ASSERT_CROAK_XS_USAGE
#define PERL_ARGS_ASSERT_CROAK_XS_USAGE assert(cv); assert(params)

/* prototype to pass -Wmissing-prototypes */
STATIC void
S_croak_xs_usage(const CV *const cv, const char *const params);

STATIC void
S_croak_xs_usage(const CV *const cv, const char *const params)
{
    const GV *const gv = CvGV(cv);

    PERL_ARGS_ASSERT_CROAK_XS_USAGE;

    if (gv) {
        const char *const gvname = GvNAME(gv);
        const HV *const stash = GvSTASH(gv);
        const char *const hvname = stash ? HvNAME(stash) : NULL;

        if (hvname)
	    Perl_croak_nocontext("Usage: %s::%s(%s)", hvname, gvname, params);
        else
	    Perl_croak_nocontext("Usage: %s(%s)", gvname, params);
    } else {
        /* Pants. I don't think that it should be possible to get here. */
	Perl_croak_nocontext("Usage: CODE(0x%" UVxf ")(%s)", PTR2UV(cv), params);
    }
}
#undef  PERL_ARGS_ASSERT_CROAK_XS_USAGE

#define croak_xs_usage        S_croak_xs_usage

#endif

/* NOTE: the prototype of newXSproto() is different in versions of perls,
 * so we define a portable version of newXSproto()
 */
#ifdef newXS_flags
#define newXSproto_portable(name, c_impl, file, proto) newXS_flags(name, c_impl, file, proto, 0)
#else
#define newXSproto_portable(name, c_impl, file, proto) (PL_Sv=(SV*)newXS(name, c_impl, file), sv_setpv(PL_Sv, proto), (CV*)PL_Sv)
#endif /* !defined(newXS_flags) */

#if PERL_VERSION_LE(5, 21, 5)
#  define newXS_deffile(a,b) Perl_newXS(aTHX_ a,b,file)
#else
#  define newXS_deffile(a,b) Perl_newXS_deffile(aTHX_ a,b)
#endif


/* INCLUDE:  Including 'XS/Panel.xs' from 'Frames.xs' */

#include <wx/panel.h>
#include "cpp/panel.h"
#include "cpp/overload.h"

XS_EUPXS(XS_Wx__Panel_new); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Panel_new)
{
    dVAR; dXSARGS;
    PERL_UNUSED_VAR(cv); /* -W */
    PERL_UNUSED_VAR(items); /* -W */
    PERL_UNUSED_VAR(ax); /* -Wall */
    SP -= items;
    {
    BEGIN_OVERLOAD()
        MATCH_VOIDM_REDISP( newDefault )
        MATCH_ANY_REDISP( newFull )
    END_OVERLOAD( "Wx::Panel::new" )
	PUTBACK;
	return;
    }
}


XS_EUPXS(XS_Wx__Panel_newDefault); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Panel_newDefault)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "CLASS");
    {
	PlClassName    CLASS = wxPli_get_class( aTHX_ ST(0) )
;
	wxPanel *	RETVAL;
    RETVAL = new wxPliPanel( CLASS );
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_object_2_sv( aTHX_ RETVALSV, RETVAL );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__Panel_newFull); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Panel_newFull)
{
    dVAR; dXSARGS;
    if (items < 2 || items > 7)
       croak_xs_usage(cv,  "CLASS, parent, id = wxID_ANY, pos = wxDefaultPosition, size = wxDefaultSize, style = wxTAB_TRAVERSAL, name = wxPanelNameStr");
    {
	PlClassName    CLASS = wxPli_get_class( aTHX_ ST(0) )
;
	wxWindow*    parent = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::Window" )
;
	wxWindowID	id;
	wxPoint	pos;
	wxSize	size;
	long	style;
	wxString	name;
	wxPanel *	RETVAL;

	if (items < 3)
	    id = wxID_ANY;
	else {
    id = wxPli_get_wxwindowid( aTHX_ ST(2) )
;
	}

	if (items < 4)
	    pos = wxDefaultPosition;
	else {
    pos = wxPli_sv_2_wxpoint( aTHX_ ST(3) )
;
	}

	if (items < 5)
	    size = wxDefaultSize;
	else {
    size = wxPli_sv_2_wxsize( aTHX_ ST(4) )
;
	}

	if (items < 6)
	    style = wxTAB_TRAVERSAL;
	else {
	    style = (long)SvIV(ST(5))
;
	}

	if (items < 7)
	    name = wxPanelNameStr;
	else {
    WXSTRING_INPUT( name, wxString, ST(6) )
;
	}
    RETVAL = new wxPliPanel( CLASS, parent, id, pos, size, style, name );
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_object_2_sv( aTHX_ RETVALSV, RETVAL );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__Panel_Create); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Panel_Create)
{
    dVAR; dXSARGS;
    if (items < 2 || items > 7)
       croak_xs_usage(cv,  "THIS, parent, id = wxID_ANY, pos = wxDefaultPosition, size = wxDefaultSize, style = wxTAB_TRAVERSAL, name = wxPanelNameStr");
    {
	wxWindow*    parent = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::Window" )
;
	wxWindowID	id;
	wxPoint	pos;
	wxSize	size;
	long	style;
	wxString	name;
	wxPanel *    THIS = (wxPanel *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Panel" )
;
	bool	RETVAL;

	if (items < 3)
	    id = wxID_ANY;
	else {
    id = wxPli_get_wxwindowid( aTHX_ ST(2) )
;
	}

	if (items < 4)
	    pos = wxDefaultPosition;
	else {
    pos = wxPli_sv_2_wxpoint( aTHX_ ST(3) )
;
	}

	if (items < 5)
	    size = wxDefaultSize;
	else {
    size = wxPli_sv_2_wxsize( aTHX_ ST(4) )
;
	}

	if (items < 6)
	    style = wxTAB_TRAVERSAL;
	else {
	    style = (long)SvIV(ST(5))
;
	}

	if (items < 7)
	    name = wxPanelNameStr;
	else {
    WXSTRING_INPUT( name, wxString, ST(6) )
;
	}

	RETVAL = THIS->Create(parent, id, pos, size, style, name);
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}

#if WXPERL_W_VERSION_GE( 2, 5, 4 )
#define XSubPPtmpAAAA 1


XS_EUPXS(XS_Wx__Panel_SetFocusIgnoringChildren); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Panel_SetFocusIgnoringChildren)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxPanel *    THIS = (wxPanel *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Panel" )
;

	THIS->SetFocusIgnoringChildren();
    }
    XSRETURN_EMPTY;
}

#endif

XS_EUPXS(XS_Wx__Panel_TransferDataFromWindow); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Panel_TransferDataFromWindow)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxPanel *    THIS = (wxPanel *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Panel" )
;
	bool	RETVAL;
    RETVAL = THIS->wxPanel::TransferDataFromWindow();
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__Panel_TransferDataToWindow); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Panel_TransferDataToWindow)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxPanel *    THIS = (wxPanel *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Panel" )
;
	bool	RETVAL;
    RETVAL = THIS->wxPanel::TransferDataToWindow();
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__Panel_Validate); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Panel_Validate)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxPanel *    THIS = (wxPanel *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Panel" )
;
	bool	RETVAL;
    RETVAL = THIS->wxPanel::Validate();
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


/* INCLUDE: Returning to 'Frames.xs' from 'XS/Panel.xs' */


/* INCLUDE_COMMAND:  Including output of '/usr/bin/perl -I./ -MExtUtils::XSpp::Cmd -e xspp -- -t typemap.xsp XS/Dialog.xsp' from 'Frames.xs' */

#include <exception>

#undef  xsp_constructor_class
#define xsp_constructor_class(c) (c)
#include <wx/dialog.h>
#include <wx/sizer.h>
#include <wx/button.h>
#include "cpp/dialog.h"
#include "cpp/overload.h"
#if WXPERL_W_VERSION_GE( 2, 6, 3 )
#define XSpp_bdca3bfd_082271
#define XSubPPtmpAAAB 1


XS_EUPXS(XS_Wx__Dialog_SetAffirmativeId); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Dialog_SetAffirmativeId)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, affirmativeId");
    {
	wxDialog *    THIS = (wxDialog *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Dialog" )
;
	int	affirmativeId = (int)SvIV(ST(1))
;
    try {
      THIS->SetAffirmativeId( affirmativeId );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__Dialog_GetAffirmativeId); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Dialog_GetAffirmativeId)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxDialog *    THIS = (wxDialog *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Dialog" )
;
	int	RETVAL;
	dXSTARG;
    try {
      RETVAL = THIS->GetAffirmativeId();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__Dialog_GetEscapeId); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Dialog_GetEscapeId)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxDialog *    THIS = (wxDialog *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Dialog" )
;
	int	RETVAL;
	dXSTARG;
    try {
      RETVAL = THIS->GetEscapeId();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}

#endif
#if WXPERL_W_VERSION_GE( 2, 7, 0 )
#define XSpp_bdca3bfd_033192
#define XSubPPtmpAAAC 1


XS_EUPXS(XS_Wx__Dialog_SetEscapeId); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Dialog_SetEscapeId)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, escapeId");
    {
	wxDialog *    THIS = (wxDialog *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Dialog" )
;
	int	escapeId = (int)SvIV(ST(1))
;
    try {
      THIS->SetEscapeId( escapeId );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}

#endif

XS_EUPXS(XS_Wx__Dialog_CreateTextSizer); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Dialog_CreateTextSizer)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, message");
    {
	wxDialog *    THIS = (wxDialog *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Dialog" )
;
	wxSizer *	RETVAL;
	wxString	message;

    WXSTRING_INPUT( message, wxString, ST(1) )
;
    try {
      RETVAL = THIS->CreateTextSizer( message );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_object_2_sv( aTHX_ RETVALSV, RETVAL );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__Dialog_CreateButtonSizer); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Dialog_CreateButtonSizer)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, flags");
    {
	wxDialog *    THIS = (wxDialog *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Dialog" )
;
	wxSizer *	RETVAL;
	long	flags = (long)SvIV(ST(1))
;
    try {
      RETVAL = THIS->CreateButtonSizer( flags );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_object_2_sv( aTHX_ RETVALSV, RETVAL );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}

#if WXPERL_W_VERSION_GE( 2, 7, 2 )
#define XSpp_bdca3bfd_045274
#define XSubPPtmpAAAD 1


XS_EUPXS(XS_Wx__Dialog_CreateSeparatedButtonSizer); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Dialog_CreateSeparatedButtonSizer)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, flags");
    {
	wxDialog *    THIS = (wxDialog *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Dialog" )
;
	wxSizer *	RETVAL;
	long	flags = (long)SvIV(ST(1))
;
    try {
      RETVAL = THIS->CreateSeparatedButtonSizer( flags );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_object_2_sv( aTHX_ RETVALSV, RETVAL );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}

#endif
#if WXPERL_W_VERSION_GE( 2, 6, 0 )
#define XSpp_bdca3bfd_001153
#define XSubPPtmpAAAE 1


XS_EUPXS(XS_Wx__Dialog_CreateStdDialogButtonSizer); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Dialog_CreateStdDialogButtonSizer)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, flags");
    {
	wxDialog *    THIS = (wxDialog *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Dialog" )
;
	wxSizer *	RETVAL;
	long	flags = (long)SvIV(ST(1))
;
    try {
      RETVAL = THIS->CreateStdDialogButtonSizer( flags );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_object_2_sv( aTHX_ RETVALSV, RETVAL );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}

#endif
#if WXPERL_W_VERSION_GE( 2, 9, 0 )
#define XSpp_bdca3bfd_058579
#define XSubPPtmpAAAF 1


XS_EUPXS(XS_Wx__Dialog_AddMainButtonId); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Dialog_AddMainButtonId)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, id");
    {
	wxDialog *    THIS = (wxDialog *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Dialog" )
;
	wxWindowID    id = wxPli_get_wxwindowid( aTHX_ ST(1) )
;
    try {
      THIS->AddMainButtonId( id );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__Dialog_IsMainButtonId); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Dialog_IsMainButtonId)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, id");
    {
	wxDialog *    THIS = (wxDialog *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Dialog" )
;
	bool	RETVAL;
	wxWindowID    id = wxPli_get_wxwindowid( aTHX_ ST(1) )
;
    try {
      RETVAL = THIS->IsMainButtonId( id );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__Dialog_GetMainButtonIds); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Dialog_GetMainButtonIds)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    PERL_UNUSED_VAR(ax); /* -Wall */
    SP -= items;
    {
	wxDialog *    THIS = (wxDialog *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Dialog" )
;
    PUTBACK;
    wxPli_intarray_push( aTHX_ THIS->GetMainButtonIds() );
    SPAGAIN;
	PUTBACK;
	return;
    }
}


XS_EUPXS(XS_Wx__Dialog_CanDoLayoutAdaptation); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Dialog_CanDoLayoutAdaptation)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxDialog *    THIS = (wxDialog *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Dialog" )
;
	bool	RETVAL;
    try {
      RETVAL = THIS->CanDoLayoutAdaptation();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__Dialog_IsLayoutAdaptationEnabled); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Dialog_IsLayoutAdaptationEnabled)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	bool	RETVAL;
    try {
      RETVAL = wxDialog::IsLayoutAdaptationEnabled();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__Dialog_EnableLayoutAdaptation); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Dialog_EnableLayoutAdaptation)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "enable");
    {
	bool	enable = (bool)SvTRUE(ST(0))
;
    try {
      wxDialog::EnableLayoutAdaptation( enable );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__Dialog_GetContentWindow); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Dialog_GetContentWindow)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxDialog *    THIS = (wxDialog *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Dialog" )
;
	wxWindow *	RETVAL;
    try {
      RETVAL = THIS->GetContentWindow();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_object_2_sv( aTHX_ RETVALSV, RETVAL );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__Dialog_SetLayoutAdaptationLevel); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Dialog_SetLayoutAdaptationLevel)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, level");
    {
	wxDialog *    THIS = (wxDialog *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Dialog" )
;
	int	level = (int)SvIV(ST(1))
;
    try {
      THIS->SetLayoutAdaptationLevel( level );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__Dialog_GetLayoutAdaptationLevel); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Dialog_GetLayoutAdaptationLevel)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxDialog *    THIS = (wxDialog *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Dialog" )
;
	int	RETVAL;
	dXSTARG;
    try {
      RETVAL = THIS->GetLayoutAdaptationLevel();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__Dialog_SetLayoutAdaptationMode); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Dialog_SetLayoutAdaptationMode)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, mode");
    {
	wxDialog *    THIS = (wxDialog *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Dialog" )
;
	wxDialogLayoutAdaptationMode	mode = (wxDialogLayoutAdaptationMode)SvIV(ST(1))
;
    try {
      THIS->SetLayoutAdaptationMode( mode );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__Dialog_GetLayoutAdaptationMode); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Dialog_GetLayoutAdaptationMode)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxDialog *    THIS = (wxDialog *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Dialog" )
;
	wxDialogLayoutAdaptationMode	RETVAL;
	dXSTARG;
    try {
      RETVAL = THIS->GetLayoutAdaptationMode();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__Dialog_SetLayoutAdaptationDone); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Dialog_SetLayoutAdaptationDone)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, adaptationDone");
    {
	wxDialog *    THIS = (wxDialog *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Dialog" )
;
	bool	adaptationDone = (bool)SvTRUE(ST(1))
;
    try {
      THIS->SetLayoutAdaptationDone( adaptationDone );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__Dialog_GetLayoutAdaptationDone); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Dialog_GetLayoutAdaptationDone)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxDialog *    THIS = (wxDialog *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Dialog" )
;
	bool	RETVAL;
    try {
      RETVAL = THIS->GetLayoutAdaptationDone();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}

#if defined(__WXMSW__) && defined(__POCKETPC__)
#define XSpp_bdca3bfd_034297
#define XSubPPtmpAAAG 1


XS_EUPXS(XS_Wx__Dialog_GetToolBar); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Dialog_GetToolBar)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxDialog *    THIS = (wxDialog *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Dialog" )
;
	wxToolBar *	RETVAL;
    try {
      RETVAL = THIS->GetToolBar();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_evthandler_2_sv( aTHX_ RETVALSV, RETVAL );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}

#endif
#endif

XS_EUPXS(XS_Wx__Dialog_new); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Dialog_new)
{
    dVAR; dXSARGS;
    PERL_UNUSED_VAR(cv); /* -W */
    PERL_UNUSED_VAR(items); /* -W */
    PERL_UNUSED_VAR(ax); /* -Wall */
    SP -= items;
    {
    BEGIN_OVERLOAD()
        MATCH_VOIDM_REDISP( newDefault )
        MATCH_ANY_REDISP( newFull )
    END_OVERLOAD( "Wx::Dialog::new" )
	PUTBACK;
	return;
    }
}


XS_EUPXS(XS_Wx__Dialog_newDefault); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Dialog_newDefault)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "CLASS");
    {
	PlClassName    CLASS = wxPli_get_class( aTHX_ ST(0) )
;
	wxDialog *	RETVAL;
    RETVAL = new wxPliDialog( CLASS );
    wxPli_create_evthandler( aTHX_ RETVAL, CLASS );
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_object_2_sv( aTHX_ RETVALSV, RETVAL );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__Dialog_newFull); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Dialog_newFull)
{
    dVAR; dXSARGS;
    if (items < 2 || items > 8)
       croak_xs_usage(cv,  "CLASS, parent, id = wxID_ANY, title = wxEmptyString, pos = wxDefaultPosition, size = wxDefaultSize, style = wxDEFAULT_DIALOG_STYLE, name = wxDialogNameStr");
    {
	PlClassName    CLASS = wxPli_get_class( aTHX_ ST(0) )
;
	wxWindow*    parent = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::Window" )
;
	wxWindowID	id;
	wxString	title;
	wxPoint	pos;
	wxSize	size;
	long	style;
	wxString	name;
	wxDialog *	RETVAL;

	if (items < 3)
	    id = wxID_ANY;
	else {
    id = wxPli_get_wxwindowid( aTHX_ ST(2) )
;
	}

	if (items < 4)
	    title = wxEmptyString;
	else {
    WXSTRING_INPUT( title, wxString, ST(3) )
;
	}

	if (items < 5)
	    pos = wxDefaultPosition;
	else {
    pos = wxPli_sv_2_wxpoint( aTHX_ ST(4) )
;
	}

	if (items < 6)
	    size = wxDefaultSize;
	else {
    size = wxPli_sv_2_wxsize( aTHX_ ST(5) )
;
	}

	if (items < 7)
	    style = wxDEFAULT_DIALOG_STYLE;
	else {
	    style = (long)SvIV(ST(6))
;
	}

	if (items < 8)
	    name = wxDialogNameStr;
	else {
    WXSTRING_INPUT( name, wxString, ST(7) )
;
	}
      RETVAL = new wxPliDialog( CLASS, parent, id, title, pos,
          size, style, name );
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_object_2_sv( aTHX_ RETVALSV, RETVAL );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__Dialog_Create); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Dialog_Create)
{
    dVAR; dXSARGS;
    if (items < 2 || items > 8)
       croak_xs_usage(cv,  "THIS, parent, id = wxID_ANY, title = wxEmptyString, pos = wxDefaultPosition, size = wxDefaultSize, style = wxDEFAULT_DIALOG_STYLE, name = wxDialogNameStr");
    {
	wxWindow*    parent = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::Window" )
;
	wxWindowID	id;
	wxString	title;
	wxPoint	pos;
	wxSize	size;
	long	style;
	wxString	name;
	wxDialog *    THIS = (wxDialog *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Dialog" )
;
	bool	RETVAL;

	if (items < 3)
	    id = wxID_ANY;
	else {
    id = wxPli_get_wxwindowid( aTHX_ ST(2) )
;
	}

	if (items < 4)
	    title = wxEmptyString;
	else {
    WXSTRING_INPUT( title, wxString, ST(3) )
;
	}

	if (items < 5)
	    pos = wxDefaultPosition;
	else {
    pos = wxPli_sv_2_wxpoint( aTHX_ ST(4) )
;
	}

	if (items < 6)
	    size = wxDefaultSize;
	else {
    size = wxPli_sv_2_wxsize( aTHX_ ST(5) )
;
	}

	if (items < 7)
	    style = wxDEFAULT_DIALOG_STYLE;
	else {
	    style = (long)SvIV(ST(6))
;
	}

	if (items < 8)
	    name = wxDialogNameStr;
	else {
    WXSTRING_INPUT( name, wxString, ST(7) )
;
	}

	RETVAL = THIS->Create(parent, id, title, pos, size, style, name);
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__Dialog_EndModal); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Dialog_EndModal)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, retCode");
    {
	int	retCode = (int)SvIV(ST(1))
;
	wxDialog *    THIS = (wxDialog *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Dialog" )
;

	THIS->EndModal(retCode);
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__Dialog_GetReturnCode); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Dialog_GetReturnCode)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxDialog *    THIS = (wxDialog *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Dialog" )
;
	int	RETVAL;
	dXSTARG;

	RETVAL = THIS->GetReturnCode();
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__Dialog_GetTitle); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Dialog_GetTitle)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxDialog *    THIS = (wxDialog *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Dialog" )
;
	wxString	RETVAL;

	RETVAL = THIS->GetTitle();
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    WXSTRING_OUTPUT( RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__Dialog_IsModal); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Dialog_IsModal)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxDialog *    THIS = (wxDialog *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Dialog" )
;
	bool	RETVAL;

	RETVAL = THIS->IsModal();
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__Dialog_SetIcon); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Dialog_SetIcon)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, icon");
    {
	wxIcon*    icon = (wxIcon *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::Icon" )
;
	wxDialog *    THIS = (wxDialog *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Dialog" )
;

	THIS->SetIcon(*icon);
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__Dialog_SetIcons); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Dialog_SetIcons)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, icons");
    {
	wxIconBundle*    icons = (wxIconBundle *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::IconBundle" )
;
	wxDialog *    THIS = (wxDialog *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Dialog" )
;

	THIS->SetIcons(*icons);
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__Dialog_SetReturnCode); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Dialog_SetReturnCode)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, retCode");
    {
	int	retCode = (int)SvIV(ST(1))
;
	wxDialog *    THIS = (wxDialog *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Dialog" )
;

	THIS->SetReturnCode(retCode);
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__Dialog_SetTitle); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Dialog_SetTitle)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, title");
    {
	wxString	title;
	wxDialog *    THIS = (wxDialog *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Dialog" )
;

    WXSTRING_INPUT( title, wxString, ST(1) )
;

	THIS->SetTitle(title);
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__Dialog_ShowModal); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Dialog_ShowModal)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxDialog *    THIS = (wxDialog *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Dialog" )
;
	int	RETVAL;
	dXSTARG;

	RETVAL = THIS->ShowModal();
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}

#if WXPERL_W_VERSION_GE( 2, 5, 4 )
#define XSubPPtmpAAAH 1


XS_EUPXS(XS_Wx__Dialog_SetFocusIgnoringChildren); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Dialog_SetFocusIgnoringChildren)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxDialog *    THIS = (wxDialog *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Dialog" )
;

	THIS->SetFocusIgnoringChildren();
    }
    XSRETURN_EMPTY;
}

#endif

XS_EUPXS(XS_Wx__Dialog_TransferDataFromWindow); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Dialog_TransferDataFromWindow)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxDialog *    THIS = (wxDialog *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Dialog" )
;
	bool	RETVAL;
    RETVAL = THIS->wxDialog::TransferDataFromWindow();
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__Dialog_TransferDataToWindow); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Dialog_TransferDataToWindow)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxDialog *    THIS = (wxDialog *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Dialog" )
;
	bool	RETVAL;
    RETVAL = THIS->wxDialog::TransferDataToWindow();
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__Dialog_Validate); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Dialog_Validate)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxDialog *    THIS = (wxDialog *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Dialog" )
;
	bool	RETVAL;
    RETVAL = THIS->wxDialog::Validate();
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


/* INCLUDE: Returning to 'Frames.xs' from '/usr/bin/perl -I./ -MExtUtils::XSpp::Cmd -e xspp -- -t typemap.xsp XS/Dialog.xsp' */


/* INCLUDE:  Including 'XS/Frame.xs' from 'Frames.xs' */


/* INCLUDE:  Including 'XS/StatusBar.xs' from 'XS/Frame.xs' */


/* INCLUDE:  Including 'XS/ToolBar.xs' from 'XS/StatusBar.xs' */


/* INCLUDE:  Including 'XS/Wizard.xs' from 'XS/ToolBar.xs' */

#include <wx/bitmap.h> 
#include <wx/panel.h>
#include <wx/dialog.h>
#include <wx/event.h>
#include <wx/wizard.h>
#include <wx/sizer.h>
#include "cpp/overload.h"
#include "cpp/wizard.h"

XS_EUPXS(XS_Wx__Wizard_new); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Wizard_new)
{
    dVAR; dXSARGS;
    if (items < 1)
       croak_xs_usage(cv,  "CLASS, ...");
    PERL_UNUSED_VAR(ax); /* -Wall */
    SP -= items;
    {
	char *	CLASS = (char *)SvPV_nolen(ST(0))
;
    BEGIN_OVERLOAD()
        MATCH_VOIDM_REDISP( newEmpty )
        MATCH_ANY_REDISP( newFull )
    END_OVERLOAD( Wx::Wizard::new )
	PUTBACK;
	return;
    }
}


XS_EUPXS(XS_Wx__Wizard_newEmpty); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Wizard_newEmpty)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "CLASS");
    {
	PlClassName    CLASS = wxPli_get_class( aTHX_ ST(0) )
;
	wxWizard *	RETVAL;
    RETVAL = new wxPliWizard( CLASS );
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_object_2_sv( aTHX_ RETVALSV, RETVAL );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__Wizard_newFull); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Wizard_newFull)
{
    dVAR; dXSARGS;
    if (items < 2 || items > 6)
       croak_xs_usage(cv,  "CLASS, parent, id = wxID_ANY, title = wxEmptyString, bitmap = (wxBitmap*)&wxNullBitmap, pos = wxDefaultPosition");
    {
	PlClassName    CLASS = wxPli_get_class( aTHX_ ST(0) )
;
	wxWindow*    parent = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::Window" )
;
	wxWindowID	id;
	wxString	title;
	wxBitmap*	bitmap;
	wxPoint	pos;
	wxWizard *	RETVAL;

	if (items < 3)
	    id = wxID_ANY;
	else {
    id = wxPli_get_wxwindowid( aTHX_ ST(2) )
;
	}

	if (items < 4)
	    title = wxEmptyString;
	else {
    WXSTRING_INPUT( title, wxString, ST(3) )
;
	}

	if (items < 5)
	    bitmap = (wxBitmap*)&wxNullBitmap;
	else {
    bitmap = (wxBitmap *) wxPli_sv_2_object( aTHX_ ST(4), "Wx::Bitmap" )
;
	}

	if (items < 6)
	    pos = wxDefaultPosition;
	else {
    pos = wxPli_sv_2_wxpoint( aTHX_ ST(5) )
;
	}
    RETVAL = new wxPliWizard( CLASS, parent, id, title, *bitmap, pos );
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_object_2_sv( aTHX_ RETVALSV, RETVAL );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__Wizard_Create); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Wizard_Create)
{
    dVAR; dXSARGS;
    if (items < 2 || items > 6)
       croak_xs_usage(cv,  "THIS, parent, id = wxID_ANY, title = wxEmptyString, bitmap = (wxBitmap*)&wxNullBitmap, pos = wxDefaultPosition");
    {
	wxWindow*    parent = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::Window" )
;
	wxWindowID	id;
	wxString	title;
	wxBitmap*	bitmap;
	wxPoint	pos;
	wxWizard *    THIS = (wxWizard *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Wizard" )
;
	bool	RETVAL;

	if (items < 3)
	    id = wxID_ANY;
	else {
    id = wxPli_get_wxwindowid( aTHX_ ST(2) )
;
	}

	if (items < 4)
	    title = wxEmptyString;
	else {
    WXSTRING_INPUT( title, wxString, ST(3) )
;
	}

	if (items < 5)
	    bitmap = (wxBitmap*)&wxNullBitmap;
	else {
    bitmap = (wxBitmap *) wxPli_sv_2_object( aTHX_ ST(4), "Wx::Bitmap" )
;
	}

	if (items < 6)
	    pos = wxDefaultPosition;
	else {
    pos = wxPli_sv_2_wxpoint( aTHX_ ST(5) )
;
	}

	RETVAL = THIS->Create(parent, id, title, *bitmap, pos);
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__Wizard_RunWizard); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Wizard_RunWizard)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, page");
    {
	wxWizardPage*    page = (wxWizardPage *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::WizardPage" )
;
	wxWizard *    THIS = (wxWizard *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Wizard" )
;
	bool	RETVAL;

	RETVAL = THIS->RunWizard(page);
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__Wizard_GetCurrentPage); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Wizard_GetCurrentPage)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxWizard *    THIS = (wxWizard *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Wizard" )
;
	wxWizardPage *	RETVAL;

	RETVAL = THIS->GetCurrentPage();
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_object_2_sv( aTHX_ RETVALSV, RETVAL );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__Wizard_GetPageSize); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Wizard_GetPageSize)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxWizard *    THIS = (wxWizard *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Wizard" )
;
	wxSize *	RETVAL;
    RETVAL = new wxSize( THIS->GetPageSize() );
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_non_object_2_sv( aTHX_ RETVALSV, RETVAL, "Wx::Size" );
    wxPli_thread_sv_register( aTHX_ "Wx::Size", RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__Wizard_SetPageSize); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Wizard_SetPageSize)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, size");
    {
	wxSize    size = wxPli_sv_2_wxsize( aTHX_ ST(1) )
;
	wxWizard *    THIS = (wxWizard *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Wizard" )
;

	THIS->SetPageSize(size);
    }
    XSRETURN_EMPTY;
}

#if WXPERL_W_VERSION_GE( 2, 5, 1 )
#define XSubPPtmpAAAI 1


XS_EUPXS(XS_Wx__Wizard_GetPageAreaSizer); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Wizard_GetPageAreaSizer)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxWizard *    THIS = (wxWizard *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Wizard" )
;
	wxSizer *	RETVAL;

	RETVAL = THIS->GetPageAreaSizer();
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_object_2_sv( aTHX_ RETVALSV, RETVAL );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}

#endif
#if WXPERL_W_VERSION_GE( 2, 8, 5 )
#define XSubPPtmpAAAJ 1


XS_EUPXS(XS_Wx__Wizard_GetBitmap); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Wizard_GetBitmap)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxWizard *    THIS = (wxWizard *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Wizard" )
;
	wxBitmap *	RETVAL;
    RETVAL = new wxBitmap( THIS->GetBitmap() );
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_object_2_sv( aTHX_ RETVALSV, RETVAL );
    wxPli_thread_sv_register( aTHX_ "Wx::Bitmap", RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__Wizard_SetBitmap); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Wizard_SetBitmap)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, bitmap");
    {
	wxBitmap*    bitmap = (wxBitmap *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::Bitmap" )
;
	wxWizard *    THIS = (wxWizard *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Wizard" )
;

	THIS->SetBitmap(*bitmap);
    }
    XSRETURN_EMPTY;
}

#endif

XS_EUPXS(XS_Wx__Wizard_FitToPage); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Wizard_FitToPage)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, firstPage");
    {
	wxWizardPage*    firstPage = (wxWizardPage *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::WizardPage" )
;
	wxWizard *    THIS = (wxWizard *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Wizard" )
;

	THIS->FitToPage(firstPage);
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__Wizard_SetBorder); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Wizard_SetBorder)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, border");
    {
	int	border = (int)SvIV(ST(1))
;
	wxWizard *    THIS = (wxWizard *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Wizard" )
;

	THIS->SetBorder(border);
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__Wizard_HasNextPage); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Wizard_HasNextPage)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, page");
    {
	wxWizardPage*    page = (wxWizardPage *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::WizardPage" )
;
	wxWizard *    THIS = (wxWizard *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Wizard" )
;
	bool	RETVAL;

	RETVAL = THIS->HasNextPage(page);
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__Wizard_HasPrevPage); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Wizard_HasPrevPage)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, page");
    {
	wxWizardPage*    page = (wxWizardPage *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::WizardPage" )
;
	wxWizard *    THIS = (wxWizard *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Wizard" )
;
	bool	RETVAL;

	RETVAL = THIS->HasPrevPage(page);
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}

#if WXPERL_W_VERSION_GE( 2, 9, 0 )
#define XSubPPtmpAAAK 1


XS_EUPXS(XS_Wx__Wizard_SetBitmapBackgroundColour); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Wizard_SetBitmapBackgroundColour)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, colour");
    {
	wxColour    colour = *(wxColour *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::Colour" )
;
	wxWizard *    THIS = (wxWizard *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Wizard" )
;

	THIS->SetBitmapBackgroundColour(colour);
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__Wizard_GetBitmapBackgroundColour); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Wizard_GetBitmapBackgroundColour)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxWizard *    THIS = (wxWizard *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Wizard" )
;
	wxColour *	RETVAL;
    RETVAL = new wxColour( THIS->GetBitmapBackgroundColour() );
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_non_object_2_sv( aTHX_ RETVALSV, RETVAL, "Wx::Colour" );
    wxPli_thread_sv_register( aTHX_ "Wx::Colour", RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__Wizard_SetBitmapPlacement); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Wizard_SetBitmapPlacement)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, placement");
    {
	int	placement = (int)SvIV(ST(1))
;
	wxWizard *    THIS = (wxWizard *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Wizard" )
;

	THIS->SetBitmapPlacement(placement);
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__Wizard_GetBitmapPlacement); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Wizard_GetBitmapPlacement)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxWizard *    THIS = (wxWizard *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Wizard" )
;
	int	RETVAL;
	dXSTARG;

	RETVAL = THIS->GetBitmapPlacement();
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__Wizard_SetMinimumBitmapWidth); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Wizard_SetMinimumBitmapWidth)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, w");
    {
	int	w = (int)SvIV(ST(1))
;
	wxWizard *    THIS = (wxWizard *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Wizard" )
;

	THIS->SetMinimumBitmapWidth(w);
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__Wizard_GetMinimumBitmapWidth); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Wizard_GetMinimumBitmapWidth)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxWizard *    THIS = (wxWizard *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Wizard" )
;
	int	RETVAL;
	dXSTARG;

	RETVAL = THIS->GetMinimumBitmapWidth();
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}

#endif

XS_EUPXS(XS_Wx__WizardPage_new); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__WizardPage_new)
{
    dVAR; dXSARGS;
    if (items < 1)
       croak_xs_usage(cv,  "CLASS, ...");
    PERL_UNUSED_VAR(ax); /* -Wall */
    SP -= items;
    {
	char *	CLASS = (char *)SvPV_nolen(ST(0))
;
    BEGIN_OVERLOAD()
        MATCH_VOIDM_REDISP( newEmpty )
        MATCH_ANY_REDISP( newFull )
    END_OVERLOAD( Wx::WizardPage::new )
	PUTBACK;
	return;
    }
}


XS_EUPXS(XS_Wx__WizardPage_newEmpty); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__WizardPage_newEmpty)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "CLASS");
    {
	PlClassName    CLASS = wxPli_get_class( aTHX_ ST(0) )
;
	wxWizardPage *	RETVAL;
    RETVAL = new wxPliWizardPage( CLASS );
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_object_2_sv( aTHX_ RETVALSV, RETVAL );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__WizardPage_newFull); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__WizardPage_newFull)
{
    dVAR; dXSARGS;
    if (items < 2 || items > 3)
       croak_xs_usage(cv,  "CLASS, parent, bitmap = (wxBitmap*)&wxNullBitmap");
    {
	PlClassName    CLASS = wxPli_get_class( aTHX_ ST(0) )
;
	wxWizard*    parent = (wxWizard *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::Wizard" )
;
	wxBitmap*	bitmap;
	wxWizardPage *	RETVAL;

	if (items < 3)
	    bitmap = (wxBitmap*)&wxNullBitmap;
	else {
    bitmap = (wxBitmap *) wxPli_sv_2_object( aTHX_ ST(2), "Wx::Bitmap" )
;
	}
    RETVAL = new wxPliWizardPage( CLASS, parent, *bitmap );
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_object_2_sv( aTHX_ RETVALSV, RETVAL );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__WizardPage_Create); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__WizardPage_Create)
{
    dVAR; dXSARGS;
    if (items < 2 || items > 3)
       croak_xs_usage(cv,  "THIS, parent, bitmap = (wxBitmap*)&wxNullBitmap");
    {
	wxWizard*    parent = (wxWizard *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::Wizard" )
;
	wxBitmap*	bitmap;
	wxWizardPage *    THIS = (wxWizardPage *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::WizardPage" )
;
	bool	RETVAL;

	if (items < 3)
	    bitmap = (wxBitmap*)&wxNullBitmap;
	else {
    bitmap = (wxBitmap *) wxPli_sv_2_object( aTHX_ ST(2), "Wx::Bitmap" )
;
	}

	RETVAL = THIS->Create(parent, *bitmap);
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__WizardPage_GetBitmap); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__WizardPage_GetBitmap)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxWizardPage *    THIS = (wxWizardPage *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::WizardPage" )
;
	wxBitmap *	RETVAL;
    RETVAL = new wxBitmap( THIS->GetBitmap() );
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_object_2_sv( aTHX_ RETVALSV, RETVAL );
    wxPli_thread_sv_register( aTHX_ "Wx::Bitmap", RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__WizardPage_GetPrev); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__WizardPage_GetPrev)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxWizardPageSimple *    THIS = (wxWizardPageSimple *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::WizardPageSimple" )
;
	wxWizardPage *	RETVAL;

	RETVAL = THIS->GetPrev();
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_object_2_sv( aTHX_ RETVALSV, RETVAL );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__WizardPage_GetNext); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__WizardPage_GetNext)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxWizardPageSimple *    THIS = (wxWizardPageSimple *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::WizardPageSimple" )
;
	wxWizardPage *	RETVAL;

	RETVAL = THIS->GetNext();
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_object_2_sv( aTHX_ RETVALSV, RETVAL );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__WizardPageSimple_new); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__WizardPageSimple_new)
{
    dVAR; dXSARGS;
    if (items < 2 || items > 4)
       croak_xs_usage(cv,  "CLASS, parent, prev = 0, next = 0");
    {
	wxWizard*    parent = (wxWizard *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::Wizard" )
;
	wxWizardPage*	prev;
	wxWizardPage*	next;
	char *	CLASS = (char *)SvPV_nolen(ST(0))
;
	wxWizardPageSimple *	RETVAL;

	if (items < 3)
	    prev = 0;
	else {
    prev = (wxWizardPage *) wxPli_sv_2_object( aTHX_ ST(2), "Wx::WizardPage" )
;
	}

	if (items < 4)
	    next = 0;
	else {
    next = (wxWizardPage *) wxPli_sv_2_object( aTHX_ ST(3), "Wx::WizardPage" )
;
	}

	RETVAL = new wxWizardPageSimple(parent, prev, next);
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_object_2_sv( aTHX_ RETVALSV, RETVAL );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__WizardPageSimple_SetPrev); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__WizardPageSimple_SetPrev)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, prev");
    {
	wxWizardPage*    prev = (wxWizardPage *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::WizardPage" )
;
	wxWizardPageSimple *    THIS = (wxWizardPageSimple *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::WizardPageSimple" )
;

	THIS->SetPrev(prev);
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__WizardPageSimple_SetNext); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__WizardPageSimple_SetNext)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, next");
    {
	wxWizardPage*    next = (wxWizardPage *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::WizardPage" )
;
	wxWizardPageSimple *    THIS = (wxWizardPageSimple *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::WizardPageSimple" )
;

	THIS->SetNext(next);
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__WizardPageSimple_Chain); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__WizardPageSimple_Chain)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "first, second");
    {
	wxWizardPageSimple*    first = (wxWizardPageSimple *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::WizardPageSimple" )
;
	wxWizardPageSimple*    second = (wxWizardPageSimple *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::WizardPageSimple" )
;
    wxWizardPageSimple::Chain( first, second );
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__WizardEvent_GetDirection); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__WizardEvent_GetDirection)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxWizardEvent *    THIS = (wxWizardEvent *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::WizardEvent" )
;
	bool	RETVAL;

	RETVAL = THIS->GetDirection();
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__WizardEvent_GetPage); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__WizardEvent_GetPage)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxWizardEvent *    THIS = (wxWizardEvent *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::WizardEvent" )
;
	wxWizardPage *	RETVAL;

	RETVAL = THIS->GetPage();
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_object_2_sv( aTHX_ RETVALSV, RETVAL );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


/* INCLUDE: Returning to 'XS/ToolBar.xs' from 'XS/Wizard.xs' */

#include <wx/toolbar.h>
#include <wx/menu.h>

XS_EUPXS(XS_Wx__ToolBarToolBase_Destroy); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ToolBarToolBase_Destroy)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxToolBarToolBase *    THIS = (wxToolBarToolBase *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::ToolBarToolBase" )
;
    delete THIS;
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__ToolBarToolBase_GetId); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ToolBarToolBase_GetId)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxToolBarToolBase *    THIS = (wxToolBarToolBase *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::ToolBarToolBase" )
;
	int	RETVAL;
	dXSTARG;

	RETVAL = THIS->GetId();
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__ToolBarToolBase_GetControl); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ToolBarToolBase_GetControl)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxToolBarToolBase *    THIS = (wxToolBarToolBase *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::ToolBarToolBase" )
;
	wxControl *	RETVAL;

	RETVAL = THIS->GetControl();
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_object_2_sv( aTHX_ RETVALSV, RETVAL );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__ToolBarToolBase_GetToolBar); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ToolBarToolBase_GetToolBar)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxToolBarToolBase *    THIS = (wxToolBarToolBase *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::ToolBarToolBase" )
;
	wxToolBarBase *	RETVAL;

	RETVAL = THIS->GetToolBar();
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_evthandler_2_sv( aTHX_ RETVALSV, RETVAL );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__ToolBarToolBase_IsButton); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ToolBarToolBase_IsButton)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxToolBarToolBase *    THIS = (wxToolBarToolBase *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::ToolBarToolBase" )
;
	bool	RETVAL;

	RETVAL = THIS->IsButton();
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__ToolBarToolBase_IsControl); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ToolBarToolBase_IsControl)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxToolBarToolBase *    THIS = (wxToolBarToolBase *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::ToolBarToolBase" )
;
	bool	RETVAL;

	RETVAL = THIS->IsControl();
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__ToolBarToolBase_IsSeparator); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ToolBarToolBase_IsSeparator)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxToolBarToolBase *    THIS = (wxToolBarToolBase *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::ToolBarToolBase" )
;
	bool	RETVAL;

	RETVAL = THIS->IsSeparator();
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__ToolBarToolBase_GetStyle); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ToolBarToolBase_GetStyle)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxToolBarToolBase *    THIS = (wxToolBarToolBase *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::ToolBarToolBase" )
;
	int	RETVAL;
	dXSTARG;

	RETVAL = THIS->GetStyle();
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__ToolBarToolBase_GetKind); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ToolBarToolBase_GetKind)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxToolBarToolBase *    THIS = (wxToolBarToolBase *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::ToolBarToolBase" )
;
	wxItemKind	RETVAL;
	dXSTARG;

	RETVAL = THIS->GetKind();
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__ToolBarToolBase_IsEnabled); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ToolBarToolBase_IsEnabled)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxToolBarToolBase *    THIS = (wxToolBarToolBase *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::ToolBarToolBase" )
;
	bool	RETVAL;

	RETVAL = THIS->IsEnabled();
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__ToolBarToolBase_IsToggled); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ToolBarToolBase_IsToggled)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxToolBarToolBase *    THIS = (wxToolBarToolBase *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::ToolBarToolBase" )
;
	bool	RETVAL;

	RETVAL = THIS->IsToggled();
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__ToolBarToolBase_CanBeToggled); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ToolBarToolBase_CanBeToggled)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxToolBarToolBase *    THIS = (wxToolBarToolBase *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::ToolBarToolBase" )
;
	bool	RETVAL;

	RETVAL = THIS->CanBeToggled();
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__ToolBarToolBase_GetNormalBitmap); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ToolBarToolBase_GetNormalBitmap)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxToolBarToolBase *    THIS = (wxToolBarToolBase *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::ToolBarToolBase" )
;
	wxBitmap *	RETVAL;
    RETVAL = new wxBitmap( THIS->GetNormalBitmap() );
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_object_2_sv( aTHX_ RETVALSV, RETVAL );
    wxPli_thread_sv_register( aTHX_ "Wx::Bitmap", RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__ToolBarToolBase_GetDisabledBitmap); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ToolBarToolBase_GetDisabledBitmap)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxToolBarToolBase *    THIS = (wxToolBarToolBase *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::ToolBarToolBase" )
;
	wxBitmap *	RETVAL;
    RETVAL = new wxBitmap( THIS->GetDisabledBitmap() );
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_object_2_sv( aTHX_ RETVALSV, RETVAL );
    wxPli_thread_sv_register( aTHX_ "Wx::Bitmap", RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__ToolBarToolBase_GetBitmap1); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ToolBarToolBase_GetBitmap1)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxToolBarToolBase *    THIS = (wxToolBarToolBase *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::ToolBarToolBase" )
;
	wxBitmap *	RETVAL;
    RETVAL = new wxBitmap( THIS->GetNormalBitmap() );
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_object_2_sv( aTHX_ RETVALSV, RETVAL );
    wxPli_thread_sv_register( aTHX_ "Wx::Bitmap", RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__ToolBarToolBase_GetBitmap2); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ToolBarToolBase_GetBitmap2)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxToolBarToolBase *    THIS = (wxToolBarToolBase *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::ToolBarToolBase" )
;
	wxBitmap *	RETVAL;
    RETVAL = new wxBitmap( THIS->GetDisabledBitmap() );
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_object_2_sv( aTHX_ RETVALSV, RETVAL );
    wxPli_thread_sv_register( aTHX_ "Wx::Bitmap", RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__ToolBarToolBase_GetBitmap); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ToolBarToolBase_GetBitmap)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxToolBarToolBase *    THIS = (wxToolBarToolBase *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::ToolBarToolBase" )
;
	wxBitmap *	RETVAL;
    RETVAL = new wxBitmap( THIS->GetBitmap() );
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_object_2_sv( aTHX_ RETVALSV, RETVAL );
    wxPli_thread_sv_register( aTHX_ "Wx::Bitmap", RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__ToolBarToolBase_GetLabel); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ToolBarToolBase_GetLabel)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxToolBarToolBase *    THIS = (wxToolBarToolBase *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::ToolBarToolBase" )
;
	wxString	RETVAL;

	RETVAL = THIS->GetLabel();
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    WXSTRING_OUTPUT( RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__ToolBarToolBase_GetShortHelp); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ToolBarToolBase_GetShortHelp)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxToolBarToolBase *    THIS = (wxToolBarToolBase *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::ToolBarToolBase" )
;
	wxString	RETVAL;

	RETVAL = THIS->GetShortHelp();
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    WXSTRING_OUTPUT( RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__ToolBarToolBase_GetLongHelp); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ToolBarToolBase_GetLongHelp)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxToolBarToolBase *    THIS = (wxToolBarToolBase *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::ToolBarToolBase" )
;
	wxString	RETVAL;

	RETVAL = THIS->GetLongHelp();
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    WXSTRING_OUTPUT( RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__ToolBarToolBase_GetClientData); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ToolBarToolBase_GetClientData)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxToolBarToolBase *    THIS = (wxToolBarToolBase *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::ToolBarToolBase" )
;
	Wx_UserDataO *	RETVAL;
    RETVAL = (Wx_UserDataO*) THIS->GetClientData();
	{
	    SV * RETVALSV;
    RETVALSV = ( RETVAL == 0 ) ? &PL_sv_undef : RETVAL->GetData();
    SvREFCNT_inc( RETVALSV ); // xsubpp mortalizes it...
	    RETVALSV = sv_2mortal(RETVALSV);
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__ToolBarToolBase_Enable); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ToolBarToolBase_Enable)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, enable");
    {
	bool	enable = (bool)SvTRUE(ST(1))
;
	wxToolBarToolBase *    THIS = (wxToolBarToolBase *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::ToolBarToolBase" )
;
	bool	RETVAL;

	RETVAL = THIS->Enable(enable);
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__ToolBarToolBase_Toggle); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ToolBarToolBase_Toggle)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, enable");
    {
	bool	enable = (bool)SvTRUE(ST(1))
;
	wxToolBarToolBase *    THIS = (wxToolBarToolBase *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::ToolBarToolBase" )
;
	bool	RETVAL;

	RETVAL = THIS->Toggle(enable);
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__ToolBarToolBase_SetToggle); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ToolBarToolBase_SetToggle)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, toggle");
    {
	bool	toggle = (bool)SvTRUE(ST(1))
;
	wxToolBarToolBase *    THIS = (wxToolBarToolBase *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::ToolBarToolBase" )
;
	bool	RETVAL;

	RETVAL = THIS->SetToggle(toggle);
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__ToolBarToolBase_SetShortHelp); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ToolBarToolBase_SetShortHelp)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, help");
    {
	wxString	help;
	wxToolBarToolBase *    THIS = (wxToolBarToolBase *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::ToolBarToolBase" )
;
	bool	RETVAL;

    WXSTRING_INPUT( help, wxString, ST(1) )
;

	RETVAL = THIS->SetShortHelp(help);
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__ToolBarToolBase_SetLongHelp); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ToolBarToolBase_SetLongHelp)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, help");
    {
	wxString	help;
	wxToolBarToolBase *    THIS = (wxToolBarToolBase *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::ToolBarToolBase" )
;
	bool	RETVAL;

    WXSTRING_INPUT( help, wxString, ST(1) )
;

	RETVAL = THIS->SetLongHelp(help);
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__ToolBarToolBase_SetNormalBitmap); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ToolBarToolBase_SetNormalBitmap)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, bmp");
    {
	wxBitmap*    bmp = (wxBitmap *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::Bitmap" )
;
	wxToolBarToolBase *    THIS = (wxToolBarToolBase *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::ToolBarToolBase" )
;
    THIS->SetNormalBitmap( *bmp );
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__ToolBarToolBase_SetDisabledBitmap); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ToolBarToolBase_SetDisabledBitmap)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, bmp");
    {
	wxBitmap*    bmp = (wxBitmap *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::Bitmap" )
;
	wxToolBarToolBase *    THIS = (wxToolBarToolBase *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::ToolBarToolBase" )
;
    THIS->SetDisabledBitmap( *bmp );
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__ToolBarToolBase_SetLabel); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ToolBarToolBase_SetLabel)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, label");
    {
	wxString	label;
	wxToolBarToolBase *    THIS = (wxToolBarToolBase *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::ToolBarToolBase" )
;

    WXSTRING_INPUT( label, wxString, ST(1) )
;

	THIS->SetLabel(label);
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__ToolBarToolBase_SetBitmap1); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ToolBarToolBase_SetBitmap1)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, bmp");
    {
	wxBitmap*    bmp = (wxBitmap *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::Bitmap" )
;
	wxToolBarToolBase *    THIS = (wxToolBarToolBase *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::ToolBarToolBase" )
;
    THIS->SetNormalBitmap( *bmp );
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__ToolBarToolBase_SetBitmap2); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ToolBarToolBase_SetBitmap2)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, bmp");
    {
	wxBitmap*    bmp = (wxBitmap *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::Bitmap" )
;
	wxToolBarToolBase *    THIS = (wxToolBarToolBase *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::ToolBarToolBase" )
;
    THIS->SetDisabledBitmap( *bmp );
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__ToolBarToolBase_SetClientData); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ToolBarToolBase_SetClientData)
{
    dVAR; dXSARGS;
    if (items < 1 || items > 2)
       croak_xs_usage(cv,  "THIS, data = 0");
    {
	Wx_UserDataO*	data;
	wxToolBarToolBase *    THIS = (wxToolBarToolBase *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::ToolBarToolBase" )
;

	if (items < 2)
	    data = 0;
	else {
    if( SvOK( ST(1) ) )
    {
	data = new wxPliUserDataO( ST(1) );
    }
    else
	data = 0
;
	}
    delete THIS->GetClientData();
    THIS->SetClientData( data );
    }
    XSRETURN_EMPTY;
}

#if WXPERL_W_VERSION_GE( 2, 9, 0 )
#define XSubPPtmpAAAL 1


XS_EUPXS(XS_Wx__ToolBarToolBase_SetDropdownMenu); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ToolBarToolBase_SetDropdownMenu)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, menu");
    {
	wxMenu*    menu = (wxMenu *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::Menu" )
;
	wxToolBarToolBase *    THIS = (wxToolBarToolBase *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::ToolBarToolBase" )
;

	THIS->SetDropdownMenu(menu);
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__ToolBarToolBase_GetDropdownMenu); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ToolBarToolBase_GetDropdownMenu)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxToolBarToolBase *    THIS = (wxToolBarToolBase *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::ToolBarToolBase" )
;
	wxMenu *	RETVAL;

	RETVAL = THIS->GetDropdownMenu();
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_object_2_sv( aTHX_ RETVALSV, RETVAL );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}

#endif

XS_EUPXS(XS_Wx__ToolBarBase_Destroy); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ToolBarBase_Destroy)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxToolBarBase *    THIS = (wxToolBarBase *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::ToolBarBase" )
;
    delete THIS;
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__ToolBarBase_AddControl); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ToolBarBase_AddControl)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, control");
    {
	wxControl*    control = (wxControl *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::Control" )
;
	wxToolBarBase *    THIS = (wxToolBarBase *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::ToolBarBase" )
;
	bool	RETVAL;

	RETVAL = THIS->AddControl(control);
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__ToolBarBase_AddSeparator); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ToolBarBase_AddSeparator)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxToolBar *    THIS = (wxToolBar *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::ToolBar" )
;

	THIS->AddSeparator();
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__ToolBarBase_AddTool); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ToolBarBase_AddTool)
{
    dVAR; dXSARGS;
    if (items < 1)
       croak_xs_usage(cv,  "THIS, ...");
    PERL_UNUSED_VAR(ax); /* -Wall */
    SP -= items;
    {
	wxToolBarBase *    THIS = (wxToolBarBase *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::ToolBarBase" )
;
    BEGIN_OVERLOAD()
        MATCH_REDISP_COUNT_ALLOWMORE( wxPliOvl_n_wbmp_wbmp_b_s_s_s,
                                      AddToolLong, 3 )
        MATCH_REDISP_COUNT_ALLOWMORE( wxPliOvl_n_wbmp_s_s, AddToolShort, 2 )
        MATCH_REDISP_COUNT_ALLOWMORE( wxPliOvl_n_s_wbmp_wbmp_n_s_s_s,
                                      AddToolNewLong, 3 )
        MATCH_REDISP_COUNT_ALLOWMORE( wxPliOvl_n_s_wbmp_s_n,
                                      AddToolNewShort, 3 )
    END_OVERLOAD( Wx::ToolBarBase::AddTool )
	PUTBACK;
	return;
    }
}


XS_EUPXS(XS_Wx__ToolBarBase_AddToolShort); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ToolBarBase_AddToolShort)
{
    dVAR; dXSARGS;
    if (items < 3 || items > 5)
       croak_xs_usage(cv,  "THIS, toolId, bitmap1, shortHelp = wxEmptyString, longHelp = wxEmptyString");
    {
	int	toolId = (int)SvIV(ST(1))
;
	wxBitmap*    bitmap1 = (wxBitmap *) wxPli_sv_2_object( aTHX_ ST(2), "Wx::Bitmap" )
;
	wxString	shortHelp;
	wxString	longHelp;
	wxToolBarBase *    THIS = (wxToolBarBase *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::ToolBarBase" )
;
	wxToolBarToolBase *	RETVAL;

	if (items < 4)
	    shortHelp = wxEmptyString;
	else {
    WXSTRING_INPUT( shortHelp, wxString, ST(3) )
;
	}

	if (items < 5)
	    longHelp = wxEmptyString;
	else {
    WXSTRING_INPUT( longHelp, wxString, ST(4) )
;
	}
#if WXPERL_W_VERSION_GE( 2, 9, 0 )
    RETVAL = THIS->AddTool( toolId, wxEmptyString, *bitmap1, wxNullBitmap,
                            wxITEM_NORMAL, shortHelp, longHelp );
#else
    RETVAL = THIS->AddTool( toolId, *bitmap1, shortHelp, longHelp );
#endif
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_non_object_2_sv( aTHX_ RETVALSV, RETVAL, "Wx::ToolBarToolBase" );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__ToolBarBase_AddToolLong); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ToolBarBase_AddToolLong)
{
    dVAR; dXSARGS;
    if (items < 3 || items > 8)
       croak_xs_usage(cv,  "THIS, toolId, bitmap1, bitmap2 = (wxBitmap*)&wxNullBitmap, isToggle = false, clientData = 0, shortHelp = wxEmptyString, longHelp = wxEmptyString");
    {
	int	toolId = (int)SvIV(ST(1))
;
	wxBitmap*    bitmap1 = (wxBitmap *) wxPli_sv_2_object( aTHX_ ST(2), "Wx::Bitmap" )
;
	wxBitmap*	bitmap2;
	bool	isToggle;
	wxPliUserDataO*	clientData;
	wxString	shortHelp;
	wxString	longHelp;
	wxToolBarBase *    THIS = (wxToolBarBase *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::ToolBarBase" )
;
	wxToolBarToolBase *	RETVAL;

	if (items < 4)
	    bitmap2 = (wxBitmap*)&wxNullBitmap;
	else {
    bitmap2 = (wxBitmap *) wxPli_sv_2_object( aTHX_ ST(3), "Wx::Bitmap" )
;
	}

	if (items < 5)
	    isToggle = false;
	else {
	    isToggle = (bool)SvTRUE(ST(4))
;
	}

	if (items < 6)
	    clientData = 0;
	else {
    if( SvOK( ST(5) ) )
    {
	clientData = new wxPliUserDataO( ST(5) );
    }
    else
	clientData = 0
;
	}

	if (items < 7)
	    shortHelp = wxEmptyString;
	else {
    WXSTRING_INPUT( shortHelp, wxString, ST(6) )
;
	}

	if (items < 8)
	    longHelp = wxEmptyString;
	else {
    WXSTRING_INPUT( longHelp, wxString, ST(7) )
;
	}
#if WXPERL_W_VERSION_GE( 2, 9, 0 )
    RETVAL = THIS->AddTool( toolId, wxEmptyString, *bitmap1, *bitmap2,
                            isToggle ? wxITEM_CHECK : wxITEM_NORMAL,
                            shortHelp, longHelp );
    if( clientData )
      RETVAL->SetClientData( clientData );
#else
    RETVAL = THIS->AddTool( toolId, *bitmap1, *bitmap2, isToggle,
        0, shortHelp, longHelp );
    if( clientData )
      RETVAL->SetClientData( clientData );
#endif
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_non_object_2_sv( aTHX_ RETVALSV, RETVAL, "Wx::ToolBarToolBase" );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__ToolBarBase_AddToolNewLong); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ToolBarBase_AddToolNewLong)
{
    dVAR; dXSARGS;
    if (items < 4 || items > 9)
       croak_xs_usage(cv,  "THIS, toolId, label, bitmap1, bitmap2 = (wxBitmap*)&wxNullBitmap, kind = wxITEM_NORMAL, shortHelp = wxEmptyString, longHelp = wxEmptyString, clientData = 0");
    {
	int	toolId = (int)SvIV(ST(1))
;
	wxString	label;
	wxBitmap*    bitmap1 = (wxBitmap *) wxPli_sv_2_object( aTHX_ ST(3), "Wx::Bitmap" )
;
	wxBitmap*	bitmap2;
	wxItemKind	kind;
	wxString	shortHelp;
	wxString	longHelp;
	wxPliUserDataO*	clientData;
	wxToolBarBase *    THIS = (wxToolBarBase *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::ToolBarBase" )
;
	wxToolBarToolBase *	RETVAL;

    WXSTRING_INPUT( label, wxString, ST(2) )
;

	if (items < 5)
	    bitmap2 = (wxBitmap*)&wxNullBitmap;
	else {
    bitmap2 = (wxBitmap *) wxPli_sv_2_object( aTHX_ ST(4), "Wx::Bitmap" )
;
	}

	if (items < 6)
	    kind = wxITEM_NORMAL;
	else {
	    kind = (wxItemKind)SvIV(ST(5))
;
	}

	if (items < 7)
	    shortHelp = wxEmptyString;
	else {
    WXSTRING_INPUT( shortHelp, wxString, ST(6) )
;
	}

	if (items < 8)
	    longHelp = wxEmptyString;
	else {
    WXSTRING_INPUT( longHelp, wxString, ST(7) )
;
	}

	if (items < 9)
	    clientData = 0;
	else {
    if( SvOK( ST(8) ) )
    {
	clientData = new wxPliUserDataO( ST(8) );
    }
    else
	clientData = 0
;
	}
    RETVAL = THIS->AddTool( toolId, label, *bitmap1, *bitmap2, kind,
                            shortHelp, longHelp );
    if( clientData )
        RETVAL->SetClientData( clientData );
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_non_object_2_sv( aTHX_ RETVALSV, RETVAL, "Wx::ToolBarToolBase" );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__ToolBarBase_AddToolNewShort); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ToolBarBase_AddToolNewShort)
{
    dVAR; dXSARGS;
    if (items < 4 || items > 6)
       croak_xs_usage(cv,  "THIS, toolId, label, bitmap, shortHelp = wxEmptyString, kind = wxITEM_NORMAL");
    {
	int	toolId = (int)SvIV(ST(1))
;
	wxString	label;
	wxBitmap*    bitmap = (wxBitmap *) wxPli_sv_2_object( aTHX_ ST(3), "Wx::Bitmap" )
;
	wxString	shortHelp;
	wxItemKind	kind;
	wxToolBarBase *    THIS = (wxToolBarBase *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::ToolBarBase" )
;
	wxToolBarToolBase *	RETVAL;

    WXSTRING_INPUT( label, wxString, ST(2) )
;

	if (items < 5)
	    shortHelp = wxEmptyString;
	else {
    WXSTRING_INPUT( shortHelp, wxString, ST(4) )
;
	}

	if (items < 6)
	    kind = wxITEM_NORMAL;
	else {
	    kind = (wxItemKind)SvIV(ST(5))
;
	}
    RETVAL = THIS->AddTool( toolId, label, *bitmap, shortHelp, kind );
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_non_object_2_sv( aTHX_ RETVALSV, RETVAL, "Wx::ToolBarToolBase" );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__ToolBarBase_AddCheckTool); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ToolBarBase_AddCheckTool)
{
    dVAR; dXSARGS;
    if (items < 5 || items > 8)
       croak_xs_usage(cv,  "THIS, toolId, label, bitmap1, bitmap2, shortHelpString = wxEmptyString, longHelpString = wxEmptyString, clientData = NULL");
    {
	int	toolId = (int)SvIV(ST(1))
;
	wxString	label;
	wxBitmap*    bitmap1 = (wxBitmap *) wxPli_sv_2_object( aTHX_ ST(3), "Wx::Bitmap" )
;
	wxBitmap*    bitmap2 = (wxBitmap *) wxPli_sv_2_object( aTHX_ ST(4), "Wx::Bitmap" )
;
	wxString	shortHelpString;
	wxString	longHelpString;
	wxPliUserDataO*	clientData;
	wxToolBarBase *    THIS = (wxToolBarBase *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::ToolBarBase" )
;
	wxToolBarToolBase *	RETVAL;

    WXSTRING_INPUT( label, wxString, ST(2) )
;

	if (items < 6)
	    shortHelpString = wxEmptyString;
	else {
    WXSTRING_INPUT( shortHelpString, wxString, ST(5) )
;
	}

	if (items < 7)
	    longHelpString = wxEmptyString;
	else {
    WXSTRING_INPUT( longHelpString, wxString, ST(6) )
;
	}

	if (items < 8)
	    clientData = NULL;
	else {
    if( SvOK( ST(7) ) )
    {
	clientData = new wxPliUserDataO( ST(7) );
    }
    else
	clientData = 0
;
	}

	RETVAL = THIS->AddCheckTool(toolId, label, *bitmap1, *bitmap2, shortHelpString, longHelpString, clientData);
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_non_object_2_sv( aTHX_ RETVALSV, RETVAL, "Wx::ToolBarToolBase" );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__ToolBarBase_AddRadioTool); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ToolBarBase_AddRadioTool)
{
    dVAR; dXSARGS;
    if (items < 5 || items > 8)
       croak_xs_usage(cv,  "THIS, toolId, label, bitmap1, bitmap2, shortHelpString = wxEmptyString, longHelpString = wxEmptyString, clientData = NULL");
    {
	int	toolId = (int)SvIV(ST(1))
;
	wxString	label;
	wxBitmap*    bitmap1 = (wxBitmap *) wxPli_sv_2_object( aTHX_ ST(3), "Wx::Bitmap" )
;
	wxBitmap*    bitmap2 = (wxBitmap *) wxPli_sv_2_object( aTHX_ ST(4), "Wx::Bitmap" )
;
	wxString	shortHelpString;
	wxString	longHelpString;
	wxPliUserDataO*	clientData;
	wxToolBarBase *    THIS = (wxToolBarBase *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::ToolBarBase" )
;
	wxToolBarToolBase *	RETVAL;

    WXSTRING_INPUT( label, wxString, ST(2) )
;

	if (items < 6)
	    shortHelpString = wxEmptyString;
	else {
    WXSTRING_INPUT( shortHelpString, wxString, ST(5) )
;
	}

	if (items < 7)
	    longHelpString = wxEmptyString;
	else {
    WXSTRING_INPUT( longHelpString, wxString, ST(6) )
;
	}

	if (items < 8)
	    clientData = NULL;
	else {
    if( SvOK( ST(7) ) )
    {
	clientData = new wxPliUserDataO( ST(7) );
    }
    else
	clientData = 0
;
	}

	RETVAL = THIS->AddRadioTool(toolId, label, *bitmap1, *bitmap2, shortHelpString, longHelpString, clientData);
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_non_object_2_sv( aTHX_ RETVALSV, RETVAL, "Wx::ToolBarToolBase" );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__ToolBarBase_DeleteTool); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ToolBarBase_DeleteTool)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, toolId");
    {
	int	toolId = (int)SvIV(ST(1))
;
	wxToolBarBase *    THIS = (wxToolBarBase *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::ToolBarBase" )
;
	bool	RETVAL;

	RETVAL = THIS->DeleteTool(toolId);
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__ToolBarBase_DeleteToolByPos); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ToolBarBase_DeleteToolByPos)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, pos");
    {
	size_t    pos = (size_t)SvUV( ST(1) )
;
	wxToolBarBase *    THIS = (wxToolBarBase *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::ToolBarBase" )
;
	bool	RETVAL;

	RETVAL = THIS->DeleteToolByPos(pos);
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__ToolBarBase_EnableTool); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ToolBarBase_EnableTool)
{
    dVAR; dXSARGS;
    if (items != 3)
       croak_xs_usage(cv,  "THIS, toolId, enable");
    {
	int	toolId = (int)SvIV(ST(1))
;
	bool	enable = (bool)SvTRUE(ST(2))
;
	wxToolBarBase *    THIS = (wxToolBarBase *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::ToolBarBase" )
;

	THIS->EnableTool(toolId, enable);
    }
    XSRETURN_EMPTY;
}

#if WXPERL_W_VERSION_GE( 2, 5, 1 )
#define XSubPPtmpAAAM 1


XS_EUPXS(XS_Wx__ToolBarBase_FindById); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ToolBarBase_FindById)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, toolid");
    {
	int	toolid = (int)SvIV(ST(1))
;
	wxToolBarBase *    THIS = (wxToolBarBase *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::ToolBarBase" )
;
	wxToolBarToolBase *	RETVAL;

	RETVAL = THIS->FindById(toolid);
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_non_object_2_sv( aTHX_ RETVALSV, RETVAL, "Wx::ToolBarToolBase" );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}

#endif

XS_EUPXS(XS_Wx__ToolBarBase_FindControl); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ToolBarBase_FindControl)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, toolid");
    {
	int	toolid = (int)SvIV(ST(1))
;
	wxToolBarBase *    THIS = (wxToolBarBase *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::ToolBarBase" )
;
	wxControl *	RETVAL;

	RETVAL = THIS->FindControl(toolid);
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_object_2_sv( aTHX_ RETVALSV, RETVAL );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__ToolBarBase_FindToolForPosition); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ToolBarBase_FindToolForPosition)
{
    dVAR; dXSARGS;
    if (items != 3)
       croak_xs_usage(cv,  "THIS, x, y");
    {
	int	x = (int)SvIV(ST(1))
;
	int	y = (int)SvIV(ST(2))
;
	wxToolBarBase *    THIS = (wxToolBarBase *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::ToolBarBase" )
;
	wxToolBarToolBase *	RETVAL;

	RETVAL = THIS->FindToolForPosition(x, y);
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_non_object_2_sv( aTHX_ RETVALSV, RETVAL, "Wx::ToolBarToolBase" );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__ToolBarBase_GetMargins); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ToolBarBase_GetMargins)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxToolBarBase *    THIS = (wxToolBarBase *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::ToolBarBase" )
;
	wxSize *	RETVAL;
    RETVAL = new wxSize( THIS->GetMargins() );
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_non_object_2_sv( aTHX_ RETVALSV, RETVAL, "Wx::Size" );
    wxPli_thread_sv_register( aTHX_ "Wx::Size", RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__ToolBarBase_GetMaxRows); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ToolBarBase_GetMaxRows)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxToolBarBase *    THIS = (wxToolBarBase *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::ToolBarBase" )
;
	int	RETVAL;
	dXSTARG;

	RETVAL = THIS->GetMaxRows();
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__ToolBarBase_GetMaxCols); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ToolBarBase_GetMaxCols)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxToolBarBase *    THIS = (wxToolBarBase *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::ToolBarBase" )
;
	int	RETVAL;
	dXSTARG;

	RETVAL = THIS->GetMaxCols();
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__ToolBarBase_GetToolSize); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ToolBarBase_GetToolSize)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxToolBarBase *    THIS = (wxToolBarBase *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::ToolBarBase" )
;
	wxSize *	RETVAL;
    RETVAL = new wxSize( THIS->GetToolSize() );
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_non_object_2_sv( aTHX_ RETVALSV, RETVAL, "Wx::Size" );
    wxPli_thread_sv_register( aTHX_ "Wx::Size", RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__ToolBarBase_GetToolBitmapSize); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ToolBarBase_GetToolBitmapSize)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxToolBarBase *    THIS = (wxToolBarBase *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::ToolBarBase" )
;
	wxSize *	RETVAL;
    RETVAL = new wxSize( THIS->GetToolBitmapSize() );
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_non_object_2_sv( aTHX_ RETVALSV, RETVAL, "Wx::Size" );
    wxPli_thread_sv_register( aTHX_ "Wx::Size", RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__ToolBarBase_GetToolClientData); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ToolBarBase_GetToolClientData)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, toolId");
    {
	int	toolId = (int)SvIV(ST(1))
;
	wxToolBar *    THIS = (wxToolBar *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::ToolBar" )
;
	Wx_UserDataO *	RETVAL;
    RETVAL = (Wx_UserDataO*) THIS->GetToolClientData( toolId );
	{
	    SV * RETVALSV;
    RETVALSV = ( RETVAL == 0 ) ? &PL_sv_undef : RETVAL->GetData();
    SvREFCNT_inc( RETVALSV ); // xsubpp mortalizes it...
	    RETVALSV = sv_2mortal(RETVALSV);
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__ToolBarBase_GetToolEnabled); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ToolBarBase_GetToolEnabled)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, toolId");
    {
	int	toolId = (int)SvIV(ST(1))
;
	wxToolBarBase *    THIS = (wxToolBarBase *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::ToolBarBase" )
;
	bool	RETVAL;

	RETVAL = THIS->GetToolEnabled(toolId);
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__ToolBarBase_GetToolLongHelp); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ToolBarBase_GetToolLongHelp)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, toolId");
    {
	int	toolId = (int)SvIV(ST(1))
;
	wxToolBarBase *    THIS = (wxToolBarBase *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::ToolBarBase" )
;
	wxString	RETVAL;

	RETVAL = THIS->GetToolLongHelp(toolId);
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    WXSTRING_OUTPUT( RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__ToolBarBase_GetToolPacking); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ToolBarBase_GetToolPacking)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxToolBarBase *    THIS = (wxToolBarBase *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::ToolBarBase" )
;
	int	RETVAL;
	dXSTARG;

	RETVAL = THIS->GetToolPacking();
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__ToolBarBase_GetToolSeparation); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ToolBarBase_GetToolSeparation)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxToolBarBase *    THIS = (wxToolBarBase *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::ToolBarBase" )
;
	int	RETVAL;
	dXSTARG;

	RETVAL = THIS->GetToolSeparation();
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__ToolBarBase_GetToolShortHelp); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ToolBarBase_GetToolShortHelp)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, toolId");
    {
	int	toolId = (int)SvIV(ST(1))
;
	wxToolBarBase *    THIS = (wxToolBarBase *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::ToolBarBase" )
;
	wxString	RETVAL;

	RETVAL = THIS->GetToolShortHelp(toolId);
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    WXSTRING_OUTPUT( RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__ToolBarBase_GetToolState); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ToolBarBase_GetToolState)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, toolId");
    {
	int	toolId = (int)SvIV(ST(1))
;
	wxToolBarBase *    THIS = (wxToolBarBase *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::ToolBarBase" )
;
	bool	RETVAL;

	RETVAL = THIS->GetToolState(toolId);
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__ToolBarBase_InsertControl); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ToolBarBase_InsertControl)
{
    dVAR; dXSARGS;
    if (items != 3)
       croak_xs_usage(cv,  "THIS, pos, control");
    {
	size_t    pos = (size_t)SvUV( ST(1) )
;
	wxControl*    control = (wxControl *) wxPli_sv_2_object( aTHX_ ST(2), "Wx::Control" )
;
	wxToolBarBase *    THIS = (wxToolBarBase *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::ToolBarBase" )
;
	wxToolBarToolBase *	RETVAL;

	RETVAL = THIS->InsertControl(pos, control);
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_non_object_2_sv( aTHX_ RETVALSV, RETVAL, "Wx::ToolBarToolBase" );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__ToolBarBase_InsertSeparator); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ToolBarBase_InsertSeparator)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, pos");
    {
	size_t    pos = (size_t)SvUV( ST(1) )
;
	wxToolBarBase *    THIS = (wxToolBarBase *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::ToolBarBase" )
;
	wxToolBarToolBase *	RETVAL;

	RETVAL = THIS->InsertSeparator(pos);
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_non_object_2_sv( aTHX_ RETVALSV, RETVAL, "Wx::ToolBarToolBase" );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__ToolBarBase_InsertTool); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ToolBarBase_InsertTool)
{
    dVAR; dXSARGS;
    if (items < 1)
       croak_xs_usage(cv,  "THIS, ...");
    PERL_UNUSED_VAR(ax); /* -Wall */
    SP -= items;
    {
	wxToolBarBase *    THIS = (wxToolBarBase *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::ToolBarBase" )
;
    BEGIN_OVERLOAD()
        MATCH_REDISP_COUNT_ALLOWMORE( wxPliOvl_n_n_wbmp_wbmp_b_s_s_s,
                                      InsertToolLong, 3 )
        MATCH_REDISP_COUNT_ALLOWMORE( wxPliOvl_n_n_s_wbmp_wbmp_b_s_s_s,
                                      InsertToolNewLong, 4 )
    END_OVERLOAD( Wx::ToolBarBase::InsertTool )
	PUTBACK;
	return;
    }
}


XS_EUPXS(XS_Wx__ToolBarBase_InsertToolLong); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ToolBarBase_InsertToolLong)
{
    dVAR; dXSARGS;
    if (items < 4 || items > 9)
       croak_xs_usage(cv,  "THIS, pos, toolId, bitmap1, bitmap2 = (wxBitmap*)&wxNullBitmap, isToggle = false, clientData = 0, shortHelp = wxEmptyString, longHelp = wxEmptyString");
    {
	size_t    pos = (size_t)SvUV( ST(1) )
;
	int	toolId = (int)SvIV(ST(2))
;
	wxBitmap*    bitmap1 = (wxBitmap *) wxPli_sv_2_object( aTHX_ ST(3), "Wx::Bitmap" )
;
	wxBitmap*	bitmap2;
	bool	isToggle;
	Wx_UserDataO*	clientData;
	wxString	shortHelp;
	wxString	longHelp;
	wxToolBarBase *    THIS = (wxToolBarBase *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::ToolBarBase" )
;
	wxToolBarToolBase *	RETVAL;

	if (items < 5)
	    bitmap2 = (wxBitmap*)&wxNullBitmap;
	else {
    bitmap2 = (wxBitmap *) wxPli_sv_2_object( aTHX_ ST(4), "Wx::Bitmap" )
;
	}

	if (items < 6)
	    isToggle = false;
	else {
	    isToggle = (bool)SvTRUE(ST(5))
;
	}

	if (items < 7)
	    clientData = 0;
	else {
    if( SvOK( ST(6) ) )
    {
	clientData = new wxPliUserDataO( ST(6) );
    }
    else
	clientData = 0
;
	}

	if (items < 8)
	    shortHelp = wxEmptyString;
	else {
    WXSTRING_INPUT( shortHelp, wxString, ST(7) )
;
	}

	if (items < 9)
	    longHelp = wxEmptyString;
	else {
    WXSTRING_INPUT( longHelp, wxString, ST(8) )
;
	}
#if WXPERL_W_VERSION_GE( 2, 9, 0 )
    RETVAL = THIS->InsertTool( pos, toolId, wxEmptyString, *bitmap1, *bitmap2,
                               isToggle ? wxITEM_CHECK : wxITEM_NORMAL,
                               shortHelp, longHelp );
    if( clientData )
        THIS->SetClientData( clientData );
#else
    RETVAL = THIS->InsertTool( pos, toolId, *bitmap1, *bitmap2, isToggle,
        0, shortHelp, longHelp );
    if( clientData )
        THIS->SetClientData( clientData );
#endif
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_non_object_2_sv( aTHX_ RETVALSV, RETVAL, "Wx::ToolBarToolBase" );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}

#if WXPERL_W_VERSION_GE( 2, 5, 3 )
#define XSubPPtmpAAAN 1


XS_EUPXS(XS_Wx__ToolBarBase_InsertToolNewLong); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ToolBarBase_InsertToolNewLong)
{
    dVAR; dXSARGS;
    if (items < 5 || items > 10)
       croak_xs_usage(cv,  "THIS, pos, toolId, label, bitmap1, bitmap2 = (wxBitmap*)&wxNullBitmap, kind = wxITEM_NORMAL, shortHelp = wxEmptyString, longHelp = wxEmptyString, clientData = 0");
    {
	size_t    pos = (size_t)SvUV( ST(1) )
;
	int	toolId = (int)SvIV(ST(2))
;
	wxString	label;
	wxBitmap*    bitmap1 = (wxBitmap *) wxPli_sv_2_object( aTHX_ ST(4), "Wx::Bitmap" )
;
	wxBitmap*	bitmap2;
	wxItemKind	kind;
	Wx_UserDataO*	clientData;
	wxString	shortHelp;
	wxString	longHelp;
	wxToolBarBase *    THIS = (wxToolBarBase *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::ToolBarBase" )
;
	wxToolBarToolBase *	RETVAL;

    WXSTRING_INPUT( label, wxString, ST(3) )
;

	if (items < 6)
	    bitmap2 = (wxBitmap*)&wxNullBitmap;
	else {
    bitmap2 = (wxBitmap *) wxPli_sv_2_object( aTHX_ ST(5), "Wx::Bitmap" )
;
	}

	if (items < 7)
	    kind = wxITEM_NORMAL;
	else {
	    kind = (wxItemKind)SvIV(ST(6))
;
	}

	if (items < 10)
	    clientData = 0;
	else {
    if( SvOK( ST(9) ) )
    {
	clientData = new wxPliUserDataO( ST(9) );
    }
    else
	clientData = 0
;
	}

	if (items < 8)
	    shortHelp = wxEmptyString;
	else {
    WXSTRING_INPUT( shortHelp, wxString, ST(7) )
;
	}

	if (items < 9)
	    longHelp = wxEmptyString;
	else {
    WXSTRING_INPUT( longHelp, wxString, ST(8) )
;
	}
    RETVAL = THIS->InsertTool( pos, toolId, label, *bitmap1,
        *bitmap2, kind, shortHelp, longHelp, 0 );
    if( clientData )
        THIS->SetClientData( clientData );
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_non_object_2_sv( aTHX_ RETVALSV, RETVAL, "Wx::ToolBarToolBase" );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}

#endif

XS_EUPXS(XS_Wx__ToolBarBase_ClearTools); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ToolBarBase_ClearTools)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxToolBarBase *    THIS = (wxToolBarBase *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::ToolBarBase" )
;

	THIS->ClearTools();
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__ToolBarBase_GetToolsCount); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ToolBarBase_GetToolsCount)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxToolBarBase *    THIS = (wxToolBarBase *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::ToolBarBase" )
;
	int	RETVAL;
	dXSTARG;

	RETVAL = THIS->GetToolsCount();
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__ToolBarBase_GetToolPos); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ToolBarBase_GetToolPos)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, toolId");
    {
	int	toolId = (int)SvIV(ST(1))
;
	wxToolBarBase *    THIS = (wxToolBarBase *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::ToolBarBase" )
;
	int	RETVAL;
	dXSTARG;

	RETVAL = THIS->GetToolPos(toolId);
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__ToolBarBase_Realize); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ToolBarBase_Realize)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxToolBarBase *    THIS = (wxToolBarBase *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::ToolBarBase" )
;
	bool	RETVAL;

	RETVAL = THIS->Realize();
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__ToolBarBase_RemoveTool); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ToolBarBase_RemoveTool)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, id");
    {
	int	id = (int)SvIV(ST(1))
;
	wxToolBarBase *    THIS = (wxToolBarBase *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::ToolBarBase" )
;
	wxToolBarToolBase *	RETVAL;

	RETVAL = THIS->RemoveTool(id);
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_non_object_2_sv( aTHX_ RETVALSV, RETVAL, "Wx::ToolBarToolBase" );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__ToolBarBase_SetMarginsSize); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ToolBarBase_SetMarginsSize)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, size");
    {
	wxSize    size = wxPli_sv_2_wxsize( aTHX_ ST(1) )
;
	wxToolBarBase *    THIS = (wxToolBarBase *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::ToolBarBase" )
;
    THIS->SetMargins( size );
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__ToolBarBase_SetMarginsXY); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ToolBarBase_SetMarginsXY)
{
    dVAR; dXSARGS;
    if (items != 3)
       croak_xs_usage(cv,  "THIS, x, y");
    {
	int	x = (int)SvIV(ST(1))
;
	int	y = (int)SvIV(ST(2))
;
	wxToolBarBase *    THIS = (wxToolBarBase *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::ToolBarBase" )
;
    THIS->SetMargins( x, y );
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__ToolBarBase_SetMargins); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ToolBarBase_SetMargins)
{
    dVAR; dXSARGS;
    if (items < 1)
       croak_xs_usage(cv,  "THIS, ...");
    PERL_UNUSED_VAR(ax); /* -Wall */
    SP -= items;
    {
	wxToolBarBase *    THIS = (wxToolBarBase *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::ToolBarBase" )
;
    BEGIN_OVERLOAD()
        MATCH_REDISP( wxPliOvl_n_n, SetMarginsXY )
        MATCH_REDISP( wxPliOvl_wsiz, SetMarginsSize )
    END_OVERLOAD( Wx::ToolBarBase::SetMargins )
	PUTBACK;
	return;
    }
}


XS_EUPXS(XS_Wx__ToolBarBase_SetMaxRowsCols); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ToolBarBase_SetMaxRowsCols)
{
    dVAR; dXSARGS;
    if (items != 3)
       croak_xs_usage(cv,  "THIS, mRows, mCols");
    {
	int	mRows = (int)SvIV(ST(1))
;
	int	mCols = (int)SvIV(ST(2))
;
	wxToolBarBase *    THIS = (wxToolBarBase *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::ToolBarBase" )
;

	THIS->SetMaxRowsCols(mRows, mCols);
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__ToolBarBase_SetRows); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ToolBarBase_SetRows)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, nRows");
    {
	int	nRows = (int)SvIV(ST(1))
;
	wxToolBarBase *    THIS = (wxToolBarBase *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::ToolBarBase" )
;

	THIS->SetRows(nRows);
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__ToolBarBase_SetToolBitmapSize); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ToolBarBase_SetToolBitmapSize)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, size");
    {
	wxSize    size = wxPli_sv_2_wxsize( aTHX_ ST(1) )
;
	wxToolBarBase *    THIS = (wxToolBarBase *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::ToolBarBase" )
;

	THIS->SetToolBitmapSize(size);
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__ToolBarBase_SetToolClientData); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ToolBarBase_SetToolClientData)
{
    dVAR; dXSARGS;
    if (items != 3)
       croak_xs_usage(cv,  "THIS, id, data");
    {
	int	id = (int)SvIV(ST(1))
;
	Wx_UserDataO*	data;
	wxToolBarBase *    THIS = (wxToolBarBase *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::ToolBarBase" )
;

    if( SvOK( ST(2) ) )
    {
        data = new wxPliUserDataO( ST(2) );
    }
    else
        data = 0
;
    delete THIS->GetToolClientData( id );
    THIS->SetToolClientData( id, data );
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__ToolBarBase_SetToolLongHelp); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ToolBarBase_SetToolLongHelp)
{
    dVAR; dXSARGS;
    if (items != 3)
       croak_xs_usage(cv,  "THIS, toolId, helpString");
    {
	int	toolId = (int)SvIV(ST(1))
;
	wxString	helpString;
	wxToolBarBase *    THIS = (wxToolBarBase *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::ToolBarBase" )
;

    WXSTRING_INPUT( helpString, wxString, ST(2) )
;

	THIS->SetToolLongHelp(toolId, helpString);
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__ToolBarBase_SetToolPacking); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ToolBarBase_SetToolPacking)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, packing");
    {
	int	packing = (int)SvIV(ST(1))
;
	wxToolBarBase *    THIS = (wxToolBarBase *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::ToolBarBase" )
;

	THIS->SetToolPacking(packing);
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__ToolBarBase_SetToolShortHelp); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ToolBarBase_SetToolShortHelp)
{
    dVAR; dXSARGS;
    if (items != 3)
       croak_xs_usage(cv,  "THIS, toolId, helpString");
    {
	int	toolId = (int)SvIV(ST(1))
;
	wxString	helpString;
	wxToolBarBase *    THIS = (wxToolBarBase *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::ToolBarBase" )
;

    WXSTRING_INPUT( helpString, wxString, ST(2) )
;

	THIS->SetToolShortHelp(toolId, helpString);
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__ToolBarBase_SetToolSeparation); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ToolBarBase_SetToolSeparation)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, separation");
    {
	int	separation = (int)SvIV(ST(1))
;
	wxToolBarBase *    THIS = (wxToolBarBase *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::ToolBarBase" )
;

	THIS->SetToolSeparation(separation);
    }
    XSRETURN_EMPTY;
}

#if WXPERL_W_VERSION_GE( 2, 9, 0 )
#define XSubPPtmpAAAO 1


XS_EUPXS(XS_Wx__ToolBarBase_SetToolNormalBitmap); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ToolBarBase_SetToolNormalBitmap)
{
    dVAR; dXSARGS;
    if (items != 3)
       croak_xs_usage(cv,  "THIS, id, bitmap");
    {
	int	id = (int)SvIV(ST(1))
;
	wxBitmap*    bitmap = (wxBitmap *) wxPli_sv_2_object( aTHX_ ST(2), "Wx::Bitmap" )
;
	wxToolBarBase *    THIS = (wxToolBarBase *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::ToolBarBase" )
;

	THIS->SetToolNormalBitmap(id, *bitmap);
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__ToolBarBase_SetToolDisabledBitmap); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ToolBarBase_SetToolDisabledBitmap)
{
    dVAR; dXSARGS;
    if (items != 3)
       croak_xs_usage(cv,  "THIS, id, bitmap");
    {
	int	id = (int)SvIV(ST(1))
;
	wxBitmap*    bitmap = (wxBitmap *) wxPli_sv_2_object( aTHX_ ST(2), "Wx::Bitmap" )
;
	wxToolBarBase *    THIS = (wxToolBarBase *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::ToolBarBase" )
;

	THIS->SetToolDisabledBitmap(id, *bitmap);
    }
    XSRETURN_EMPTY;
}

#endif

XS_EUPXS(XS_Wx__ToolBarBase_ToggleTool); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ToolBarBase_ToggleTool)
{
    dVAR; dXSARGS;
    if (items != 3)
       croak_xs_usage(cv,  "THIS, toolId, toggle");
    {
	int	toolId = (int)SvIV(ST(1))
;
	bool	toggle = (bool)SvTRUE(ST(2))
;
	wxToolBarBase *    THIS = (wxToolBarBase *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::ToolBarBase" )
;

	THIS->ToggleTool(toolId, toggle);
    }
    XSRETURN_EMPTY;
}

#if WXPERL_W_VERSION_GE( 2, 9, 0 )
#define XSubPPtmpAAAP 1


XS_EUPXS(XS_Wx__ToolBarBase_SetDropdownMenu); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ToolBarBase_SetDropdownMenu)
{
    dVAR; dXSARGS;
    if (items != 3)
       croak_xs_usage(cv,  "THIS, toolid, menu");
    {
	int	toolid = (int)SvIV(ST(1))
;
	wxMenu*    menu = (wxMenu *) wxPli_sv_2_object( aTHX_ ST(2), "Wx::Menu" )
;
	wxToolBarBase *    THIS = (wxToolBarBase *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::ToolBarBase" )
;
	bool	RETVAL;

	RETVAL = THIS->SetDropdownMenu(toolid, menu);
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}

#endif

XS_EUPXS(XS_Wx__ToolBar_new); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ToolBar_new)
{
    dVAR; dXSARGS;
    PERL_UNUSED_VAR(cv); /* -W */
    PERL_UNUSED_VAR(items); /* -W */
    PERL_UNUSED_VAR(ax); /* -Wall */
    SP -= items;
    {
    BEGIN_OVERLOAD()
        MATCH_VOIDM_REDISP( newDefault )
        MATCH_ANY_REDISP( newFull )
    END_OVERLOAD( "Wx::ToolBar::new" )
	PUTBACK;
	return;
    }
}


XS_EUPXS(XS_Wx__ToolBar_newDefault); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ToolBar_newDefault)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "CLASS");
    {
	PlClassName    CLASS = wxPli_get_class( aTHX_ ST(0) )
;
	wxToolBar *	RETVAL;
    RETVAL = new wxToolBar();
    wxPli_create_evthandler( aTHX_ RETVAL, CLASS );
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_evthandler_2_sv( aTHX_ RETVALSV, RETVAL );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__ToolBar_newFull); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ToolBar_newFull)
{
    dVAR; dXSARGS;
    if (items < 2 || items > 7)
       croak_xs_usage(cv,  "CLASS, parent, id = wxID_ANY, pos = wxDefaultPosition, size = wxDefaultSize, style = wxTB_HORIZONTAL | wxNO_BORDER, name = wxPanelNameStr");
    {
	PlClassName    CLASS = wxPli_get_class( aTHX_ ST(0) )
;
	wxWindow*    parent = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::Window" )
;
	wxWindowID	id;
	wxPoint	pos;
	wxSize	size;
	long	style;
	wxString	name;
	wxToolBar *	RETVAL;

	if (items < 3)
	    id = wxID_ANY;
	else {
    id = wxPli_get_wxwindowid( aTHX_ ST(2) )
;
	}

	if (items < 4)
	    pos = wxDefaultPosition;
	else {
    pos = wxPli_sv_2_wxpoint( aTHX_ ST(3) )
;
	}

	if (items < 5)
	    size = wxDefaultSize;
	else {
    size = wxPli_sv_2_wxsize( aTHX_ ST(4) )
;
	}

	if (items < 6)
	    style = wxTB_HORIZONTAL | wxNO_BORDER;
	else {
	    style = (long)SvIV(ST(5))
;
	}

	if (items < 7)
	    name = wxPanelNameStr;
	else {
    WXSTRING_INPUT( name, wxString, ST(6) )
;
	}
    RETVAL = new wxToolBar( parent, id, pos, size, style, name );
    wxPli_create_evthandler( aTHX_ RETVAL, CLASS );
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_evthandler_2_sv( aTHX_ RETVALSV, RETVAL );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__ToolBar_Create); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ToolBar_Create)
{
    dVAR; dXSARGS;
    if (items < 2 || items > 7)
       croak_xs_usage(cv,  "THIS, parent, id = wxID_ANY, pos = wxDefaultPosition, size = wxDefaultSize, style = wxTB_HORIZONTAL | wxNO_BORDER, name = wxPanelNameStr");
    {
	wxWindow*    parent = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::Window" )
;
	wxWindowID	id;
	wxPoint	pos;
	wxSize	size;
	long	style;
	wxString	name;
	wxToolBar *    THIS = (wxToolBar *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::ToolBar" )
;
	bool	RETVAL;

	if (items < 3)
	    id = wxID_ANY;
	else {
    id = wxPli_get_wxwindowid( aTHX_ ST(2) )
;
	}

	if (items < 4)
	    pos = wxDefaultPosition;
	else {
    pos = wxPli_sv_2_wxpoint( aTHX_ ST(3) )
;
	}

	if (items < 5)
	    size = wxDefaultSize;
	else {
    size = wxPli_sv_2_wxsize( aTHX_ ST(4) )
;
	}

	if (items < 6)
	    style = wxTB_HORIZONTAL | wxNO_BORDER;
	else {
	    style = (long)SvIV(ST(5))
;
	}

	if (items < 7)
	    name = wxPanelNameStr;
	else {
    WXSTRING_INPUT( name, wxString, ST(6) )
;
	}

	RETVAL = THIS->Create(parent, id, pos, size, style, name);
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


/* INCLUDE: Returning to 'XS/StatusBar.xs' from 'XS/ToolBar.xs' */

#include <wx/statusbr.h>

XS_EUPXS(XS_Wx__StatusBar_new); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StatusBar_new)
{
    dVAR; dXSARGS;
    if (items < 2 || items > 5)
       croak_xs_usage(cv,  "CLASS, parent, id = wxID_ANY, style = 0, name = wxEmptyString");
    {
	wxWindow*    parent = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::Window" )
;
	wxWindowID	id;
	long	style;
	wxString	name;
	char *	CLASS = (char *)SvPV_nolen(ST(0))
;
	wxStatusBar *	RETVAL;

	if (items < 3)
	    id = wxID_ANY;
	else {
    id = wxPli_get_wxwindowid( aTHX_ ST(2) )
;
	}

	if (items < 4)
	    style = 0;
	else {
	    style = (long)SvIV(ST(3))
;
	}

	if (items < 5)
	    name = wxEmptyString;
	else {
    WXSTRING_INPUT( name, wxString, ST(4) )
;
	}
    RETVAL = new wxStatusBar( parent, id, style, name );
    wxPli_create_evthandler( aTHX_ RETVAL, CLASS );
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_evthandler_2_sv( aTHX_ RETVALSV, RETVAL );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__StatusBar_GetFieldRect); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StatusBar_GetFieldRect)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, index");
    {
	int	index = (int)SvIV(ST(1))
;
    wxRect rect;
    bool found;
	wxStatusBar *    THIS = (wxStatusBar *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StatusBar" )
;
	wxRect *	RETVAL;
    found = THIS->GetFieldRect( index, rect );
    if( !found )
        RETVAL = 0;
    else
        RETVAL = new wxRect( rect );
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_non_object_2_sv( aTHX_ RETVALSV, RETVAL, "Wx::Rect" );
    wxPli_thread_sv_register( aTHX_ "Wx::Rect", RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__StatusBar_GetFieldsCount); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StatusBar_GetFieldsCount)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxStatusBar *    THIS = (wxStatusBar *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StatusBar" )
;
	int	RETVAL;
	dXSTARG;

	RETVAL = THIS->GetFieldsCount();
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__StatusBar_GetStatusText); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StatusBar_GetStatusText)
{
    dVAR; dXSARGS;
    if (items < 1 || items > 2)
       croak_xs_usage(cv,  "THIS, ir = 0");
    {
	int	ir;
	wxStatusBar *    THIS = (wxStatusBar *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StatusBar" )
;
	wxString	RETVAL;

	if (items < 2)
	    ir = 0;
	else {
	    ir = (int)SvIV(ST(1))
;
	}

	RETVAL = THIS->GetStatusText(ir);
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    WXSTRING_OUTPUT( RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__StatusBar_PushStatusText); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StatusBar_PushStatusText)
{
    dVAR; dXSARGS;
    if (items < 2 || items > 3)
       croak_xs_usage(cv,  "THIS, string, n = 0");
    {
	wxString	string;
	int	n;
	wxStatusBar *    THIS = (wxStatusBar *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StatusBar" )
;

    WXSTRING_INPUT( string, wxString, ST(1) )
;

	if (items < 3)
	    n = 0;
	else {
	    n = (int)SvIV(ST(2))
;
	}

	THIS->PushStatusText(string, n);
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__StatusBar_PopStatusText); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StatusBar_PopStatusText)
{
    dVAR; dXSARGS;
    if (items < 1 || items > 2)
       croak_xs_usage(cv,  "THIS, n = 0");
    {
	int	n;
	wxStatusBar *    THIS = (wxStatusBar *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StatusBar" )
;

	if (items < 2)
	    n = 0;
	else {
	    n = (int)SvIV(ST(1))
;
	}

	THIS->PopStatusText(n);
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__StatusBar_SetFieldsCount); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StatusBar_SetFieldsCount)
{
    dVAR; dXSARGS;
    if (items < 1 || items > 2)
       croak_xs_usage(cv,  "THIS, number = 1");
    {
	int	number;
	wxStatusBar *    THIS = (wxStatusBar *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StatusBar" )
;

	if (items < 2)
	    number = 1;
	else {
	    number = (int)SvIV(ST(1))
;
	}

	THIS->SetFieldsCount(number);
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__StatusBar_SetMinHeight); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StatusBar_SetMinHeight)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, height");
    {
	int	height = (int)SvIV(ST(1))
;
	wxStatusBar *    THIS = (wxStatusBar *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StatusBar" )
;

	THIS->SetMinHeight(height);
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__StatusBar_SetStatusText); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StatusBar_SetStatusText)
{
    dVAR; dXSARGS;
    if (items < 2 || items > 3)
       croak_xs_usage(cv,  "THIS, text, i = 0");
    {
	wxString	text;
	int	i;
	wxStatusBar *    THIS = (wxStatusBar *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StatusBar" )
;

    WXSTRING_INPUT( text, wxString, ST(1) )
;

	if (items < 3)
	    i = 0;
	else {
	    i = (int)SvIV(ST(2))
;
	}

	THIS->SetStatusText(text, i);
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__StatusBar_SetStatusWidths); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StatusBar_SetStatusWidths)
{
    dVAR; dXSARGS;
    if (items < 1)
       croak_xs_usage(cv,  "THIS, ...");
    {
    int* widths;
    int i;
	wxStatusBar *    THIS = (wxStatusBar *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StatusBar" )
;
    widths = new int[items-1];
    for( i = 1; i < items; ++i )
    {
      widths[i-1] = SvIV( ST(i) );
    }
    THIS->SetStatusWidths( items-1, widths );

    delete[] widths;
    }
    XSRETURN_EMPTY;
}

#if WXPERL_W_VERSION_GE( 2, 5, 3 )
#define XSubPPtmpAAAQ 1


XS_EUPXS(XS_Wx__StatusBar_SetStatusStyles); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StatusBar_SetStatusStyles)
{
    dVAR; dXSARGS;
    if (items < 1)
       croak_xs_usage(cv,  "THIS, ...");
    {
    int* styles;
    int i;
	wxStatusBar *    THIS = (wxStatusBar *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StatusBar" )
;
    styles = new int[items-1];
    for( i = 1; i < items; ++i )
    {
      styles[i-1] = SvIV( ST(i) );
    }
    THIS->SetStatusStyles( items-1, styles );

    delete[] styles;
    }
    XSRETURN_EMPTY;
}

#endif

/* INCLUDE: Returning to 'XS/Frame.xs' from 'XS/StatusBar.xs' */

#include <wx/frame.h>
#include <wx/menu.h>
#include <wx/icon.h>
#if wxPERL_USE_MINIFRAME
#include <wx/minifram.h>
#endif
#include "cpp/frame.h"

XS_EUPXS(XS_Wx__Frame_new); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Frame_new)
{
    dVAR; dXSARGS;
    PERL_UNUSED_VAR(cv); /* -W */
    PERL_UNUSED_VAR(items); /* -W */
    PERL_UNUSED_VAR(ax); /* -Wall */
    SP -= items;
    {
    BEGIN_OVERLOAD()
        MATCH_VOIDM_REDISP( newDefault )
        MATCH_ANY_REDISP( newFull )
    END_OVERLOAD( "Wx::Frame::new" )
	PUTBACK;
	return;
    }
}


XS_EUPXS(XS_Wx__Frame_newDefault); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Frame_newDefault)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "CLASS");
    {
	char*	CLASS = (char *)SvPV_nolen(ST(0))
;
	wxFrame *	RETVAL;
    RETVAL = new wxPliFrame( CLASS );
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_object_2_sv( aTHX_ RETVALSV, RETVAL );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__Frame_newFull); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Frame_newFull)
{
    dVAR; dXSARGS;
    if (items < 4 || items > 8)
       croak_xs_usage(cv,  "CLASS, parent, id, title, pos = wxDefaultPosition, size = wxDefaultSize, style = wxDEFAULT_FRAME_STYLE, name = wxFrameNameStr");
    {
	char*	CLASS = (char *)SvPV_nolen(ST(0))
;
	wxWindow*    parent = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::Window" )
;
	wxWindowID    id = wxPli_get_wxwindowid( aTHX_ ST(2) )
;
	wxString	title;
	wxPoint	pos;
	wxSize	size;
	long	style;
	wxString	name;
	wxFrame *	RETVAL;

    WXSTRING_INPUT( title, wxString, ST(3) )
;

	if (items < 5)
	    pos = wxDefaultPosition;
	else {
    pos = wxPli_sv_2_wxpoint( aTHX_ ST(4) )
;
	}

	if (items < 6)
	    size = wxDefaultSize;
	else {
    size = wxPli_sv_2_wxsize( aTHX_ ST(5) )
;
	}

	if (items < 7)
	    style = wxDEFAULT_FRAME_STYLE;
	else {
	    style = (long)SvIV(ST(6))
;
	}

	if (items < 8)
	    name = wxFrameNameStr;
	else {
    WXSTRING_INPUT( name, wxString, ST(7) )
;
	}
    RETVAL = new wxPliFrame( CLASS , parent, id, title, pos,
         size, style, name );
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_object_2_sv( aTHX_ RETVALSV, RETVAL );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__Frame_Create); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Frame_Create)
{
    dVAR; dXSARGS;
    if (items < 4 || items > 8)
       croak_xs_usage(cv,  "THIS, parent, id, title, pos = wxDefaultPosition, size = wxDefaultSize, style = wxDEFAULT_FRAME_STYLE, name = wxFrameNameStr");
    {
	wxWindow*    parent = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::Window" )
;
	wxWindowID    id = wxPli_get_wxwindowid( aTHX_ ST(2) )
;
	wxString	title;
	wxPoint	pos;
	wxSize	size;
	long	style;
	wxString	name;
	wxFrame *    THIS = (wxFrame *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Frame" )
;
	bool	RETVAL;

    WXSTRING_INPUT( title, wxString, ST(3) )
;

	if (items < 5)
	    pos = wxDefaultPosition;
	else {
    pos = wxPli_sv_2_wxpoint( aTHX_ ST(4) )
;
	}

	if (items < 6)
	    size = wxDefaultSize;
	else {
    size = wxPli_sv_2_wxsize( aTHX_ ST(5) )
;
	}

	if (items < 7)
	    style = wxDEFAULT_FRAME_STYLE;
	else {
	    style = (long)SvIV(ST(6))
;
	}

	if (items < 8)
	    name = wxFrameNameStr;
	else {
    WXSTRING_INPUT( name, wxString, ST(7) )
;
	}

	RETVAL = THIS->Create(parent, id, title, pos, size, style, name);
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}

#if WXPERL_W_VERSION_GE( 2, 8, 12 )
#define XSubPPtmpAAAR 1


XS_EUPXS(XS_Wx__Frame_ProcessCommand); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Frame_ProcessCommand)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, id");
    {
	int	id = (int)SvIV(ST(1))
;
	wxFrame *    THIS = (wxFrame *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Frame" )
;

	THIS->ProcessCommand(id);
    }
    XSRETURN_EMPTY;
}

#endif

XS_EUPXS(XS_Wx__Frame_CreateStatusBar); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Frame_CreateStatusBar)
{
    dVAR; dXSARGS;
    if (items < 1 || items > 5)
       croak_xs_usage(cv,  "THIS, number = 1, style = 0, id = wxID_ANY, name = wxEmptyString");
    {
	int	number;
	long	style;
	wxWindowID	id;
	wxString	name;
	wxFrame *    THIS = (wxFrame *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Frame" )
;
	wxStatusBar *	RETVAL;

	if (items < 2)
	    number = 1;
	else {
	    number = (int)SvIV(ST(1))
;
	}

	if (items < 3)
	    style = 0;
	else {
	    style = (long)SvIV(ST(2))
;
	}

	if (items < 4)
	    id = wxID_ANY;
	else {
    id = wxPli_get_wxwindowid( aTHX_ ST(3) )
;
	}

	if (items < 5)
	    name = wxEmptyString;
	else {
    WXSTRING_INPUT( name, wxString, ST(4) )
;
	}

	RETVAL = THIS->CreateStatusBar(number, style, id, name);
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_evthandler_2_sv( aTHX_ RETVALSV, RETVAL );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__Frame_CreateToolBar); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Frame_CreateToolBar)
{
    dVAR; dXSARGS;
    if (items < 1 || items > 4)
       croak_xs_usage(cv,  "THIS, style = wxNO_BORDER | wxTB_HORIZONTAL, id = wxID_ANY, name = wxToolBarNameStr");
    {
	long	style;
	wxWindowID	id;
	wxString	name;
	wxFrame *    THIS = (wxFrame *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Frame" )
;
	wxToolBar *	RETVAL;

	if (items < 2)
	    style = wxNO_BORDER | wxTB_HORIZONTAL;
	else {
	    style = (long)SvIV(ST(1))
;
	}

	if (items < 3)
	    id = wxID_ANY;
	else {
    id = wxPli_get_wxwindowid( aTHX_ ST(2) )
;
	}

	if (items < 4)
	    name = wxToolBarNameStr;
	else {
    WXSTRING_INPUT( name, wxString, ST(3) )
;
	}

	RETVAL = THIS->CreateToolBar(style, id, name);
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_evthandler_2_sv( aTHX_ RETVALSV, RETVAL );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__Frame_GetClientAreaOrigin); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Frame_GetClientAreaOrigin)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxFrame *    THIS = (wxFrame *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Frame" )
;
	wxPoint *	RETVAL;
    RETVAL = new wxPoint( THIS->GetClientAreaOrigin() );
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_non_object_2_sv( aTHX_ RETVALSV, RETVAL, "Wx::Point" );
    wxPli_thread_sv_register( aTHX_ "Wx::Point", RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__Frame_GetMenuBar); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Frame_GetMenuBar)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxFrame *    THIS = (wxFrame *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Frame" )
;
	wxMenuBar *	RETVAL;

	RETVAL = THIS->GetMenuBar();
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_object_2_sv( aTHX_ RETVALSV, RETVAL );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__Frame_GetStatusBar); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Frame_GetStatusBar)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxFrame *    THIS = (wxFrame *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Frame" )
;
	wxStatusBar *	RETVAL;

	RETVAL = THIS->GetStatusBar();
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_evthandler_2_sv( aTHX_ RETVALSV, RETVAL );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__Frame_GetStatusBarPane); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Frame_GetStatusBarPane)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxFrame *    THIS = (wxFrame *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Frame" )
;
	int	RETVAL;
	dXSTARG;

	RETVAL = THIS->GetStatusBarPane();
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__Frame_GetTitle); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Frame_GetTitle)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxFrame *    THIS = (wxFrame *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Frame" )
;
	wxString	RETVAL;

	RETVAL = THIS->GetTitle();
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    WXSTRING_OUTPUT( RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__Frame_GetToolBar); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Frame_GetToolBar)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxFrame *    THIS = (wxFrame *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Frame" )
;
	wxToolBar *	RETVAL;

	RETVAL = THIS->GetToolBar();
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_evthandler_2_sv( aTHX_ RETVALSV, RETVAL );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}

#if defined( __WXMAC__ ) && WXPERL_W_VERSION_GE( 2, 5, 2 ) \
    && WXPERL_W_VERSION_LT( 2, 7, 0 )
#define XSubPPtmpAAAS 1


XS_EUPXS(XS_Wx__Frame_MacSetMetalAppearance); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Frame_MacSetMetalAppearance)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, ismetal");
    {
	bool	ismetal = (bool)SvTRUE(ST(1))
;
	wxFrame *    THIS = (wxFrame *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Frame" )
;

	THIS->MacSetMetalAppearance(ismetal);
    }
    XSRETURN_EMPTY;
}

#endif

XS_EUPXS(XS_Wx__Frame_OnCreateStatusBar); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Frame_OnCreateStatusBar)
{
    dVAR; dXSARGS;
    if (items != 5)
       croak_xs_usage(cv,  "THIS, number, style, id, name");
    {
	int	number = (int)SvIV(ST(1))
;
	long	style = (long)SvIV(ST(2))
;
	wxWindowID    id = wxPli_get_wxwindowid( aTHX_ ST(3) )
;
	wxString	name;
	wxFrame *    THIS = (wxFrame *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Frame" )
;
	wxStatusBar *	RETVAL;

    WXSTRING_INPUT( name, wxString, ST(4) )
;
    RETVAL = THIS->wxFrame::OnCreateStatusBar( number, style, id, name );
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_evthandler_2_sv( aTHX_ RETVALSV, RETVAL );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__Frame_SendSizeEvent); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Frame_SendSizeEvent)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxFrame *    THIS = (wxFrame *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Frame" )
;

	THIS->SendSizeEvent();
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__Frame_SetIcon); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Frame_SetIcon)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, icon");
    {
	wxIcon*    icon = (wxIcon *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::Icon" )
;
	wxFrame *    THIS = (wxFrame *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Frame" )
;
    THIS->SetIcon( *icon );
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__Frame_SetIcons); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Frame_SetIcons)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, icons");
    {
	wxIconBundle*    icons = (wxIconBundle *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::IconBundle" )
;
	wxFrame *    THIS = (wxFrame *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Frame" )
;

	THIS->SetIcons(*icons);
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__Frame_SetMenuBar); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Frame_SetMenuBar)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, menubar");
    {
	wxMenuBar*    menubar = (wxMenuBar *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::MenuBar" )
;
	wxFrame *    THIS = (wxFrame *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Frame" )
;

	THIS->SetMenuBar(menubar);
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__Frame_SetStatusBar); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Frame_SetStatusBar)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, statusBar");
    {
	wxStatusBar*    statusBar = (wxStatusBar *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::StatusBar" )
;
	wxFrame *    THIS = (wxFrame *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Frame" )
;

	THIS->SetStatusBar(statusBar);
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__Frame_SetTitle); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Frame_SetTitle)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, title");
    {
	wxString	title;
	wxFrame *    THIS = (wxFrame *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Frame" )
;

    WXSTRING_INPUT( title, wxString, ST(1) )
;

	THIS->SetTitle(title);
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__Frame_SetToolBar); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Frame_SetToolBar)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, toolbar");
    {
	wxToolBar*    toolbar = (wxToolBar *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::ToolBar" )
;
	wxFrame *    THIS = (wxFrame *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Frame" )
;

	THIS->SetToolBar(toolbar);
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__Frame_SetStatusText); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Frame_SetStatusText)
{
    dVAR; dXSARGS;
    if (items < 2 || items > 3)
       croak_xs_usage(cv,  "THIS, text, number = 0");
    {
	wxString	text;
	int	number;
	wxFrame *    THIS = (wxFrame *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Frame" )
;

    WXSTRING_INPUT( text, wxString, ST(1) )
;

	if (items < 3)
	    number = 0;
	else {
	    number = (int)SvIV(ST(2))
;
	}

	THIS->SetStatusText(text, number);
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__Frame_SetStatusBarPane); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Frame_SetStatusBarPane)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, n");
    {
	int	n = (int)SvIV(ST(1))
;
	wxFrame *    THIS = (wxFrame *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Frame" )
;

	THIS->SetStatusBarPane(n);
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__Frame_SetStatusWidths); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Frame_SetStatusWidths)
{
    dVAR; dXSARGS;
    if (items < 1)
       croak_xs_usage(cv,  "THIS, ...");
    {
    int* w;
    int i;
	wxFrame *    THIS = (wxFrame *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Frame" )
;
    w = new int[items - 1];
    for( i = 0; i < items - 1; ++i )
    {
      w[i] = SvIV( ST( i + 1 ) );
    }
    THIS->SetStatusWidths( items - 1, w );
    delete [] w;
    }
    XSRETURN_EMPTY;
}

#if wxPERL_USE_MINIFRAME
#define XSubPPtmpAAAT 1


XS_EUPXS(XS_Wx__MiniFrame_new); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__MiniFrame_new)
{
    dVAR; dXSARGS;
    if (items < 4 || items > 8)
       croak_xs_usage(cv,  "CLASS, parent, id, title, pos = wxDefaultPosition, size = wxDefaultSize, style = wxDEFAULT_FRAME_STYLE, name = wxFrameNameStr");
    {
	wxWindow*    parent = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::Window" )
;
	wxWindowID    id = wxPli_get_wxwindowid( aTHX_ ST(2) )
;
	wxString	title;
	wxPoint	pos;
	wxSize	size;
	long	style;
	wxString	name;
	char *	CLASS = (char *)SvPV_nolen(ST(0))
;
	wxMiniFrame *	RETVAL;

    WXSTRING_INPUT( title, wxString, ST(3) )
;

	if (items < 5)
	    pos = wxDefaultPosition;
	else {
    pos = wxPli_sv_2_wxpoint( aTHX_ ST(4) )
;
	}

	if (items < 6)
	    size = wxDefaultSize;
	else {
    size = wxPli_sv_2_wxsize( aTHX_ ST(5) )
;
	}

	if (items < 7)
	    style = wxDEFAULT_FRAME_STYLE;
	else {
	    style = (long)SvIV(ST(6))
;
	}

	if (items < 8)
	    name = wxFrameNameStr;
	else {
    WXSTRING_INPUT( name, wxString, ST(7) )
;
	}
    RETVAL = new wxMiniFrame( parent, id, title, pos, size, 
        style, name );
    wxPli_create_evthandler( aTHX_ RETVAL, CLASS );
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_object_2_sv( aTHX_ RETVALSV, RETVAL );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}

#endif

/* INCLUDE: Returning to 'Frames.xs' from 'XS/Frame.xs' */


/* INCLUDE_COMMAND:  Including output of '/usr/bin/perl -I./ -MExtUtils::XSpp::Cmd -e xspp -- -t typemap.xsp XS/IconBundle.xsp' from 'Frames.xs' */

#include <exception>

#undef  xsp_constructor_class
#define xsp_constructor_class(c) (c)
#include <wx/icon.h>
#include <wx/iconbndl.h>
#include "cpp/overload.h"
#undef  xsp_constructor_class
#define xsp_constructor_class(c) (CLASS)

XS_EUPXS(XS_Wx__IconBundle_newEmpty); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__IconBundle_newEmpty)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "CLASS");
    {
	char *	CLASS = (char *)SvPV_nolen(ST(0))
;
	wxIconBundle *	RETVAL;
    try {
      RETVAL = new wxIconBundle();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_non_object_2_sv( aTHX_ RETVALSV, RETVAL, "Wx::IconBundle" );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}

#undef  xsp_constructor_class
#define xsp_constructor_class(c) (c)
#undef  xsp_constructor_class
#define xsp_constructor_class(c) (CLASS)

XS_EUPXS(XS_Wx__IconBundle_newFile); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__IconBundle_newFile)
{
    dVAR; dXSARGS;
    if (items < 2 || items > 3)
       croak_xs_usage(cv,  "CLASS, file, type= wxBITMAP_TYPE_ANY");
    {
	char *	CLASS = (char *)SvPV_nolen(ST(0))
;
	wxIconBundle *	RETVAL;
	wxString	file;
	wxBitmapType	type;

    WXSTRING_INPUT( file, wxString, ST(1) )
;

	if (items < 3)
	    type = wxBITMAP_TYPE_ANY;
	else {
	    type = (wxBitmapType)SvIV(ST(2))
;
	}
    try {
      RETVAL = new wxIconBundle( file, type );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_non_object_2_sv( aTHX_ RETVALSV, RETVAL, "Wx::IconBundle" );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}

#undef  xsp_constructor_class
#define xsp_constructor_class(c) (c)
#undef  xsp_constructor_class
#define xsp_constructor_class(c) (CLASS)

XS_EUPXS(XS_Wx__IconBundle_newIcon); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__IconBundle_newIcon)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "CLASS, icon");
    {
	char *	CLASS = (char *)SvPV_nolen(ST(0))
;
	wxIconBundle *	RETVAL;
	wxIcon*    icon = (wxIcon *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::Icon" )
;
    try {
      RETVAL = new wxIconBundle( *( icon ) );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_non_object_2_sv( aTHX_ RETVALSV, RETVAL, "Wx::IconBundle" );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}

#undef  xsp_constructor_class
#define xsp_constructor_class(c) (c)

XS_EUPXS(XS_Wx__IconBundle_AddIconFile); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__IconBundle_AddIconFile)
{
    dVAR; dXSARGS;
    if (items < 2 || items > 3)
       croak_xs_usage(cv,  "THIS, filr, type= wxBITMAP_TYPE_ANY");
    {
	wxIconBundle *    THIS = (wxIconBundle *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::IconBundle" )
;
	wxString	filr;
	wxBitmapType	type;

    WXSTRING_INPUT( filr, wxString, ST(1) )
;

	if (items < 3)
	    type = wxBITMAP_TYPE_ANY;
	else {
	    type = (wxBitmapType)SvIV(ST(2))
;
	}
    try {
      THIS->AddIcon( filr, type );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__IconBundle_AddIconIcon); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__IconBundle_AddIconIcon)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, icon");
    {
	wxIconBundle *    THIS = (wxIconBundle *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::IconBundle" )
;
	wxIcon*    icon = (wxIcon *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::Icon" )
;
    try {
      THIS->AddIcon( *( icon ) );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__IconBundle_GetIconSize); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__IconBundle_GetIconSize)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, size");
    {
	wxIconBundle *    THIS = (wxIconBundle *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::IconBundle" )
;
	wxIcon *	RETVAL;
	wxSize    size = wxPli_sv_2_wxsize( aTHX_ ST(1) )
;
    try {
      RETVAL = new wxIcon( THIS->GetIcon( size ) );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_object_2_sv( aTHX_ RETVALSV, RETVAL );
    wxPli_thread_sv_register( aTHX_ "Wx::Icon", RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__IconBundle_GetIconCoord); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__IconBundle_GetIconCoord)
{
    dVAR; dXSARGS;
    if (items < 1 || items > 2)
       croak_xs_usage(cv,  "THIS, size= -1");
    {
	wxIconBundle *    THIS = (wxIconBundle *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::IconBundle" )
;
	wxIcon *	RETVAL;
	wxCoord	size;

	if (items < 2)
	    size = -1;
	else {
	    size = (wxCoord)SvIV(ST(1))
;
	}
    try {
      RETVAL = new wxIcon( THIS->GetIcon( size ) );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_object_2_sv( aTHX_ RETVALSV, RETVAL );
    wxPli_thread_sv_register( aTHX_ "Wx::Icon", RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}

#if WXPERL_W_VERSION_GE( 2, 9, 0 )
#define XSpp_670eb715_039241
#define XSubPPtmpAAAU 1


XS_EUPXS(XS_Wx__IconBundle_IsEmpty); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__IconBundle_IsEmpty)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxIconBundle *    THIS = (wxIconBundle *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::IconBundle" )
;
	bool	RETVAL;
    try {
      RETVAL = THIS->IsEmpty();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__IconBundle_GetIconOfExactSizeSize); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__IconBundle_GetIconOfExactSizeSize)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, size");
    {
	wxIconBundle *    THIS = (wxIconBundle *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::IconBundle" )
;
	wxIcon *	RETVAL;
	wxSize    size = wxPli_sv_2_wxsize( aTHX_ ST(1) )
;
    try {
      RETVAL = new wxIcon( THIS->GetIconOfExactSize( size ) );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_object_2_sv( aTHX_ RETVALSV, RETVAL );
    wxPli_thread_sv_register( aTHX_ "Wx::Icon", RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__IconBundle_GetIconOfExactSizeCoord); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__IconBundle_GetIconOfExactSizeCoord)
{
    dVAR; dXSARGS;
    if (items < 1 || items > 2)
       croak_xs_usage(cv,  "THIS, size= -1");
    {
	wxIconBundle *    THIS = (wxIconBundle *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::IconBundle" )
;
	wxIcon *	RETVAL;
	wxCoord	size;

	if (items < 2)
	    size = -1;
	else {
	    size = (wxCoord)SvIV(ST(1))
;
	}
    try {
      RETVAL = new wxIcon( THIS->GetIconOfExactSize( size ) );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_object_2_sv( aTHX_ RETVALSV, RETVAL );
    wxPli_thread_sv_register( aTHX_ "Wx::Icon", RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__IconBundle_GetIconOfExactSize); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__IconBundle_GetIconOfExactSize)
{
    dVAR; dXSARGS;
    if (items < 1)
       croak_xs_usage(cv,  "THIS, ...");
    PERL_UNUSED_VAR(ax); /* -Wall */
    SP -= items;
    {
	wxIconBundle *    THIS = (wxIconBundle *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::IconBundle" )
;
    BEGIN_OVERLOAD()
        MATCH_REDISP( wxPliOvl_wsiz, GetIconOfExactSizeSize )
        MATCH_REDISP( wxPliOvl_n, GetIconOfExactSizeCoord )
    END_OVERLOAD( Wx::IconBundle::GetIconOfExactSize )
	PUTBACK;
	return;
    }
}

#endif

XS_EUPXS(XS_Wx__IconBundle_new); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__IconBundle_new)
{
    dVAR; dXSARGS;
    if (items < 1)
       croak_xs_usage(cv,  "CLASS, ...");
    PERL_UNUSED_VAR(ax); /* -Wall */
    SP -= items;
    {
	char *	CLASS = (char *)SvPV_nolen(ST(0))
;
    BEGIN_OVERLOAD()
        MATCH_VOIDM_REDISP( newEmpty )
        MATCH_REDISP( wxPliOvl_wico, newIcon )
        MATCH_REDISP_COUNT_ALLOWMORE( wxPliOvl_s_n, newFile, 1 )
    END_OVERLOAD( Wx::IconBundle::new )
	PUTBACK;
	return;
    }
}


XS_EUPXS(XS_Wx__IconBundle_AddIcon); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__IconBundle_AddIcon)
{
    dVAR; dXSARGS;
    if (items < 1)
       croak_xs_usage(cv,  "THIS, ...");
    PERL_UNUSED_VAR(ax); /* -Wall */
    SP -= items;
    {
	wxIconBundle *    THIS = (wxIconBundle *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::IconBundle" )
;
    BEGIN_OVERLOAD()
        MATCH_REDISP( wxPliOvl_wico, AddIconIcon )
        MATCH_REDISP_COUNT_ALLOWMORE( wxPliOvl_s_n, AddIconFile, 1 )
    END_OVERLOAD( Wx::IconBundle::AddIcon )
	PUTBACK;
	return;
    }
}


XS_EUPXS(XS_Wx__IconBundle_GetIcon); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__IconBundle_GetIcon)
{
    dVAR; dXSARGS;
    if (items < 1)
       croak_xs_usage(cv,  "THIS, ...");
    PERL_UNUSED_VAR(ax); /* -Wall */
    SP -= items;
    {
	wxIconBundle *    THIS = (wxIconBundle *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::IconBundle" )
;
    BEGIN_OVERLOAD()
        MATCH_REDISP( wxPliOvl_wsiz, GetIconSize )
        MATCH_REDISP( wxPliOvl_n, GetIconCoord )
    END_OVERLOAD( Wx::IconBundle::GetIcon )
	PUTBACK;
	return;
    }
}


/* INCLUDE: Returning to 'Frames.xs' from '/usr/bin/perl -I./ -MExtUtils::XSpp::Cmd -e xspp -- -t typemap.xsp XS/IconBundle.xsp' */


/* INCLUDE_COMMAND:  Including output of '/usr/bin/perl -I./ -MExtUtils::XSpp::Cmd -e xspp -- -t typemap.xsp XS/TopLevelWindow.xsp' from 'Frames.xs' */

#include <exception>

#undef  xsp_constructor_class
#define xsp_constructor_class(c) (c)
#if !defined(__WXMOTIF__) || WXPERL_W_VERSION_GE( 2, 5, 1 )
#define XSpp_a57b1b3c_070970
#include <wx/toplevel.h>
#include "cpp/overload.h"
#if WXPERL_W_VERSION_GE( 2, 5, 3 )
#define XSpp_a57b1b3c_069376
#define XSubPPtmpAAAV 1


XS_EUPXS(XS_Wx__TopLevelWindow_RequestUserAttention); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__TopLevelWindow_RequestUserAttention)
{
    dVAR; dXSARGS;
    if (items < 1 || items > 2)
       croak_xs_usage(cv,  "THIS, flags= wxUSER_ATTENTION_INFO");
    {
	wxTopLevelWindow *    THIS = (wxTopLevelWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::TopLevelWindow" )
;
	int	flags;

	if (items < 2)
	    flags = wxUSER_ATTENTION_INFO;
	else {
	    flags = (int)SvIV(ST(1))
;
	}
    try {
      THIS->RequestUserAttention( flags );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}

#endif
#if WXPERL_W_VERSION_GE( 2, 7, 0 )
#define XSpp_a57b1b3c_012199
#define XSubPPtmpAAAW 1


XS_EUPXS(XS_Wx__TopLevelWindow_IsAlwaysMaximized); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__TopLevelWindow_IsAlwaysMaximized)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxTopLevelWindow *    THIS = (wxTopLevelWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::TopLevelWindow" )
;
	bool	RETVAL;
    try {
      RETVAL = THIS->IsAlwaysMaximized();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__TopLevelWindow_GetDefaultItem); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__TopLevelWindow_GetDefaultItem)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxTopLevelWindow *    THIS = (wxTopLevelWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::TopLevelWindow" )
;
	wxWindow *	RETVAL;
    try {
      RETVAL = THIS->GetDefaultItem();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_object_2_sv( aTHX_ RETVALSV, RETVAL );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__TopLevelWindow_SetDefaultItem); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__TopLevelWindow_SetDefaultItem)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, win");
    {
	wxTopLevelWindow *    THIS = (wxTopLevelWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::TopLevelWindow" )
;
	wxWindow *	RETVAL;
	wxWindow*    win = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::Window" )
;
    try {
      RETVAL = THIS->SetDefaultItem( win );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_object_2_sv( aTHX_ RETVALSV, RETVAL );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__TopLevelWindow_GetTmpDefaultItem); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__TopLevelWindow_GetTmpDefaultItem)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxTopLevelWindow *    THIS = (wxTopLevelWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::TopLevelWindow" )
;
	wxWindow *	RETVAL;
    try {
      RETVAL = THIS->GetTmpDefaultItem();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_object_2_sv( aTHX_ RETVALSV, RETVAL );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__TopLevelWindow_SetTmpDefaultItem); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__TopLevelWindow_SetTmpDefaultItem)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, win");
    {
	wxTopLevelWindow *    THIS = (wxTopLevelWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::TopLevelWindow" )
;
	wxWindow *	RETVAL;
	wxWindow*    win = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::Window" )
;
    try {
      RETVAL = THIS->SetTmpDefaultItem( win );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_object_2_sv( aTHX_ RETVALSV, RETVAL );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__TopLevelWindow_SetTransparent); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__TopLevelWindow_SetTransparent)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, alpha");
    {
	wxTopLevelWindow *    THIS = (wxTopLevelWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::TopLevelWindow" )
;
	bool	RETVAL;
	wxByte	alpha = (unsigned char)SvUV(ST(1))
;
    try {
      RETVAL = THIS->SetTransparent( alpha );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__TopLevelWindow_CanSetTransparent); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__TopLevelWindow_CanSetTransparent)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxTopLevelWindow *    THIS = (wxTopLevelWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::TopLevelWindow" )
;
	bool	RETVAL;
    try {
      RETVAL = THIS->CanSetTransparent();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}

#endif
#if WXPERL_W_VERSION_GE( 2, 7, 2 )
#define XSpp_a57b1b3c_017403
#define XSubPPtmpAAAX 1


XS_EUPXS(XS_Wx__TopLevelWindow_EnableCloseButton); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__TopLevelWindow_EnableCloseButton)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, enable");
    {
	wxTopLevelWindow *    THIS = (wxTopLevelWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::TopLevelWindow" )
;
	bool	RETVAL;
	bool	enable = (bool)SvTRUE(ST(1))
;
    try {
      RETVAL = THIS->EnableCloseButton( enable );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}

#endif
#define XSubPPtmpAAAY 1


XS_EUPXS(XS_Wx__TopLevelWindow_GetIcon); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__TopLevelWindow_GetIcon)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxTopLevelWindow *    THIS = (wxTopLevelWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::TopLevelWindow" )
;
	wxIcon *	RETVAL;
    try {
      RETVAL = new wxIcon( THIS->GetIcon() );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_object_2_sv( aTHX_ RETVALSV, RETVAL );
    wxPli_thread_sv_register( aTHX_ "Wx::Icon", RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__TopLevelWindow_GetIcons); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__TopLevelWindow_GetIcons)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxTopLevelWindow *    THIS = (wxTopLevelWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::TopLevelWindow" )
;
	wxIconBundle *	RETVAL;
    try {
      RETVAL = new wxIconBundle( THIS->GetIcons() );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_non_object_2_sv( aTHX_ RETVALSV, RETVAL, "Wx::IconBundle" );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__TopLevelWindow_SetIcon); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__TopLevelWindow_SetIcon)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, icon");
    {
	wxTopLevelWindow *    THIS = (wxTopLevelWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::TopLevelWindow" )
;
	wxIcon*    icon = (wxIcon *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::Icon" )
;
    try {
      THIS->SetIcon( *( icon ) );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__TopLevelWindow_SetIcons); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__TopLevelWindow_SetIcons)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, icons");
    {
	wxTopLevelWindow *    THIS = (wxTopLevelWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::TopLevelWindow" )
;
	wxIconBundle*    icons = (wxIconBundle *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::IconBundle" )
;
    try {
      THIS->SetIcons( *( icons ) );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__TopLevelWindow_Iconize); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__TopLevelWindow_Iconize)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, iconize");
    {
	wxTopLevelWindow *    THIS = (wxTopLevelWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::TopLevelWindow" )
;
	bool	iconize = (bool)SvTRUE(ST(1))
;
    try {
      THIS->Iconize( iconize );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__TopLevelWindow_Maximize); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__TopLevelWindow_Maximize)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, maximize");
    {
	wxTopLevelWindow *    THIS = (wxTopLevelWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::TopLevelWindow" )
;
	bool	maximize = (bool)SvTRUE(ST(1))
;
    try {
      THIS->Maximize( maximize );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__TopLevelWindow_ShowFullScreen); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__TopLevelWindow_ShowFullScreen)
{
    dVAR; dXSARGS;
    if (items < 2 || items > 3)
       croak_xs_usage(cv,  "THIS, show, style= wxFULLSCREEN_ALL");
    {
	wxTopLevelWindow *    THIS = (wxTopLevelWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::TopLevelWindow" )
;
	bool	RETVAL;
	bool	show = (bool)SvTRUE(ST(1))
;
	long	style;

	if (items < 3)
	    style = wxFULLSCREEN_ALL;
	else {
	    style = (long)SvIV(ST(2))
;
	}
    try {
      RETVAL = THIS->ShowFullScreen( show, style );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__TopLevelWindow_IsFullScreen); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__TopLevelWindow_IsFullScreen)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxTopLevelWindow *    THIS = (wxTopLevelWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::TopLevelWindow" )
;
	bool	RETVAL;
    try {
      RETVAL = THIS->IsFullScreen();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__TopLevelWindow_IsActive); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__TopLevelWindow_IsActive)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxTopLevelWindow *    THIS = (wxTopLevelWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::TopLevelWindow" )
;
	bool	RETVAL;
    try {
      RETVAL = THIS->IsActive();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__TopLevelWindow_IsIconized); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__TopLevelWindow_IsIconized)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxTopLevelWindow *    THIS = (wxTopLevelWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::TopLevelWindow" )
;
	bool	RETVAL;
    try {
      RETVAL = THIS->IsIconized();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__TopLevelWindow_IsMaximized); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__TopLevelWindow_IsMaximized)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxTopLevelWindow *    THIS = (wxTopLevelWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::TopLevelWindow" )
;
	bool	RETVAL;
    try {
      RETVAL = THIS->IsMaximized();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}

#ifdef __WXUNIVERSAL__
#define XSpp_a57b1b3c_006829
#define XSubPPtmpAAAZ 1


XS_EUPXS(XS_Wx__TopLevelWindow_IsUsingNativeDecorations); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__TopLevelWindow_IsUsingNativeDecorations)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxTopLevelWindow *    THIS = (wxTopLevelWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::TopLevelWindow" )
;
	bool	RETVAL;
    try {
      RETVAL = THIS->IsUsingNativeDecorations();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}

#endif
#if defined(__WXMSW__) && WXPERL_W_VERSION_GE( 2, 7, 1 )
#define XSpp_a57b1b3c_036345
#define XSubPPtmpAABA 1


XS_EUPXS(XS_Wx__TopLevelWindow_SetLayoutDirection); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__TopLevelWindow_SetLayoutDirection)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, direction");
    {
	wxTopLevelWindow *    THIS = (wxTopLevelWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::TopLevelWindow" )
;
	wxLayoutDirection	direction = (wxLayoutDirection)SvIV(ST(1))
;
    try {
      THIS->SetLayoutDirection( direction );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}

#endif

XS_EUPXS(XS_Wx__TopLevelWindow_SetShape); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__TopLevelWindow_SetShape)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, region");
    {
	wxTopLevelWindow *    THIS = (wxTopLevelWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::TopLevelWindow" )
;
	wxRegion*    region = (wxRegion *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::Region" )
;
    try {
      THIS->SetShape( *( region ) );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}

#if WXPERL_W_VERSION_GE( 2, 7, 2 )
#define XSpp_a57b1b3c_092957
#define XSubPPtmpAABB 1


XS_EUPXS(XS_Wx__TopLevelWindow_ShouldPreventAppExit); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__TopLevelWindow_ShouldPreventAppExit)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxTopLevelWindow *    THIS = (wxTopLevelWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::TopLevelWindow" )
;
	bool	RETVAL;
    try {
      RETVAL = THIS->ShouldPreventAppExit();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}

#endif
#if defined(__WXMSW__) && WXPERL_W_VERSION_GE( 2, 9, 3 )
#define XSpp_a57b1b3c_029944
#define XSubPPtmpAABC 1


XS_EUPXS(XS_Wx__TopLevelWindow_MSWGetSystemMenu); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__TopLevelWindow_MSWGetSystemMenu)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxTopLevelWindow *    THIS = (wxTopLevelWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::TopLevelWindow" )
;
	wxMenu *	RETVAL;
    try {
      RETVAL = THIS->MSWGetSystemMenu();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_object_2_sv( aTHX_ RETVALSV, RETVAL );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}

#endif
#if WXPERL_W_VERSION_GE( 2, 9, 4 )
#define XSpp_a57b1b3c_001847
#define XSubPPtmpAABD 1


XS_EUPXS(XS_Wx__TopLevelWindow_OSXIsModified); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__TopLevelWindow_OSXIsModified)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxTopLevelWindow *    THIS = (wxTopLevelWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::TopLevelWindow" )
;
	bool	RETVAL;
    try {
      RETVAL = THIS->OSXIsModified();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__TopLevelWindow_OSXSetModified); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__TopLevelWindow_OSXSetModified)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, modified");
    {
	wxTopLevelWindow *    THIS = (wxTopLevelWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::TopLevelWindow" )
;
	bool	modified = (bool)SvTRUE(ST(1))
;
    try {
      THIS->OSXSetModified( modified );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__TopLevelWindow_SetRepresentedFilename); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__TopLevelWindow_SetRepresentedFilename)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, filename");
    {
	wxTopLevelWindow *    THIS = (wxTopLevelWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::TopLevelWindow" )
;
	wxString	filename;

    WXSTRING_INPUT( filename, wxString, ST(1) )
;
    try {
      THIS->SetRepresentedFilename( filename );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__TopLevelWindow_SetMinSize); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__TopLevelWindow_SetMinSize)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, minSize");
    {
	wxTopLevelWindow *    THIS = (wxTopLevelWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::TopLevelWindow" )
;
	wxSize    minSize = wxPli_sv_2_wxsize( aTHX_ ST(1) )
;
    try {
      THIS->SetMinSize( minSize );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__TopLevelWindow_SetMaxSize); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__TopLevelWindow_SetMaxSize)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, maxSize");
    {
	wxTopLevelWindow *    THIS = (wxTopLevelWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::TopLevelWindow" )
;
	wxSize    maxSize = wxPli_sv_2_wxsize( aTHX_ ST(1) )
;
    try {
      THIS->SetMaxSize( maxSize );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}

#endif
#ifdef __WXUNIVERSAL__
#define XSpp_a57b1b3c_063301
#define XSubPPtmpAABE 1


XS_EUPXS(XS_Wx__TopLevelWindow_UseNativeDecorations); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__TopLevelWindow_UseNativeDecorations)
{
    dVAR; dXSARGS;
    if (items < 1 || items > 2)
       croak_xs_usage(cv,  "THIS, native= true");
    {
	wxTopLevelWindow *    THIS = (wxTopLevelWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::TopLevelWindow" )
;
	bool	native;

	if (items < 2)
	    native = true;
	else {
	    native = (bool)SvTRUE(ST(1))
;
	}
    try {
      THIS->UseNativeDecorations( native );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__TopLevelWindow_UseNativeDecorationsByDefault); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__TopLevelWindow_UseNativeDecorationsByDefault)
{
    dVAR; dXSARGS;
    if (items < 1 || items > 2)
       croak_xs_usage(cv,  "THIS, native = true");
    {
	bool	native;
	wxTopLevelWindow *    THIS = (wxTopLevelWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::TopLevelWindow" )
;

	if (items < 2)
	    native = true;
	else {
	    native = (bool)SvTRUE(ST(1))
;
	}
    wxTopLevelWindow::UseNativeDecorationsByDefault( native );
    }
    XSRETURN_EMPTY;
}

#endif
#endif

/* INCLUDE: Returning to 'Frames.xs' from '/usr/bin/perl -I./ -MExtUtils::XSpp::Cmd -e xspp -- -t typemap.xsp XS/TopLevelWindow.xsp' */


/* INCLUDE_COMMAND:  Including output of '/usr/bin/perl -I./ -MExtUtils::XSpp::Cmd -e xspp -- -t typemap.xsp XS/PopupWindow.xsp' from 'Frames.xs' */

#include <exception>

#undef  xsp_constructor_class
#define xsp_constructor_class(c) (c)
#if wxUSE_POPUPWIN
#define XSpp_bed891a6_088235
#include "wx/popupwin.h"
#include "xspp/popupwin.h"
#undef  xsp_constructor_class
#define xsp_constructor_class(c) (CLASS)
#define XSubPPtmpAABF 1


XS_EUPXS(XS_Wx__PopupWindow_newDefault); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__PopupWindow_newDefault)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "CLASS");
    {
	char *	CLASS = (char *)SvPV_nolen(ST(0))
;
	wxPopupWindow *	RETVAL;
     RETVAL = new wxPopupWindow();
                wxPli_create_evthandler( aTHX_ RETVAL, CLASS );
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_object_2_sv( aTHX_ RETVALSV, RETVAL );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}

#undef  xsp_constructor_class
#define xsp_constructor_class(c) (c)
#undef  xsp_constructor_class
#define xsp_constructor_class(c) (CLASS)

XS_EUPXS(XS_Wx__PopupWindow_newFull); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__PopupWindow_newFull)
{
    dVAR; dXSARGS;
    if (items < 2 || items > 3)
       croak_xs_usage(cv,  "CLASS, parent, flags= wxBORDER_NONE");
    {
	char *	CLASS = (char *)SvPV_nolen(ST(0))
;
	wxPopupWindow *	RETVAL;
	wxWindow*    parent = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::Window" )
;
	int	flags;

	if (items < 3)
	    flags = wxBORDER_NONE;
	else {
	    flags = (int)SvIV(ST(2))
;
	}
     RETVAL = new wxPopupWindow( parent, flags );
                wxPli_create_evthandler( aTHX_ RETVAL, CLASS );
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_object_2_sv( aTHX_ RETVALSV, RETVAL );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}

#undef  xsp_constructor_class
#define xsp_constructor_class(c) (c)

XS_EUPXS(XS_Wx__PopupWindow_Create); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__PopupWindow_Create)
{
    dVAR; dXSARGS;
    if (items < 2 || items > 3)
       croak_xs_usage(cv,  "THIS, parent, flags= wxBORDER_NONE");
    {
	wxPopupWindow *    THIS = (wxPopupWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::PopupWindow" )
;
	bool	RETVAL;
	wxWindow*    parent = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::Window" )
;
	int	flags;

	if (items < 3)
	    flags = wxBORDER_NONE;
	else {
	    flags = (int)SvIV(ST(2))
;
	}
    try {
      RETVAL = THIS->Create( parent, flags );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__PopupWindow_Position); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__PopupWindow_Position)
{
    dVAR; dXSARGS;
    if (items != 3)
       croak_xs_usage(cv,  "THIS, ptOrigin, size");
    {
	wxPopupWindow *    THIS = (wxPopupWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::PopupWindow" )
;
	wxPoint    ptOrigin = wxPli_sv_2_wxpoint( aTHX_ ST(1) )
;
	wxSize    size = wxPli_sv_2_wxsize( aTHX_ ST(2) )
;
    try {
      THIS->Position( ptOrigin, size );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__PopupWindow_new); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__PopupWindow_new)
{
    dVAR; dXSARGS;
    PERL_UNUSED_VAR(cv); /* -W */
    PERL_UNUSED_VAR(items); /* -W */
    PERL_UNUSED_VAR(ax); /* -Wall */
    SP -= items;
    {
    BEGIN_OVERLOAD()
        MATCH_VOIDM_REDISP( newDefault )
        MATCH_ANY_REDISP( newFull )
    END_OVERLOAD( "Wx::PopupWindow::new" )
	PUTBACK;
	return;
    }
}

#undef  xsp_constructor_class
#define xsp_constructor_class(c) (CLASS)

XS_EUPXS(XS_Wx__PopupTransientWindow_newDefault); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__PopupTransientWindow_newDefault)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "CLASS");
    {
	char *	CLASS = (char *)SvPV_nolen(ST(0))
;
	wxPopupTransientWindow *	RETVAL;
     RETVAL = new wxPopupTransientWindow();
                wxPli_create_evthandler( aTHX_ RETVAL, CLASS );
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_object_2_sv( aTHX_ RETVALSV, RETVAL );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}

#undef  xsp_constructor_class
#define xsp_constructor_class(c) (c)
#undef  xsp_constructor_class
#define xsp_constructor_class(c) (CLASS)

XS_EUPXS(XS_Wx__PopupTransientWindow_newFull); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__PopupTransientWindow_newFull)
{
    dVAR; dXSARGS;
    if (items < 2 || items > 3)
       croak_xs_usage(cv,  "CLASS, parent, flags= wxBORDER_NONE");
    {
	char *	CLASS = (char *)SvPV_nolen(ST(0))
;
	wxPopupTransientWindow *	RETVAL;
	wxWindow*    parent = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::Window" )
;
	int	flags;

	if (items < 3)
	    flags = wxBORDER_NONE;
	else {
	    flags = (int)SvIV(ST(2))
;
	}
     RETVAL = new wxPopupTransientWindow( parent, flags );
                wxPli_create_evthandler( aTHX_ RETVAL, CLASS );
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_object_2_sv( aTHX_ RETVALSV, RETVAL );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}

#undef  xsp_constructor_class
#define xsp_constructor_class(c) (c)

XS_EUPXS(XS_Wx__PopupTransientWindow_Popup); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__PopupTransientWindow_Popup)
{
    dVAR; dXSARGS;
    if (items < 1 || items > 2)
       croak_xs_usage(cv,  "THIS, focus= NULL");
    {
	wxPopupTransientWindow *    THIS = (wxPopupTransientWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::PopupTransientWindow" )
;
	wxWindow*	focus;

	if (items < 2)
	    focus = NULL;
	else {
    focus = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::Window" )
;
	}
    try {
      THIS->Popup( focus );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__PopupTransientWindow_Dismiss); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__PopupTransientWindow_Dismiss)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxPopupTransientWindow *    THIS = (wxPopupTransientWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::PopupTransientWindow" )
;
    try {
      THIS->Dismiss();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__PopupTransientWindow_CanDismiss); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__PopupTransientWindow_CanDismiss)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxPopupTransientWindow *    THIS = (wxPopupTransientWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::PopupTransientWindow" )
;
	bool	RETVAL;
    try {
      RETVAL = THIS->CanDismiss();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__PopupTransientWindow_ProcessLeftDown); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__PopupTransientWindow_ProcessLeftDown)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, event");
    {
	wxPopupTransientWindow *    THIS = (wxPopupTransientWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::PopupTransientWindow" )
;
	bool	RETVAL;
	wxMouseEvent*    event = (wxMouseEvent *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::MouseEvent" )
;
    try {
      RETVAL = THIS->ProcessLeftDown( *( event ) );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__PopupTransientWindow_new); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__PopupTransientWindow_new)
{
    dVAR; dXSARGS;
    PERL_UNUSED_VAR(cv); /* -W */
    PERL_UNUSED_VAR(items); /* -W */
    PERL_UNUSED_VAR(ax); /* -Wall */
    SP -= items;
    {
    BEGIN_OVERLOAD()
        MATCH_VOIDM_REDISP( newDefault )
        MATCH_ANY_REDISP( newFull )
    END_OVERLOAD( "Wx::PopupTransientWindow::new" )
	PUTBACK;
	return;
    }
}

#define Popup wxPopupTransientWindow::Popup
#define Dismiss wxPopupTransientWindow::Dismiss
#define CanDismiss wxPopupTransientWindow::CanDismiss
#define ProcessLeftDown wxPopupTransientWindow::ProcessLeftDown
#undef  xsp_constructor_class
#define xsp_constructor_class(c) (CLASS)

XS_EUPXS(XS_Wx__PlPopupTransientWindow_newDefault); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__PlPopupTransientWindow_newDefault)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "CLASS");
    {
	char *	CLASS = (char *)SvPV_nolen(ST(0))
;
	wxPlPopupTransientWindow *	RETVAL;
     RETVAL = new wxPlPopupTransientWindow( CLASS );
                wxPli_create_evthandler( aTHX_ RETVAL, CLASS );
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_object_2_sv( aTHX_ RETVALSV, RETVAL );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}

#undef  xsp_constructor_class
#define xsp_constructor_class(c) (c)
#undef  xsp_constructor_class
#define xsp_constructor_class(c) (CLASS)

XS_EUPXS(XS_Wx__PlPopupTransientWindow_newFull); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__PlPopupTransientWindow_newFull)
{
    dVAR; dXSARGS;
    if (items < 2 || items > 3)
       croak_xs_usage(cv,  "CLASS, parent, flags= wxBORDER_NONE");
    {
	char *	CLASS = (char *)SvPV_nolen(ST(0))
;
	wxPlPopupTransientWindow *	RETVAL;
	wxWindow*    parent = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::Window" )
;
	int	flags;

	if (items < 3)
	    flags = wxBORDER_NONE;
	else {
	    flags = (int)SvIV(ST(2))
;
	}
     RETVAL = new wxPlPopupTransientWindow( CLASS, parent, flags );
                wxPli_create_evthandler( aTHX_ RETVAL, CLASS );
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_object_2_sv( aTHX_ RETVALSV, RETVAL );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}

#undef  xsp_constructor_class
#define xsp_constructor_class(c) (c)

XS_EUPXS(XS_Wx__PlPopupTransientWindow_Popup); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__PlPopupTransientWindow_Popup)
{
    dVAR; dXSARGS;
    if (items < 1 || items > 2)
       croak_xs_usage(cv,  "THIS, focus= NULL");
    {
	wxPlPopupTransientWindow *    THIS = (wxPlPopupTransientWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::PlPopupTransientWindow" )
;
	wxWindow*	focus;

	if (items < 2)
	    focus = NULL;
	else {
    focus = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::Window" )
;
	}
    try {
      THIS->Popup( focus );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__PlPopupTransientWindow_Dismiss); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__PlPopupTransientWindow_Dismiss)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxPlPopupTransientWindow *    THIS = (wxPlPopupTransientWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::PlPopupTransientWindow" )
;
    try {
      THIS->Dismiss();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__PlPopupTransientWindow_CanDismiss); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__PlPopupTransientWindow_CanDismiss)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxPlPopupTransientWindow *    THIS = (wxPlPopupTransientWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::PlPopupTransientWindow" )
;
	bool	RETVAL;
    try {
      RETVAL = THIS->CanDismiss();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__PlPopupTransientWindow_ProcessLeftDown); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__PlPopupTransientWindow_ProcessLeftDown)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, event");
    {
	wxPlPopupTransientWindow *    THIS = (wxPlPopupTransientWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::PlPopupTransientWindow" )
;
	bool	RETVAL;
	wxMouseEvent*    event = (wxMouseEvent *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::MouseEvent" )
;
    try {
      RETVAL = THIS->ProcessLeftDown( *( event ) );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}

#undef Popup
#undef Dismiss
#undef CanDismiss
#undef ProcessLeftDown

XS_EUPXS(XS_Wx__PlPopupTransientWindow_new); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__PlPopupTransientWindow_new)
{
    dVAR; dXSARGS;
    PERL_UNUSED_VAR(cv); /* -W */
    PERL_UNUSED_VAR(items); /* -W */
    PERL_UNUSED_VAR(ax); /* -Wall */
    SP -= items;
    {
    BEGIN_OVERLOAD()
        MATCH_VOIDM_REDISP( newDefault )
        MATCH_ANY_REDISP( newFull )
    END_OVERLOAD( "Wx::PlPopupTransientWindow::new" )
	PUTBACK;
	return;
    }
}

#endif // wxUSE_POPUPWIN

/* INCLUDE: Returning to 'Frames.xs' from '/usr/bin/perl -I./ -MExtUtils::XSpp::Cmd -e xspp -- -t typemap.xsp XS/PopupWindow.xsp' */


/* INCLUDE:  Including 'XS/ColourDialog.xs' from 'Frames.xs' */


/* INCLUDE:  Including 'XS/DirDialog.xs' from 'XS/ColourDialog.xs' */


/* INCLUDE:  Including 'XS/FileDialog.xs' from 'XS/DirDialog.xs' */


/* INCLUDE:  Including 'XS/TextEntryDialog.xs' from 'XS/FileDialog.xs' */

#include <wx/textdlg.h>

XS_EUPXS(XS_Wx__TextEntryDialog_new); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__TextEntryDialog_new)
{
    dVAR; dXSARGS;
    if (items < 3 || items > 7)
       croak_xs_usage(cv,  "CLASS, parent, message, caption = wxGetTextFromUserPromptStr, defaultValue = wxEmptyString, style = wxTextEntryDialogStyle, pos = wxDefaultPosition");
    {
	wxWindow*    parent = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::Window" )
;
	wxString	message;
	wxString	caption;
	wxString	defaultValue;
	long	style;
	wxPoint	pos;
	char *	CLASS = (char *)SvPV_nolen(ST(0))
;
	wxTextEntryDialog *	RETVAL;

    WXSTRING_INPUT( message, wxString, ST(2) )
;

	if (items < 4)
	    caption = wxGetTextFromUserPromptStr;
	else {
    WXSTRING_INPUT( caption, wxString, ST(3) )
;
	}

	if (items < 5)
	    defaultValue = wxEmptyString;
	else {
    WXSTRING_INPUT( defaultValue, wxString, ST(4) )
;
	}

	if (items < 6)
	    style = wxTextEntryDialogStyle;
	else {
	    style = (long)SvIV(ST(5))
;
	}

	if (items < 7)
	    pos = wxDefaultPosition;
	else {
    pos = wxPli_sv_2_wxpoint( aTHX_ ST(6) )
;
	}

	RETVAL = new wxTextEntryDialog(parent, message, caption, defaultValue, style, pos);
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_object_2_sv( aTHX_ RETVALSV, RETVAL );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__TextEntryDialog_GetValue); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__TextEntryDialog_GetValue)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxTextEntryDialog *    THIS = (wxTextEntryDialog *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::TextEntryDialog" )
;
	wxString	RETVAL;

	RETVAL = THIS->GetValue();
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    WXSTRING_OUTPUT( RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__TextEntryDialog_SetValue); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__TextEntryDialog_SetValue)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, string");
    {
	wxString	string;
	wxTextEntryDialog *    THIS = (wxTextEntryDialog *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::TextEntryDialog" )
;

    WXSTRING_INPUT( string, wxString, ST(1) )
;

	THIS->SetValue(string);
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__TextEntryDialog_ShowModal); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__TextEntryDialog_ShowModal)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxTextEntryDialog *    THIS = (wxTextEntryDialog *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::TextEntryDialog" )
;
	int	RETVAL;
	dXSTARG;

	RETVAL = THIS->ShowModal();
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}

#if WXPERL_W_VERSION_GE( 2, 6, 0 )
#define XSubPPtmpAABG 1


XS_EUPXS(XS_Wx__PasswordEntryDialog_new); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__PasswordEntryDialog_new)
{
    dVAR; dXSARGS;
    if (items < 3 || items > 7)
       croak_xs_usage(cv,  "CLASS, parent, message, caption = wxGetPasswordFromUserPromptStr, defaultValue = wxEmptyString, style = wxTextEntryDialogStyle, pos = wxDefaultPosition");
    {
	wxWindow*    parent = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::Window" )
;
	wxString	message;
	wxString	caption;
	wxString	defaultValue;
	long	style;
	wxPoint	pos;
	char *	CLASS = (char *)SvPV_nolen(ST(0))
;
	wxPasswordEntryDialog *	RETVAL;

    WXSTRING_INPUT( message, wxString, ST(2) )
;

	if (items < 4)
	    caption = wxGetPasswordFromUserPromptStr;
	else {
    WXSTRING_INPUT( caption, wxString, ST(3) )
;
	}

	if (items < 5)
	    defaultValue = wxEmptyString;
	else {
    WXSTRING_INPUT( defaultValue, wxString, ST(4) )
;
	}

	if (items < 6)
	    style = wxTextEntryDialogStyle;
	else {
	    style = (long)SvIV(ST(5))
;
	}

	if (items < 7)
	    pos = wxDefaultPosition;
	else {
    pos = wxPli_sv_2_wxpoint( aTHX_ ST(6) )
;
	}

	RETVAL = new wxPasswordEntryDialog(parent, message, caption, defaultValue, style, pos);
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_object_2_sv( aTHX_ RETVALSV, RETVAL );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}

#endif
#if WXPERL_W_VERSION_GE( 2, 5, 1 )
#include <wx/numdlg.h>
#define XSubPPtmpAABH 1


XS_EUPXS(XS_Wx__NumberEntryDialog_new); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__NumberEntryDialog_new)
{
    dVAR; dXSARGS;
    if (items != 9)
       croak_xs_usage(cv,  "CLASS, parent, message, prompt, caption, value, min, max, pos");
    {
	wxWindow*    parent = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::Window" )
;
	wxString	message;
	wxString	prompt;
	wxString	caption;
	long	value = (long)SvIV(ST(5))
;
	long	min = (long)SvIV(ST(6))
;
	long	max = (long)SvIV(ST(7))
;
	wxPoint    pos = wxPli_sv_2_wxpoint( aTHX_ ST(8) )
;
	char *	CLASS = (char *)SvPV_nolen(ST(0))
;
	wxNumberEntryDialog *	RETVAL;

    WXSTRING_INPUT( message, wxString, ST(2) )
;

    WXSTRING_INPUT( prompt, wxString, ST(3) )
;

    WXSTRING_INPUT( caption, wxString, ST(4) )
;

	RETVAL = new wxNumberEntryDialog(parent, message, prompt, caption, value, min, max, pos);
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_object_2_sv( aTHX_ RETVALSV, RETVAL );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__NumberEntryDialog_GetValue); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__NumberEntryDialog_GetValue)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxNumberEntryDialog *    THIS = (wxNumberEntryDialog *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::NumberEntryDialog" )
;
	long	RETVAL;
	dXSTARG;

	RETVAL = THIS->GetValue();
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}

#endif

XS_EUPXS(XS_Wx_GetNumberFromUser); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx_GetNumberFromUser)
{
    dVAR; dXSARGS;
    if (items < 4 || items > 8)
       croak_xs_usage(cv,  "message, prompt, caption, value, min = 0, max = 100, parent = 0, pos = wxDefaultPosition");
    {
	wxString	message;
	wxString	prompt;
	wxString	caption;
	long	value = (long)SvIV(ST(3))
;
	long	min;
	long	max;
	wxWindow*	parent;
	wxPoint	pos;
	long	RETVAL;
	dXSTARG;

    WXSTRING_INPUT( message, wxString, ST(0) )
;

    WXSTRING_INPUT( prompt, wxString, ST(1) )
;

    WXSTRING_INPUT( caption, wxString, ST(2) )
;

	if (items < 5)
	    min = 0;
	else {
	    min = (long)SvIV(ST(4))
;
	}

	if (items < 6)
	    max = 100;
	else {
	    max = (long)SvIV(ST(5))
;
	}

	if (items < 7)
	    parent = 0;
	else {
    parent = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(6), "Wx::Window" )
;
	}

	if (items < 8)
	    pos = wxDefaultPosition;
	else {
    pos = wxPli_sv_2_wxpoint( aTHX_ ST(7) )
;
	}
    RETVAL = wxGetNumberFromUser( message, prompt, caption, value, min, max, parent, pos );
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx_GetPasswordFromUser); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx_GetPasswordFromUser)
{
    dVAR; dXSARGS;
    if (items < 1 || items > 4)
       croak_xs_usage(cv,  "message, caption = wxGetTextFromUserPromptStr, default_value = wxEmptyString, parent = 0");
    {
	wxString	message;
	wxString	caption;
	wxString	default_value;
	wxWindow*	parent;
	wxString	RETVAL;

    WXSTRING_INPUT( message, wxString, ST(0) )
;

	if (items < 2)
	    caption = wxGetTextFromUserPromptStr;
	else {
    WXSTRING_INPUT( caption, wxString, ST(1) )
;
	}

	if (items < 3)
	    default_value = wxEmptyString;
	else {
    WXSTRING_INPUT( default_value, wxString, ST(2) )
;
	}

	if (items < 4)
	    parent = 0;
	else {
    parent = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(3), "Wx::Window" )
;
	}

	RETVAL = wxGetPasswordFromUser(message, caption, default_value, parent);
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    WXSTRING_OUTPUT( RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx_GetTextFromUser); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx_GetTextFromUser)
{
    dVAR; dXSARGS;
    if (items < 1 || items > 7)
       croak_xs_usage(cv,  "message, caption = wxGetTextFromUserPromptStr, default_value = wxEmptyString, parent = 0, x = -1, y = -1, centre = true");
    {
	wxString	message;
	wxString	caption;
	wxString	default_value;
	wxWindow*	parent;
	int	x;
	int	y;
	bool	centre;
	wxString	RETVAL;

    WXSTRING_INPUT( message, wxString, ST(0) )
;

	if (items < 2)
	    caption = wxGetTextFromUserPromptStr;
	else {
    WXSTRING_INPUT( caption, wxString, ST(1) )
;
	}

	if (items < 3)
	    default_value = wxEmptyString;
	else {
    WXSTRING_INPUT( default_value, wxString, ST(2) )
;
	}

	if (items < 4)
	    parent = 0;
	else {
    parent = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(3), "Wx::Window" )
;
	}

	if (items < 5)
	    x = -1;
	else {
	    x = (int)SvIV(ST(4))
;
	}

	if (items < 6)
	    y = -1;
	else {
	    y = (int)SvIV(ST(5))
;
	}

	if (items < 7)
	    centre = true;
	else {
	    centre = (bool)SvTRUE(ST(6))
;
	}

	RETVAL = wxGetTextFromUser(message, caption, default_value, parent, x, y, centre);
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    WXSTRING_OUTPUT( RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


/* INCLUDE: Returning to 'XS/FileDialog.xs' from 'XS/TextEntryDialog.xs' */

#include <wx/filedlg.h>

XS_EUPXS(XS_Wx__FileDialog_new); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__FileDialog_new)
{
    dVAR; dXSARGS;
    if (items < 2 || items > 8)
       croak_xs_usage(cv,  "CLASS, parent, message = wxFileSelectorPromptStr, defaultDir = wxEmptyString, defaultFile = wxEmptyString, wildcard = wxFileSelectorDefaultWildcardStr, style = 0, pos = wxDefaultPosition");
    {
	wxWindow*    parent = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::Window" )
;
	wxString	message;
	wxString	defaultDir;
	wxString	defaultFile;
	wxString	wildcard;
	long	style;
	wxPoint	pos;
	char *	CLASS = (char *)SvPV_nolen(ST(0))
;
	wxFileDialog *	RETVAL;

	if (items < 3)
	    message = wxFileSelectorPromptStr;
	else {
    WXSTRING_INPUT( message, wxString, ST(2) )
;
	}

	if (items < 4)
	    defaultDir = wxEmptyString;
	else {
    WXSTRING_INPUT( defaultDir, wxString, ST(3) )
;
	}

	if (items < 5)
	    defaultFile = wxEmptyString;
	else {
    WXSTRING_INPUT( defaultFile, wxString, ST(4) )
;
	}

	if (items < 6)
	    wildcard = wxFileSelectorDefaultWildcardStr;
	else {
    WXSTRING_INPUT( wildcard, wxString, ST(5) )
;
	}

	if (items < 7)
	    style = 0;
	else {
	    style = (long)SvIV(ST(6))
;
	}

	if (items < 8)
	    pos = wxDefaultPosition;
	else {
    pos = wxPli_sv_2_wxpoint( aTHX_ ST(7) )
;
	}

	RETVAL = new wxFileDialog(parent, message, defaultDir, defaultFile, wildcard, style, pos);
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_object_2_sv( aTHX_ RETVALSV, RETVAL );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__FileDialog_GetDirectory); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__FileDialog_GetDirectory)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxFileDialog *    THIS = (wxFileDialog *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::FileDialog" )
;
	wxString	RETVAL;

	RETVAL = THIS->GetDirectory();
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    WXSTRING_OUTPUT( RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__FileDialog_GetFilename); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__FileDialog_GetFilename)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxFileDialog *    THIS = (wxFileDialog *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::FileDialog" )
;
	wxString	RETVAL;

	RETVAL = THIS->GetFilename();
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    WXSTRING_OUTPUT( RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__FileDialog_GetFilenames); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__FileDialog_GetFilenames)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    PERL_UNUSED_VAR(ax); /* -Wall */
    SP -= items;
    {
    wxArrayString filenames;
    int i, max;
	wxFileDialog *    THIS = (wxFileDialog *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::FileDialog" )
;
    THIS->GetFilenames( filenames );
    max = filenames.GetCount();
    EXTEND( SP, max );
    for( i = 0; i < max; ++i ) {
#if wxUSE_UNICODE
      SV* tmp = sv_2mortal( newSVpv( filenames[i].mb_str(wxConvUTF8), 0 ) );
      SvUTF8_on( tmp );
      PUSHs( tmp );
#else
      PUSHs( sv_2mortal( newSVpv( CHAR_P filenames[i].c_str(), 0 ) ) );
#endif
    }
	PUTBACK;
	return;
    }
}


XS_EUPXS(XS_Wx__FileDialog_GetFilterIndex); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__FileDialog_GetFilterIndex)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxFileDialog *    THIS = (wxFileDialog *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::FileDialog" )
;
	int	RETVAL;
	dXSTARG;

	RETVAL = THIS->GetFilterIndex();
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__FileDialog_GetMessage); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__FileDialog_GetMessage)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxFileDialog *    THIS = (wxFileDialog *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::FileDialog" )
;
	wxString	RETVAL;

	RETVAL = THIS->GetMessage();
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    WXSTRING_OUTPUT( RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__FileDialog_GetPath); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__FileDialog_GetPath)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxFileDialog *    THIS = (wxFileDialog *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::FileDialog" )
;
	wxString	RETVAL;

	RETVAL = THIS->GetPath();
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    WXSTRING_OUTPUT( RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__FileDialog_GetPaths); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__FileDialog_GetPaths)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    PERL_UNUSED_VAR(ax); /* -Wall */
    SP -= items;
    {
    wxArrayString filenames;
    int i, max;
	wxFileDialog *    THIS = (wxFileDialog *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::FileDialog" )
;
    THIS->GetPaths( filenames );
    max = filenames.GetCount();
    EXTEND( SP, max );
    for( i = 0; i < max; ++i ) {
#if wxUSE_UNICODE
      SV* tmp = sv_2mortal( newSVpv( filenames[i].mb_str(wxConvUTF8), 0 ) );
      SvUTF8_on( tmp );
      PUSHs( tmp );
#else
      PUSHs( sv_2mortal( newSVpv( CHAR_P filenames[i].c_str(), 0 ) ) );
#endif
    }
	PUTBACK;
	return;
    }
}

#if WXPERL_W_VERSION_LT( 2, 7, 0 )
#define XSubPPtmpAABI 1


XS_EUPXS(XS_Wx__FileDialog_GetStyle); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__FileDialog_GetStyle)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxFileDialog *    THIS = (wxFileDialog *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::FileDialog" )
;
	long	RETVAL;
	dXSTARG;

	RETVAL = THIS->GetStyle();
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}

#endif

XS_EUPXS(XS_Wx__FileDialog_GetWildcard); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__FileDialog_GetWildcard)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxFileDialog *    THIS = (wxFileDialog *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::FileDialog" )
;
	wxString	RETVAL;

	RETVAL = THIS->GetWildcard();
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    WXSTRING_OUTPUT( RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__FileDialog_SetDirectory); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__FileDialog_SetDirectory)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, directory");
    {
	wxString	directory;
	wxFileDialog *    THIS = (wxFileDialog *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::FileDialog" )
;

    WXSTRING_INPUT( directory, wxString, ST(1) )
;

	THIS->SetDirectory(directory);
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__FileDialog_SetFilename); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__FileDialog_SetFilename)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, name");
    {
	wxString	name;
	wxFileDialog *    THIS = (wxFileDialog *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::FileDialog" )
;

    WXSTRING_INPUT( name, wxString, ST(1) )
;

	THIS->SetFilename(name);
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__FileDialog_SetFilterIndex); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__FileDialog_SetFilterIndex)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, index");
    {
	int	index = (int)SvIV(ST(1))
;
	wxFileDialog *    THIS = (wxFileDialog *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::FileDialog" )
;

	THIS->SetFilterIndex(index);
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__FileDialog_SetMessage); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__FileDialog_SetMessage)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, message");
    {
	wxString	message;
	wxFileDialog *    THIS = (wxFileDialog *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::FileDialog" )
;

    WXSTRING_INPUT( message, wxString, ST(1) )
;

	THIS->SetMessage(message);
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__FileDialog_SetPath); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__FileDialog_SetPath)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, path");
    {
	wxString	path;
	wxFileDialog *    THIS = (wxFileDialog *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::FileDialog" )
;

    WXSTRING_INPUT( path, wxString, ST(1) )
;

	THIS->SetPath(path);
    }
    XSRETURN_EMPTY;
}

#if WXPERL_W_VERSION_LT( 2, 7, 0 )
#define XSubPPtmpAABJ 1


XS_EUPXS(XS_Wx__FileDialog_SetStyle); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__FileDialog_SetStyle)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, style");
    {
	long	style = (long)SvIV(ST(1))
;
	wxFileDialog *    THIS = (wxFileDialog *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::FileDialog" )
;

	THIS->SetStyle(style);
    }
    XSRETURN_EMPTY;
}

#endif

XS_EUPXS(XS_Wx__FileDialog_SetWildcard); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__FileDialog_SetWildcard)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, wildcard");
    {
	wxString	wildcard;
	wxFileDialog *    THIS = (wxFileDialog *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::FileDialog" )
;

    WXSTRING_INPUT( wildcard, wxString, ST(1) )
;

	THIS->SetWildcard(wildcard);
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__FileDialog_ShowModal); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__FileDialog_ShowModal)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxFileDialog *    THIS = (wxFileDialog *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::FileDialog" )
;
	int	RETVAL;
	dXSTARG;

	RETVAL = THIS->ShowModal();
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx_FileSelector); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx_FileSelector)
{
    dVAR; dXSARGS;
    if (items < 1 || items > 9)
       croak_xs_usage(cv,  "message, default_path = wxEmptyString, default_filename = wxEmptyString, default_extension = wxEmptyString, wildcard = wxT(\"*.*\"), flags = 0, parent = 0, x = -1, y = -1");
    {
	wxString	message;
	wxString	default_path;
	wxString	default_filename;
	wxString	default_extension;
	wxString	wildcard;
	int	flags;
	wxWindow*	parent;
	int	x;
	int	y;
	wxString	RETVAL;

    WXSTRING_INPUT( message, wxString, ST(0) )
;

	if (items < 2)
	    default_path = wxEmptyString;
	else {
    WXSTRING_INPUT( default_path, wxString, ST(1) )
;
	}

	if (items < 3)
	    default_filename = wxEmptyString;
	else {
    WXSTRING_INPUT( default_filename, wxString, ST(2) )
;
	}

	if (items < 4)
	    default_extension = wxEmptyString;
	else {
    WXSTRING_INPUT( default_extension, wxString, ST(3) )
;
	}

	if (items < 5)
	    wildcard = wxT("*.*");
	else {
    WXSTRING_INPUT( wildcard, wxString, ST(4) )
;
	}

	if (items < 6)
	    flags = 0;
	else {
	    flags = (int)SvIV(ST(5))
;
	}

	if (items < 7)
	    parent = 0;
	else {
    parent = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(6), "Wx::Window" )
;
	}

	if (items < 8)
	    x = -1;
	else {
	    x = (int)SvIV(ST(7))
;
	}

	if (items < 9)
	    y = -1;
	else {
	    y = (int)SvIV(ST(8))
;
	}

	RETVAL = wxFileSelector(message, default_path, default_filename, default_extension, wildcard, flags, parent, x, y);
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    WXSTRING_OUTPUT( RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


/* INCLUDE: Returning to 'XS/DirDialog.xs' from 'XS/FileDialog.xs' */

#include <wx/dirdlg.h>

XS_EUPXS(XS_Wx__DirDialog_new); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__DirDialog_new)
{
    dVAR; dXSARGS;
    if (items < 2 || items > 6)
       croak_xs_usage(cv,  "CLASS, parent, message = wxFileSelectorPromptStr, defaultPath = wxEmptyString, style = 0, pos = wxDefaultPosition");
    {
	wxWindow*    parent = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::Window" )
;
	wxString	message;
	wxString	defaultPath;
	long	style;
	wxPoint	pos;
	char *	CLASS = (char *)SvPV_nolen(ST(0))
;
	wxDirDialog *	RETVAL;

	if (items < 3)
	    message = wxFileSelectorPromptStr;
	else {
    WXSTRING_INPUT( message, wxString, ST(2) )
;
	}

	if (items < 4)
	    defaultPath = wxEmptyString;
	else {
    WXSTRING_INPUT( defaultPath, wxString, ST(3) )
;
	}

	if (items < 5)
	    style = 0;
	else {
	    style = (long)SvIV(ST(4))
;
	}

	if (items < 6)
	    pos = wxDefaultPosition;
	else {
    pos = wxPli_sv_2_wxpoint( aTHX_ ST(5) )
;
	}

	RETVAL = new wxDirDialog(parent, message, defaultPath, style, pos);
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_non_object_2_sv( aTHX_ RETVALSV, RETVAL, "Wx::DirDialog" );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__DirDialog_GetPath); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__DirDialog_GetPath)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxDirDialog *    THIS = (wxDirDialog *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::DirDialog" )
;
	wxString	RETVAL;

	RETVAL = THIS->GetPath();
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    WXSTRING_OUTPUT( RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__DirDialog_GetMessage); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__DirDialog_GetMessage)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxDirDialog *    THIS = (wxDirDialog *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::DirDialog" )
;
	wxString	RETVAL;

	RETVAL = THIS->GetMessage();
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    WXSTRING_OUTPUT( RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}

#if WXPERL_W_VERSION_LT( 2, 7, 0 )
#define XSubPPtmpAABK 1


XS_EUPXS(XS_Wx__DirDialog_GetStyle); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__DirDialog_GetStyle)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxDirDialog *    THIS = (wxDirDialog *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::DirDialog" )
;
	long	RETVAL;
	dXSTARG;

	RETVAL = THIS->GetStyle();
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}

#endif

XS_EUPXS(XS_Wx__DirDialog_SetMessage); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__DirDialog_SetMessage)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, message");
    {
	wxString	message;
	wxDirDialog *    THIS = (wxDirDialog *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::DirDialog" )
;

    WXSTRING_INPUT( message, wxString, ST(1) )
;

	THIS->SetMessage(message);
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__DirDialog_SetPath); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__DirDialog_SetPath)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, path");
    {
	wxString	path;
	wxDirDialog *    THIS = (wxDirDialog *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::DirDialog" )
;

    WXSTRING_INPUT( path, wxString, ST(1) )
;

	THIS->SetPath(path);
    }
    XSRETURN_EMPTY;
}

#if WXPERL_W_VERSION_LT( 2, 7, 0 )
#define XSubPPtmpAABL 1


XS_EUPXS(XS_Wx__DirDialog_SetStyle); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__DirDialog_SetStyle)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, style");
    {
	long	style = (long)SvIV(ST(1))
;
	wxDirDialog *    THIS = (wxDirDialog *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::DirDialog" )
;

	THIS->SetStyle(style);
    }
    XSRETURN_EMPTY;
}

#endif

XS_EUPXS(XS_Wx__DirDialog_ShowModal); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__DirDialog_ShowModal)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxDirDialog *    THIS = (wxDirDialog *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::DirDialog" )
;
	int	RETVAL;
	dXSTARG;

	RETVAL = THIS->ShowModal();
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx_DirSelector); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx_DirSelector)
{
    dVAR; dXSARGS;
    if (items < 1 || items > 5)
       croak_xs_usage(cv,  "message, default_path = wxEmptyString, style = 0, pos = wxDefaultPosition, parent = 0");
    {
	wxString	message;
	wxString	default_path;
	long	style;
	wxPoint	pos;
	wxWindow*	parent;
	wxString	RETVAL;

    WXSTRING_INPUT( message, wxString, ST(0) )
;

	if (items < 2)
	    default_path = wxEmptyString;
	else {
    WXSTRING_INPUT( default_path, wxString, ST(1) )
;
	}

	if (items < 3)
	    style = 0;
	else {
	    style = (long)SvIV(ST(2))
;
	}

	if (items < 4)
	    pos = wxDefaultPosition;
	else {
    pos = wxPli_sv_2_wxpoint( aTHX_ ST(3) )
;
	}

	if (items < 5)
	    parent = 0;
	else {
    parent = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(4), "Wx::Window" )
;
	}

	RETVAL = wxDirSelector(message, default_path, style, pos, parent);
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    WXSTRING_OUTPUT( RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


/* INCLUDE: Returning to 'XS/ColourDialog.xs' from 'XS/DirDialog.xs' */

#include <wx/colordlg.h>

XS_EUPXS(XS_Wx__ColourDialog_new); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ColourDialog_new)
{
    dVAR; dXSARGS;
    if (items < 2 || items > 3)
       croak_xs_usage(cv,  "CLASS, parent, data = 0");
    {
	wxWindow*    parent = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::Window" )
;
	wxColourData*	data;
	char *	CLASS = (char *)SvPV_nolen(ST(0))
;
	wxColourDialog *	RETVAL;

	if (items < 3)
	    data = 0;
	else {
    data = (wxColourData *) wxPli_sv_2_object( aTHX_ ST(2), "Wx::ColourData" )
;
	}

	RETVAL = new wxColourDialog(parent, data);
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_object_2_sv( aTHX_ RETVALSV, RETVAL );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__ColourDialog_GetColourData); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ColourDialog_GetColourData)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxColourDialog *    THIS = (wxColourDialog *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::ColourDialog" )
;
	wxColourData *	RETVAL;
    RETVAL = new wxColourData( THIS->GetColourData() );
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_object_2_sv( aTHX_ RETVALSV, RETVAL );
    wxPli_thread_sv_register( aTHX_ "Wx::ColourData", RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__ColourDialog_ShowModal); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ColourDialog_ShowModal)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxColourDialog *    THIS = (wxColourDialog *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::ColourDialog" )
;
	int	RETVAL;
	dXSTARG;

	RETVAL = THIS->ShowModal();
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__ColourData_new); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ColourData_new)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "CLASS");
    {
	char *	CLASS = (char *)SvPV_nolen(ST(0))
;
	wxColourData *	RETVAL;

	RETVAL = new wxColourData();
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_object_2_sv( aTHX_ RETVALSV, RETVAL );
    wxPli_thread_sv_register( aTHX_ "Wx::ColourData", RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__ColourData_CLONE); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ColourData_CLONE)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "CLASS");
    {
	char *	CLASS = (char *)SvPV_nolen(ST(0))
;
    wxPli_thread_sv_clone( aTHX_ CLASS, (wxPliCloneSV)wxPli_detach_object );
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__ColourData_DESTROY); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ColourData_DESTROY)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxColourData *    THIS = (wxColourData *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::ColourData" )
;
    wxPli_thread_sv_unregister( aTHX_ "Wx::ColourData", THIS, ST(0) );
    delete THIS;
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__ColourData_GetChooseFull); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ColourData_GetChooseFull)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxColourData *    THIS = (wxColourData *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::ColourData" )
;
	bool	RETVAL;

	RETVAL = THIS->GetChooseFull();
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__ColourData_GetColour); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ColourData_GetColour)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxColourData *    THIS = (wxColourData *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::ColourData" )
;
	wxColour *	RETVAL;
    RETVAL = new wxColour( THIS->GetColour() );
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_non_object_2_sv( aTHX_ RETVALSV, RETVAL, "Wx::Colour" );
    wxPli_thread_sv_register( aTHX_ "Wx::Colour", RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__ColourData_GetCustomColour); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ColourData_GetCustomColour)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, i");
    {
	int	i = (int)SvIV(ST(1))
;
	wxColourData *    THIS = (wxColourData *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::ColourData" )
;
	wxColour *	RETVAL;
    RETVAL = new wxColour( THIS->GetCustomColour( i ) );
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_non_object_2_sv( aTHX_ RETVALSV, RETVAL, "Wx::Colour" );
    wxPli_thread_sv_register( aTHX_ "Wx::Colour", RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__ColourData_SetChooseFull); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ColourData_SetChooseFull)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, flag");
    {
	bool	flag = (bool)SvTRUE(ST(1))
;
	wxColourData *    THIS = (wxColourData *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::ColourData" )
;

	THIS->SetChooseFull(flag);
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__ColourData_SetColour); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ColourData_SetColour)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, colour");
    {
	wxColour*    colour = (wxColour *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::Colour" )
;
	wxColourData *    THIS = (wxColourData *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::ColourData" )
;

	THIS->SetColour(*colour);
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__ColourData_SetCustomColour); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ColourData_SetCustomColour)
{
    dVAR; dXSARGS;
    if (items != 3)
       croak_xs_usage(cv,  "THIS, i, colour");
    {
	int	i = (int)SvIV(ST(1))
;
	wxColour*    colour = (wxColour *) wxPli_sv_2_object( aTHX_ ST(2), "Wx::Colour" )
;
	wxColourData *    THIS = (wxColourData *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::ColourData" )
;

	THIS->SetCustomColour(i, *colour);
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx_GetColourFromUser); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx_GetColourFromUser)
{
    dVAR; dXSARGS;
    if (items < 1 || items > 2)
       croak_xs_usage(cv,  "parent, colInit = (wxColour*)&wxNullColour");
    {
	wxWindow*    parent = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Window" )
;
	wxColour*	colInit;
	wxColour *	RETVAL;

	if (items < 2)
	    colInit = (wxColour*)&wxNullColour;
	else {
    colInit = (wxColour *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::Colour" )
;
	}
    RETVAL = new wxColour( wxGetColourFromUser( parent, *colInit ) );
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_non_object_2_sv( aTHX_ RETVALSV, RETVAL, "Wx::Colour" );
    wxPli_thread_sv_register( aTHX_ "Wx::Colour", RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


/* INCLUDE: Returning to 'Frames.xs' from 'XS/ColourDialog.xs' */


/* INCLUDE_COMMAND:  Including output of '/usr/bin/perl -I./ -MExtUtils::XSpp::Cmd -e xspp -- -t typemap.xsp XS/MessageDialog.xsp' from 'Frames.xs' */

#include <exception>

#undef  xsp_constructor_class
#define xsp_constructor_class(c) (c)
#include <wx/msgdlg.h>
#define wxPL_MSGDLG_STYLE wxOK|wxCENTRE
#undef  xsp_constructor_class
#define xsp_constructor_class(c) (CLASS)

XS_EUPXS(XS_Wx__MessageDialog_new); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__MessageDialog_new)
{
    dVAR; dXSARGS;
    if (items < 3 || items > 6)
       croak_xs_usage(cv,  "CLASS, parent, message, caption= wxMessageBoxCaptionStr, style= wxPL_MSGDLG_STYLE, pos= wxDefaultPosition");
    {
	char *	CLASS = (char *)SvPV_nolen(ST(0))
;
	wxMessageDialog *	RETVAL;
	wxWindow*    parent = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::Window" )
;
	wxString	message;
	wxString	caption;
	long	style;
	wxPoint	pos;

    WXSTRING_INPUT( message, wxString, ST(2) )
;

	if (items < 4)
	    caption = wxMessageBoxCaptionStr;
	else {
    WXSTRING_INPUT( caption, wxString, ST(3) )
;
	}

	if (items < 5)
	    style = wxPL_MSGDLG_STYLE;
	else {
	    style = (long)SvIV(ST(4))
;
	}

	if (items < 6)
	    pos = wxDefaultPosition;
	else {
    pos = wxPli_sv_2_wxpoint( aTHX_ ST(5) )
;
	}
    try {
      RETVAL = new wxMessageDialog( parent, message, caption, style, pos );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_object_2_sv( aTHX_ RETVALSV, RETVAL );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}

#undef  xsp_constructor_class
#define xsp_constructor_class(c) (c)

XS_EUPXS(XS_Wx__MessageDialog_ShowModal); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__MessageDialog_ShowModal)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxMessageDialog *    THIS = (wxMessageDialog *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::MessageDialog" )
;
	int	RETVAL;
	dXSTARG;
    try {
      RETVAL = THIS->ShowModal();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}

#if WXPERL_W_VERSION_GE( 2, 9, 0 )
#define XSpp_f95ecc9c_034485
#define XSubPPtmpAABM 1


XS_EUPXS(XS_Wx__MessageDialog_SetYesNoLabels); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__MessageDialog_SetYesNoLabels)
{
    dVAR; dXSARGS;
    if (items != 3)
       croak_xs_usage(cv,  "THIS, yes, no");
    {
	wxMessageDialog *    THIS = (wxMessageDialog *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::MessageDialog" )
;
	bool	RETVAL;
	wxString	yes;
	wxString	no;

    WXSTRING_INPUT( yes, wxString, ST(1) )
;

    WXSTRING_INPUT( no, wxString, ST(2) )
;
    try {
      RETVAL = THIS->SetYesNoLabels( yes, no );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__MessageDialog_SetYesNoCancelLabels); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__MessageDialog_SetYesNoCancelLabels)
{
    dVAR; dXSARGS;
    if (items != 4)
       croak_xs_usage(cv,  "THIS, yes, no, cancel");
    {
	wxMessageDialog *    THIS = (wxMessageDialog *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::MessageDialog" )
;
	bool	RETVAL;
	wxString	yes;
	wxString	no;
	wxString	cancel;

    WXSTRING_INPUT( yes, wxString, ST(1) )
;

    WXSTRING_INPUT( no, wxString, ST(2) )
;

    WXSTRING_INPUT( cancel, wxString, ST(3) )
;
    try {
      RETVAL = THIS->SetYesNoCancelLabels( yes, no, cancel );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__MessageDialog_SetOKLabel); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__MessageDialog_SetOKLabel)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, ok");
    {
	wxMessageDialog *    THIS = (wxMessageDialog *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::MessageDialog" )
;
	bool	RETVAL;
	wxString	ok;

    WXSTRING_INPUT( ok, wxString, ST(1) )
;
    try {
      RETVAL = THIS->SetOKLabel( ok );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__MessageDialog_SetOKCancelLabels); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__MessageDialog_SetOKCancelLabels)
{
    dVAR; dXSARGS;
    if (items != 3)
       croak_xs_usage(cv,  "THIS, ok, cancel");
    {
	wxMessageDialog *    THIS = (wxMessageDialog *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::MessageDialog" )
;
	bool	RETVAL;
	wxString	ok;
	wxString	cancel;

    WXSTRING_INPUT( ok, wxString, ST(1) )
;

    WXSTRING_INPUT( cancel, wxString, ST(2) )
;
    try {
      RETVAL = THIS->SetOKCancelLabels( ok, cancel );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__MessageDialog_SetMessage); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__MessageDialog_SetMessage)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, message");
    {
	wxMessageDialog *    THIS = (wxMessageDialog *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::MessageDialog" )
;
	wxString	message;

    WXSTRING_INPUT( message, wxString, ST(1) )
;
    try {
      THIS->SetMessage( message );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__MessageDialog_SetExtendedMessage); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__MessageDialog_SetExtendedMessage)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, extendedMessage");
    {
	wxMessageDialog *    THIS = (wxMessageDialog *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::MessageDialog" )
;
	wxString	extendedMessage;

    WXSTRING_INPUT( extendedMessage, wxString, ST(1) )
;
    try {
      THIS->SetExtendedMessage( extendedMessage );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}

#endif
#if WXPERL_W_VERSION_GE( 2, 9, 3 )
#define XSpp_f95ecc9c_043797
#define XSubPPtmpAABN 1


XS_EUPXS(XS_Wx__MessageDialog_SetHelpLabel); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__MessageDialog_SetHelpLabel)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, help");
    {
	wxMessageDialog *    THIS = (wxMessageDialog *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::MessageDialog" )
;
	bool	RETVAL;
	wxString	help;

    WXSTRING_INPUT( help, wxString, ST(1) )
;
    try {
      RETVAL = THIS->SetHelpLabel( help );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}

#endif

XS_EUPXS(XS_Wx_MessageBox); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx_MessageBox)
{
    dVAR; dXSARGS;
    if (items < 1 || items > 6)
       croak_xs_usage(cv,  "message, caption= wxT(\"Message\"), style= wxPL_MSGDLG_STYLE, parent= NULL, x= -1, y= -1");
    {
	int	RETVAL;
	dXSTARG;
	wxString	message;
	wxString	caption;
	int	style;
	wxWindow*	parent;
	int	x;
	int	y;

    WXSTRING_INPUT( message, wxString, ST(0) )
;

	if (items < 2)
	    caption = wxT("Message");
	else {
    WXSTRING_INPUT( caption, wxString, ST(1) )
;
	}

	if (items < 3)
	    style = wxPL_MSGDLG_STYLE;
	else {
	    style = (int)SvIV(ST(2))
;
	}

	if (items < 4)
	    parent = NULL;
	else {
    parent = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(3), "Wx::Window" )
;
	}

	if (items < 5)
	    x = -1;
	else {
	    x = (int)SvIV(ST(4))
;
	}

	if (items < 6)
	    y = -1;
	else {
	    y = (int)SvIV(ST(5))
;
	}
    try {
      RETVAL = wxMessageBox( message, caption, style, parent, x, y );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


/* INCLUDE: Returning to 'Frames.xs' from '/usr/bin/perl -I./ -MExtUtils::XSpp::Cmd -e xspp -- -t typemap.xsp XS/MessageDialog.xsp' */


/* INCLUDE:  Including 'XS/ProgressDialog.xs' from 'Frames.xs' */


/* INCLUDE:  Including 'XS/SingleChoiceDialog.xs' from 'XS/ProgressDialog.xs' */


/* INCLUDE:  Including 'XS/MultiChoiceDialog.xs' from 'XS/SingleChoiceDialog.xs' */


/* INCLUDE:  Including 'XS/FontDialog.xs' from 'XS/MultiChoiceDialog.xs' */

#if wxPERL_USE_FONTDLG
#include <wx/fontdlg.h>
#define XSubPPtmpAABO 1


XS_EUPXS(XS_Wx__FontData_new); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__FontData_new)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "CLASS");
    {
	char *	CLASS = (char *)SvPV_nolen(ST(0))
;
	wxFontData *	RETVAL;

	RETVAL = new wxFontData();
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_object_2_sv( aTHX_ RETVALSV, RETVAL );
    wxPli_thread_sv_register( aTHX_ "Wx::FontData", RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__FontData_CLONE); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__FontData_CLONE)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "CLASS");
    {
	char *	CLASS = (char *)SvPV_nolen(ST(0))
;
    wxPli_thread_sv_clone( aTHX_ CLASS, (wxPliCloneSV)wxPli_detach_object );
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__FontData_DESTROY); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__FontData_DESTROY)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxFontData *    THIS = (wxFontData *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::FontData" )
;
    wxPli_thread_sv_unregister( aTHX_ "Wx::FontData", THIS, ST(0) );
    delete THIS;
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__FontData_EnableEffects); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__FontData_EnableEffects)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, enable");
    {
	bool	enable = (bool)SvTRUE(ST(1))
;
	wxFontData *    THIS = (wxFontData *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::FontData" )
;

	THIS->EnableEffects(enable);
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__FontData_GetAllowSymbols); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__FontData_GetAllowSymbols)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxFontData *    THIS = (wxFontData *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::FontData" )
;
	bool	RETVAL;

	RETVAL = THIS->GetAllowSymbols();
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__FontData_GetColour); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__FontData_GetColour)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxFontData *    THIS = (wxFontData *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::FontData" )
;
	wxColour *	RETVAL;
    RETVAL = new wxColour( THIS->GetColour() );
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_non_object_2_sv( aTHX_ RETVALSV, RETVAL, "Wx::Colour" );
    wxPli_thread_sv_register( aTHX_ "Wx::Colour", RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__FontData_GetChosenFont); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__FontData_GetChosenFont)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxFontData *    THIS = (wxFontData *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::FontData" )
;
	wxFont *	RETVAL;
    RETVAL = new wxFont( THIS->GetChosenFont() );
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_object_2_sv( aTHX_ RETVALSV, RETVAL );
    wxPli_thread_sv_register( aTHX_ "Wx::Font", RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__FontData_GetEnableEffects); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__FontData_GetEnableEffects)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxFontData *    THIS = (wxFontData *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::FontData" )
;
	bool	RETVAL;

	RETVAL = THIS->GetEnableEffects();
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__FontData_GetInitialFont); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__FontData_GetInitialFont)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxFontData *    THIS = (wxFontData *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::FontData" )
;
	wxFont *	RETVAL;
    RETVAL = new wxFont( THIS->GetInitialFont() );
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_object_2_sv( aTHX_ RETVALSV, RETVAL );
    wxPli_thread_sv_register( aTHX_ "Wx::Font", RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__FontData_GetShowHelp); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__FontData_GetShowHelp)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxFontData *    THIS = (wxFontData *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::FontData" )
;
	bool	RETVAL;

	RETVAL = THIS->GetShowHelp();
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__FontData_SetAllowSymbols); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__FontData_SetAllowSymbols)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, allow");
    {
	bool	allow = (bool)SvTRUE(ST(1))
;
	wxFontData *    THIS = (wxFontData *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::FontData" )
;

	THIS->SetAllowSymbols(allow);
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__FontData_SetChosenFont); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__FontData_SetChosenFont)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, font");
    {
	wxFont*    font = (wxFont *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::Font" )
;
	wxFontData *    THIS = (wxFontData *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::FontData" )
;
    THIS->SetChosenFont( *font );
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__FontData_SetColour); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__FontData_SetColour)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, colour");
    {
	wxColour    colour = *(wxColour *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::Colour" )
;
	wxFontData *    THIS = (wxFontData *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::FontData" )
;

	THIS->SetColour(colour);
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__FontData_SetInitialFont); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__FontData_SetInitialFont)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, font");
    {
	wxFont*    font = (wxFont *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::Font" )
;
	wxFontData *    THIS = (wxFontData *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::FontData" )
;
    THIS->SetInitialFont( *font );
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__FontData_SetRange); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__FontData_SetRange)
{
    dVAR; dXSARGS;
    if (items != 3)
       croak_xs_usage(cv,  "THIS, min, max");
    {
	int	min = (int)SvIV(ST(1))
;
	int	max = (int)SvIV(ST(2))
;
	wxFontData *    THIS = (wxFontData *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::FontData" )
;

	THIS->SetRange(min, max);
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__FontData_SetShowHelp); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__FontData_SetShowHelp)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, show");
    {
	bool	show = (bool)SvTRUE(ST(1))
;
	wxFontData *    THIS = (wxFontData *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::FontData" )
;

	THIS->SetShowHelp(show);
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__FontDialog_new); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__FontDialog_new)
{
    dVAR; dXSARGS;
    if (items < 2 || items > 3)
       croak_xs_usage(cv,  "CLASS, parent, data = 0");
    {
	wxWindow*    parent = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::Window" )
;
	wxFontData*	data;
	char *	CLASS = (char *)SvPV_nolen(ST(0))
;
	wxFontDialog *	RETVAL;

	if (items < 3)
	    data = 0;
	else {
    data = (wxFontData *) wxPli_sv_2_object( aTHX_ ST(2), "Wx::FontData" )
;
	}
    RETVAL = new wxFontDialog( parent, *data );
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_object_2_sv( aTHX_ RETVALSV, RETVAL );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__FontDialog_GetFontData); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__FontDialog_GetFontData)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxFontDialog *    THIS = (wxFontDialog *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::FontDialog" )
;
	wxFontData *	RETVAL;
    RETVAL = new wxFontData( THIS->GetFontData() );
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_object_2_sv( aTHX_ RETVALSV, RETVAL );
    wxPli_thread_sv_register( aTHX_ "Wx::FontData", RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx_GetFontFromUser); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx_GetFontFromUser)
{
    dVAR; dXSARGS;
    if (items < 0 || items > 2)
       croak_xs_usage(cv,  "parent = 0, fontInit = (wxFont*)&wxNullFont");
    {
	wxWindow*	parent;
	wxFont*	fontInit;
	wxFont *	RETVAL;

	if (items < 1)
	    parent = 0;
	else {
    parent = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Window" )
;
	}

	if (items < 2)
	    fontInit = (wxFont*)&wxNullFont;
	else {
    fontInit = (wxFont *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::Font" )
;
	}
    RETVAL = new wxFont( wxGetFontFromUser( parent, *fontInit ) );
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_object_2_sv( aTHX_ RETVALSV, RETVAL );
    wxPli_thread_sv_register( aTHX_ "Wx::Font", RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}

#endif

/* INCLUDE: Returning to 'XS/MultiChoiceDialog.xs' from 'XS/FontDialog.xs' */

#include <wx/choicdlg.h>

XS_EUPXS(XS_Wx__MultiChoiceDialog_new); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__MultiChoiceDialog_new)
{
    dVAR; dXSARGS;
    if (items < 5 || items > 7)
       croak_xs_usage(cv,  "CLASS, parent, message, caption, chs, style = wxCHOICEDLG_STYLE, pos = wxDefaultPosition");
    {
	wxWindow*    parent = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::Window" )
;
	wxString	message;
	wxString	caption;
	SV*	chs = ST(4)
;
	long	style;
	wxPoint	pos;
    wxString* choices;
    int n;
	char *	CLASS = (char *)SvPV_nolen(ST(0))
;
	wxMultiChoiceDialog *	RETVAL;

    WXSTRING_INPUT( message, wxString, ST(2) )
;

    WXSTRING_INPUT( caption, wxString, ST(3) )
;

	if (items < 6)
	    style = wxCHOICEDLG_STYLE;
	else {
	    style = (long)SvIV(ST(5))
;
	}

	if (items < 7)
	    pos = wxDefaultPosition;
	else {
    pos = wxPli_sv_2_wxpoint( aTHX_ ST(6) )
;
	}
    n = wxPli_av_2_stringarray( aTHX_ chs, &choices );
    RETVAL = new wxMultiChoiceDialog( parent, message, caption, n, choices,
        style, pos );
    delete[] choices;
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_object_2_sv( aTHX_ RETVALSV, RETVAL );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__MultiChoiceDialog_GetSelections); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__MultiChoiceDialog_GetSelections)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    PERL_UNUSED_VAR(ax); /* -Wall */
    SP -= items;
    {
    wxArrayInt ret;
    int i, max;
	wxMultiChoiceDialog *    THIS = (wxMultiChoiceDialog *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::MultiChoiceDialog" )
;
    ret = THIS->GetSelections();
    max = ret.GetCount();
    EXTEND( SP, max );
    for( i = 0; i < max; ++i )
    {
      PUSHs( sv_2mortal( newSViv( ret[i] ) ) );
    }
	PUTBACK;
	return;
    }
}


XS_EUPXS(XS_Wx__MultiChoiceDialog_SetSelections); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__MultiChoiceDialog_SetSelections)
{
    dVAR; dXSARGS;
    if (items < 1)
       croak_xs_usage(cv,  "THIS, ...");
    {
    wxArrayInt array;
    int i;
	wxMultiChoiceDialog *    THIS = (wxMultiChoiceDialog *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::MultiChoiceDialog" )
;
    array.Alloc( items - 1 );
    for( i = 1; i < items; ++i )
    {
      array.Add( SvIV( ST( i ) ) );
    }
    THIS->SetSelections( array );
    }
    XSRETURN_EMPTY;
}


/* INCLUDE: Returning to 'XS/SingleChoiceDialog.xs' from 'XS/MultiChoiceDialog.xs' */

#include <wx/choicdlg.h>
#include "cpp/singlechoicedialog.h"

XS_EUPXS(XS_Wx__SingleChoiceDialog_new); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__SingleChoiceDialog_new)
{
    dVAR; dXSARGS;
    if (items < 5 || items > 8)
       croak_xs_usage(cv,  "CLASS, parent, message, caption, chs, dt = &PL_sv_undef, style = wxCHOICEDLG_STYLE, pos = wxDefaultPosition");
    {
	wxWindow*    parent = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::Window" )
;
	wxString	message;
	wxString	caption;
	SV*	chs = ST(4)
;
	SV*	dt;
	long	style;
	wxPoint	pos;
    wxString* choices;
    SV** data;
    int n, n2;
	char *	CLASS = (char *)SvPV_nolen(ST(0))
;
	wxSingleChoiceDialog *	RETVAL;

    WXSTRING_INPUT( message, wxString, ST(2) )
;

    WXSTRING_INPUT( caption, wxString, ST(3) )
;

	if (items < 6)
	    dt = &PL_sv_undef;
	else {
	    dt = ST(5)
;
	}

	if (items < 7)
	    style = wxCHOICEDLG_STYLE;
	else {
	    style = (long)SvIV(ST(6))
;
	}

	if (items < 8)
	    pos = wxDefaultPosition;
	else {
    pos = wxPli_sv_2_wxpoint( aTHX_ ST(7) )
;
	}
    n = wxPli_av_2_stringarray( aTHX_ chs, &choices );
    if( !SvOK( dt ) )
    {
      RETVAL = new wxPliSingleChoiceDialog( parent, message, caption, n,
            choices, 0, style, pos );
    }
    else
    {
      n2 = wxPli_av_2_svarray( aTHX_ dt, &data );
      if( n != n2 )
      {
        delete[] choices;
        delete[] data;
        choices = 0; data = 0; n = 0;
        croak( "supplied arrays of different size" );
      }
      RETVAL = new wxPliSingleChoiceDialog( parent, message, caption, n,
            choices, data, style, pos );
      delete[] data;
    }
    delete[] choices;
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_object_2_sv( aTHX_ RETVALSV, RETVAL );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__SingleChoiceDialog_GetSelection); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__SingleChoiceDialog_GetSelection)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxSingleChoiceDialog *    THIS = (wxSingleChoiceDialog *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::SingleChoiceDialog" )
;
	int	RETVAL;
	dXSTARG;

	RETVAL = THIS->GetSelection();
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__SingleChoiceDialog_GetSelectionClientData); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__SingleChoiceDialog_GetSelectionClientData)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
    char* t;
	wxSingleChoiceDialog *    THIS = (wxSingleChoiceDialog *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::SingleChoiceDialog" )
;
	SV *	RETVAL;
    t = THIS->GetSelectionClientData();
    RETVAL = &PL_sv_undef;
    if( t )
    {
        RETVAL = (SV*)t;
    }
    SvREFCNT_inc( RETVAL );
	RETVAL = sv_2mortal(RETVAL);
	ST(0) = RETVAL;
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__SingleChoiceDialog_GetStringSelection); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__SingleChoiceDialog_GetStringSelection)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxSingleChoiceDialog *    THIS = (wxSingleChoiceDialog *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::SingleChoiceDialog" )
;
	wxString	RETVAL;

	RETVAL = THIS->GetStringSelection();
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    WXSTRING_OUTPUT( RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__SingleChoiceDialog_SetSelection); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__SingleChoiceDialog_SetSelection)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, selection");
    {
	int	selection = (int)SvIV(ST(1))
;
	wxSingleChoiceDialog *    THIS = (wxSingleChoiceDialog *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::SingleChoiceDialog" )
;

	THIS->SetSelection(selection);
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx_GetSingleChoice); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx_GetSingleChoice)
{
    dVAR; dXSARGS;
    if (items < 3 || items > 9)
       croak_xs_usage(cv,  "message, caption, chs, parent = 0, x = -1, y = -1, centre = true, width = wxCHOICE_WIDTH, height = wxCHOICE_HEIGHT");
    {
	wxString	message;
	wxString	caption;
	SV*	chs = ST(2)
;
	wxWindow*	parent;
	int	x;
	int	y;
	bool	centre;
	int	width;
	int	height;
    wxString* choices;
    int n;
	wxString	RETVAL;

    WXSTRING_INPUT( message, wxString, ST(0) )
;

    WXSTRING_INPUT( caption, wxString, ST(1) )
;

	if (items < 4)
	    parent = 0;
	else {
    parent = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(3), "Wx::Window" )
;
	}

	if (items < 5)
	    x = -1;
	else {
	    x = (int)SvIV(ST(4))
;
	}

	if (items < 6)
	    y = -1;
	else {
	    y = (int)SvIV(ST(5))
;
	}

	if (items < 7)
	    centre = true;
	else {
	    centre = (bool)SvTRUE(ST(6))
;
	}

	if (items < 8)
	    width = wxCHOICE_WIDTH;
	else {
	    width = (int)SvIV(ST(7))
;
	}

	if (items < 9)
	    height = wxCHOICE_HEIGHT;
	else {
	    height = (int)SvIV(ST(8))
;
	}
    n = wxPli_av_2_stringarray( aTHX_ chs, &choices );
    RETVAL = wxGetSingleChoice( message, caption, n, choices, parent, x, y,
        centre, width, height );
    delete[] choices;
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    WXSTRING_OUTPUT( RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx_GetSingleChoiceIndex); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx_GetSingleChoiceIndex)
{
    dVAR; dXSARGS;
    if (items < 3 || items > 9)
       croak_xs_usage(cv,  "message, caption, chs, parent = 0, x = -1, y = -1, centre = true, width = wxCHOICE_WIDTH, height = wxCHOICE_HEIGHT");
    {
	wxString	message;
	wxString	caption;
	SV*	chs = ST(2)
;
	wxWindow*	parent;
	int	x;
	int	y;
	bool	centre;
	int	width;
	int	height;
    wxString* choices;
    int n;
	int	RETVAL;
	dXSTARG;

    WXSTRING_INPUT( message, wxString, ST(0) )
;

    WXSTRING_INPUT( caption, wxString, ST(1) )
;

	if (items < 4)
	    parent = 0;
	else {
    parent = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(3), "Wx::Window" )
;
	}

	if (items < 5)
	    x = -1;
	else {
	    x = (int)SvIV(ST(4))
;
	}

	if (items < 6)
	    y = -1;
	else {
	    y = (int)SvIV(ST(5))
;
	}

	if (items < 7)
	    centre = true;
	else {
	    centre = (bool)SvTRUE(ST(6))
;
	}

	if (items < 8)
	    width = wxCHOICE_WIDTH;
	else {
	    width = (int)SvIV(ST(7))
;
	}

	if (items < 9)
	    height = wxCHOICE_HEIGHT;
	else {
	    height = (int)SvIV(ST(8))
;
	}
    n = wxPli_av_2_stringarray( aTHX_ chs, &choices );
    RETVAL = wxGetSingleChoiceIndex( message, caption, n, choices,
        parent, x, y, centre, width, height );
    delete[] choices;
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx_GetSingleChoiceData); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx_GetSingleChoiceData)
{
    dVAR; dXSARGS;
    if (items < 4 || items > 10)
       croak_xs_usage(cv,  "message, caption, chs, dt, parent = 0, x = -1, y = -1, centre = true, width = wxCHOICE_WIDTH, height = wxCHOICE_HEIGHT");
    {
	wxString	message;
	wxString	caption;
	SV*	chs = ST(2)
;
	SV*	dt = ST(3)
;
	wxWindow*	parent;
	int	x;
	int	y;
	bool	centre;
	int	width;
	int	height;
    wxString* choices;
    SV** data;
    int n, n2;
    void* rt;
	SV *	RETVAL;

    WXSTRING_INPUT( message, wxString, ST(0) )
;

    WXSTRING_INPUT( caption, wxString, ST(1) )
;

	if (items < 5)
	    parent = 0;
	else {
    parent = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(4), "Wx::Window" )
;
	}

	if (items < 6)
	    x = -1;
	else {
	    x = (int)SvIV(ST(5))
;
	}

	if (items < 7)
	    y = -1;
	else {
	    y = (int)SvIV(ST(6))
;
	}

	if (items < 8)
	    centre = true;
	else {
	    centre = (bool)SvTRUE(ST(7))
;
	}

	if (items < 9)
	    width = wxCHOICE_WIDTH;
	else {
	    width = (int)SvIV(ST(8))
;
	}

	if (items < 10)
	    height = wxCHOICE_HEIGHT;
	else {
	    height = (int)SvIV(ST(9))
;
	}
    n = wxPli_av_2_stringarray( aTHX_ chs, &choices );
    n2 = wxPli_av_2_svarray( aTHX_ dt, &data );
    if( n != n2 )
    {
      delete[] choices;
      delete[] data;
      choices = 0; data = 0; n = 0;
      croak( "supplied arrays of different sizes" );
    }
    rt = wxGetSingleChoiceData( message, caption, n, choices, (void**)data,
        parent, x, y, centre, width, height );
    RETVAL = rt ? (SV*)rt : &PL_sv_undef;
    SvREFCNT_inc( RETVAL );
    delete[] choices;
    delete[] data;
	RETVAL = sv_2mortal(RETVAL);
	ST(0) = RETVAL;
    }
    XSRETURN(1);
}


/* INCLUDE: Returning to 'XS/ProgressDialog.xs' from 'XS/SingleChoiceDialog.xs' */

#include <wx/progdlg.h>

XS_EUPXS(XS_Wx__ProgressDialog_new); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ProgressDialog_new)
{
    dVAR; dXSARGS;
    if (items < 3 || items > 6)
       croak_xs_usage(cv,  "CLASS, title, message, maximum = 100, parent = 0, style = wxPD_AUTO_HIDE|wxPD_APP_MODAL");
    {
	wxString	title;
	wxString	message;
	int	maximum;
	wxWindow*	parent;
	long	style;
	char *	CLASS = (char *)SvPV_nolen(ST(0))
;
	wxProgressDialog *	RETVAL;

    WXSTRING_INPUT( title, wxString, ST(1) )
;

    WXSTRING_INPUT( message, wxString, ST(2) )
;

	if (items < 4)
	    maximum = 100;
	else {
	    maximum = (int)SvIV(ST(3))
;
	}

	if (items < 5)
	    parent = 0;
	else {
    parent = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(4), "Wx::Window" )
;
	}

	if (items < 6)
	    style = wxPD_AUTO_HIDE|wxPD_APP_MODAL;
	else {
	    style = (long)SvIV(ST(5))
;
	}
    RETVAL = new wxProgressDialog( title, message, maximum, parent, style );
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_object_2_sv( aTHX_ RETVALSV, RETVAL );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__ProgressDialog_Resume); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ProgressDialog_Resume)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxProgressDialog *    THIS = (wxProgressDialog *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::ProgressDialog" )
;

	THIS->Resume();
    }
    XSRETURN_EMPTY;
}

#if WXPERL_W_VERSION_GE( 2, 9, 1 )
#define XSubPPtmpAABP 1


XS_EUPXS(XS_Wx__ProgressDialog_Update); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ProgressDialog_Update)
{
    dVAR; dXSARGS;
    if (items < 1 || items > 3)
       croak_xs_usage(cv,  "THIS, value = -1, newmsg = wxEmptyString");
    {
	int	value;
	wxString	newmsg;
    bool skipval = false;
	wxProgressDialog *    THIS = (wxProgressDialog *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::ProgressDialog" )
;
	bool	RETVAL;

	if (items < 2)
	    value = -1;
	else {
	    value = (int)SvIV(ST(1))
;
	}

	if (items < 3)
	    newmsg = wxEmptyString;
	else {
    WXSTRING_INPUT( newmsg, wxString, ST(2) )
;
	}
    RETVAL = THIS->Update( value, newmsg, &skipval);
    if( skipval )
        RETVAL = false;

	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__ProgressDialog_Pulse); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ProgressDialog_Pulse)
{
    dVAR; dXSARGS;
    if (items < 1 || items > 2)
       croak_xs_usage(cv,  "THIS, newmsg = wxEmptyString");
    {
	wxString	newmsg;
    bool skipval = false;    
	wxProgressDialog *    THIS = (wxProgressDialog *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::ProgressDialog" )
;
	bool	RETVAL;

	if (items < 2)
	    newmsg = wxEmptyString;
	else {
    WXSTRING_INPUT( newmsg, wxString, ST(1) )
;
	}
    RETVAL = THIS->Pulse(newmsg, &skipval);
    if( skipval )
        RETVAL = false;

	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__ProgressDialog_GetRange); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ProgressDialog_GetRange)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxProgressDialog *    THIS = (wxProgressDialog *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::ProgressDialog" )
;
	int	RETVAL;
	dXSTARG;

	RETVAL = THIS->GetRange();
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__ProgressDialog_GetValue); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ProgressDialog_GetValue)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxProgressDialog *    THIS = (wxProgressDialog *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::ProgressDialog" )
;
	int	RETVAL;
	dXSTARG;

	RETVAL = THIS->GetValue();
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__ProgressDialog_GetMessage); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ProgressDialog_GetMessage)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxProgressDialog *    THIS = (wxProgressDialog *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::ProgressDialog" )
;
	wxString	RETVAL;

	RETVAL = THIS->GetMessage();
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    WXSTRING_OUTPUT( RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__ProgressDialog_SetRange); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ProgressDialog_SetRange)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, maximum");
    {
	int	maximum = (int)SvIV(ST(1))
;
	wxProgressDialog *    THIS = (wxProgressDialog *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::ProgressDialog" )
;

	THIS->SetRange(maximum);
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__ProgressDialog_WasCancelled); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ProgressDialog_WasCancelled)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxProgressDialog *    THIS = (wxProgressDialog *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::ProgressDialog" )
;
	bool	RETVAL;

	RETVAL = THIS->WasCancelled();
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__ProgressDialog_WasSkipped); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ProgressDialog_WasSkipped)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxProgressDialog *    THIS = (wxProgressDialog *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::ProgressDialog" )
;
	bool	RETVAL;

	RETVAL = THIS->WasSkipped();
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__ProgressDialog_Show); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ProgressDialog_Show)
{
    dVAR; dXSARGS;
    if (items < 1 || items > 2)
       croak_xs_usage(cv,  "THIS, show = true");
    {
	bool	show;
	wxProgressDialog *    THIS = (wxProgressDialog *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::ProgressDialog" )
;
	bool	RETVAL;

	if (items < 2)
	    show = true;
	else {
	    show = (bool)SvTRUE(ST(1))
;
	}

	RETVAL = THIS->Show(show);
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}

#else
#define XSubPPtmpAABQ 1


XS_EUPXS(XS_Wx__ProgressDialog_Update); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ProgressDialog_Update)
{
    dVAR; dXSARGS;
    if (items < 1 || items > 3)
       croak_xs_usage(cv,  "THIS, value = -1, newmsg = wxEmptyString");
    {
	int	value;
	wxString	newmsg;
	wxProgressDialog *    THIS = (wxProgressDialog *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::ProgressDialog" )
;
	bool	RETVAL;

	if (items < 2)
	    value = -1;
	else {
	    value = (int)SvIV(ST(1))
;
	}

	if (items < 3)
	    newmsg = wxEmptyString;
	else {
    WXSTRING_INPUT( newmsg, wxString, ST(2) )
;
	}

	RETVAL = THIS->Update(value, newmsg);
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}

#if WXPERL_W_VERSION_GE( 2, 8, 0 )
#define XSubPPtmpAABR 1


XS_EUPXS(XS_Wx__ProgressDialog_Show); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ProgressDialog_Show)
{
    dVAR; dXSARGS;
    if (items < 1 || items > 2)
       croak_xs_usage(cv,  "THIS, show = true");
    {
	bool	show;
	wxProgressDialog *    THIS = (wxProgressDialog *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::ProgressDialog" )
;
	bool	RETVAL;

	if (items < 2)
	    show = true;
	else {
	    show = (bool)SvTRUE(ST(1))
;
	}

	RETVAL = THIS->Show(show);
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__ProgressDialog_Pulse); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ProgressDialog_Pulse)
{
    dVAR; dXSARGS;
    if (items < 1 || items > 2)
       croak_xs_usage(cv,  "THIS, newmsg = wxEmptyString");
    {
	wxString	newmsg;
	wxProgressDialog *    THIS = (wxProgressDialog *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::ProgressDialog" )
;
	bool	RETVAL;

	if (items < 2)
	    newmsg = wxEmptyString;
	else {
    WXSTRING_INPUT( newmsg, wxString, ST(1) )
;
	}

	RETVAL = THIS->Pulse(newmsg);
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}

#endif
#endif

/* INCLUDE: Returning to 'Frames.xs' from 'XS/ProgressDialog.xs' */


/* INCLUDE_COMMAND:  Including output of '/usr/bin/perl -I./ -MExtUtils::XSpp::Cmd -e xspp -- -t typemap.xsp XS/FindReplaceDialog.xsp' from 'Frames.xs' */

#include <exception>

#undef  xsp_constructor_class
#define xsp_constructor_class(c) (c)
#include <wx/fdrepdlg.h>

XS_EUPXS(XS_Wx__FindReplaceData_CLONE); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__FindReplaceData_CLONE)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "CLASS");
    {
	char *	CLASS = (char *)SvPV_nolen(ST(0))
;
    wxPli_thread_sv_clone( aTHX_ CLASS, (wxPliCloneSV)wxPli_detach_object );
    }
    XSRETURN_EMPTY;
}

#undef  xsp_constructor_class
#define xsp_constructor_class(c) (CLASS)

XS_EUPXS(XS_Wx__FindReplaceData_new); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__FindReplaceData_new)
{
    dVAR; dXSARGS;
    if (items < 1 || items > 2)
       croak_xs_usage(cv,  "CLASS, flags= 0");
    {
	char *	CLASS = (char *)SvPV_nolen(ST(0))
;
	wxFindReplaceData *	RETVAL;
	wxUint32	flags;

	if (items < 2)
	    flags = 0;
	else {
	    flags = (wxUint32)SvIV(ST(1))
;
	}
    try {
      RETVAL = new wxFindReplaceData( flags );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_non_object_2_sv( aTHX_ RETVALSV, RETVAL, "Wx::FindReplaceData" );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}

#undef  xsp_constructor_class
#define xsp_constructor_class(c) (c)

XS_EUPXS(XS_Wx__FindReplaceData_DESTROY); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__FindReplaceData_DESTROY)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxFindReplaceData *    THIS = (wxFindReplaceData *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::FindReplaceData" )
;
     wxPli_thread_sv_unregister( aTHX_ wxPli_get_class( aTHX_ ST(0) ), THIS, ST(0) );
                delete THIS;
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__FindReplaceData_GetFindString); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__FindReplaceData_GetFindString)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxFindReplaceData *    THIS = (wxFindReplaceData *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::FindReplaceData" )
;
	wxString	RETVAL;
    try {
      RETVAL = THIS->GetFindString();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    WXSTRING_OUTPUT( RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__FindReplaceData_GetFlags); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__FindReplaceData_GetFlags)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxFindReplaceData *    THIS = (wxFindReplaceData *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::FindReplaceData" )
;
	int	RETVAL;
	dXSTARG;
    try {
      RETVAL = THIS->GetFlags();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__FindReplaceData_GetReplaceString); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__FindReplaceData_GetReplaceString)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxFindReplaceData *    THIS = (wxFindReplaceData *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::FindReplaceData" )
;
	wxString	RETVAL;
    try {
      RETVAL = THIS->GetReplaceString();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    WXSTRING_OUTPUT( RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__FindReplaceData_SetFindString); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__FindReplaceData_SetFindString)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, str");
    {
	wxFindReplaceData *    THIS = (wxFindReplaceData *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::FindReplaceData" )
;
	wxString	str;

    WXSTRING_INPUT( str, wxString, ST(1) )
;
    try {
      THIS->SetFindString( str );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__FindReplaceData_SetFlags); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__FindReplaceData_SetFlags)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, flags");
    {
	wxFindReplaceData *    THIS = (wxFindReplaceData *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::FindReplaceData" )
;
	wxUint32	flags = (wxUint32)SvIV(ST(1))
;
    try {
      THIS->SetFlags( flags );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__FindReplaceData_SetReplaceString); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__FindReplaceData_SetReplaceString)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, str");
    {
	wxFindReplaceData *    THIS = (wxFindReplaceData *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::FindReplaceData" )
;
	wxString	str;

    WXSTRING_INPUT( str, wxString, ST(1) )
;
    try {
      THIS->SetReplaceString( str );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}

#undef  xsp_constructor_class
#define xsp_constructor_class(c) (CLASS)

XS_EUPXS(XS_Wx__FindReplaceDialog_newDefault); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__FindReplaceDialog_newDefault)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "CLASS");
    {
	char *	CLASS = (char *)SvPV_nolen(ST(0))
;
	wxFindReplaceDialog *	RETVAL;
    try {
      RETVAL = new wxFindReplaceDialog();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
     wxPli_create_evthandler( aTHX_ RETVAL, CLASS ); 
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_object_2_sv( aTHX_ RETVALSV, RETVAL );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}

#undef  xsp_constructor_class
#define xsp_constructor_class(c) (c)
#undef  xsp_constructor_class
#define xsp_constructor_class(c) (CLASS)

XS_EUPXS(XS_Wx__FindReplaceDialog_newFull); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__FindReplaceDialog_newFull)
{
    dVAR; dXSARGS;
    if (items < 4 || items > 5)
       croak_xs_usage(cv,  "CLASS, parent, data, title, style= 0");
    {
	char *	CLASS = (char *)SvPV_nolen(ST(0))
;
	wxFindReplaceDialog *	RETVAL;
	wxWindow*    parent = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::Window" )
;
	wxFindReplaceData*    data = (wxFindReplaceData *) wxPli_sv_2_object( aTHX_ ST(2), "Wx::FindReplaceData" )
;
	wxString	title;
	int	style;

    WXSTRING_INPUT( title, wxString, ST(3) )
;

	if (items < 5)
	    style = 0;
	else {
	    style = (int)SvIV(ST(4))
;
	}
    try {
      RETVAL = new wxFindReplaceDialog( parent, data, title, style );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
     wxPli_create_evthandler( aTHX_ RETVAL, CLASS ); 
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_object_2_sv( aTHX_ RETVALSV, RETVAL );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}

#undef  xsp_constructor_class
#define xsp_constructor_class(c) (c)

XS_EUPXS(XS_Wx__FindReplaceDialog_Create); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__FindReplaceDialog_Create)
{
    dVAR; dXSARGS;
    if (items < 4 || items > 5)
       croak_xs_usage(cv,  "THIS, parent, data, title, style= 0");
    {
	wxFindReplaceDialog *    THIS = (wxFindReplaceDialog *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::FindReplaceDialog" )
;
	bool	RETVAL;
	wxWindow*    parent = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::Window" )
;
	wxFindReplaceData*    data = (wxFindReplaceData *) wxPli_sv_2_object( aTHX_ ST(2), "Wx::FindReplaceData" )
;
	wxString	title;
	int	style;

    WXSTRING_INPUT( title, wxString, ST(3) )
;

	if (items < 5)
	    style = 0;
	else {
	    style = (int)SvIV(ST(4))
;
	}
    try {
      RETVAL = THIS->Create( parent, data, title, style );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__FindReplaceDialog_GetData); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__FindReplaceDialog_GetData)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxFindReplaceDialog *    THIS = (wxFindReplaceDialog *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::FindReplaceDialog" )
;
	wxFindReplaceData *	RETVAL;
     RETVAL = (wxFindReplaceData*)THIS->GetData(); 
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_non_object_2_sv( aTHX_ RETVALSV, RETVAL, "Wx::FindReplaceData" );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__FindReplaceDialog_SetData); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__FindReplaceDialog_SetData)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, data");
    {
	wxFindReplaceDialog *    THIS = (wxFindReplaceDialog *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::FindReplaceDialog" )
;
	wxFindReplaceData*    data = (wxFindReplaceData *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::FindReplaceData" )
;
    try {
      THIS->SetData( data );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}

#include "cpp/overload.h"
#if 1
#define XSubPPtmpAABS 1


XS_EUPXS(XS_Wx__FindReplaceDialog_new); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__FindReplaceDialog_new)
{
    dVAR; dXSARGS;
    if (items < 1)
       croak_xs_usage(cv,  "CLASS, ...");
    PERL_UNUSED_VAR(ax); /* -Wall */
    SP -= items;
    {
	char *	CLASS = (char *)SvPV_nolen(ST(0))
;
#if 1
    static wxPliPrototype void_proto( NULL, 0 );
#endif // 1
    static wxPliPrototype *wxPliOvl_all_prototypes[] = {
#if 1
        &void_proto,
#endif // 1
        NULL };
    BEGIN_OVERLOAD()
#if 1
        MATCH_VOIDM_REDISP( newDefault )
#endif // 1
#if 1
        MATCH_ANY_REDISP( newFull )
#endif // 1
    END_OVERLOAD_MESSAGE( Wx::FindReplaceDialog::new, wxPliOvl_all_prototypes )
	PUTBACK;
	return;
    }
}

#endif // 1

XS_EUPXS(XS_Wx__FindDialogEvent_GetDialog); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__FindDialogEvent_GetDialog)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxFindDialogEvent *    THIS = (wxFindDialogEvent *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::FindDialogEvent" )
;
	wxFindReplaceDialog *	RETVAL;
    try {
      RETVAL = THIS->GetDialog();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_object_2_sv( aTHX_ RETVALSV, RETVAL );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__FindDialogEvent_GetFindString); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__FindDialogEvent_GetFindString)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxFindDialogEvent *    THIS = (wxFindDialogEvent *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::FindDialogEvent" )
;
	wxString	RETVAL;
    try {
      RETVAL = THIS->GetFindString();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    WXSTRING_OUTPUT( RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__FindDialogEvent_GetFlags); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__FindDialogEvent_GetFlags)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxFindDialogEvent *    THIS = (wxFindDialogEvent *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::FindDialogEvent" )
;
	int	RETVAL;
	dXSTARG;
    try {
      RETVAL = THIS->GetFlags();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__FindDialogEvent_GetReplaceString); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__FindDialogEvent_GetReplaceString)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxFindDialogEvent *    THIS = (wxFindDialogEvent *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::FindDialogEvent" )
;
	wxString	RETVAL;
    try {
      RETVAL = THIS->GetReplaceString();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    WXSTRING_OUTPUT( RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


/* INCLUDE: Returning to 'Frames.xs' from '/usr/bin/perl -I./ -MExtUtils::XSpp::Cmd -e xspp -- -t typemap.xsp XS/FindReplaceDialog.xsp' */


/* INCLUDE_COMMAND:  Including output of '/usr/bin/perl -I./ -MExtUtils::XSpp::Cmd -e xspp -- -t typemap.xsp XS/AboutDialog.xsp' from 'Frames.xs' */

#include <exception>

#undef  xsp_constructor_class
#define xsp_constructor_class(c) (c)
#if WXPERL_W_VERSION_GE( 2, 7, 2 )
#define XSpp_5c2d93c5_084981
#include <wx/aboutdlg.h>
#undef  xsp_constructor_class
#define xsp_constructor_class(c) (CLASS)
#define XSubPPtmpAABT 1


XS_EUPXS(XS_Wx__AboutDialogInfo_new); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__AboutDialogInfo_new)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "CLASS");
    {
	char *	CLASS = (char *)SvPV_nolen(ST(0))
;
	wxAboutDialogInfo *	RETVAL;
    try {
      RETVAL = new wxAboutDialogInfo();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_non_object_2_sv( aTHX_ RETVALSV, RETVAL, "Wx::AboutDialogInfo" );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}

#undef  xsp_constructor_class
#define xsp_constructor_class(c) (c)

XS_EUPXS(XS_Wx__AboutDialogInfo_SetName); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__AboutDialogInfo_SetName)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, name");
    {
	wxAboutDialogInfo *    THIS = (wxAboutDialogInfo *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::AboutDialogInfo" )
;
	wxString	name;

    WXSTRING_INPUT( name, wxString, ST(1) )
;
    try {
      THIS->SetName( name );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__AboutDialogInfo_GetName); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__AboutDialogInfo_GetName)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxAboutDialogInfo *    THIS = (wxAboutDialogInfo *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::AboutDialogInfo" )
;
	wxString	RETVAL;
    try {
      RETVAL = THIS->GetName();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    WXSTRING_OUTPUT( RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__AboutDialogInfo_SetVersion); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__AboutDialogInfo_SetVersion)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, version");
    {
	wxAboutDialogInfo *    THIS = (wxAboutDialogInfo *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::AboutDialogInfo" )
;
	wxString	version;

    WXSTRING_INPUT( version, wxString, ST(1) )
;
    try {
      THIS->SetVersion( version );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__AboutDialogInfo_HasVersion); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__AboutDialogInfo_HasVersion)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxAboutDialogInfo *    THIS = (wxAboutDialogInfo *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::AboutDialogInfo" )
;
	bool	RETVAL;
    try {
      RETVAL = THIS->HasVersion();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__AboutDialogInfo_GetVersion); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__AboutDialogInfo_GetVersion)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxAboutDialogInfo *    THIS = (wxAboutDialogInfo *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::AboutDialogInfo" )
;
	wxString	RETVAL;
    try {
      RETVAL = THIS->GetVersion();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    WXSTRING_OUTPUT( RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__AboutDialogInfo_SetDescription); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__AboutDialogInfo_SetDescription)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, desc");
    {
	wxAboutDialogInfo *    THIS = (wxAboutDialogInfo *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::AboutDialogInfo" )
;
	wxString	desc;

    WXSTRING_INPUT( desc, wxString, ST(1) )
;
    try {
      THIS->SetDescription( desc );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__AboutDialogInfo_HasDescription); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__AboutDialogInfo_HasDescription)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxAboutDialogInfo *    THIS = (wxAboutDialogInfo *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::AboutDialogInfo" )
;
	bool	RETVAL;
    try {
      RETVAL = THIS->HasDescription();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__AboutDialogInfo_GetDescription); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__AboutDialogInfo_GetDescription)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxAboutDialogInfo *    THIS = (wxAboutDialogInfo *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::AboutDialogInfo" )
;
	wxString	RETVAL;
    try {
      RETVAL = THIS->GetDescription();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    WXSTRING_OUTPUT( RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__AboutDialogInfo_SetCopyright); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__AboutDialogInfo_SetCopyright)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, copyright");
    {
	wxAboutDialogInfo *    THIS = (wxAboutDialogInfo *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::AboutDialogInfo" )
;
	wxString	copyright;

    WXSTRING_INPUT( copyright, wxString, ST(1) )
;
    try {
      THIS->SetCopyright( copyright );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__AboutDialogInfo_HasCopyright); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__AboutDialogInfo_HasCopyright)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxAboutDialogInfo *    THIS = (wxAboutDialogInfo *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::AboutDialogInfo" )
;
	bool	RETVAL;
    try {
      RETVAL = THIS->HasCopyright();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__AboutDialogInfo_GetCopyright); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__AboutDialogInfo_GetCopyright)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxAboutDialogInfo *    THIS = (wxAboutDialogInfo *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::AboutDialogInfo" )
;
	wxString	RETVAL;
    try {
      RETVAL = THIS->GetCopyright();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    WXSTRING_OUTPUT( RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__AboutDialogInfo_SetLicence); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__AboutDialogInfo_SetLicence)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, licence");
    {
	wxAboutDialogInfo *    THIS = (wxAboutDialogInfo *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::AboutDialogInfo" )
;
	wxString	licence;

    WXSTRING_INPUT( licence, wxString, ST(1) )
;
    try {
      THIS->SetLicence( licence );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__AboutDialogInfo_SetLicense); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__AboutDialogInfo_SetLicense)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, licence");
    {
	wxAboutDialogInfo *    THIS = (wxAboutDialogInfo *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::AboutDialogInfo" )
;
	wxString	licence;

    WXSTRING_INPUT( licence, wxString, ST(1) )
;
    try {
      THIS->SetLicense( licence );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__AboutDialogInfo_HasLicence); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__AboutDialogInfo_HasLicence)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxAboutDialogInfo *    THIS = (wxAboutDialogInfo *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::AboutDialogInfo" )
;
	bool	RETVAL;
    try {
      RETVAL = THIS->HasLicence();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__AboutDialogInfo_GetLicence); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__AboutDialogInfo_GetLicence)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxAboutDialogInfo *    THIS = (wxAboutDialogInfo *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::AboutDialogInfo" )
;
	wxString	RETVAL;
    try {
      RETVAL = THIS->GetLicence();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    WXSTRING_OUTPUT( RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__AboutDialogInfo_SetIcon); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__AboutDialogInfo_SetIcon)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, icon");
    {
	wxAboutDialogInfo *    THIS = (wxAboutDialogInfo *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::AboutDialogInfo" )
;
	wxIcon*    icon = (wxIcon *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::Icon" )
;
    try {
      THIS->SetIcon( *( icon ) );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__AboutDialogInfo_HasIcon); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__AboutDialogInfo_HasIcon)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxAboutDialogInfo *    THIS = (wxAboutDialogInfo *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::AboutDialogInfo" )
;
	bool	RETVAL;
    try {
      RETVAL = THIS->HasIcon();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__AboutDialogInfo_GetIcon); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__AboutDialogInfo_GetIcon)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxAboutDialogInfo *    THIS = (wxAboutDialogInfo *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::AboutDialogInfo" )
;
	wxIcon *	RETVAL;
    try {
      RETVAL = new wxIcon( THIS->GetIcon() );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_object_2_sv( aTHX_ RETVALSV, RETVAL );
    wxPli_thread_sv_register( aTHX_ "Wx::Icon", RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__AboutDialogInfo_SetWebSite); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__AboutDialogInfo_SetWebSite)
{
    dVAR; dXSARGS;
    if (items < 2 || items > 3)
       croak_xs_usage(cv,  "THIS, url, desc= wxEmptyString");
    {
	wxAboutDialogInfo *    THIS = (wxAboutDialogInfo *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::AboutDialogInfo" )
;
	wxString	url;
	wxString	desc;

    WXSTRING_INPUT( url, wxString, ST(1) )
;

	if (items < 3)
	    desc = wxEmptyString;
	else {
    WXSTRING_INPUT( desc, wxString, ST(2) )
;
	}
    try {
      THIS->SetWebSite( url, desc );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__AboutDialogInfo_HasWebSite); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__AboutDialogInfo_HasWebSite)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxAboutDialogInfo *    THIS = (wxAboutDialogInfo *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::AboutDialogInfo" )
;
	bool	RETVAL;
    try {
      RETVAL = THIS->HasWebSite();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__AboutDialogInfo_GetWebSiteURL); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__AboutDialogInfo_GetWebSiteURL)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxAboutDialogInfo *    THIS = (wxAboutDialogInfo *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::AboutDialogInfo" )
;
	wxString	RETVAL;
    try {
      RETVAL = THIS->GetWebSiteURL();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    WXSTRING_OUTPUT( RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__AboutDialogInfo_GetWebSiteDescription); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__AboutDialogInfo_GetWebSiteDescription)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxAboutDialogInfo *    THIS = (wxAboutDialogInfo *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::AboutDialogInfo" )
;
	wxString	RETVAL;
    try {
      RETVAL = THIS->GetWebSiteDescription();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    WXSTRING_OUTPUT( RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__AboutDialogInfo_SetDevelopers); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__AboutDialogInfo_SetDevelopers)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, developers");
    {
	wxAboutDialogInfo *    THIS = (wxAboutDialogInfo *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::AboutDialogInfo" )
;
	wxArrayString	developers;

    wxPli_av_2_arraystring( aTHX_ ST(1), & developers )
;
    try {
      THIS->SetDevelopers( developers );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__AboutDialogInfo_AddDeveloper); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__AboutDialogInfo_AddDeveloper)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, developer");
    {
	wxAboutDialogInfo *    THIS = (wxAboutDialogInfo *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::AboutDialogInfo" )
;
	wxString	developer;

    WXSTRING_INPUT( developer, wxString, ST(1) )
;
    try {
      THIS->AddDeveloper( developer );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__AboutDialogInfo_HasDevelopers); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__AboutDialogInfo_HasDevelopers)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxAboutDialogInfo *    THIS = (wxAboutDialogInfo *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::AboutDialogInfo" )
;
	bool	RETVAL;
    try {
      RETVAL = THIS->HasDevelopers();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__AboutDialogInfo_GetDevelopers); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__AboutDialogInfo_GetDevelopers)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    PERL_UNUSED_VAR(ax); /* -Wall */
    SP -= items;
    {
	wxAboutDialogInfo *    THIS = (wxAboutDialogInfo *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::AboutDialogInfo" )
;
	wxArrayString	RETVAL;
    try {
      RETVAL = THIS->GetDevelopers();
    PUTBACK;
    wxPli_stringarray_push( aTHX_ RETVAL );
    SPAGAIN;
  ;
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	PUTBACK;
	return;
    }
}


XS_EUPXS(XS_Wx__AboutDialogInfo_SetDocWriters); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__AboutDialogInfo_SetDocWriters)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, docwriters");
    {
	wxAboutDialogInfo *    THIS = (wxAboutDialogInfo *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::AboutDialogInfo" )
;
	wxArrayString	docwriters;

    wxPli_av_2_arraystring( aTHX_ ST(1), & docwriters )
;
    try {
      THIS->SetDocWriters( docwriters );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__AboutDialogInfo_AddDocWriter); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__AboutDialogInfo_AddDocWriter)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, docwriter");
    {
	wxAboutDialogInfo *    THIS = (wxAboutDialogInfo *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::AboutDialogInfo" )
;
	wxString	docwriter;

    WXSTRING_INPUT( docwriter, wxString, ST(1) )
;
    try {
      THIS->AddDocWriter( docwriter );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__AboutDialogInfo_HasDocWriters); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__AboutDialogInfo_HasDocWriters)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxAboutDialogInfo *    THIS = (wxAboutDialogInfo *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::AboutDialogInfo" )
;
	bool	RETVAL;
    try {
      RETVAL = THIS->HasDocWriters();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__AboutDialogInfo_GetDocWriters); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__AboutDialogInfo_GetDocWriters)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    PERL_UNUSED_VAR(ax); /* -Wall */
    SP -= items;
    {
	wxAboutDialogInfo *    THIS = (wxAboutDialogInfo *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::AboutDialogInfo" )
;
	wxArrayString	RETVAL;
    try {
      RETVAL = THIS->GetDocWriters();
    PUTBACK;
    wxPli_stringarray_push( aTHX_ RETVAL );
    SPAGAIN;
  ;
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	PUTBACK;
	return;
    }
}


XS_EUPXS(XS_Wx__AboutDialogInfo_SetArtists); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__AboutDialogInfo_SetArtists)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, artists");
    {
	wxAboutDialogInfo *    THIS = (wxAboutDialogInfo *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::AboutDialogInfo" )
;
	wxArrayString	artists;

    wxPli_av_2_arraystring( aTHX_ ST(1), & artists )
;
    try {
      THIS->SetArtists( artists );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__AboutDialogInfo_AddArtist); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__AboutDialogInfo_AddArtist)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, artist");
    {
	wxAboutDialogInfo *    THIS = (wxAboutDialogInfo *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::AboutDialogInfo" )
;
	wxString	artist;

    WXSTRING_INPUT( artist, wxString, ST(1) )
;
    try {
      THIS->AddArtist( artist );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__AboutDialogInfo_HasArtists); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__AboutDialogInfo_HasArtists)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxAboutDialogInfo *    THIS = (wxAboutDialogInfo *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::AboutDialogInfo" )
;
	bool	RETVAL;
    try {
      RETVAL = THIS->HasArtists();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__AboutDialogInfo_GetArtists); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__AboutDialogInfo_GetArtists)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    PERL_UNUSED_VAR(ax); /* -Wall */
    SP -= items;
    {
	wxAboutDialogInfo *    THIS = (wxAboutDialogInfo *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::AboutDialogInfo" )
;
	wxArrayString	RETVAL;
    try {
      RETVAL = THIS->GetArtists();
    PUTBACK;
    wxPli_stringarray_push( aTHX_ RETVAL );
    SPAGAIN;
  ;
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	PUTBACK;
	return;
    }
}


XS_EUPXS(XS_Wx__AboutDialogInfo_SetTranslators); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__AboutDialogInfo_SetTranslators)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, translators");
    {
	wxAboutDialogInfo *    THIS = (wxAboutDialogInfo *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::AboutDialogInfo" )
;
	wxArrayString	translators;

    wxPli_av_2_arraystring( aTHX_ ST(1), & translators )
;
    try {
      THIS->SetTranslators( translators );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__AboutDialogInfo_AddTranslator); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__AboutDialogInfo_AddTranslator)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, translator");
    {
	wxAboutDialogInfo *    THIS = (wxAboutDialogInfo *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::AboutDialogInfo" )
;
	wxString	translator;

    WXSTRING_INPUT( translator, wxString, ST(1) )
;
    try {
      THIS->AddTranslator( translator );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__AboutDialogInfo_HasTranslators); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__AboutDialogInfo_HasTranslators)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxAboutDialogInfo *    THIS = (wxAboutDialogInfo *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::AboutDialogInfo" )
;
	bool	RETVAL;
    try {
      RETVAL = THIS->HasTranslators();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__AboutDialogInfo_GetTranslators); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__AboutDialogInfo_GetTranslators)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    PERL_UNUSED_VAR(ax); /* -Wall */
    SP -= items;
    {
	wxAboutDialogInfo *    THIS = (wxAboutDialogInfo *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::AboutDialogInfo" )
;
	wxArrayString	RETVAL;
    try {
      RETVAL = THIS->GetTranslators();
    PUTBACK;
    wxPli_stringarray_push( aTHX_ RETVAL );
    SPAGAIN;
  ;
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	PUTBACK;
	return;
    }
}


XS_EUPXS(XS_Wx_AboutBox); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx_AboutBox)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "info");
    {
	wxAboutDialogInfo*    info = (wxAboutDialogInfo *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::AboutDialogInfo" )
;
    try {
      wxAboutBox( *( info ) );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}

#endif

/* INCLUDE: Returning to 'Frames.xs' from '/usr/bin/perl -I./ -MExtUtils::XSpp::Cmd -e xspp -- -t typemap.xsp XS/AboutDialog.xsp' */


/* INCLUDE_COMMAND:  Including output of '/usr/bin/perl -I./ -MExtUtils::XSpp::Cmd -e xspp -- -t typemap.xsp XS/PropertySheetDialog.xsp' from 'Frames.xs' */

#include <exception>

#undef  xsp_constructor_class
#define xsp_constructor_class(c) (c)
#if WXPERL_W_VERSION_GE( 2, 6, 0 )
#define XSpp_dfcfcbe7_016958
#include <wx/bookctrl.h>
#include <wx/propdlg.h>
#undef  xsp_constructor_class
#define xsp_constructor_class(c) (CLASS)
#define XSubPPtmpAABU 1


XS_EUPXS(XS_Wx__PropertySheetDialog_newDefault); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__PropertySheetDialog_newDefault)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "CLASS");
    {
	char *	CLASS = (char *)SvPV_nolen(ST(0))
;
	wxPropertySheetDialog *	RETVAL;
     RETVAL = new wxPropertySheetDialog();
                wxPli_create_evthandler( aTHX_ RETVAL, CLASS );
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_object_2_sv( aTHX_ RETVALSV, RETVAL );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}

#undef  xsp_constructor_class
#define xsp_constructor_class(c) (c)
#undef  xsp_constructor_class
#define xsp_constructor_class(c) (CLASS)

XS_EUPXS(XS_Wx__PropertySheetDialog_newFull); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__PropertySheetDialog_newFull)
{
    dVAR; dXSARGS;
    if (items < 4 || items > 8)
       croak_xs_usage(cv,  "CLASS, parent, id, title, pos= wxDefaultPosition, size= wxDefaultSize, style= wxDEFAULT_DIALOG_STYLE, name= wxDialogNameStr");
    {
	char *	CLASS = (char *)SvPV_nolen(ST(0))
;
	wxPropertySheetDialog *	RETVAL;
	wxWindow*    parent = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::Window" )
;
	wxWindowID    id = wxPli_get_wxwindowid( aTHX_ ST(2) )
;
	wxString	title;
	wxPoint	pos;
	wxSize	size;
	long	style;
	wxString	name;

    WXSTRING_INPUT( title, wxString, ST(3) )
;

	if (items < 5)
	    pos = wxDefaultPosition;
	else {
    pos = wxPli_sv_2_wxpoint( aTHX_ ST(4) )
;
	}

	if (items < 6)
	    size = wxDefaultSize;
	else {
    size = wxPli_sv_2_wxsize( aTHX_ ST(5) )
;
	}

	if (items < 7)
	    style = wxDEFAULT_DIALOG_STYLE;
	else {
	    style = (long)SvIV(ST(6))
;
	}

	if (items < 8)
	    name = wxDialogNameStr;
	else {
    WXSTRING_INPUT( name, wxString, ST(7) )
;
	}
     RETVAL = new wxPropertySheetDialog( parent, id, title, pos,
                                                    size, style, name );
                wxPli_create_evthandler( aTHX_ RETVAL, CLASS );
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_object_2_sv( aTHX_ RETVALSV, RETVAL );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}

#undef  xsp_constructor_class
#define xsp_constructor_class(c) (c)

XS_EUPXS(XS_Wx__PropertySheetDialog_Create); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__PropertySheetDialog_Create)
{
    dVAR; dXSARGS;
    if (items < 4 || items > 8)
       croak_xs_usage(cv,  "THIS, parent, id, title, pos= wxDefaultPosition, size= wxDefaultSize, style= wxDEFAULT_DIALOG_STYLE, name= wxDialogNameStr");
    {
	wxPropertySheetDialog *    THIS = (wxPropertySheetDialog *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::PropertySheetDialog" )
;
	bool	RETVAL;
	wxWindow*    parent = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::Window" )
;
	wxWindowID    id = wxPli_get_wxwindowid( aTHX_ ST(2) )
;
	wxString	title;
	wxPoint	pos;
	wxSize	size;
	long	style;
	wxString	name;

    WXSTRING_INPUT( title, wxString, ST(3) )
;

	if (items < 5)
	    pos = wxDefaultPosition;
	else {
    pos = wxPli_sv_2_wxpoint( aTHX_ ST(4) )
;
	}

	if (items < 6)
	    size = wxDefaultSize;
	else {
    size = wxPli_sv_2_wxsize( aTHX_ ST(5) )
;
	}

	if (items < 7)
	    style = wxDEFAULT_DIALOG_STYLE;
	else {
	    style = (long)SvIV(ST(6))
;
	}

	if (items < 8)
	    name = wxDialogNameStr;
	else {
    WXSTRING_INPUT( name, wxString, ST(7) )
;
	}
    try {
      RETVAL = THIS->Create( parent, id, title, pos, size, style, name );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__PropertySheetDialog_SetBookCtrl); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__PropertySheetDialog_SetBookCtrl)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, book");
    {
	wxPropertySheetDialog *    THIS = (wxPropertySheetDialog *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::PropertySheetDialog" )
;
	wxBookCtrlBase*    book = (wxBookCtrlBase *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::BookCtrlBase" )
;
    try {
      THIS->SetBookCtrl( book );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__PropertySheetDialog_GetBookCtrl); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__PropertySheetDialog_GetBookCtrl)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxPropertySheetDialog *    THIS = (wxPropertySheetDialog *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::PropertySheetDialog" )
;
	wxBookCtrlBase *	RETVAL;
    try {
      RETVAL = THIS->GetBookCtrl();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_evthandler_2_sv( aTHX_ RETVALSV, RETVAL );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__PropertySheetDialog_SetInnerSize); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__PropertySheetDialog_SetInnerSize)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, sizer");
    {
	wxPropertySheetDialog *    THIS = (wxPropertySheetDialog *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::PropertySheetDialog" )
;
	wxSizer*    sizer = (wxSizer *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::Sizer" )
;
    try {
      THIS->SetInnerSize( sizer );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__PropertySheetDialog_GetInnerSizer); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__PropertySheetDialog_GetInnerSizer)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxPropertySheetDialog *    THIS = (wxPropertySheetDialog *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::PropertySheetDialog" )
;
	wxSizer *	RETVAL;
    try {
      RETVAL = THIS->GetInnerSizer();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_object_2_sv( aTHX_ RETVALSV, RETVAL );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}

#if WXPERL_W_VERSION_GE( 2, 7, 2 )
#define XSpp_dfcfcbe7_074074
#define XSubPPtmpAABV 1


XS_EUPXS(XS_Wx__PropertySheetDialog_SetSheetStyle); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__PropertySheetDialog_SetSheetStyle)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, sheetStyle");
    {
	wxPropertySheetDialog *    THIS = (wxPropertySheetDialog *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::PropertySheetDialog" )
;
	long	sheetStyle = (long)SvIV(ST(1))
;
    try {
      THIS->SetSheetStyle( sheetStyle );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__PropertySheetDialog_GetSheetStyle); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__PropertySheetDialog_GetSheetStyle)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxPropertySheetDialog *    THIS = (wxPropertySheetDialog *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::PropertySheetDialog" )
;
	long	RETVAL;
	dXSTARG;
    try {
      RETVAL = THIS->GetSheetStyle();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__PropertySheetDialog_SetSheetOuterBorder); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__PropertySheetDialog_SetSheetOuterBorder)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, border");
    {
	wxPropertySheetDialog *    THIS = (wxPropertySheetDialog *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::PropertySheetDialog" )
;
	int	border = (int)SvIV(ST(1))
;
    try {
      THIS->SetSheetOuterBorder( border );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__PropertySheetDialog_GetSheetOuterBorder); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__PropertySheetDialog_GetSheetOuterBorder)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxPropertySheetDialog *    THIS = (wxPropertySheetDialog *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::PropertySheetDialog" )
;
	int	RETVAL;
	dXSTARG;
    try {
      RETVAL = THIS->GetSheetOuterBorder();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__PropertySheetDialog_SetSheetInnerBorder); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__PropertySheetDialog_SetSheetInnerBorder)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, border");
    {
	wxPropertySheetDialog *    THIS = (wxPropertySheetDialog *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::PropertySheetDialog" )
;
	int	border = (int)SvIV(ST(1))
;
    try {
      THIS->SetSheetInnerBorder( border );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__PropertySheetDialog_GetSheetInnerBorder); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__PropertySheetDialog_GetSheetInnerBorder)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxPropertySheetDialog *    THIS = (wxPropertySheetDialog *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::PropertySheetDialog" )
;
	int	RETVAL;
	dXSTARG;
    try {
      RETVAL = THIS->GetSheetInnerBorder();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}

#endif
#define wxPLI_OK_CANCEL wxOK|wxCANCEL

XS_EUPXS(XS_Wx__PropertySheetDialog_CreateButtons); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__PropertySheetDialog_CreateButtons)
{
    dVAR; dXSARGS;
    if (items < 1 || items > 2)
       croak_xs_usage(cv,  "THIS, flags= wxPLI_OK_CANCEL");
    {
	wxPropertySheetDialog *    THIS = (wxPropertySheetDialog *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::PropertySheetDialog" )
;
	int	flags;

	if (items < 2)
	    flags = wxPLI_OK_CANCEL;
	else {
	    flags = (int)SvIV(ST(1))
;
	}
    try {
      THIS->CreateButtons( flags );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}

#if WXPERL_W_VERSION_GE( 2, 7, 2 )
#define XSpp_dfcfcbe7_017943
#define XSubPPtmpAABW 1


XS_EUPXS(XS_Wx__PropertySheetDialog_LayoutDialog); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__PropertySheetDialog_LayoutDialog)
{
    dVAR; dXSARGS;
    if (items < 1 || items > 2)
       croak_xs_usage(cv,  "THIS, centreFlags= wxBOTH");
    {
	wxPropertySheetDialog *    THIS = (wxPropertySheetDialog *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::PropertySheetDialog" )
;
	int	centreFlags;

	if (items < 2)
	    centreFlags = wxBOTH;
	else {
	    centreFlags = (int)SvIV(ST(1))
;
	}
    try {
      THIS->LayoutDialog( centreFlags );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}

#else
#define XSpp_dfcfcbe7_099582
#define XSubPPtmpAABX 1


XS_EUPXS(XS_Wx__PropertySheetDialog_LayoutDialog); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__PropertySheetDialog_LayoutDialog)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxPropertySheetDialog *    THIS = (wxPropertySheetDialog *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::PropertySheetDialog" )
;
    try {
      THIS->LayoutDialog();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}

#endif
#endif

/* INCLUDE: Returning to 'Frames.xs' from '/usr/bin/perl -I./ -MExtUtils::XSpp::Cmd -e xspp -- -t typemap.xsp XS/PropertySheetDialog.xsp' */

#ifdef __cplusplus
extern "C"
#endif
XS_EXTERNAL(boot_Wx_Wnd); /* prototype to pass -Wmissing-prototypes */
XS_EXTERNAL(boot_Wx_Wnd)
{
#if PERL_VERSION_LE(5, 21, 5)
    dVAR; dXSARGS;
#else
    dVAR; dXSBOOTARGSXSAPIVERCHK;
#endif
#if PERL_VERSION_LE(5, 8, 999) /* PERL_VERSION_LT is 5.33+ */
    char* file = __FILE__;
#else
    const char* file = __FILE__;
#endif

    PERL_UNUSED_VAR(file);

    PERL_UNUSED_VAR(cv); /* -W */
    PERL_UNUSED_VAR(items); /* -W */
#if PERL_VERSION_LE(5, 21, 5)
    XS_VERSION_BOOTCHECK;
#  ifdef XS_APIVERSION_BOOTCHECK
    XS_APIVERSION_BOOTCHECK;
#  endif
#endif

        newXS_deffile("Wx::Panel::new", XS_Wx__Panel_new);
        newXS_deffile("Wx::Panel::newDefault", XS_Wx__Panel_newDefault);
        newXS_deffile("Wx::Panel::newFull", XS_Wx__Panel_newFull);
        newXS_deffile("Wx::Panel::Create", XS_Wx__Panel_Create);
#if XSubPPtmpAAAA
        newXS_deffile("Wx::Panel::SetFocusIgnoringChildren", XS_Wx__Panel_SetFocusIgnoringChildren);
#endif
        newXS_deffile("Wx::Panel::TransferDataFromWindow", XS_Wx__Panel_TransferDataFromWindow);
        newXS_deffile("Wx::Panel::TransferDataToWindow", XS_Wx__Panel_TransferDataToWindow);
        newXS_deffile("Wx::Panel::Validate", XS_Wx__Panel_Validate);
#if XSubPPtmpAAAB
        newXS_deffile("Wx::Dialog::SetAffirmativeId", XS_Wx__Dialog_SetAffirmativeId);
        newXS_deffile("Wx::Dialog::GetAffirmativeId", XS_Wx__Dialog_GetAffirmativeId);
        newXS_deffile("Wx::Dialog::GetEscapeId", XS_Wx__Dialog_GetEscapeId);
#endif
#if XSubPPtmpAAAC
        newXS_deffile("Wx::Dialog::SetEscapeId", XS_Wx__Dialog_SetEscapeId);
#endif
        newXS_deffile("Wx::Dialog::CreateTextSizer", XS_Wx__Dialog_CreateTextSizer);
        newXS_deffile("Wx::Dialog::CreateButtonSizer", XS_Wx__Dialog_CreateButtonSizer);
#if XSubPPtmpAAAD
        newXS_deffile("Wx::Dialog::CreateSeparatedButtonSizer", XS_Wx__Dialog_CreateSeparatedButtonSizer);
#endif
#if XSubPPtmpAAAE
        newXS_deffile("Wx::Dialog::CreateStdDialogButtonSizer", XS_Wx__Dialog_CreateStdDialogButtonSizer);
#endif
#if XSubPPtmpAAAF
        newXS_deffile("Wx::Dialog::AddMainButtonId", XS_Wx__Dialog_AddMainButtonId);
        newXS_deffile("Wx::Dialog::IsMainButtonId", XS_Wx__Dialog_IsMainButtonId);
        newXS_deffile("Wx::Dialog::GetMainButtonIds", XS_Wx__Dialog_GetMainButtonIds);
        newXS_deffile("Wx::Dialog::CanDoLayoutAdaptation", XS_Wx__Dialog_CanDoLayoutAdaptation);
        newXS_deffile("Wx::Dialog::IsLayoutAdaptationEnabled", XS_Wx__Dialog_IsLayoutAdaptationEnabled);
        newXS_deffile("Wx::Dialog::EnableLayoutAdaptation", XS_Wx__Dialog_EnableLayoutAdaptation);
        newXS_deffile("Wx::Dialog::GetContentWindow", XS_Wx__Dialog_GetContentWindow);
        newXS_deffile("Wx::Dialog::SetLayoutAdaptationLevel", XS_Wx__Dialog_SetLayoutAdaptationLevel);
        newXS_deffile("Wx::Dialog::GetLayoutAdaptationLevel", XS_Wx__Dialog_GetLayoutAdaptationLevel);
        newXS_deffile("Wx::Dialog::SetLayoutAdaptationMode", XS_Wx__Dialog_SetLayoutAdaptationMode);
        newXS_deffile("Wx::Dialog::GetLayoutAdaptationMode", XS_Wx__Dialog_GetLayoutAdaptationMode);
        newXS_deffile("Wx::Dialog::SetLayoutAdaptationDone", XS_Wx__Dialog_SetLayoutAdaptationDone);
        newXS_deffile("Wx::Dialog::GetLayoutAdaptationDone", XS_Wx__Dialog_GetLayoutAdaptationDone);
#if XSubPPtmpAAAG
        newXS_deffile("Wx::Dialog::GetToolBar", XS_Wx__Dialog_GetToolBar);
#endif
#endif
        newXS_deffile("Wx::Dialog::new", XS_Wx__Dialog_new);
        newXS_deffile("Wx::Dialog::newDefault", XS_Wx__Dialog_newDefault);
        newXS_deffile("Wx::Dialog::newFull", XS_Wx__Dialog_newFull);
        newXS_deffile("Wx::Dialog::Create", XS_Wx__Dialog_Create);
        newXS_deffile("Wx::Dialog::EndModal", XS_Wx__Dialog_EndModal);
        newXS_deffile("Wx::Dialog::GetReturnCode", XS_Wx__Dialog_GetReturnCode);
        newXS_deffile("Wx::Dialog::GetTitle", XS_Wx__Dialog_GetTitle);
        newXS_deffile("Wx::Dialog::IsModal", XS_Wx__Dialog_IsModal);
        newXS_deffile("Wx::Dialog::SetIcon", XS_Wx__Dialog_SetIcon);
        newXS_deffile("Wx::Dialog::SetIcons", XS_Wx__Dialog_SetIcons);
        newXS_deffile("Wx::Dialog::SetReturnCode", XS_Wx__Dialog_SetReturnCode);
        newXS_deffile("Wx::Dialog::SetTitle", XS_Wx__Dialog_SetTitle);
        newXS_deffile("Wx::Dialog::ShowModal", XS_Wx__Dialog_ShowModal);
#if XSubPPtmpAAAH
        newXS_deffile("Wx::Dialog::SetFocusIgnoringChildren", XS_Wx__Dialog_SetFocusIgnoringChildren);
#endif
        newXS_deffile("Wx::Dialog::TransferDataFromWindow", XS_Wx__Dialog_TransferDataFromWindow);
        newXS_deffile("Wx::Dialog::TransferDataToWindow", XS_Wx__Dialog_TransferDataToWindow);
        newXS_deffile("Wx::Dialog::Validate", XS_Wx__Dialog_Validate);
        newXS_deffile("Wx::Wizard::new", XS_Wx__Wizard_new);
        newXS_deffile("Wx::Wizard::newEmpty", XS_Wx__Wizard_newEmpty);
        newXS_deffile("Wx::Wizard::newFull", XS_Wx__Wizard_newFull);
        newXS_deffile("Wx::Wizard::Create", XS_Wx__Wizard_Create);
        newXS_deffile("Wx::Wizard::RunWizard", XS_Wx__Wizard_RunWizard);
        newXS_deffile("Wx::Wizard::GetCurrentPage", XS_Wx__Wizard_GetCurrentPage);
        newXS_deffile("Wx::Wizard::GetPageSize", XS_Wx__Wizard_GetPageSize);
        newXS_deffile("Wx::Wizard::SetPageSize", XS_Wx__Wizard_SetPageSize);
#if XSubPPtmpAAAI
        newXS_deffile("Wx::Wizard::GetPageAreaSizer", XS_Wx__Wizard_GetPageAreaSizer);
#endif
#if XSubPPtmpAAAJ
        newXS_deffile("Wx::Wizard::GetBitmap", XS_Wx__Wizard_GetBitmap);
        newXS_deffile("Wx::Wizard::SetBitmap", XS_Wx__Wizard_SetBitmap);
#endif
        newXS_deffile("Wx::Wizard::FitToPage", XS_Wx__Wizard_FitToPage);
        newXS_deffile("Wx::Wizard::SetBorder", XS_Wx__Wizard_SetBorder);
        newXS_deffile("Wx::Wizard::HasNextPage", XS_Wx__Wizard_HasNextPage);
        newXS_deffile("Wx::Wizard::HasPrevPage", XS_Wx__Wizard_HasPrevPage);
#if XSubPPtmpAAAK
        newXS_deffile("Wx::Wizard::SetBitmapBackgroundColour", XS_Wx__Wizard_SetBitmapBackgroundColour);
        newXS_deffile("Wx::Wizard::GetBitmapBackgroundColour", XS_Wx__Wizard_GetBitmapBackgroundColour);
        newXS_deffile("Wx::Wizard::SetBitmapPlacement", XS_Wx__Wizard_SetBitmapPlacement);
        newXS_deffile("Wx::Wizard::GetBitmapPlacement", XS_Wx__Wizard_GetBitmapPlacement);
        newXS_deffile("Wx::Wizard::SetMinimumBitmapWidth", XS_Wx__Wizard_SetMinimumBitmapWidth);
        newXS_deffile("Wx::Wizard::GetMinimumBitmapWidth", XS_Wx__Wizard_GetMinimumBitmapWidth);
#endif
        newXS_deffile("Wx::WizardPage::new", XS_Wx__WizardPage_new);
        newXS_deffile("Wx::WizardPage::newEmpty", XS_Wx__WizardPage_newEmpty);
        newXS_deffile("Wx::WizardPage::newFull", XS_Wx__WizardPage_newFull);
        newXS_deffile("Wx::WizardPage::Create", XS_Wx__WizardPage_Create);
        newXS_deffile("Wx::WizardPage::GetBitmap", XS_Wx__WizardPage_GetBitmap);
        newXS_deffile("Wx::WizardPage::GetPrev", XS_Wx__WizardPage_GetPrev);
        newXS_deffile("Wx::WizardPage::GetNext", XS_Wx__WizardPage_GetNext);
        newXS_deffile("Wx::WizardPageSimple::new", XS_Wx__WizardPageSimple_new);
        newXS_deffile("Wx::WizardPageSimple::SetPrev", XS_Wx__WizardPageSimple_SetPrev);
        newXS_deffile("Wx::WizardPageSimple::SetNext", XS_Wx__WizardPageSimple_SetNext);
        newXS_deffile("Wx::WizardPageSimple::Chain", XS_Wx__WizardPageSimple_Chain);
        newXS_deffile("Wx::WizardEvent::GetDirection", XS_Wx__WizardEvent_GetDirection);
        newXS_deffile("Wx::WizardEvent::GetPage", XS_Wx__WizardEvent_GetPage);
        newXS_deffile("Wx::ToolBarToolBase::Destroy", XS_Wx__ToolBarToolBase_Destroy);
        newXS_deffile("Wx::ToolBarToolBase::GetId", XS_Wx__ToolBarToolBase_GetId);
        newXS_deffile("Wx::ToolBarToolBase::GetControl", XS_Wx__ToolBarToolBase_GetControl);
        newXS_deffile("Wx::ToolBarToolBase::GetToolBar", XS_Wx__ToolBarToolBase_GetToolBar);
        newXS_deffile("Wx::ToolBarToolBase::IsButton", XS_Wx__ToolBarToolBase_IsButton);
        newXS_deffile("Wx::ToolBarToolBase::IsControl", XS_Wx__ToolBarToolBase_IsControl);
        newXS_deffile("Wx::ToolBarToolBase::IsSeparator", XS_Wx__ToolBarToolBase_IsSeparator);
        newXS_deffile("Wx::ToolBarToolBase::GetStyle", XS_Wx__ToolBarToolBase_GetStyle);
        newXS_deffile("Wx::ToolBarToolBase::GetKind", XS_Wx__ToolBarToolBase_GetKind);
        newXS_deffile("Wx::ToolBarToolBase::IsEnabled", XS_Wx__ToolBarToolBase_IsEnabled);
        newXS_deffile("Wx::ToolBarToolBase::IsToggled", XS_Wx__ToolBarToolBase_IsToggled);
        newXS_deffile("Wx::ToolBarToolBase::CanBeToggled", XS_Wx__ToolBarToolBase_CanBeToggled);
        newXS_deffile("Wx::ToolBarToolBase::GetNormalBitmap", XS_Wx__ToolBarToolBase_GetNormalBitmap);
        newXS_deffile("Wx::ToolBarToolBase::GetDisabledBitmap", XS_Wx__ToolBarToolBase_GetDisabledBitmap);
        newXS_deffile("Wx::ToolBarToolBase::GetBitmap1", XS_Wx__ToolBarToolBase_GetBitmap1);
        newXS_deffile("Wx::ToolBarToolBase::GetBitmap2", XS_Wx__ToolBarToolBase_GetBitmap2);
        newXS_deffile("Wx::ToolBarToolBase::GetBitmap", XS_Wx__ToolBarToolBase_GetBitmap);
        newXS_deffile("Wx::ToolBarToolBase::GetLabel", XS_Wx__ToolBarToolBase_GetLabel);
        newXS_deffile("Wx::ToolBarToolBase::GetShortHelp", XS_Wx__ToolBarToolBase_GetShortHelp);
        newXS_deffile("Wx::ToolBarToolBase::GetLongHelp", XS_Wx__ToolBarToolBase_GetLongHelp);
        newXS_deffile("Wx::ToolBarToolBase::GetClientData", XS_Wx__ToolBarToolBase_GetClientData);
        newXS_deffile("Wx::ToolBarToolBase::Enable", XS_Wx__ToolBarToolBase_Enable);
        newXS_deffile("Wx::ToolBarToolBase::Toggle", XS_Wx__ToolBarToolBase_Toggle);
        newXS_deffile("Wx::ToolBarToolBase::SetToggle", XS_Wx__ToolBarToolBase_SetToggle);
        newXS_deffile("Wx::ToolBarToolBase::SetShortHelp", XS_Wx__ToolBarToolBase_SetShortHelp);
        newXS_deffile("Wx::ToolBarToolBase::SetLongHelp", XS_Wx__ToolBarToolBase_SetLongHelp);
        newXS_deffile("Wx::ToolBarToolBase::SetNormalBitmap", XS_Wx__ToolBarToolBase_SetNormalBitmap);
        newXS_deffile("Wx::ToolBarToolBase::SetDisabledBitmap", XS_Wx__ToolBarToolBase_SetDisabledBitmap);
        newXS_deffile("Wx::ToolBarToolBase::SetLabel", XS_Wx__ToolBarToolBase_SetLabel);
        newXS_deffile("Wx::ToolBarToolBase::SetBitmap1", XS_Wx__ToolBarToolBase_SetBitmap1);
        newXS_deffile("Wx::ToolBarToolBase::SetBitmap2", XS_Wx__ToolBarToolBase_SetBitmap2);
        newXS_deffile("Wx::ToolBarToolBase::SetClientData", XS_Wx__ToolBarToolBase_SetClientData);
#if XSubPPtmpAAAL
        newXS_deffile("Wx::ToolBarToolBase::SetDropdownMenu", XS_Wx__ToolBarToolBase_SetDropdownMenu);
        newXS_deffile("Wx::ToolBarToolBase::GetDropdownMenu", XS_Wx__ToolBarToolBase_GetDropdownMenu);
#endif
        newXS_deffile("Wx::ToolBarBase::Destroy", XS_Wx__ToolBarBase_Destroy);
        newXS_deffile("Wx::ToolBarBase::AddControl", XS_Wx__ToolBarBase_AddControl);
        newXS_deffile("Wx::ToolBarBase::AddSeparator", XS_Wx__ToolBarBase_AddSeparator);
        newXS_deffile("Wx::ToolBarBase::AddTool", XS_Wx__ToolBarBase_AddTool);
        newXS_deffile("Wx::ToolBarBase::AddToolShort", XS_Wx__ToolBarBase_AddToolShort);
        newXS_deffile("Wx::ToolBarBase::AddToolLong", XS_Wx__ToolBarBase_AddToolLong);
        newXS_deffile("Wx::ToolBarBase::AddToolNewLong", XS_Wx__ToolBarBase_AddToolNewLong);
        newXS_deffile("Wx::ToolBarBase::AddToolNewShort", XS_Wx__ToolBarBase_AddToolNewShort);
        newXS_deffile("Wx::ToolBarBase::AddCheckTool", XS_Wx__ToolBarBase_AddCheckTool);
        newXS_deffile("Wx::ToolBarBase::AddRadioTool", XS_Wx__ToolBarBase_AddRadioTool);
        newXS_deffile("Wx::ToolBarBase::DeleteTool", XS_Wx__ToolBarBase_DeleteTool);
        newXS_deffile("Wx::ToolBarBase::DeleteToolByPos", XS_Wx__ToolBarBase_DeleteToolByPos);
        newXS_deffile("Wx::ToolBarBase::EnableTool", XS_Wx__ToolBarBase_EnableTool);
#if XSubPPtmpAAAM
        newXS_deffile("Wx::ToolBarBase::FindById", XS_Wx__ToolBarBase_FindById);
#endif
        newXS_deffile("Wx::ToolBarBase::FindControl", XS_Wx__ToolBarBase_FindControl);
        newXS_deffile("Wx::ToolBarBase::FindToolForPosition", XS_Wx__ToolBarBase_FindToolForPosition);
        newXS_deffile("Wx::ToolBarBase::GetMargins", XS_Wx__ToolBarBase_GetMargins);
        newXS_deffile("Wx::ToolBarBase::GetMaxRows", XS_Wx__ToolBarBase_GetMaxRows);
        newXS_deffile("Wx::ToolBarBase::GetMaxCols", XS_Wx__ToolBarBase_GetMaxCols);
        newXS_deffile("Wx::ToolBarBase::GetToolSize", XS_Wx__ToolBarBase_GetToolSize);
        newXS_deffile("Wx::ToolBarBase::GetToolBitmapSize", XS_Wx__ToolBarBase_GetToolBitmapSize);
        newXS_deffile("Wx::ToolBarBase::GetToolClientData", XS_Wx__ToolBarBase_GetToolClientData);
        newXS_deffile("Wx::ToolBarBase::GetToolEnabled", XS_Wx__ToolBarBase_GetToolEnabled);
        newXS_deffile("Wx::ToolBarBase::GetToolLongHelp", XS_Wx__ToolBarBase_GetToolLongHelp);
        newXS_deffile("Wx::ToolBarBase::GetToolPacking", XS_Wx__ToolBarBase_GetToolPacking);
        newXS_deffile("Wx::ToolBarBase::GetToolSeparation", XS_Wx__ToolBarBase_GetToolSeparation);
        newXS_deffile("Wx::ToolBarBase::GetToolShortHelp", XS_Wx__ToolBarBase_GetToolShortHelp);
        newXS_deffile("Wx::ToolBarBase::GetToolState", XS_Wx__ToolBarBase_GetToolState);
        newXS_deffile("Wx::ToolBarBase::InsertControl", XS_Wx__ToolBarBase_InsertControl);
        newXS_deffile("Wx::ToolBarBase::InsertSeparator", XS_Wx__ToolBarBase_InsertSeparator);
        newXS_deffile("Wx::ToolBarBase::InsertTool", XS_Wx__ToolBarBase_InsertTool);
        newXS_deffile("Wx::ToolBarBase::InsertToolLong", XS_Wx__ToolBarBase_InsertToolLong);
#if XSubPPtmpAAAN
        newXS_deffile("Wx::ToolBarBase::InsertToolNewLong", XS_Wx__ToolBarBase_InsertToolNewLong);
#endif
        newXS_deffile("Wx::ToolBarBase::ClearTools", XS_Wx__ToolBarBase_ClearTools);
        newXS_deffile("Wx::ToolBarBase::GetToolsCount", XS_Wx__ToolBarBase_GetToolsCount);
        newXS_deffile("Wx::ToolBarBase::GetToolPos", XS_Wx__ToolBarBase_GetToolPos);
        newXS_deffile("Wx::ToolBarBase::Realize", XS_Wx__ToolBarBase_Realize);
        newXS_deffile("Wx::ToolBarBase::RemoveTool", XS_Wx__ToolBarBase_RemoveTool);
        newXS_deffile("Wx::ToolBarBase::SetMarginsSize", XS_Wx__ToolBarBase_SetMarginsSize);
        newXS_deffile("Wx::ToolBarBase::SetMarginsXY", XS_Wx__ToolBarBase_SetMarginsXY);
        newXS_deffile("Wx::ToolBarBase::SetMargins", XS_Wx__ToolBarBase_SetMargins);
        newXS_deffile("Wx::ToolBarBase::SetMaxRowsCols", XS_Wx__ToolBarBase_SetMaxRowsCols);
        newXS_deffile("Wx::ToolBarBase::SetRows", XS_Wx__ToolBarBase_SetRows);
        newXS_deffile("Wx::ToolBarBase::SetToolBitmapSize", XS_Wx__ToolBarBase_SetToolBitmapSize);
        newXS_deffile("Wx::ToolBarBase::SetToolClientData", XS_Wx__ToolBarBase_SetToolClientData);
        newXS_deffile("Wx::ToolBarBase::SetToolLongHelp", XS_Wx__ToolBarBase_SetToolLongHelp);
        newXS_deffile("Wx::ToolBarBase::SetToolPacking", XS_Wx__ToolBarBase_SetToolPacking);
        newXS_deffile("Wx::ToolBarBase::SetToolShortHelp", XS_Wx__ToolBarBase_SetToolShortHelp);
        newXS_deffile("Wx::ToolBarBase::SetToolSeparation", XS_Wx__ToolBarBase_SetToolSeparation);
#if XSubPPtmpAAAO
        newXS_deffile("Wx::ToolBarBase::SetToolNormalBitmap", XS_Wx__ToolBarBase_SetToolNormalBitmap);
        newXS_deffile("Wx::ToolBarBase::SetToolDisabledBitmap", XS_Wx__ToolBarBase_SetToolDisabledBitmap);
#endif
        newXS_deffile("Wx::ToolBarBase::ToggleTool", XS_Wx__ToolBarBase_ToggleTool);
#if XSubPPtmpAAAP
        newXS_deffile("Wx::ToolBarBase::SetDropdownMenu", XS_Wx__ToolBarBase_SetDropdownMenu);
#endif
        newXS_deffile("Wx::ToolBar::new", XS_Wx__ToolBar_new);
        newXS_deffile("Wx::ToolBar::newDefault", XS_Wx__ToolBar_newDefault);
        newXS_deffile("Wx::ToolBar::newFull", XS_Wx__ToolBar_newFull);
        newXS_deffile("Wx::ToolBar::Create", XS_Wx__ToolBar_Create);
        newXS_deffile("Wx::StatusBar::new", XS_Wx__StatusBar_new);
        newXS_deffile("Wx::StatusBar::GetFieldRect", XS_Wx__StatusBar_GetFieldRect);
        newXS_deffile("Wx::StatusBar::GetFieldsCount", XS_Wx__StatusBar_GetFieldsCount);
        newXS_deffile("Wx::StatusBar::GetStatusText", XS_Wx__StatusBar_GetStatusText);
        newXS_deffile("Wx::StatusBar::PushStatusText", XS_Wx__StatusBar_PushStatusText);
        newXS_deffile("Wx::StatusBar::PopStatusText", XS_Wx__StatusBar_PopStatusText);
        newXS_deffile("Wx::StatusBar::SetFieldsCount", XS_Wx__StatusBar_SetFieldsCount);
        newXS_deffile("Wx::StatusBar::SetMinHeight", XS_Wx__StatusBar_SetMinHeight);
        newXS_deffile("Wx::StatusBar::SetStatusText", XS_Wx__StatusBar_SetStatusText);
        newXS_deffile("Wx::StatusBar::SetStatusWidths", XS_Wx__StatusBar_SetStatusWidths);
#if XSubPPtmpAAAQ
        newXS_deffile("Wx::StatusBar::SetStatusStyles", XS_Wx__StatusBar_SetStatusStyles);
#endif
        newXS_deffile("Wx::Frame::new", XS_Wx__Frame_new);
        newXS_deffile("Wx::Frame::newDefault", XS_Wx__Frame_newDefault);
        newXS_deffile("Wx::Frame::newFull", XS_Wx__Frame_newFull);
        newXS_deffile("Wx::Frame::Create", XS_Wx__Frame_Create);
#if XSubPPtmpAAAR
        newXS_deffile("Wx::Frame::ProcessCommand", XS_Wx__Frame_ProcessCommand);
#endif
        newXS_deffile("Wx::Frame::CreateStatusBar", XS_Wx__Frame_CreateStatusBar);
        newXS_deffile("Wx::Frame::CreateToolBar", XS_Wx__Frame_CreateToolBar);
        newXS_deffile("Wx::Frame::GetClientAreaOrigin", XS_Wx__Frame_GetClientAreaOrigin);
        newXS_deffile("Wx::Frame::GetMenuBar", XS_Wx__Frame_GetMenuBar);
        newXS_deffile("Wx::Frame::GetStatusBar", XS_Wx__Frame_GetStatusBar);
        newXS_deffile("Wx::Frame::GetStatusBarPane", XS_Wx__Frame_GetStatusBarPane);
        newXS_deffile("Wx::Frame::GetTitle", XS_Wx__Frame_GetTitle);
        newXS_deffile("Wx::Frame::GetToolBar", XS_Wx__Frame_GetToolBar);
#if XSubPPtmpAAAS
        newXS_deffile("Wx::Frame::MacSetMetalAppearance", XS_Wx__Frame_MacSetMetalAppearance);
#endif
        newXS_deffile("Wx::Frame::OnCreateStatusBar", XS_Wx__Frame_OnCreateStatusBar);
        newXS_deffile("Wx::Frame::SendSizeEvent", XS_Wx__Frame_SendSizeEvent);
        newXS_deffile("Wx::Frame::SetIcon", XS_Wx__Frame_SetIcon);
        newXS_deffile("Wx::Frame::SetIcons", XS_Wx__Frame_SetIcons);
        newXS_deffile("Wx::Frame::SetMenuBar", XS_Wx__Frame_SetMenuBar);
        newXS_deffile("Wx::Frame::SetStatusBar", XS_Wx__Frame_SetStatusBar);
        newXS_deffile("Wx::Frame::SetTitle", XS_Wx__Frame_SetTitle);
        newXS_deffile("Wx::Frame::SetToolBar", XS_Wx__Frame_SetToolBar);
        newXS_deffile("Wx::Frame::SetStatusText", XS_Wx__Frame_SetStatusText);
        newXS_deffile("Wx::Frame::SetStatusBarPane", XS_Wx__Frame_SetStatusBarPane);
        newXS_deffile("Wx::Frame::SetStatusWidths", XS_Wx__Frame_SetStatusWidths);
#if XSubPPtmpAAAT
        newXS_deffile("Wx::MiniFrame::new", XS_Wx__MiniFrame_new);
#endif
        newXS_deffile("Wx::IconBundle::newEmpty", XS_Wx__IconBundle_newEmpty);
        newXS_deffile("Wx::IconBundle::newFile", XS_Wx__IconBundle_newFile);
        newXS_deffile("Wx::IconBundle::newIcon", XS_Wx__IconBundle_newIcon);
        newXS_deffile("Wx::IconBundle::AddIconFile", XS_Wx__IconBundle_AddIconFile);
        newXS_deffile("Wx::IconBundle::AddIconIcon", XS_Wx__IconBundle_AddIconIcon);
        newXS_deffile("Wx::IconBundle::GetIconSize", XS_Wx__IconBundle_GetIconSize);
        newXS_deffile("Wx::IconBundle::GetIconCoord", XS_Wx__IconBundle_GetIconCoord);
#if XSubPPtmpAAAU
        newXS_deffile("Wx::IconBundle::IsEmpty", XS_Wx__IconBundle_IsEmpty);
        newXS_deffile("Wx::IconBundle::GetIconOfExactSizeSize", XS_Wx__IconBundle_GetIconOfExactSizeSize);
        newXS_deffile("Wx::IconBundle::GetIconOfExactSizeCoord", XS_Wx__IconBundle_GetIconOfExactSizeCoord);
        newXS_deffile("Wx::IconBundle::GetIconOfExactSize", XS_Wx__IconBundle_GetIconOfExactSize);
#endif
        newXS_deffile("Wx::IconBundle::new", XS_Wx__IconBundle_new);
        newXS_deffile("Wx::IconBundle::AddIcon", XS_Wx__IconBundle_AddIcon);
        newXS_deffile("Wx::IconBundle::GetIcon", XS_Wx__IconBundle_GetIcon);
#if XSubPPtmpAAAV
        newXS_deffile("Wx::TopLevelWindow::RequestUserAttention", XS_Wx__TopLevelWindow_RequestUserAttention);
#endif
#if XSubPPtmpAAAW
        newXS_deffile("Wx::TopLevelWindow::IsAlwaysMaximized", XS_Wx__TopLevelWindow_IsAlwaysMaximized);
        newXS_deffile("Wx::TopLevelWindow::GetDefaultItem", XS_Wx__TopLevelWindow_GetDefaultItem);
        newXS_deffile("Wx::TopLevelWindow::SetDefaultItem", XS_Wx__TopLevelWindow_SetDefaultItem);
        newXS_deffile("Wx::TopLevelWindow::GetTmpDefaultItem", XS_Wx__TopLevelWindow_GetTmpDefaultItem);
        newXS_deffile("Wx::TopLevelWindow::SetTmpDefaultItem", XS_Wx__TopLevelWindow_SetTmpDefaultItem);
        newXS_deffile("Wx::TopLevelWindow::SetTransparent", XS_Wx__TopLevelWindow_SetTransparent);
        newXS_deffile("Wx::TopLevelWindow::CanSetTransparent", XS_Wx__TopLevelWindow_CanSetTransparent);
#endif
#if XSubPPtmpAAAX
        newXS_deffile("Wx::TopLevelWindow::EnableCloseButton", XS_Wx__TopLevelWindow_EnableCloseButton);
#endif
#if XSubPPtmpAAAY
        newXS_deffile("Wx::TopLevelWindow::GetIcon", XS_Wx__TopLevelWindow_GetIcon);
        newXS_deffile("Wx::TopLevelWindow::GetIcons", XS_Wx__TopLevelWindow_GetIcons);
        newXS_deffile("Wx::TopLevelWindow::SetIcon", XS_Wx__TopLevelWindow_SetIcon);
        newXS_deffile("Wx::TopLevelWindow::SetIcons", XS_Wx__TopLevelWindow_SetIcons);
        newXS_deffile("Wx::TopLevelWindow::Iconize", XS_Wx__TopLevelWindow_Iconize);
        newXS_deffile("Wx::TopLevelWindow::Maximize", XS_Wx__TopLevelWindow_Maximize);
        newXS_deffile("Wx::TopLevelWindow::ShowFullScreen", XS_Wx__TopLevelWindow_ShowFullScreen);
        newXS_deffile("Wx::TopLevelWindow::IsFullScreen", XS_Wx__TopLevelWindow_IsFullScreen);
        newXS_deffile("Wx::TopLevelWindow::IsActive", XS_Wx__TopLevelWindow_IsActive);
        newXS_deffile("Wx::TopLevelWindow::IsIconized", XS_Wx__TopLevelWindow_IsIconized);
        newXS_deffile("Wx::TopLevelWindow::IsMaximized", XS_Wx__TopLevelWindow_IsMaximized);
#if XSubPPtmpAAAZ
        newXS_deffile("Wx::TopLevelWindow::IsUsingNativeDecorations", XS_Wx__TopLevelWindow_IsUsingNativeDecorations);
#endif
#if XSubPPtmpAABA
        newXS_deffile("Wx::TopLevelWindow::SetLayoutDirection", XS_Wx__TopLevelWindow_SetLayoutDirection);
#endif
        newXS_deffile("Wx::TopLevelWindow::SetShape", XS_Wx__TopLevelWindow_SetShape);
#if XSubPPtmpAABB
        newXS_deffile("Wx::TopLevelWindow::ShouldPreventAppExit", XS_Wx__TopLevelWindow_ShouldPreventAppExit);
#endif
#if XSubPPtmpAABC
        newXS_deffile("Wx::TopLevelWindow::MSWGetSystemMenu", XS_Wx__TopLevelWindow_MSWGetSystemMenu);
#endif
#if XSubPPtmpAABD
        newXS_deffile("Wx::TopLevelWindow::OSXIsModified", XS_Wx__TopLevelWindow_OSXIsModified);
        newXS_deffile("Wx::TopLevelWindow::OSXSetModified", XS_Wx__TopLevelWindow_OSXSetModified);
        newXS_deffile("Wx::TopLevelWindow::SetRepresentedFilename", XS_Wx__TopLevelWindow_SetRepresentedFilename);
        newXS_deffile("Wx::TopLevelWindow::SetMinSize", XS_Wx__TopLevelWindow_SetMinSize);
        newXS_deffile("Wx::TopLevelWindow::SetMaxSize", XS_Wx__TopLevelWindow_SetMaxSize);
#endif
#if XSubPPtmpAABE
        newXS_deffile("Wx::TopLevelWindow::UseNativeDecorations", XS_Wx__TopLevelWindow_UseNativeDecorations);
        newXS_deffile("Wx::TopLevelWindow::UseNativeDecorationsByDefault", XS_Wx__TopLevelWindow_UseNativeDecorationsByDefault);
#endif
#endif
#if XSubPPtmpAABF
        newXS_deffile("Wx::PopupWindow::newDefault", XS_Wx__PopupWindow_newDefault);
        newXS_deffile("Wx::PopupWindow::newFull", XS_Wx__PopupWindow_newFull);
        newXS_deffile("Wx::PopupWindow::Create", XS_Wx__PopupWindow_Create);
        newXS_deffile("Wx::PopupWindow::Position", XS_Wx__PopupWindow_Position);
        newXS_deffile("Wx::PopupWindow::new", XS_Wx__PopupWindow_new);
        newXS_deffile("Wx::PopupTransientWindow::newDefault", XS_Wx__PopupTransientWindow_newDefault);
        newXS_deffile("Wx::PopupTransientWindow::newFull", XS_Wx__PopupTransientWindow_newFull);
        newXS_deffile("Wx::PopupTransientWindow::Popup", XS_Wx__PopupTransientWindow_Popup);
        newXS_deffile("Wx::PopupTransientWindow::Dismiss", XS_Wx__PopupTransientWindow_Dismiss);
        newXS_deffile("Wx::PopupTransientWindow::CanDismiss", XS_Wx__PopupTransientWindow_CanDismiss);
        newXS_deffile("Wx::PopupTransientWindow::ProcessLeftDown", XS_Wx__PopupTransientWindow_ProcessLeftDown);
        newXS_deffile("Wx::PopupTransientWindow::new", XS_Wx__PopupTransientWindow_new);
        newXS_deffile("Wx::PlPopupTransientWindow::newDefault", XS_Wx__PlPopupTransientWindow_newDefault);
        newXS_deffile("Wx::PlPopupTransientWindow::newFull", XS_Wx__PlPopupTransientWindow_newFull);
        newXS_deffile("Wx::PlPopupTransientWindow::Popup", XS_Wx__PlPopupTransientWindow_Popup);
        newXS_deffile("Wx::PlPopupTransientWindow::Dismiss", XS_Wx__PlPopupTransientWindow_Dismiss);
        newXS_deffile("Wx::PlPopupTransientWindow::CanDismiss", XS_Wx__PlPopupTransientWindow_CanDismiss);
        newXS_deffile("Wx::PlPopupTransientWindow::ProcessLeftDown", XS_Wx__PlPopupTransientWindow_ProcessLeftDown);
        newXS_deffile("Wx::PlPopupTransientWindow::new", XS_Wx__PlPopupTransientWindow_new);
#endif
        newXS_deffile("Wx::TextEntryDialog::new", XS_Wx__TextEntryDialog_new);
        newXS_deffile("Wx::TextEntryDialog::GetValue", XS_Wx__TextEntryDialog_GetValue);
        newXS_deffile("Wx::TextEntryDialog::SetValue", XS_Wx__TextEntryDialog_SetValue);
        newXS_deffile("Wx::TextEntryDialog::ShowModal", XS_Wx__TextEntryDialog_ShowModal);
#if XSubPPtmpAABG
        newXS_deffile("Wx::PasswordEntryDialog::new", XS_Wx__PasswordEntryDialog_new);
#endif
#if XSubPPtmpAABH
        newXS_deffile("Wx::NumberEntryDialog::new", XS_Wx__NumberEntryDialog_new);
        newXS_deffile("Wx::NumberEntryDialog::GetValue", XS_Wx__NumberEntryDialog_GetValue);
#endif
        newXS_deffile("Wx::GetNumberFromUser", XS_Wx_GetNumberFromUser);
        newXS_deffile("Wx::GetPasswordFromUser", XS_Wx_GetPasswordFromUser);
        newXS_deffile("Wx::GetTextFromUser", XS_Wx_GetTextFromUser);
        newXS_deffile("Wx::FileDialog::new", XS_Wx__FileDialog_new);
        newXS_deffile("Wx::FileDialog::GetDirectory", XS_Wx__FileDialog_GetDirectory);
        newXS_deffile("Wx::FileDialog::GetFilename", XS_Wx__FileDialog_GetFilename);
        newXS_deffile("Wx::FileDialog::GetFilenames", XS_Wx__FileDialog_GetFilenames);
        newXS_deffile("Wx::FileDialog::GetFilterIndex", XS_Wx__FileDialog_GetFilterIndex);
        newXS_deffile("Wx::FileDialog::GetMessage", XS_Wx__FileDialog_GetMessage);
        newXS_deffile("Wx::FileDialog::GetPath", XS_Wx__FileDialog_GetPath);
        newXS_deffile("Wx::FileDialog::GetPaths", XS_Wx__FileDialog_GetPaths);
#if XSubPPtmpAABI
        newXS_deffile("Wx::FileDialog::GetStyle", XS_Wx__FileDialog_GetStyle);
#endif
        newXS_deffile("Wx::FileDialog::GetWildcard", XS_Wx__FileDialog_GetWildcard);
        newXS_deffile("Wx::FileDialog::SetDirectory", XS_Wx__FileDialog_SetDirectory);
        newXS_deffile("Wx::FileDialog::SetFilename", XS_Wx__FileDialog_SetFilename);
        newXS_deffile("Wx::FileDialog::SetFilterIndex", XS_Wx__FileDialog_SetFilterIndex);
        newXS_deffile("Wx::FileDialog::SetMessage", XS_Wx__FileDialog_SetMessage);
        newXS_deffile("Wx::FileDialog::SetPath", XS_Wx__FileDialog_SetPath);
#if XSubPPtmpAABJ
        newXS_deffile("Wx::FileDialog::SetStyle", XS_Wx__FileDialog_SetStyle);
#endif
        newXS_deffile("Wx::FileDialog::SetWildcard", XS_Wx__FileDialog_SetWildcard);
        newXS_deffile("Wx::FileDialog::ShowModal", XS_Wx__FileDialog_ShowModal);
        newXS_deffile("Wx::FileSelector", XS_Wx_FileSelector);
        newXS_deffile("Wx::DirDialog::new", XS_Wx__DirDialog_new);
        newXS_deffile("Wx::DirDialog::GetPath", XS_Wx__DirDialog_GetPath);
        newXS_deffile("Wx::DirDialog::GetMessage", XS_Wx__DirDialog_GetMessage);
#if XSubPPtmpAABK
        newXS_deffile("Wx::DirDialog::GetStyle", XS_Wx__DirDialog_GetStyle);
#endif
        newXS_deffile("Wx::DirDialog::SetMessage", XS_Wx__DirDialog_SetMessage);
        newXS_deffile("Wx::DirDialog::SetPath", XS_Wx__DirDialog_SetPath);
#if XSubPPtmpAABL
        newXS_deffile("Wx::DirDialog::SetStyle", XS_Wx__DirDialog_SetStyle);
#endif
        newXS_deffile("Wx::DirDialog::ShowModal", XS_Wx__DirDialog_ShowModal);
        newXS_deffile("Wx::DirSelector", XS_Wx_DirSelector);
        newXS_deffile("Wx::ColourDialog::new", XS_Wx__ColourDialog_new);
        newXS_deffile("Wx::ColourDialog::GetColourData", XS_Wx__ColourDialog_GetColourData);
        newXS_deffile("Wx::ColourDialog::ShowModal", XS_Wx__ColourDialog_ShowModal);
        newXS_deffile("Wx::ColourData::new", XS_Wx__ColourData_new);
        newXS_deffile("Wx::ColourData::CLONE", XS_Wx__ColourData_CLONE);
        newXS_deffile("Wx::ColourData::DESTROY", XS_Wx__ColourData_DESTROY);
        newXS_deffile("Wx::ColourData::GetChooseFull", XS_Wx__ColourData_GetChooseFull);
        newXS_deffile("Wx::ColourData::GetColour", XS_Wx__ColourData_GetColour);
        newXS_deffile("Wx::ColourData::GetCustomColour", XS_Wx__ColourData_GetCustomColour);
        newXS_deffile("Wx::ColourData::SetChooseFull", XS_Wx__ColourData_SetChooseFull);
        newXS_deffile("Wx::ColourData::SetColour", XS_Wx__ColourData_SetColour);
        newXS_deffile("Wx::ColourData::SetCustomColour", XS_Wx__ColourData_SetCustomColour);
        newXS_deffile("Wx::GetColourFromUser", XS_Wx_GetColourFromUser);
        newXS_deffile("Wx::MessageDialog::new", XS_Wx__MessageDialog_new);
        newXS_deffile("Wx::MessageDialog::ShowModal", XS_Wx__MessageDialog_ShowModal);
#if XSubPPtmpAABM
        newXS_deffile("Wx::MessageDialog::SetYesNoLabels", XS_Wx__MessageDialog_SetYesNoLabels);
        newXS_deffile("Wx::MessageDialog::SetYesNoCancelLabels", XS_Wx__MessageDialog_SetYesNoCancelLabels);
        newXS_deffile("Wx::MessageDialog::SetOKLabel", XS_Wx__MessageDialog_SetOKLabel);
        newXS_deffile("Wx::MessageDialog::SetOKCancelLabels", XS_Wx__MessageDialog_SetOKCancelLabels);
        newXS_deffile("Wx::MessageDialog::SetMessage", XS_Wx__MessageDialog_SetMessage);
        newXS_deffile("Wx::MessageDialog::SetExtendedMessage", XS_Wx__MessageDialog_SetExtendedMessage);
#endif
#if XSubPPtmpAABN
        newXS_deffile("Wx::MessageDialog::SetHelpLabel", XS_Wx__MessageDialog_SetHelpLabel);
#endif
        newXS_deffile("Wx::MessageBox", XS_Wx_MessageBox);
#if XSubPPtmpAABO
        newXS_deffile("Wx::FontData::new", XS_Wx__FontData_new);
        newXS_deffile("Wx::FontData::CLONE", XS_Wx__FontData_CLONE);
        newXS_deffile("Wx::FontData::DESTROY", XS_Wx__FontData_DESTROY);
        newXS_deffile("Wx::FontData::EnableEffects", XS_Wx__FontData_EnableEffects);
        newXS_deffile("Wx::FontData::GetAllowSymbols", XS_Wx__FontData_GetAllowSymbols);
        newXS_deffile("Wx::FontData::GetColour", XS_Wx__FontData_GetColour);
        newXS_deffile("Wx::FontData::GetChosenFont", XS_Wx__FontData_GetChosenFont);
        newXS_deffile("Wx::FontData::GetEnableEffects", XS_Wx__FontData_GetEnableEffects);
        newXS_deffile("Wx::FontData::GetInitialFont", XS_Wx__FontData_GetInitialFont);
        newXS_deffile("Wx::FontData::GetShowHelp", XS_Wx__FontData_GetShowHelp);
        newXS_deffile("Wx::FontData::SetAllowSymbols", XS_Wx__FontData_SetAllowSymbols);
        newXS_deffile("Wx::FontData::SetChosenFont", XS_Wx__FontData_SetChosenFont);
        newXS_deffile("Wx::FontData::SetColour", XS_Wx__FontData_SetColour);
        newXS_deffile("Wx::FontData::SetInitialFont", XS_Wx__FontData_SetInitialFont);
        newXS_deffile("Wx::FontData::SetRange", XS_Wx__FontData_SetRange);
        newXS_deffile("Wx::FontData::SetShowHelp", XS_Wx__FontData_SetShowHelp);
        newXS_deffile("Wx::FontDialog::new", XS_Wx__FontDialog_new);
        newXS_deffile("Wx::FontDialog::GetFontData", XS_Wx__FontDialog_GetFontData);
        newXS_deffile("Wx::GetFontFromUser", XS_Wx_GetFontFromUser);
#endif
        newXS_deffile("Wx::MultiChoiceDialog::new", XS_Wx__MultiChoiceDialog_new);
        newXS_deffile("Wx::MultiChoiceDialog::GetSelections", XS_Wx__MultiChoiceDialog_GetSelections);
        newXS_deffile("Wx::MultiChoiceDialog::SetSelections", XS_Wx__MultiChoiceDialog_SetSelections);
        newXS_deffile("Wx::SingleChoiceDialog::new", XS_Wx__SingleChoiceDialog_new);
        newXS_deffile("Wx::SingleChoiceDialog::GetSelection", XS_Wx__SingleChoiceDialog_GetSelection);
        newXS_deffile("Wx::SingleChoiceDialog::GetSelectionClientData", XS_Wx__SingleChoiceDialog_GetSelectionClientData);
        newXS_deffile("Wx::SingleChoiceDialog::GetStringSelection", XS_Wx__SingleChoiceDialog_GetStringSelection);
        newXS_deffile("Wx::SingleChoiceDialog::SetSelection", XS_Wx__SingleChoiceDialog_SetSelection);
        newXS_deffile("Wx::GetSingleChoice", XS_Wx_GetSingleChoice);
        newXS_deffile("Wx::GetSingleChoiceIndex", XS_Wx_GetSingleChoiceIndex);
        newXS_deffile("Wx::GetSingleChoiceData", XS_Wx_GetSingleChoiceData);
        newXS_deffile("Wx::ProgressDialog::new", XS_Wx__ProgressDialog_new);
        newXS_deffile("Wx::ProgressDialog::Resume", XS_Wx__ProgressDialog_Resume);
#if XSubPPtmpAABP
        newXS_deffile("Wx::ProgressDialog::Update", XS_Wx__ProgressDialog_Update);
        newXS_deffile("Wx::ProgressDialog::Pulse", XS_Wx__ProgressDialog_Pulse);
        newXS_deffile("Wx::ProgressDialog::GetRange", XS_Wx__ProgressDialog_GetRange);
        newXS_deffile("Wx::ProgressDialog::GetValue", XS_Wx__ProgressDialog_GetValue);
        newXS_deffile("Wx::ProgressDialog::GetMessage", XS_Wx__ProgressDialog_GetMessage);
        newXS_deffile("Wx::ProgressDialog::SetRange", XS_Wx__ProgressDialog_SetRange);
        newXS_deffile("Wx::ProgressDialog::WasCancelled", XS_Wx__ProgressDialog_WasCancelled);
        newXS_deffile("Wx::ProgressDialog::WasSkipped", XS_Wx__ProgressDialog_WasSkipped);
        newXS_deffile("Wx::ProgressDialog::Show", XS_Wx__ProgressDialog_Show);
#endif
#if XSubPPtmpAABQ
        newXS_deffile("Wx::ProgressDialog::Update", XS_Wx__ProgressDialog_Update);
#if XSubPPtmpAABR
        newXS_deffile("Wx::ProgressDialog::Show", XS_Wx__ProgressDialog_Show);
        newXS_deffile("Wx::ProgressDialog::Pulse", XS_Wx__ProgressDialog_Pulse);
#endif
#endif
        newXS_deffile("Wx::FindReplaceData::CLONE", XS_Wx__FindReplaceData_CLONE);
        newXS_deffile("Wx::FindReplaceData::new", XS_Wx__FindReplaceData_new);
        newXS_deffile("Wx::FindReplaceData::DESTROY", XS_Wx__FindReplaceData_DESTROY);
        newXS_deffile("Wx::FindReplaceData::GetFindString", XS_Wx__FindReplaceData_GetFindString);
        newXS_deffile("Wx::FindReplaceData::GetFlags", XS_Wx__FindReplaceData_GetFlags);
        newXS_deffile("Wx::FindReplaceData::GetReplaceString", XS_Wx__FindReplaceData_GetReplaceString);
        newXS_deffile("Wx::FindReplaceData::SetFindString", XS_Wx__FindReplaceData_SetFindString);
        newXS_deffile("Wx::FindReplaceData::SetFlags", XS_Wx__FindReplaceData_SetFlags);
        newXS_deffile("Wx::FindReplaceData::SetReplaceString", XS_Wx__FindReplaceData_SetReplaceString);
        newXS_deffile("Wx::FindReplaceDialog::newDefault", XS_Wx__FindReplaceDialog_newDefault);
        newXS_deffile("Wx::FindReplaceDialog::newFull", XS_Wx__FindReplaceDialog_newFull);
        newXS_deffile("Wx::FindReplaceDialog::Create", XS_Wx__FindReplaceDialog_Create);
        newXS_deffile("Wx::FindReplaceDialog::GetData", XS_Wx__FindReplaceDialog_GetData);
        newXS_deffile("Wx::FindReplaceDialog::SetData", XS_Wx__FindReplaceDialog_SetData);
#if XSubPPtmpAABS
        newXS_deffile("Wx::FindReplaceDialog::new", XS_Wx__FindReplaceDialog_new);
#endif
        newXS_deffile("Wx::FindDialogEvent::GetDialog", XS_Wx__FindDialogEvent_GetDialog);
        newXS_deffile("Wx::FindDialogEvent::GetFindString", XS_Wx__FindDialogEvent_GetFindString);
        newXS_deffile("Wx::FindDialogEvent::GetFlags", XS_Wx__FindDialogEvent_GetFlags);
        newXS_deffile("Wx::FindDialogEvent::GetReplaceString", XS_Wx__FindDialogEvent_GetReplaceString);
#if XSubPPtmpAABT
        newXS_deffile("Wx::AboutDialogInfo::new", XS_Wx__AboutDialogInfo_new);
        newXS_deffile("Wx::AboutDialogInfo::SetName", XS_Wx__AboutDialogInfo_SetName);
        newXS_deffile("Wx::AboutDialogInfo::GetName", XS_Wx__AboutDialogInfo_GetName);
        newXS_deffile("Wx::AboutDialogInfo::SetVersion", XS_Wx__AboutDialogInfo_SetVersion);
        newXS_deffile("Wx::AboutDialogInfo::HasVersion", XS_Wx__AboutDialogInfo_HasVersion);
        newXS_deffile("Wx::AboutDialogInfo::GetVersion", XS_Wx__AboutDialogInfo_GetVersion);
        newXS_deffile("Wx::AboutDialogInfo::SetDescription", XS_Wx__AboutDialogInfo_SetDescription);
        newXS_deffile("Wx::AboutDialogInfo::HasDescription", XS_Wx__AboutDialogInfo_HasDescription);
        newXS_deffile("Wx::AboutDialogInfo::GetDescription", XS_Wx__AboutDialogInfo_GetDescription);
        newXS_deffile("Wx::AboutDialogInfo::SetCopyright", XS_Wx__AboutDialogInfo_SetCopyright);
        newXS_deffile("Wx::AboutDialogInfo::HasCopyright", XS_Wx__AboutDialogInfo_HasCopyright);
        newXS_deffile("Wx::AboutDialogInfo::GetCopyright", XS_Wx__AboutDialogInfo_GetCopyright);
        newXS_deffile("Wx::AboutDialogInfo::SetLicence", XS_Wx__AboutDialogInfo_SetLicence);
        newXS_deffile("Wx::AboutDialogInfo::SetLicense", XS_Wx__AboutDialogInfo_SetLicense);
        newXS_deffile("Wx::AboutDialogInfo::HasLicence", XS_Wx__AboutDialogInfo_HasLicence);
        newXS_deffile("Wx::AboutDialogInfo::GetLicence", XS_Wx__AboutDialogInfo_GetLicence);
        newXS_deffile("Wx::AboutDialogInfo::SetIcon", XS_Wx__AboutDialogInfo_SetIcon);
        newXS_deffile("Wx::AboutDialogInfo::HasIcon", XS_Wx__AboutDialogInfo_HasIcon);
        newXS_deffile("Wx::AboutDialogInfo::GetIcon", XS_Wx__AboutDialogInfo_GetIcon);
        newXS_deffile("Wx::AboutDialogInfo::SetWebSite", XS_Wx__AboutDialogInfo_SetWebSite);
        newXS_deffile("Wx::AboutDialogInfo::HasWebSite", XS_Wx__AboutDialogInfo_HasWebSite);
        newXS_deffile("Wx::AboutDialogInfo::GetWebSiteURL", XS_Wx__AboutDialogInfo_GetWebSiteURL);
        newXS_deffile("Wx::AboutDialogInfo::GetWebSiteDescription", XS_Wx__AboutDialogInfo_GetWebSiteDescription);
        newXS_deffile("Wx::AboutDialogInfo::SetDevelopers", XS_Wx__AboutDialogInfo_SetDevelopers);
        newXS_deffile("Wx::AboutDialogInfo::AddDeveloper", XS_Wx__AboutDialogInfo_AddDeveloper);
        newXS_deffile("Wx::AboutDialogInfo::HasDevelopers", XS_Wx__AboutDialogInfo_HasDevelopers);
        newXS_deffile("Wx::AboutDialogInfo::GetDevelopers", XS_Wx__AboutDialogInfo_GetDevelopers);
        newXS_deffile("Wx::AboutDialogInfo::SetDocWriters", XS_Wx__AboutDialogInfo_SetDocWriters);
        newXS_deffile("Wx::AboutDialogInfo::AddDocWriter", XS_Wx__AboutDialogInfo_AddDocWriter);
        newXS_deffile("Wx::AboutDialogInfo::HasDocWriters", XS_Wx__AboutDialogInfo_HasDocWriters);
        newXS_deffile("Wx::AboutDialogInfo::GetDocWriters", XS_Wx__AboutDialogInfo_GetDocWriters);
        newXS_deffile("Wx::AboutDialogInfo::SetArtists", XS_Wx__AboutDialogInfo_SetArtists);
        newXS_deffile("Wx::AboutDialogInfo::AddArtist", XS_Wx__AboutDialogInfo_AddArtist);
        newXS_deffile("Wx::AboutDialogInfo::HasArtists", XS_Wx__AboutDialogInfo_HasArtists);
        newXS_deffile("Wx::AboutDialogInfo::GetArtists", XS_Wx__AboutDialogInfo_GetArtists);
        newXS_deffile("Wx::AboutDialogInfo::SetTranslators", XS_Wx__AboutDialogInfo_SetTranslators);
        newXS_deffile("Wx::AboutDialogInfo::AddTranslator", XS_Wx__AboutDialogInfo_AddTranslator);
        newXS_deffile("Wx::AboutDialogInfo::HasTranslators", XS_Wx__AboutDialogInfo_HasTranslators);
        newXS_deffile("Wx::AboutDialogInfo::GetTranslators", XS_Wx__AboutDialogInfo_GetTranslators);
        newXS_deffile("Wx::AboutBox", XS_Wx_AboutBox);
#endif
#if XSubPPtmpAABU
        newXS_deffile("Wx::PropertySheetDialog::newDefault", XS_Wx__PropertySheetDialog_newDefault);
        newXS_deffile("Wx::PropertySheetDialog::newFull", XS_Wx__PropertySheetDialog_newFull);
        newXS_deffile("Wx::PropertySheetDialog::Create", XS_Wx__PropertySheetDialog_Create);
        newXS_deffile("Wx::PropertySheetDialog::SetBookCtrl", XS_Wx__PropertySheetDialog_SetBookCtrl);
        newXS_deffile("Wx::PropertySheetDialog::GetBookCtrl", XS_Wx__PropertySheetDialog_GetBookCtrl);
        newXS_deffile("Wx::PropertySheetDialog::SetInnerSize", XS_Wx__PropertySheetDialog_SetInnerSize);
        newXS_deffile("Wx::PropertySheetDialog::GetInnerSizer", XS_Wx__PropertySheetDialog_GetInnerSizer);
#if XSubPPtmpAABV
        newXS_deffile("Wx::PropertySheetDialog::SetSheetStyle", XS_Wx__PropertySheetDialog_SetSheetStyle);
        newXS_deffile("Wx::PropertySheetDialog::GetSheetStyle", XS_Wx__PropertySheetDialog_GetSheetStyle);
        newXS_deffile("Wx::PropertySheetDialog::SetSheetOuterBorder", XS_Wx__PropertySheetDialog_SetSheetOuterBorder);
        newXS_deffile("Wx::PropertySheetDialog::GetSheetOuterBorder", XS_Wx__PropertySheetDialog_GetSheetOuterBorder);
        newXS_deffile("Wx::PropertySheetDialog::SetSheetInnerBorder", XS_Wx__PropertySheetDialog_SetSheetInnerBorder);
        newXS_deffile("Wx::PropertySheetDialog::GetSheetInnerBorder", XS_Wx__PropertySheetDialog_GetSheetInnerBorder);
#endif
        newXS_deffile("Wx::PropertySheetDialog::CreateButtons", XS_Wx__PropertySheetDialog_CreateButtons);
#if XSubPPtmpAABW
        newXS_deffile("Wx::PropertySheetDialog::LayoutDialog", XS_Wx__PropertySheetDialog_LayoutDialog);
#endif
#if XSubPPtmpAABX
        newXS_deffile("Wx::PropertySheetDialog::LayoutDialog", XS_Wx__PropertySheetDialog_LayoutDialog);
#endif
#endif

    /* Initialisation Section */

#if XSubPPtmpAAAA
#endif
#if XSubPPtmpAAAB
#endif
#if XSubPPtmpAAAC
#endif
#if XSubPPtmpAAAD
#endif
#if XSubPPtmpAAAE
#endif
#if XSubPPtmpAAAF
#if XSubPPtmpAAAG
#endif
#endif
#if XSubPPtmpAAAH
#endif
#if XSubPPtmpAAAI
#endif
#if XSubPPtmpAAAJ
#endif
#if XSubPPtmpAAAK
#endif
#if XSubPPtmpAAAL
#endif
#if XSubPPtmpAAAM
#endif
#if XSubPPtmpAAAN
#endif
#if XSubPPtmpAAAO
#endif
#if XSubPPtmpAAAP
#endif
#if XSubPPtmpAAAQ
#endif
#if XSubPPtmpAAAR
#endif
#if XSubPPtmpAAAS
#endif
#if XSubPPtmpAAAT
#endif
#if XSubPPtmpAAAU
#endif
#if XSubPPtmpAAAV
#endif
#if XSubPPtmpAAAW
#endif
#if XSubPPtmpAAAX
#endif
#if XSubPPtmpAAAY
#if XSubPPtmpAAAZ
#endif
#if XSubPPtmpAABA
#endif
#if XSubPPtmpAABB
#endif
#if XSubPPtmpAABC
#endif
#if XSubPPtmpAABD
#endif
#if XSubPPtmpAABE
#endif
#endif
#if XSubPPtmpAABF
#endif
#if XSubPPtmpAABG
#endif
#if XSubPPtmpAABH
#endif
#if XSubPPtmpAABI
#endif
#if XSubPPtmpAABJ
#endif
#if XSubPPtmpAABK
#endif
#if XSubPPtmpAABL
#endif
#if XSubPPtmpAABM
#endif
#if XSubPPtmpAABN
#endif
#if XSubPPtmpAABO
#endif
#if XSubPPtmpAABP
#endif
#if XSubPPtmpAABQ
#if XSubPPtmpAABR
#endif
#endif
#if XSubPPtmpAABS
#endif
#if XSubPPtmpAABT
#endif
#if XSubPPtmpAABU
#if XSubPPtmpAABV
#endif
#if XSubPPtmpAABW
#endif
#if XSubPPtmpAABX
#endif
#endif

    /* End of Initialisation Section */

#if PERL_VERSION_LE(5, 21, 5)
#  if PERL_VERSION_GE(5, 9, 0)
    if (PL_unitcheckav)
        call_list(PL_scopestack_ix, PL_unitcheckav);
#  endif
    XSRETURN_YES;
#else
    Perl_xs_boot_epilog(aTHX_ ax);
#endif
}

