/*
 * This file was generated automatically by ExtUtils::ParseXS version 3.44 from the
 * contents of Window.xs. Do not edit this file, edit Window.xs instead.
 *
 *    ANY CHANGES MADE HERE WILL BE LOST!
 *
 */

/////////////////////////////////////////////////////////////////////////////
// Name:        Window.xs
// Purpose:     XS for Wx::Window
// Author:      Mattia Barbon
// Modified by:
// Created:     29/10/2000
// RCS-ID:      $Id: Window.xs 3525 2014-10-28 01:36:38Z mdootson $
// Copyright:   (c) 2000-2002, 2004-2010 Mattia Barbon
// Licence:     This program is free software; you can redistribute it and/or
//              modify it under the same terms as Perl itself
/////////////////////////////////////////////////////////////////////////////

#define PERL_NO_GET_CONTEXT

#include "cpp/wxapi.h"

#include <wx/window.h>
#include <wx/layout.h>
#include <wx/sizer.h>

#include "cpp/overload.h"

#if wxPERL_USE_TOOLTIPS
#include <wx/tooltip.h>
#endif

#undef THIS

#include "cpp/v_cback.h"
#include "cpp/window.h"

WXPLI_BOOT_ONCE(Wx_Win);
#define boot_Wx_Win wxPli_boot_Wx_Win

#ifndef PERL_UNUSED_VAR
#  define PERL_UNUSED_VAR(var) if (0) var = var
#endif

#ifndef dVAR
#  define dVAR		dNOOP
#endif


/* This stuff is not part of the API! You have been warned. */
#ifndef PERL_VERSION_DECIMAL
#  define PERL_VERSION_DECIMAL(r,v,s) (r*1000000 + v*1000 + s)
#endif
#ifndef PERL_DECIMAL_VERSION
#  define PERL_DECIMAL_VERSION \
	  PERL_VERSION_DECIMAL(PERL_REVISION,PERL_VERSION,PERL_SUBVERSION)
#endif
#ifndef PERL_VERSION_GE
#  define PERL_VERSION_GE(r,v,s) \
	  (PERL_DECIMAL_VERSION >= PERL_VERSION_DECIMAL(r,v,s))
#endif
#ifndef PERL_VERSION_LE
#  define PERL_VERSION_LE(r,v,s) \
	  (PERL_DECIMAL_VERSION <= PERL_VERSION_DECIMAL(r,v,s))
#endif

/* XS_INTERNAL is the explicit static-linkage variant of the default
 * XS macro.
 *
 * XS_EXTERNAL is the same as XS_INTERNAL except it does not include
 * "STATIC", ie. it exports XSUB symbols. You probably don't want that
 * for anything but the BOOT XSUB.
 *
 * See XSUB.h in core!
 */


/* TODO: This might be compatible further back than 5.10.0. */
#if PERL_VERSION_GE(5, 10, 0) && PERL_VERSION_LE(5, 15, 1)
#  undef XS_EXTERNAL
#  undef XS_INTERNAL
#  if defined(__CYGWIN__) && defined(USE_DYNAMIC_LOADING)
#    define XS_EXTERNAL(name) __declspec(dllexport) XSPROTO(name)
#    define XS_INTERNAL(name) STATIC XSPROTO(name)
#  endif
#  if defined(__SYMBIAN32__)
#    define XS_EXTERNAL(name) EXPORT_C XSPROTO(name)
#    define XS_INTERNAL(name) EXPORT_C STATIC XSPROTO(name)
#  endif
#  ifndef XS_EXTERNAL
#    if defined(HASATTRIBUTE_UNUSED) && !defined(__cplusplus)
#      define XS_EXTERNAL(name) void name(pTHX_ CV* cv __attribute__unused__)
#      define XS_INTERNAL(name) STATIC void name(pTHX_ CV* cv __attribute__unused__)
#    else
#      ifdef __cplusplus
#        define XS_EXTERNAL(name) extern "C" XSPROTO(name)
#        define XS_INTERNAL(name) static XSPROTO(name)
#      else
#        define XS_EXTERNAL(name) XSPROTO(name)
#        define XS_INTERNAL(name) STATIC XSPROTO(name)
#      endif
#    endif
#  endif
#endif

/* perl >= 5.10.0 && perl <= 5.15.1 */


/* The XS_EXTERNAL macro is used for functions that must not be static
 * like the boot XSUB of a module. If perl didn't have an XS_EXTERNAL
 * macro defined, the best we can do is assume XS is the same.
 * Dito for XS_INTERNAL.
 */
#ifndef XS_EXTERNAL
#  define XS_EXTERNAL(name) XS(name)
#endif
#ifndef XS_INTERNAL
#  define XS_INTERNAL(name) XS(name)
#endif

/* Now, finally, after all this mess, we want an ExtUtils::ParseXS
 * internal macro that we're free to redefine for varying linkage due
 * to the EXPORT_XSUB_SYMBOLS XS keyword. This is internal, use
 * XS_EXTERNAL(name) or XS_INTERNAL(name) in your code if you need to!
 */

#undef XS_EUPXS
#if defined(PERL_EUPXS_ALWAYS_EXPORT)
#  define XS_EUPXS(name) XS_EXTERNAL(name)
#else
   /* default to internal */
#  define XS_EUPXS(name) XS_INTERNAL(name)
#endif

#ifndef PERL_ARGS_ASSERT_CROAK_XS_USAGE
#define PERL_ARGS_ASSERT_CROAK_XS_USAGE assert(cv); assert(params)

/* prototype to pass -Wmissing-prototypes */
STATIC void
S_croak_xs_usage(const CV *const cv, const char *const params);

STATIC void
S_croak_xs_usage(const CV *const cv, const char *const params)
{
    const GV *const gv = CvGV(cv);

    PERL_ARGS_ASSERT_CROAK_XS_USAGE;

    if (gv) {
        const char *const gvname = GvNAME(gv);
        const HV *const stash = GvSTASH(gv);
        const char *const hvname = stash ? HvNAME(stash) : NULL;

        if (hvname)
	    Perl_croak_nocontext("Usage: %s::%s(%s)", hvname, gvname, params);
        else
	    Perl_croak_nocontext("Usage: %s(%s)", gvname, params);
    } else {
        /* Pants. I don't think that it should be possible to get here. */
	Perl_croak_nocontext("Usage: CODE(0x%" UVxf ")(%s)", PTR2UV(cv), params);
    }
}
#undef  PERL_ARGS_ASSERT_CROAK_XS_USAGE

#define croak_xs_usage        S_croak_xs_usage

#endif

/* NOTE: the prototype of newXSproto() is different in versions of perls,
 * so we define a portable version of newXSproto()
 */
#ifdef newXS_flags
#define newXSproto_portable(name, c_impl, file, proto) newXS_flags(name, c_impl, file, proto, 0)
#else
#define newXSproto_portable(name, c_impl, file, proto) (PL_Sv=(SV*)newXS(name, c_impl, file), sv_setpv(PL_Sv, proto), (CV*)PL_Sv)
#endif /* !defined(newXS_flags) */

#if PERL_VERSION_LE(5, 21, 5)
#  define newXS_deffile(a,b) Perl_newXS(aTHX_ a,b,file)
#else
#  define newXS_deffile(a,b) Perl_newXS_deffile(aTHX_ a,b)
#endif


XS_EUPXS(XS_Wx_GetMousePosition); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx_GetMousePosition)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
    int x, y;
	wxPoint *	RETVAL;
    ::wxGetMousePosition( &x, &y );
    RETVAL = new wxPoint( x, y );
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_non_object_2_sv( aTHX_ RETVALSV, RETVAL, "Wx::Point" );
    wxPli_thread_sv_register( aTHX_ "Wx::Point", RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx_GetMousePositionXY); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx_GetMousePositionXY)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    PERL_UNUSED_VAR(ax); /* -Wall */
    SP -= items;
    {
    int x, y;
    ::wxGetMousePosition( &x, &y );
    EXTEND( SP, 2 );
    PUSHs( newSViv( x ) );
    PUSHs( newSViv( y ) );
	PUTBACK;
	return;
    }
}


XS_EUPXS(XS_Wx_GetTopLevelParent); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx_GetTopLevelParent)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "window");
    {
	wxWindow*    window = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Window" )
;
	wxWindow *	RETVAL;

	RETVAL = wxGetTopLevelParent(window);
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_object_2_sv( aTHX_ RETVALSV, RETVAL );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx_FindWindowAtPointer); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx_FindWindowAtPointer)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "pt");
    {
	wxPoint    pt = wxPli_sv_2_wxpoint( aTHX_ ST(0) )
;
	wxWindow *	RETVAL;

	RETVAL = wxFindWindowAtPointer(pt);
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_object_2_sv( aTHX_ RETVALSV, RETVAL );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx_GetActiveWindow); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx_GetActiveWindow)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	wxWindow *	RETVAL;

	RETVAL = wxGetActiveWindow();
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_object_2_sv( aTHX_ RETVALSV, RETVAL );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}

#if WXPERL_W_VERSION_LT( 2, 9, 0 )
#define XSubPPtmpAAAA 1


XS_EUPXS(XS_Wx__Window_NewControlId); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Window_NewControlId)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	int	RETVAL;
	dXSTARG;
    RETVAL = wxWindowBase::NewControlId();
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__Window_NextControlId); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Window_NextControlId)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "winid");
    {
	int	winid = (int)SvIV(ST(0))
;
	int	RETVAL;
	dXSTARG;
    RETVAL = wxWindowBase::NextControlId( winid );
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__Window_PrevControlId); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Window_PrevControlId)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "winid");
    {
	int	winid = (int)SvIV(ST(0))
;
	int	RETVAL;
	dXSTARG;
    RETVAL = wxWindowBase::PrevControlId( winid );
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}

#else
#define XSubPPtmpAAAB 1


XS_EUPXS(XS_Wx__Window_NewControlId); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Window_NewControlId)
{
    dVAR; dXSARGS;
    if (items < 0 || items > 1)
       croak_xs_usage(cv,  "idcount = 1");
    {
	int	idcount;
	wxWindowID	RETVAL;
	dXSTARG;

	if (items < 1)
	    idcount = 1;
	else {
	    idcount = (int)SvIV(ST(0))
;
	}
    RETVAL = wxWindowBase::NewControlId( idcount );
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__Window_UnreserveControlId); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Window_UnreserveControlId)
{
    dVAR; dXSARGS;
    if (items < 1 || items > 2)
       croak_xs_usage(cv,  "id, idcount = 1");
    {
	wxWindowID    id = wxPli_get_wxwindowid( aTHX_ ST(0) )
;
	int	idcount;

	if (items < 2)
	    idcount = 1;
	else {
	    idcount = (int)SvIV(ST(1))
;
	}
    wxWindowBase::UnreserveControlId( id, idcount );
    }
    XSRETURN_EMPTY;
}

#endif

XS_EUPXS(XS_Wx__Window_new); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Window_new)
{
    dVAR; dXSARGS;
    PERL_UNUSED_VAR(cv); /* -W */
    PERL_UNUSED_VAR(items); /* -W */
    PERL_UNUSED_VAR(ax); /* -Wall */
    SP -= items;
    {
    BEGIN_OVERLOAD()
        MATCH_VOIDM_REDISP( newDefault )
        MATCH_ANY_REDISP( newFull )
    END_OVERLOAD( "Wx::Window::new" )
	PUTBACK;
	return;
    }
}


XS_EUPXS(XS_Wx__Window_newDefault); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Window_newDefault)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "CLASS");
    {
	PlClassName    CLASS = wxPli_get_class( aTHX_ ST(0) )
;
	wxWindow *	RETVAL;
    RETVAL = new wxPliWindow( CLASS );
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_object_2_sv( aTHX_ RETVALSV, RETVAL );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__Window_newFull); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Window_newFull)
{
    dVAR; dXSARGS;
    if (items < 2 || items > 7)
       croak_xs_usage(cv,  "CLASS, parent, id = wxID_ANY, pos = wxDefaultPosition, size = wxDefaultSize, style = 0, name = wxPanelNameStr");
    {
	PlClassName    CLASS = wxPli_get_class( aTHX_ ST(0) )
;
	wxWindow*    parent = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::Window" )
;
	wxWindowID	id;
	wxPoint	pos;
	wxSize	size;
	long	style;
	wxString	name;
	wxWindow *	RETVAL;

	if (items < 3)
	    id = wxID_ANY;
	else {
    id = wxPli_get_wxwindowid( aTHX_ ST(2) )
;
	}

	if (items < 4)
	    pos = wxDefaultPosition;
	else {
    pos = wxPli_sv_2_wxpoint( aTHX_ ST(3) )
;
	}

	if (items < 5)
	    size = wxDefaultSize;
	else {
    size = wxPli_sv_2_wxsize( aTHX_ ST(4) )
;
	}

	if (items < 6)
	    style = 0;
	else {
	    style = (long)SvIV(ST(5))
;
	}

	if (items < 7)
	    name = wxPanelNameStr;
	else {
    WXSTRING_INPUT( name, wxString, ST(6) )
;
	}
    RETVAL = new wxPliWindow( CLASS, parent, id, pos, size, style, name );
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_object_2_sv( aTHX_ RETVALSV, RETVAL );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__Window_Create); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Window_Create)
{
    dVAR; dXSARGS;
    if (items < 2 || items > 7)
       croak_xs_usage(cv,  "THIS, parent, id = wxID_ANY, pos = wxDefaultPosition, size = wxDefaultSize, style = 0, name = wxPanelNameStr");
    {
	wxWindow*    parent = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::Window" )
;
	wxWindowID	id;
	wxPoint	pos;
	wxSize	size;
	long	style;
	wxString	name;
	wxWindow *    THIS = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Window" )
;
	bool	RETVAL;

	if (items < 3)
	    id = wxID_ANY;
	else {
    id = wxPli_get_wxwindowid( aTHX_ ST(2) )
;
	}

	if (items < 4)
	    pos = wxDefaultPosition;
	else {
    pos = wxPli_sv_2_wxpoint( aTHX_ ST(3) )
;
	}

	if (items < 5)
	    size = wxDefaultSize;
	else {
    size = wxPli_sv_2_wxsize( aTHX_ ST(4) )
;
	}

	if (items < 6)
	    style = 0;
	else {
	    style = (long)SvIV(ST(5))
;
	}

	if (items < 7)
	    name = wxPanelNameStr;
	else {
    WXSTRING_INPUT( name, wxString, ST(6) )
;
	}

	RETVAL = THIS->Create(parent, id, pos, size, style, name);
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__Window_CaptureMouse); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Window_CaptureMouse)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxWindow *    THIS = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Window" )
;

	THIS->CaptureMouse();
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__Window_Centre); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Window_Centre)
{
    dVAR; dXSARGS;
    if (items < 1 || items > 2)
       croak_xs_usage(cv,  "THIS, direction = wxBOTH");
    {
	int	direction;
	wxWindow *    THIS = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Window" )
;

	if (items < 2)
	    direction = wxBOTH;
	else {
	    direction = (int)SvIV(ST(1))
;
	}

	THIS->Centre(direction);
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__Window_CentreOnParent); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Window_CentreOnParent)
{
    dVAR; dXSARGS;
    if (items < 1 || items > 2)
       croak_xs_usage(cv,  "THIS, direction = wxBOTH");
    {
	int	direction;
	wxWindow *    THIS = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Window" )
;

	if (items < 2)
	    direction = wxBOTH;
	else {
	    direction = (int)SvIV(ST(1))
;
	}

	THIS->CentreOnParent(direction);
    }
    XSRETURN_EMPTY;
}

#if WXPERL_W_VERSION_GE( 2, 7, 0 )
#define XSubPPtmpAAAC 1


XS_EUPXS(XS_Wx__Window_CentreOnScreen); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Window_CentreOnScreen)
{
    dVAR; dXSARGS;
    if (items < 1 || items > 2)
       croak_xs_usage(cv,  "THIS, direction = wxBOTH");
    {
	int	direction;
	wxWindow *    THIS = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Window" )
;

	if (items < 2)
	    direction = wxBOTH;
	else {
	    direction = (int)SvIV(ST(1))
;
	}
    THIS->Centre( direction | wxCENTER_ON_SCREEN );
    }
    XSRETURN_EMPTY;
}

#else
#define XSubPPtmpAAAD 1


XS_EUPXS(XS_Wx__Window_CentreOnScreen); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Window_CentreOnScreen)
{
    dVAR; dXSARGS;
    if (items < 1 || items > 2)
       croak_xs_usage(cv,  "THIS, direction = wxBOTH");
    {
	int	direction;
	wxWindow *    THIS = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Window" )
;

	if (items < 2)
	    direction = wxBOTH;
	else {
	    direction = (int)SvIV(ST(1))
;
	}

	THIS->CentreOnScreen(direction);
    }
    XSRETURN_EMPTY;
}

#endif
#if WXPERL_W_VERSION_GE( 2, 5, 1 )
#define XSubPPtmpAAAE 1


XS_EUPXS(XS_Wx__Window_ClearBackground); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Window_ClearBackground)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxWindow *    THIS = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Window" )
;

	THIS->ClearBackground();
    }
    XSRETURN_EMPTY;
}

#else
#define XSubPPtmpAAAF 1


XS_EUPXS(XS_Wx__Window_Clear); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Window_Clear)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxWindow *    THIS = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Window" )
;

	THIS->Clear();
    }
    XSRETURN_EMPTY;
}

#endif

XS_EUPXS(XS_Wx__Window_ClientToScreen); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Window_ClientToScreen)
{
    dVAR; dXSARGS;
    if (items < 1)
       croak_xs_usage(cv,  "THIS, ...");
    PERL_UNUSED_VAR(ax); /* -Wall */
    SP -= items;
    {
	wxWindow *    THIS = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Window" )
;
    BEGIN_OVERLOAD()
        MATCH_REDISP( wxPliOvl_n_n, ClientToScreenXY )
        MATCH_REDISP( wxPliOvl_wpoi, ClientToScreenPoint )
    END_OVERLOAD( Wx::Window::ClientToScreen )
	PUTBACK;
	return;
    }
}


XS_EUPXS(XS_Wx__Window_ClientToScreenPoint); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Window_ClientToScreenPoint)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, point");
    {
	wxPoint    point = wxPli_sv_2_wxpoint( aTHX_ ST(1) )
;
	wxWindow *    THIS = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Window" )
;
	wxPoint *	RETVAL;
    RETVAL = new wxPoint( THIS->ClientToScreen( point ) );
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_non_object_2_sv( aTHX_ RETVALSV, RETVAL, "Wx::Point" );
    wxPli_thread_sv_register( aTHX_ "Wx::Point", RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__Window_ClientToScreenXY); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Window_ClientToScreenXY)
{
    dVAR; dXSARGS;
    if (items != 3)
       croak_xs_usage(cv,  "THIS, x, y");
    PERL_UNUSED_VAR(ax); /* -Wall */
    SP -= items;
    {
	int	x = (int)SvIV(ST(1))
;
	int	y = (int)SvIV(ST(2))
;
	wxWindow *    THIS = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Window" )
;
    THIS->ClientToScreen( &x, &y );
    EXTEND( SP, 2 );
    PUSHs( sv_2mortal( newSViv( x ) ) );
    PUSHs( sv_2mortal( newSViv( y ) ) );
	PUTBACK;
	return;
    }
}


XS_EUPXS(XS_Wx__Window_Close); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Window_Close)
{
    dVAR; dXSARGS;
    if (items < 1 || items > 2)
       croak_xs_usage(cv,  "THIS, force = false");
    {
	bool	force;
	wxWindow *    THIS = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Window" )
;
	bool	RETVAL;

	if (items < 2)
	    force = false;
	else {
	    force = (bool)SvTRUE(ST(1))
;
	}

	RETVAL = THIS->Close(force);
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__Window_ConvertDialogToPixels); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Window_ConvertDialogToPixels)
{
    dVAR; dXSARGS;
    if (items < 1)
       croak_xs_usage(cv,  "THIS, ...");
    PERL_UNUSED_VAR(ax); /* -Wall */
    SP -= items;
    {
	wxWindow *    THIS = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Window" )
;
    BEGIN_OVERLOAD()
        MATCH_REDISP( wxPliOvl_wpoi, ConvertDialogPointToPixels )
        MATCH_REDISP( wxPliOvl_wsiz, ConvertDialogSizeToPixels )
    END_OVERLOAD( Wx::Window::ConvertDialogToPixels )
	PUTBACK;
	return;
    }
}


XS_EUPXS(XS_Wx__Window_ConvertDialogPointToPixels); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Window_ConvertDialogPointToPixels)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, point");
    {
	wxPoint    point = wxPli_sv_2_wxpoint( aTHX_ ST(1) )
;
	wxWindow *    THIS = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Window" )
;
	wxPoint *	RETVAL;
    RETVAL = new wxPoint( THIS->ConvertDialogToPixels( point ) );
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_non_object_2_sv( aTHX_ RETVALSV, RETVAL, "Wx::Point" );
    wxPli_thread_sv_register( aTHX_ "Wx::Point", RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__Window_ConvertDialogSizeToPixels); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Window_ConvertDialogSizeToPixels)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, size");
    {
	wxSize    size = wxPli_sv_2_wxsize( aTHX_ ST(1) )
;
	wxWindow *    THIS = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Window" )
;
	wxSize *	RETVAL;
    RETVAL = new wxSize( THIS->ConvertDialogToPixels( size ) );
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_non_object_2_sv( aTHX_ RETVALSV, RETVAL, "Wx::Size" );
    wxPli_thread_sv_register( aTHX_ "Wx::Size", RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__Window_ConvertPixelsToDialog); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Window_ConvertPixelsToDialog)
{
    dVAR; dXSARGS;
    if (items < 1)
       croak_xs_usage(cv,  "THIS, ...");
    PERL_UNUSED_VAR(ax); /* -Wall */
    SP -= items;
    {
	wxWindow *    THIS = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Window" )
;
    BEGIN_OVERLOAD()
        MATCH_REDISP( wxPliOvl_wpoi, ConvertPixelsPointToDialog )
        MATCH_REDISP( wxPliOvl_wsiz, ConvertPixelsSizeToDialog )
    END_OVERLOAD( Wx::Window::ConvertPixelsToDialog )
	PUTBACK;
	return;
    }
}


XS_EUPXS(XS_Wx__Window_ConvertPixelsPointToDialog); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Window_ConvertPixelsPointToDialog)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, point");
    {
	wxPoint    point = wxPli_sv_2_wxpoint( aTHX_ ST(1) )
;
	wxWindow *    THIS = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Window" )
;
	wxPoint *	RETVAL;
    RETVAL = new wxPoint( THIS->ConvertPixelsToDialog( point ) );
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_non_object_2_sv( aTHX_ RETVALSV, RETVAL, "Wx::Point" );
    wxPli_thread_sv_register( aTHX_ "Wx::Point", RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__Window_ConvertPixelsSizeToDialog); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Window_ConvertPixelsSizeToDialog)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, size");
    {
	wxSize    size = wxPli_sv_2_wxsize( aTHX_ ST(1) )
;
	wxWindow *    THIS = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Window" )
;
	wxSize *	RETVAL;
    RETVAL = new wxSize( THIS->ConvertPixelsToDialog( size ) );
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_non_object_2_sv( aTHX_ RETVALSV, RETVAL, "Wx::Size" );
    wxPli_thread_sv_register( aTHX_ "Wx::Size", RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__Window_Destroy); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Window_Destroy)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxWindow *    THIS = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Window" )
;
	bool	RETVAL;

	RETVAL = THIS->Destroy();
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}

#if    defined( __WXMSW__ ) \
    || ( WXPERL_W_VERSION_GE( 2, 9, 0 ) && !defined( __WXGTK__ ) )
#define XSubPPtmpAAAG 1


XS_EUPXS(XS_Wx__Window_DragAcceptFiles); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Window_DragAcceptFiles)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, accept");
    {
	bool	accept = (bool)SvTRUE(ST(1))
;
	wxWindow *    THIS = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Window" )
;

	THIS->DragAcceptFiles(accept);
    }
    XSRETURN_EMPTY;
}

#endif

XS_EUPXS(XS_Wx__Window_Enable); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Window_Enable)
{
    dVAR; dXSARGS;
    if (items < 1 || items > 2)
       croak_xs_usage(cv,  "THIS, enable = true");
    {
	bool	enable;
	wxWindow *    THIS = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Window" )
;

	if (items < 2)
	    enable = true;
	else {
	    enable = (bool)SvTRUE(ST(1))
;
	}

	THIS->Enable(enable);
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__Window_Disable); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Window_Disable)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxWindow *    THIS = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Window" )
;

	THIS->Disable();
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__Window_FindFocus); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Window_FindFocus)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	wxWindow *	RETVAL;
    RETVAL = wxWindow::FindFocus();
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_object_2_sv( aTHX_ RETVALSV, RETVAL );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__Window_FindWindow); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Window_FindWindow)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, i");
    {
	SV*	i = ST(1)
;
	wxWindow *    THIS = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Window" )
;
	wxWindow *	RETVAL;
    if( looks_like_number( i ) ) {
      int id = SvIV( i );
      RETVAL = THIS->FindWindow( id );
    }
    else {
      wxString name;
      WXSTRING_INPUT( name, const char*, i );
      RETVAL = THIS->FindWindow( name );
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_object_2_sv( aTHX_ RETVALSV, RETVAL );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__Window_FindWindowById); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Window_FindWindowById)
{
    dVAR; dXSARGS;
    if (items < 1 || items > 2)
       croak_xs_usage(cv,  "id, parent = NULL");
    {
	wxWindowID    id = wxPli_get_wxwindowid( aTHX_ ST(0) )
;
	wxWindow*	parent;
	wxWindow *	RETVAL;

	if (items < 2)
	    parent = NULL;
	else {
    parent = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::Window" )
;
	}
    RETVAL = wxWindow::FindWindowById( id, parent );
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_object_2_sv( aTHX_ RETVALSV, RETVAL );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__Window_FindWindowByName); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Window_FindWindowByName)
{
    dVAR; dXSARGS;
    if (items < 1 || items > 2)
       croak_xs_usage(cv,  "id, parent = NULL");
    {
	wxString	id;
	wxWindow*	parent;
	wxWindow *	RETVAL;

    WXSTRING_INPUT( id, wxString, ST(0) )
;

	if (items < 2)
	    parent = NULL;
	else {
    parent = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::Window" )
;
	}
    RETVAL = wxWindow::FindWindowByName( id, parent );
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_object_2_sv( aTHX_ RETVALSV, RETVAL );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__Window_FindWindowByLabel); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Window_FindWindowByLabel)
{
    dVAR; dXSARGS;
    if (items < 1 || items > 2)
       croak_xs_usage(cv,  "id, parent = NULL");
    {
	wxString	id;
	wxWindow*	parent;
	wxWindow *	RETVAL;

    WXSTRING_INPUT( id, wxString, ST(0) )
;

	if (items < 2)
	    parent = NULL;
	else {
    parent = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::Window" )
;
	}
    RETVAL = wxWindow::FindWindowByLabel( id, parent );
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_object_2_sv( aTHX_ RETVALSV, RETVAL );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__Window_Fit); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Window_Fit)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxWindow *    THIS = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Window" )
;

	THIS->Fit();
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__Window_FitInside); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Window_FitInside)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxWindow *    THIS = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Window" )
;

	THIS->FitInside();
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__Window_Freeze); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Window_Freeze)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxWindow *    THIS = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Window" )
;

	THIS->Freeze();
    }
    XSRETURN_EMPTY;
}

#if WXPERL_W_VERSION_GE( 2, 7, 1 )
#define XSubPPtmpAAAH 1


XS_EUPXS(XS_Wx__Window_IsFrozen); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Window_IsFrozen)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxWindow *    THIS = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Window" )
;
	bool	RETVAL;

	RETVAL = THIS->IsFrozen();
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}

#endif

XS_EUPXS(XS_Wx__Window_GetAcceleratorTable); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Window_GetAcceleratorTable)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxWindow *    THIS = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Window" )
;
	wxAcceleratorTable *	RETVAL;
    RETVAL = new wxAcceleratorTable( *THIS->GetAcceleratorTable() );
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_object_2_sv( aTHX_ RETVALSV, RETVAL );
    wxPli_thread_sv_register( aTHX_ "Wx::AcceleratorTable", RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}

#if WXPERL_W_VERSION_GE( 2, 5, 3 )
#define XSubPPtmpAAAI 1


XS_EUPXS(XS_Wx__Window_GetBackgroundStyle); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Window_GetBackgroundStyle)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxWindow *    THIS = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Window" )
;
	wxBackgroundStyle	RETVAL;
	dXSTARG;

	RETVAL = THIS->GetBackgroundStyle();
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}

#endif

XS_EUPXS(XS_Wx__Window_GetBackgroundColour); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Window_GetBackgroundColour)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxWindow *    THIS = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Window" )
;
	wxColour *	RETVAL;
    RETVAL = new wxColour( THIS->GetBackgroundColour() );
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_non_object_2_sv( aTHX_ RETVALSV, RETVAL, "Wx::Colour" );
    wxPli_thread_sv_register( aTHX_ "Wx::Colour", RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__Window_GetBestSize); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Window_GetBestSize)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxWindow *    THIS = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Window" )
;
	wxSize *	RETVAL;
    RETVAL = new wxSize( THIS->GetBestSize() );
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_non_object_2_sv( aTHX_ RETVALSV, RETVAL, "Wx::Size" );
    wxPli_thread_sv_register( aTHX_ "Wx::Size", RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__Window_GetCaret); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Window_GetCaret)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxWindow *    THIS = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Window" )
;
	wxCaret *	RETVAL;

	RETVAL = THIS->GetCaret();
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_non_object_2_sv( aTHX_ RETVALSV, RETVAL, "Wx::Caret" );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__Window_GetCharHeight); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Window_GetCharHeight)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxWindow *    THIS = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Window" )
;
	int	RETVAL;
	dXSTARG;

	RETVAL = THIS->GetCharHeight();
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__Window_GetCharWidth); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Window_GetCharWidth)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxWindow *    THIS = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Window" )
;
	int	RETVAL;
	dXSTARG;

	RETVAL = THIS->GetCharWidth();
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__Window_GetChildren); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Window_GetChildren)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    PERL_UNUSED_VAR(ax); /* -Wall */
    SP -= items;
    {
	wxWindow *    THIS = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Window" )
;
    const wxWindowList& list = THIS->GetChildren();
    wxWindowList::compatibility_iterator node;

    EXTEND( SP, (IV) list.GetCount() );

    for( node = list.GetFirst(); node; node = node->GetNext() )
      PUSHs( wxPli_object_2_sv( aTHX_ sv_newmortal(), node->GetData() ) );
	PUTBACK;
	return;
    }
}


XS_EUPXS(XS_Wx__Window_GetClientSize); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Window_GetClientSize)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxWindow *    THIS = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Window" )
;
	wxSize *	RETVAL;
    RETVAL = new wxSize( THIS->GetClientSize() );
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_non_object_2_sv( aTHX_ RETVALSV, RETVAL, "Wx::Size" );
    wxPli_thread_sv_register( aTHX_ "Wx::Size", RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__Window_GetClientSizeXY); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Window_GetClientSizeXY)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    PERL_UNUSED_VAR(ax); /* -Wall */
    SP -= items;
    {
    int x;
    int y;
	wxWindow *    THIS = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Window" )
;
    THIS->GetClientSize( &x, &y );
    EXTEND( SP, 2 );
    PUSHs( sv_2mortal( newSViv( x ) ) );
    PUSHs( sv_2mortal( newSViv( y ) ) );
	PUTBACK;
	return;
    }
}


XS_EUPXS(XS_Wx__Window_GetContainingSizer); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Window_GetContainingSizer)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxWindow *    THIS = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Window" )
;
	wxSizer *	RETVAL;

	RETVAL = THIS->GetContainingSizer();
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_object_2_sv( aTHX_ RETVALSV, RETVAL );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}

#if wxPERL_USE_DRAG_AND_DROP
#define XSubPPtmpAAAJ 1


XS_EUPXS(XS_Wx__Window_GetDropTarget); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Window_GetDropTarget)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxWindow *    THIS = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Window" )
;
	wxDropTarget *	RETVAL;

	RETVAL = THIS->GetDropTarget();
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_non_object_2_sv( aTHX_ RETVALSV, RETVAL, "Wx::DropTarget" );
	    ST(0) = RETVALSV;
	}
    wxPli_object_set_deleteable( aTHX_ ST(0), false );
    }
    XSRETURN(1);
}

#endif
#if WXPERL_W_VERSION_LT( 2, 7, 0 )
#define XSubPPtmpAAAK 1


XS_EUPXS(XS_Wx__Window_GetDefaultItem); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Window_GetDefaultItem)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxWindow *    THIS = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Window" )
;
	wxWindow *	RETVAL;

	RETVAL = THIS->GetDefaultItem();
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_object_2_sv( aTHX_ RETVALSV, RETVAL );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}

#endif

XS_EUPXS(XS_Wx__Window_GetEventHandler); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Window_GetEventHandler)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxWindow *    THIS = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Window" )
;
	wxEvtHandler *	RETVAL;

	RETVAL = THIS->GetEventHandler();
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_object_2_sv( aTHX_ RETVALSV, RETVAL );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__Window_GetExtraStyle); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Window_GetExtraStyle)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxWindow *    THIS = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Window" )
;
	long	RETVAL;
	dXSTARG;

	RETVAL = THIS->GetExtraStyle();
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__Window_GetFont); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Window_GetFont)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxWindow *    THIS = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Window" )
;
	wxFont *	RETVAL;
    RETVAL = new wxFont( THIS->GetFont() );
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_object_2_sv( aTHX_ RETVALSV, RETVAL );
    wxPli_thread_sv_register( aTHX_ "Wx::Font", RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__Window_GetForegroundColour); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Window_GetForegroundColour)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxWindow *    THIS = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Window" )
;
	wxColour *	RETVAL;
    RETVAL = new wxColour( THIS->GetForegroundColour() );
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_non_object_2_sv( aTHX_ RETVALSV, RETVAL, "Wx::Colour" );
    wxPli_thread_sv_register( aTHX_ "Wx::Colour", RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__Window_GetGrandParent); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Window_GetGrandParent)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxWindow *    THIS = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Window" )
;
	wxWindow *	RETVAL;

	RETVAL = THIS->GetGrandParent();
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_object_2_sv( aTHX_ RETVALSV, RETVAL );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}

#if defined( __WXMSW__ )
#define XSubPPtmpAAAL 1


XS_EUPXS(XS_Wx__Window_CreateWindowFromHWND); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Window_CreateWindowFromHWND)
{
    dVAR; dXSARGS;
    if (items != 3)
       croak_xs_usage(cv,  "THIS, parent, hWnd");
    {
	wxWindow*    parent = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::Window" )
;
	void*	hWnd = INT2PTR(void *,SvIV(ST(2)))
;
	wxWindow *    THIS = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Window" )
;
	wxWindow *	RETVAL;

	RETVAL = THIS->CreateWindowFromHWND(parent, (WXHWND) hWnd);
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_object_2_sv( aTHX_ RETVALSV, RETVAL );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}

#endif
#if ( WXPERL_W_VERSION_GE( 2, 5, 1 ) && defined( __WXMSW__ ) ) \
    || WXPERL_W_VERSION_GE( 2, 5, 4 )
#define XSubPPtmpAAAM 1


XS_EUPXS(XS_Wx__Window_GetHandle); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Window_GetHandle)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxWindow *    THIS = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Window" )
;
	void *	RETVAL;
	dXSTARG;

	RETVAL = THIS->GetHandle();
	XSprePUSH;
	PUSHi(PTR2IV(RETVAL));
    }
    XSRETURN(1);
}

#else
#define XSubPPtmpAAAN 1


XS_EUPXS(XS_Wx__Window_GetHandle); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Window_GetHandle)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxWindow *    THIS = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Window" )
;
	IV	RETVAL;
	dXSTARG;
#ifdef __WXMSW__
    WXHWND handle = THIS->GetHandle();
    RETVAL = handle;
#else
    WXWidget handle = THIS->GetHandle();
    RETVAL = PTR2IV(handle);
#endif
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}

#endif

XS_EUPXS(XS_Wx__Window_GetHelpText); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Window_GetHelpText)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxWindow *    THIS = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Window" )
;
	wxString	RETVAL;

	RETVAL = THIS->GetHelpText();
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    WXSTRING_OUTPUT( RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__Window_GetId); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Window_GetId)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxWindow *    THIS = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Window" )
;
	int	RETVAL;
	dXSTARG;

	RETVAL = THIS->GetId();
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__Window_GetLabel); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Window_GetLabel)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxWindow *    THIS = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Window" )
;
	wxString	RETVAL;

	RETVAL = THIS->GetLabel();
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    WXSTRING_OUTPUT( RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__Window_GetConstraints); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Window_GetConstraints)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxWindow *    THIS = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Window" )
;
	wxLayoutConstraints *	RETVAL;

	RETVAL = THIS->GetConstraints();
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_object_2_sv( aTHX_ RETVALSV, RETVAL );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}

#if WXPERL_W_VERSION_GE( 2, 5, 3 )
#define XSubPPtmpAAAO 1


XS_EUPXS(XS_Wx__Window_GetMinSize); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Window_GetMinSize)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxWindow *    THIS = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Window" )
;
	wxSize *	RETVAL;
    RETVAL = new wxSize( THIS->GetMinSize() );
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_non_object_2_sv( aTHX_ RETVALSV, RETVAL, "Wx::Size" );
    wxPli_thread_sv_register( aTHX_ "Wx::Size", RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__Window_GetMaxSize); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Window_GetMaxSize)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxWindow *    THIS = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Window" )
;
	wxSize *	RETVAL;
    RETVAL = new wxSize( THIS->GetMaxSize() );
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_non_object_2_sv( aTHX_ RETVALSV, RETVAL, "Wx::Size" );
    wxPli_thread_sv_register( aTHX_ "Wx::Size", RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}

#endif

XS_EUPXS(XS_Wx__Window_GetName); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Window_GetName)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxWindow *    THIS = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Window" )
;
	wxString	RETVAL;

	RETVAL = THIS->GetName();
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    WXSTRING_OUTPUT( RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__Window_GetParent); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Window_GetParent)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxWindow *    THIS = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Window" )
;
	wxWindow *	RETVAL;

	RETVAL = THIS->GetParent();
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_object_2_sv( aTHX_ RETVALSV, RETVAL );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__Window_GetPosition); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Window_GetPosition)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxWindow *    THIS = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Window" )
;
	wxPoint *	RETVAL;
    RETVAL = new wxPoint( THIS->GetPosition() );
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_non_object_2_sv( aTHX_ RETVALSV, RETVAL, "Wx::Point" );
    wxPli_thread_sv_register( aTHX_ "Wx::Point", RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__Window_GetPositionXY); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Window_GetPositionXY)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    PERL_UNUSED_VAR(ax); /* -Wall */
    SP -= items;
    {
    int x;
    int y;
	wxWindow *    THIS = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Window" )
;
    THIS->GetPosition( &x, &y );
    EXTEND( SP, 2 );
    PUSHs( sv_2mortal( newSViv( (IV) x ) ) );
    PUSHs( sv_2mortal( newSViv( (IV) y ) ) );
	PUTBACK;
	return;
    }
}


XS_EUPXS(XS_Wx__Window_GetRect); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Window_GetRect)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxWindow *    THIS = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Window" )
;
	wxRect *	RETVAL;
    RETVAL = new wxRect( THIS->GetRect() );
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_non_object_2_sv( aTHX_ RETVALSV, RETVAL, "Wx::Rect" );
    wxPli_thread_sv_register( aTHX_ "Wx::Rect", RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__Window_GetScrollThumb); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Window_GetScrollThumb)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, orientation");
    {
	int	orientation = (int)SvIV(ST(1))
;
	wxWindow *    THIS = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Window" )
;
	int	RETVAL;
	dXSTARG;

	RETVAL = THIS->GetScrollThumb(orientation);
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__Window_GetScrollPos); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Window_GetScrollPos)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, orientation");
    {
	int	orientation = (int)SvIV(ST(1))
;
	wxWindow *    THIS = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Window" )
;
	int	RETVAL;
	dXSTARG;

	RETVAL = THIS->GetScrollPos(orientation);
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__Window_GetScrollRange); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Window_GetScrollRange)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, orientation");
    {
	int	orientation = (int)SvIV(ST(1))
;
	wxWindow *    THIS = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Window" )
;
	int	RETVAL;
	dXSTARG;

	RETVAL = THIS->GetScrollRange(orientation);
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__Window_GetSize); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Window_GetSize)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxWindow *    THIS = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Window" )
;
	wxSize *	RETVAL;
    RETVAL = new wxSize( THIS->GetSize() );
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_non_object_2_sv( aTHX_ RETVALSV, RETVAL, "Wx::Size" );
    wxPli_thread_sv_register( aTHX_ "Wx::Size", RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__Window_GetSizer); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Window_GetSizer)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxWindow *    THIS = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Window" )
;
	wxSizer *	RETVAL;

	RETVAL = THIS->GetSizer();
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_object_2_sv( aTHX_ RETVALSV, RETVAL );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__Window_GetSizeWH); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Window_GetSizeWH)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    PERL_UNUSED_VAR(ax); /* -Wall */
    SP -= items;
    {
    int x;
    int y;
	wxWindow *    THIS = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Window" )
;
    THIS->GetSize( &x, &y );
    EXTEND( SP, 2 );
    PUSHs( sv_2mortal( newSViv( (IV) x ) ) );
    PUSHs( sv_2mortal( newSViv( (IV) y ) ) );
	PUTBACK;
	return;
    }
}


XS_EUPXS(XS_Wx__Window_GetTextExtent); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Window_GetTextExtent)
{
    dVAR; dXSARGS;
    if (items < 2 || items > 3)
       croak_xs_usage(cv,  "THIS, string, font = 0");
    PERL_UNUSED_VAR(ax); /* -Wall */
    SP -= items;
    {
	wxString	string;
	wxFont*	font;
    int x;
    int y;
    int descent;
    int externalLeading;
	wxWindow *    THIS = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Window" )
;

    WXSTRING_INPUT( string, wxString, ST(1) )
;

	if (items < 3)
	    font = 0;
	else {
    font = (wxFont *) wxPli_sv_2_object( aTHX_ ST(2), "Wx::Font" )
;
	}
    THIS->GetTextExtent( string, &x, &y, &descent, &externalLeading,
        font );
    EXTEND( SP, 4 );
    PUSHs( sv_2mortal( newSViv( x ) ) );
    PUSHs( sv_2mortal( newSViv( y ) ) );
    PUSHs( sv_2mortal( newSViv( descent ) ) );
    PUSHs( sv_2mortal( newSViv( externalLeading ) ) );
	PUTBACK;
	return;
    }
}

#if WXPERL_W_VERSION_GE( 2, 7, 0 )
#define XSubPPtmpAAAP 1


XS_EUPXS(XS_Wx__Window_GetTitle); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Window_GetTitle)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxWindow *    THIS = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Window" )
;
	wxString	RETVAL;
    RETVAL = THIS->GetLabel();
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    WXSTRING_OUTPUT( RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}

#else
#define XSubPPtmpAAAQ 1


XS_EUPXS(XS_Wx__Window_GetTitle); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Window_GetTitle)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxWindow *    THIS = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Window" )
;
	wxString	RETVAL;

	RETVAL = THIS->GetTitle();
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    WXSTRING_OUTPUT( RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}

#endif
#if wxPERL_USE_TOOLTIPS
#define XSubPPtmpAAAR 1


XS_EUPXS(XS_Wx__Window_GetToolTip); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Window_GetToolTip)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxWindow *    THIS = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Window" )
;
	wxToolTip *	RETVAL;

	RETVAL = THIS->GetToolTip();
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_object_2_sv( aTHX_ RETVALSV, RETVAL );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}

#endif

XS_EUPXS(XS_Wx__Window_GetUpdateRegion); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Window_GetUpdateRegion)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxWindow *    THIS = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Window" )
;
	wxRegion *	RETVAL;
    RETVAL = new wxRegion( THIS->GetUpdateRegion() );
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_object_2_sv( aTHX_ RETVALSV, RETVAL );
    wxPli_thread_sv_register( aTHX_ "Wx::Region", RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__Window_GetValidator); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Window_GetValidator)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxWindow *    THIS = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Window" )
;
	wxValidator *	RETVAL;

	RETVAL = THIS->GetValidator();
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_object_2_sv( aTHX_ RETVALSV, RETVAL );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__Window_GetWindowStyleFlag); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Window_GetWindowStyleFlag)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxWindow *    THIS = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Window" )
;
	long	RETVAL;
	dXSTARG;

	RETVAL = THIS->GetWindowStyleFlag();
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}

#if WXPERL_W_VERSION_GE( 2, 8, 0 )
#define XSubPPtmpAAAS 1


XS_EUPXS(XS_Wx__Window_GetWindowBorderSize); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Window_GetWindowBorderSize)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxWindow *    THIS = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Window" )
;
	wxSize	RETVAL;

	RETVAL = THIS->GetWindowBorderSize();
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_non_object_2_sv( aTHX_ RETVALSV, new wxSize(RETVAL), "Wx::Size" );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}

#endif
#if WXPERL_W_VERSION_GE( 2, 5, 3 )
#define XSubPPtmpAAAT 1


XS_EUPXS(XS_Wx__Window_InvalidateBestSize); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Window_InvalidateBestSize)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxWindow *    THIS = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Window" )
;

	THIS->InvalidateBestSize();
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__Window_InheritAttributes); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Window_InheritAttributes)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxWindow *    THIS = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Window" )
;

	THIS->InheritAttributes();
    }
    XSRETURN_EMPTY;
}

#endif

XS_EUPXS(XS_Wx__Window_IsEnabled); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Window_IsEnabled)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxWindow *    THIS = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Window" )
;
	bool	RETVAL;

	RETVAL = THIS->IsEnabled();
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}

#if WXPERL_W_VERSION_GE( 2, 9, 0 )
#define XSubPPtmpAAAU 1


XS_EUPXS(XS_Wx__Window_IsThisEnabled); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Window_IsThisEnabled)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxWindow *    THIS = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Window" )
;
	bool	RETVAL;

	RETVAL = THIS->IsThisEnabled();
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}

#endif
#if WXPERL_W_VERSION_GE( 2, 9, 5 )
#define XSubPPtmpAAAV 1


XS_EUPXS(XS_Wx__Window_GetContentScaleFactor); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Window_GetContentScaleFactor)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxWindow *    THIS = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Window" )
;
	double	RETVAL;
	dXSTARG;

	RETVAL = THIS->GetContentScaleFactor();
	XSprePUSH;
	PUSHn((double)RETVAL);
    }
    XSRETURN(1);
}

#endif

XS_EUPXS(XS_Wx__Window_IsExposed); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Window_IsExposed)
{
    dVAR; dXSARGS;
    if (items < 1)
       croak_xs_usage(cv,  "THIS, ...");
    PERL_UNUSED_VAR(ax); /* -Wall */
    SP -= items;
    {
	wxWindow *    THIS = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Window" )
;
    BEGIN_OVERLOAD()
        MATCH_REDISP( wxPliOvl_wpoi, IsExposedPoint )
        MATCH_REDISP( wxPliOvl_wrec, IsExposedRect )
        MATCH_REDISP( wxPliOvl_n_n_n_n, IsExposedXYWH )
    END_OVERLOAD( Wx::Window::IsExposed )
	PUTBACK;
	return;
    }
}


XS_EUPXS(XS_Wx__Window_IsExposedXYWH); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Window_IsExposedXYWH)
{
    dVAR; dXSARGS;
    if (items < 3 || items > 5)
       croak_xs_usage(cv,  "THIS, x, y, w = 0, h = 0");
    {
	int	x = (int)SvIV(ST(1))
;
	int	y = (int)SvIV(ST(2))
;
	int	w;
	int	h;
	wxWindow *    THIS = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Window" )
;
	bool	RETVAL;

	if (items < 4)
	    w = 0;
	else {
	    w = (int)SvIV(ST(3))
;
	}

	if (items < 5)
	    h = 0;
	else {
	    h = (int)SvIV(ST(4))
;
	}
    RETVAL = THIS->IsExposed( x, y, w, h );
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__Window_IsExposedPoint); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Window_IsExposedPoint)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, point");
    {
	wxPoint    point = wxPli_sv_2_wxpoint( aTHX_ ST(1) )
;
	wxWindow *    THIS = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Window" )
;
	bool	RETVAL;
    RETVAL = THIS->IsExposed( point );
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__Window_IsExposedRect); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Window_IsExposedRect)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, rect");
    {
	wxRect*    rect = (wxRect *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::Rect" )
;
	wxWindow *    THIS = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Window" )
;
	bool	RETVAL;
    RETVAL = THIS->IsExposed( *rect );
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__Window_IsRetained); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Window_IsRetained)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxWindow *    THIS = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Window" )
;
	bool	RETVAL;

	RETVAL = THIS->IsRetained();
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__Window_IsShown); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Window_IsShown)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxWindow *    THIS = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Window" )
;
	bool	RETVAL;

	RETVAL = THIS->IsShown();
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__Window_IsTopLevel); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Window_IsTopLevel)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxWindow *    THIS = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Window" )
;
	bool	RETVAL;

	RETVAL = THIS->IsTopLevel();
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}

#if WXPERL_W_VERSION_GE( 2, 7, 2 )
#define XSubPPtmpAAAW 1


XS_EUPXS(XS_Wx__Window_IsDoubleBuffered); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Window_IsDoubleBuffered)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxWindow *    THIS = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Window" )
;
	bool	RETVAL;

	RETVAL = THIS->IsDoubleBuffered();
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__Window_IsShownOnScreen); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Window_IsShownOnScreen)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxWindow *    THIS = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Window" )
;
	bool	RETVAL;

	RETVAL = THIS->IsShownOnScreen();
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}

#endif

XS_EUPXS(XS_Wx__Window_Layout); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Window_Layout)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxWindow *    THIS = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Window" )
;

	THIS->Layout();
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__Window_Lower); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Window_Lower)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxWindow *    THIS = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Window" )
;

	THIS->Lower();
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__Window_MakeModal); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Window_MakeModal)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, flag");
    {
	bool	flag = (bool)SvTRUE(ST(1))
;
	wxWindow *    THIS = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Window" )
;

	THIS->MakeModal(flag);
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__Window_Move); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Window_Move)
{
    dVAR; dXSARGS;
    if (items < 1)
       croak_xs_usage(cv,  "THIS, ...");
    PERL_UNUSED_VAR(ax); /* -Wall */
    SP -= items;
    {
	wxWindow *    THIS = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Window" )
;
    BEGIN_OVERLOAD()
        MATCH_REDISP( wxPliOvl_wpoi, MovePoint )
        MATCH_REDISP( wxPliOvl_n_n, MoveXY )
    END_OVERLOAD( Wx::Window::Move )
	PUTBACK;
	return;
    }
}


XS_EUPXS(XS_Wx__Window_MoveXY); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Window_MoveXY)
{
    dVAR; dXSARGS;
    if (items != 3)
       croak_xs_usage(cv,  "THIS, x, y");
    {
	int	x = (int)SvIV(ST(1))
;
	int	y = (int)SvIV(ST(2))
;
	wxWindow *    THIS = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Window" )
;
    THIS->Move( x, y );
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__Window_MovePoint); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Window_MovePoint)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, point");
    {
	wxPoint    point = wxPli_sv_2_wxpoint( aTHX_ ST(1) )
;
	wxWindow *    THIS = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Window" )
;
    THIS->Move( point );
    }
    XSRETURN_EMPTY;
}

#if WXPERL_W_VERSION_GE( 2, 5, 3 )
#define XSubPPtmpAAAX 1


XS_EUPXS(XS_Wx__Window_MoveBeforeInTabOrder); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Window_MoveBeforeInTabOrder)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, window");
    {
	wxWindow*    window = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::Window" )
;
	wxWindow *    THIS = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Window" )
;

	THIS->MoveBeforeInTabOrder(window);
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__Window_MoveAfterInTabOrder); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Window_MoveAfterInTabOrder)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, window");
    {
	wxWindow*    window = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::Window" )
;
	wxWindow *    THIS = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Window" )
;

	THIS->MoveAfterInTabOrder(window);
    }
    XSRETURN_EMPTY;
}

#endif
#if WXPERL_W_VERSION_GE( 2, 9, 0 )
#define XSubPPtmpAAAY 1


XS_EUPXS(XS_Wx__Window_NavigateIn); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Window_NavigateIn)
{
    dVAR; dXSARGS;
    if (items < 1 || items > 2)
       croak_xs_usage(cv,  "THIS, flags = wxNavigationKeyEvent::IsForward");
    {
	int	flags;
	wxWindow *    THIS = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Window" )
;
	bool	RETVAL;

	if (items < 2)
	    flags = wxNavigationKeyEvent::IsForward;
	else {
	    flags = (int)SvIV(ST(1))
;
	}

	RETVAL = THIS->NavigateIn(flags);
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}

#endif

XS_EUPXS(XS_Wx__Window_Navigate); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Window_Navigate)
{
    dVAR; dXSARGS;
    if (items < 1 || items > 2)
       croak_xs_usage(cv,  "THIS, flags = wxNavigationKeyEvent::IsForward");
    {
	int	flags;
	wxWindow *    THIS = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Window" )
;
	bool	RETVAL;

	if (items < 2)
	    flags = wxNavigationKeyEvent::IsForward;
	else {
	    flags = (int)SvIV(ST(1))
;
	}

	RETVAL = THIS->Navigate(flags);
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__Window_PopEventHandler); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Window_PopEventHandler)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, deleteHandler");
    {
	bool	deleteHandler = (bool)SvTRUE(ST(1))
;
	wxWindow *    THIS = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Window" )
;
	wxEvtHandler *	RETVAL;

	RETVAL = THIS->PopEventHandler(deleteHandler);
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_object_2_sv( aTHX_ RETVALSV, RETVAL );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__Window_PopupMenu); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Window_PopupMenu)
{
    dVAR; dXSARGS;
    if (items < 1)
       croak_xs_usage(cv,  "THIS, ...");
    PERL_UNUSED_VAR(ax); /* -Wall */
    SP -= items;
    {
	wxWindow *    THIS = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Window" )
;
    BEGIN_OVERLOAD()
        MATCH_REDISP( wxPliOvl_wmen_wpoi, PopupMenuPoint )
        MATCH_REDISP( wxPliOvl_wmen_n_n, PopupMenuXY )
    END_OVERLOAD( Wx::Window::PopupMenu )
	PUTBACK;
	return;
    }
}


XS_EUPXS(XS_Wx__Window_PopupMenuPoint); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Window_PopupMenuPoint)
{
    dVAR; dXSARGS;
    if (items != 3)
       croak_xs_usage(cv,  "THIS, menu, point");
    {
	wxMenu*    menu = (wxMenu *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::Menu" )
;
	wxPoint    point = wxPli_sv_2_wxpoint( aTHX_ ST(2) )
;
	wxWindow *    THIS = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Window" )
;
	bool	RETVAL;
    RETVAL = THIS->PopupMenu( menu, point );
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__Window_PopupMenuXY); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Window_PopupMenuXY)
{
    dVAR; dXSARGS;
    if (items != 4)
       croak_xs_usage(cv,  "THIS, menu, x, y");
    {
	wxMenu*    menu = (wxMenu *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::Menu" )
;
	int	x = (int)SvIV(ST(2))
;
	int	y = (int)SvIV(ST(3))
;
	wxWindow *    THIS = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Window" )
;
	bool	RETVAL;
    RETVAL = THIS->PopupMenu( menu, x, y );
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__Window_PushEventHandler); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Window_PushEventHandler)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, handler");
    {
	wxEvtHandler*    handler = (wxEvtHandler *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::EvtHandler" )
;
	wxWindow *    THIS = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Window" )
;

	THIS->PushEventHandler(handler);
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__Window_Raise); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Window_Raise)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxWindow *    THIS = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Window" )
;

	THIS->Raise();
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__Window_Refresh); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Window_Refresh)
{
    dVAR; dXSARGS;
    if (items < 1 || items > 3)
       croak_xs_usage(cv,  "THIS, eraseBackground = true, rect = 0");
    {
	bool	eraseBackground;
	wxRect*	rect;
	wxWindow *    THIS = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Window" )
;

	if (items < 2)
	    eraseBackground = true;
	else {
	    eraseBackground = (bool)SvTRUE(ST(1))
;
	}

	if (items < 3)
	    rect = 0;
	else {
    rect = (wxRect *) wxPli_sv_2_object( aTHX_ ST(2), "Wx::Rect" )
;
	}

	THIS->Refresh(eraseBackground, rect);
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__Window_ReleaseMouse); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Window_ReleaseMouse)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxWindow *    THIS = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Window" )
;

	THIS->ReleaseMouse();
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__Window_RemoveEventHandler); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Window_RemoveEventHandler)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, handler");
    {
	wxEvtHandler*    handler = (wxEvtHandler *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::EvtHandler" )
;
	wxWindow *    THIS = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Window" )
;
	bool	RETVAL;

	RETVAL = THIS->RemoveEventHandler(handler);
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__Window_Reparent); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Window_Reparent)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, newParent");
    {
	wxWindow*    newParent = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::Window" )
;
	wxWindow *    THIS = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Window" )
;
	bool	RETVAL;

	RETVAL = THIS->Reparent(newParent);
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__Window_ScreenToClient); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Window_ScreenToClient)
{
    dVAR; dXSARGS;
    if (items < 1)
       croak_xs_usage(cv,  "THIS, ...");
    PERL_UNUSED_VAR(ax); /* -Wall */
    SP -= items;
    {
	wxWindow *    THIS = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Window" )
;
    BEGIN_OVERLOAD()
        MATCH_REDISP( wxPliOvl_n_n, ScreenToClientXY )
        MATCH_REDISP( wxPliOvl_wpoi, ScreenToClientPoint )
    END_OVERLOAD( Wx::Window::ScreenToClient )
	PUTBACK;
	return;
    }
}


XS_EUPXS(XS_Wx__Window_ScreenToClientPoint); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Window_ScreenToClientPoint)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, point");
    {
	wxPoint    point = wxPli_sv_2_wxpoint( aTHX_ ST(1) )
;
	wxWindow *    THIS = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Window" )
;
	wxPoint *	RETVAL;
    RETVAL = new wxPoint( THIS->ScreenToClient( point ) );
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_non_object_2_sv( aTHX_ RETVALSV, RETVAL, "Wx::Point" );
    wxPli_thread_sv_register( aTHX_ "Wx::Point", RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__Window_ScreenToClientXY); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Window_ScreenToClientXY)
{
    dVAR; dXSARGS;
    if (items != 3)
       croak_xs_usage(cv,  "THIS, x, y");
    PERL_UNUSED_VAR(ax); /* -Wall */
    SP -= items;
    {
	int	x = (int)SvIV(ST(1))
;
	int	y = (int)SvIV(ST(2))
;
	wxWindow *    THIS = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Window" )
;
    THIS->ScreenToClient( &x, &y );
    EXTEND( SP, 2 );
    PUSHs( sv_2mortal( newSViv( (IV) x ) ) );
    PUSHs( sv_2mortal( newSViv( (IV) y ) ) );
	PUTBACK;
	return;
    }
}


XS_EUPXS(XS_Wx__Window_ScrollLines); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Window_ScrollLines)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, lines");
    {
	int	lines = (int)SvIV(ST(1))
;
	wxWindow *    THIS = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Window" )
;
	bool	RETVAL;

	RETVAL = THIS->ScrollLines(lines);
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__Window_ScrollPages); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Window_ScrollPages)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, lines");
    {
	int	lines = (int)SvIV(ST(1))
;
	wxWindow *    THIS = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Window" )
;
	bool	RETVAL;

	RETVAL = THIS->ScrollPages(lines);
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__Window_ScrollWindow); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Window_ScrollWindow)
{
    dVAR; dXSARGS;
    if (items < 3 || items > 4)
       croak_xs_usage(cv,  "THIS, x, y, rect = 0");
    {
	int	x = (int)SvIV(ST(1))
;
	int	y = (int)SvIV(ST(2))
;
	wxRect*	rect;
	wxWindow *    THIS = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Window" )
;

	if (items < 4)
	    rect = 0;
	else {
    rect = (wxRect *) wxPli_sv_2_object( aTHX_ ST(3), "Wx::Rect" )
;
	}

	THIS->ScrollWindow(x, y, rect);
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__Window_SetAcceleratorTable); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Window_SetAcceleratorTable)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, accel");
    {
	wxAcceleratorTable*    accel = (wxAcceleratorTable *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::AcceleratorTable" )
;
	wxWindow *    THIS = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Window" )
;

	THIS->SetAcceleratorTable(*accel);
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__Window_SetAutoLayout); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Window_SetAutoLayout)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, autoLayout");
    {
	bool	autoLayout = (bool)SvTRUE(ST(1))
;
	wxWindow *    THIS = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Window" )
;

	THIS->SetAutoLayout(autoLayout);
    }
    XSRETURN_EMPTY;
}

#ifdef __WXGTK__
#define XSubPPtmpAAAZ 1


XS_EUPXS(XS_Wx__Window_SetThemeEnabled); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Window_SetThemeEnabled)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, themeEnabled");
    {
	bool	themeEnabled = (bool)SvTRUE(ST(1))
;
	wxWindow *    THIS = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Window" )
;

	THIS->SetThemeEnabled(themeEnabled);
    }
    XSRETURN_EMPTY;
}

#endif
#if WXPERL_W_VERSION_GE( 2, 5, 3 )
#define XSubPPtmpAABA 1


XS_EUPXS(XS_Wx__Window_SetBackgroundStyle); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Window_SetBackgroundStyle)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, style");
    {
	wxBackgroundStyle	style = (wxBackgroundStyle)SvIV(ST(1))
;
	wxWindow *    THIS = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Window" )
;
	bool	RETVAL;

	RETVAL = THIS->SetBackgroundStyle(style);
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}

#endif
#if WXPERL_W_VERSION_GE( 2, 5, 3 )
#define XSubPPtmpAABB 1


XS_EUPXS(XS_Wx__Window_SetBestFittingSize); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Window_SetBestFittingSize)
{
    dVAR; dXSARGS;
    if (items < 1 || items > 2)
       croak_xs_usage(cv,  "THIS, size = wxDefaultSize");
    {
	wxSize	size;
	wxWindow *    THIS = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Window" )
;

	if (items < 2)
	    size = wxDefaultSize;
	else {
    size = wxPli_sv_2_wxsize( aTHX_ ST(1) )
;
	}
#if WXPERL_W_VERSION_LT( 2, 7, 2 )
    THIS->SetBestFittingSize( size );
#else
    THIS->SetInitialSize( size );
#endif
    }
    XSRETURN_EMPTY;
}

#endif
#if WXPERL_W_VERSION_GE( 2, 7, 2 )
#define XSubPPtmpAABC 1


XS_EUPXS(XS_Wx__Window_SetInitialSize); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Window_SetInitialSize)
{
    dVAR; dXSARGS;
    if (items < 1 || items > 2)
       croak_xs_usage(cv,  "THIS, size = wxDefaultSize");
    {
	wxSize	size;
	wxWindow *    THIS = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Window" )
;

	if (items < 2)
	    size = wxDefaultSize;
	else {
    size = wxPli_sv_2_wxsize( aTHX_ ST(1) )
;
	}

	THIS->SetInitialSize(size);
    }
    XSRETURN_EMPTY;
}

#endif

XS_EUPXS(XS_Wx__Window_SetCaret); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Window_SetCaret)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, caret");
    {
	wxCaret*    caret = (wxCaret *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::Caret" )
;
	wxWindow *    THIS = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Window" )
;

	THIS->SetCaret(caret);
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__Window_SetClientSize); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Window_SetClientSize)
{
    dVAR; dXSARGS;
    if (items < 1)
       croak_xs_usage(cv,  "THIS, ...");
    PERL_UNUSED_VAR(ax); /* -Wall */
    SP -= items;
    {
	wxWindow *    THIS = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Window" )
;
    BEGIN_OVERLOAD()
        MATCH_REDISP( wxPliOvl_wsiz, SetClientSizeSize )
        MATCH_REDISP( wxPliOvl_n_n, SetClientSizeWH )
    END_OVERLOAD( Wx::Window::SetClientSize )
	PUTBACK;
	return;
    }
}


XS_EUPXS(XS_Wx__Window_SetClientSizeSize); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Window_SetClientSizeSize)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, size");
    {
	wxSize    size = wxPli_sv_2_wxsize( aTHX_ ST(1) )
;
	wxWindow *    THIS = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Window" )
;
    THIS->SetClientSize( size );
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__Window_SetClientSizeWH); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Window_SetClientSizeWH)
{
    dVAR; dXSARGS;
    if (items != 3)
       croak_xs_usage(cv,  "THIS, width, height");
    {
	int	width = (int)SvIV(ST(1))
;
	int	height = (int)SvIV(ST(2))
;
	wxWindow *    THIS = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Window" )
;
    THIS->SetClientSize( width, height );
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__Window_SetConstraints); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Window_SetConstraints)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, constraints");
    {
	wxLayoutConstraints*    constraints = (wxLayoutConstraints *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::LayoutConstraints" )
;
	wxWindow *    THIS = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Window" )
;

	THIS->SetConstraints(constraints);
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__Window_SetContainingSizer); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Window_SetContainingSizer)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, sizer");
    {
	wxSizer*    sizer = (wxSizer *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::Sizer" )
;
	wxWindow *    THIS = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Window" )
;

	THIS->SetContainingSizer(sizer);
    }
    XSRETURN_EMPTY;
}

#if WXPERL_W_VERSION_LT( 2, 7, 0 )
#define XSubPPtmpAABD 1


XS_EUPXS(XS_Wx__Window_SetDefaultItem); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Window_SetDefaultItem)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, window");
    {
	wxWindow*    window = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::Window" )
;
	wxWindow *    THIS = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Window" )
;
	wxWindow *	RETVAL;

	RETVAL = THIS->SetDefaultItem(window);
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_object_2_sv( aTHX_ RETVALSV, RETVAL );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}

#endif
#if wxPERL_USE_DRAG_AND_DROP
#define XSubPPtmpAABE 1


XS_EUPXS(XS_Wx__Window_SetDropTarget); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Window_SetDropTarget)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, target");
    {
	wxDropTarget*    target = (wxDropTarget *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::DropTarget" )
;
	wxWindow *    THIS = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Window" )
;
    wxPli_object_set_deleteable( aTHX_ ST(1), false );
    SvREFCNT_inc( SvRV( ST(1) ) ); // at this point the scalar must not go away
    THIS->SetDropTarget( target );
    }
    XSRETURN_EMPTY;
}

#endif

XS_EUPXS(XS_Wx__Window_SetEventHandler); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Window_SetEventHandler)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, handler");
    {
	wxEvtHandler*    handler = (wxEvtHandler *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::EvtHandler" )
;
	wxWindow *    THIS = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Window" )
;

	THIS->SetEventHandler(handler);
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__Window_SetExtraStyle); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Window_SetExtraStyle)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, style");
    {
	long	style = (long)SvIV(ST(1))
;
	wxWindow *    THIS = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Window" )
;

	THIS->SetExtraStyle(style);
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__Window_SetFocus); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Window_SetFocus)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxWindow *    THIS = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Window" )
;

	THIS->SetFocus();
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__Window_SetHelpText); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Window_SetHelpText)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, text");
    {
	wxString	text;
	wxWindow *    THIS = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Window" )
;

    WXSTRING_INPUT( text, wxString, ST(1) )
;

	THIS->SetHelpText(text);
    }
    XSRETURN_EMPTY;
}

#if WXPERL_W_VERSION_LT( 2, 9, 0 ) || WXWIN_COMPATIBILITY_2_8
#define XSubPPtmpAABF 1


XS_EUPXS(XS_Wx__Window_SetHelpTextForId); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Window_SetHelpTextForId)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, text");
    {
	wxString	text;
	wxWindow *    THIS = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Window" )
;

    WXSTRING_INPUT( text, wxString, ST(1) )
;

	THIS->SetHelpTextForId(text);
    }
    XSRETURN_EMPTY;
}

#endif

XS_EUPXS(XS_Wx__Window_SetId); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Window_SetId)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, id");
    {
	int	id = (int)SvIV(ST(1))
;
	wxWindow *    THIS = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Window" )
;

	THIS->SetId(id);
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__Window_SetLabel); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Window_SetLabel)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, label");
    {
	wxString	label;
	wxWindow *    THIS = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Window" )
;

    WXSTRING_INPUT( label, wxString, ST(1) )
;

	THIS->SetLabel(label);
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__Window_SetName); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Window_SetName)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, name");
    {
	wxString	name;
	wxWindow *    THIS = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Window" )
;

    WXSTRING_INPUT( name, wxString, ST(1) )
;

	THIS->SetName(name);
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__Window_SetScrollbar); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Window_SetScrollbar)
{
    dVAR; dXSARGS;
    if (items < 5 || items > 6)
       croak_xs_usage(cv,  "THIS, orientation, position, thumbSize, range, refresh = true");
    {
	int	orientation = (int)SvIV(ST(1))
;
	int	position = (int)SvIV(ST(2))
;
	int	thumbSize = (int)SvIV(ST(3))
;
	int	range = (int)SvIV(ST(4))
;
	bool	refresh;
	wxWindow *    THIS = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Window" )
;

	if (items < 6)
	    refresh = true;
	else {
	    refresh = (bool)SvTRUE(ST(5))
;
	}

	THIS->SetScrollbar(orientation, position, thumbSize, range, refresh);
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__Window_SetScrollPos); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Window_SetScrollPos)
{
    dVAR; dXSARGS;
    if (items < 3 || items > 4)
       croak_xs_usage(cv,  "THIS, orientation, position, refresh = true");
    {
	int	orientation = (int)SvIV(ST(1))
;
	int	position = (int)SvIV(ST(2))
;
	bool	refresh;
	wxWindow *    THIS = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Window" )
;

	if (items < 4)
	    refresh = true;
	else {
	    refresh = (bool)SvTRUE(ST(3))
;
	}

	THIS->SetScrollPos(orientation, position, refresh);
    }
    XSRETURN_EMPTY;
}

#if WXPERL_W_VERSION_GE( 2, 5, 3 )
#define XSubPPtmpAABG 1


XS_EUPXS(XS_Wx__Window_SetMinSize); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Window_SetMinSize)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, size");
    {
	wxSize    size = wxPli_sv_2_wxsize( aTHX_ ST(1) )
;
	wxWindow *    THIS = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Window" )
;

	THIS->SetMinSize(size);
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__Window_SetMaxSize); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Window_SetMaxSize)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, size");
    {
	wxSize    size = wxPli_sv_2_wxsize( aTHX_ ST(1) )
;
	wxWindow *    THIS = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Window" )
;

	THIS->SetMaxSize(size);
    }
    XSRETURN_EMPTY;
}

#endif

XS_EUPXS(XS_Wx__Window_SetSize); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Window_SetSize)
{
    dVAR; dXSARGS;
    if (items < 1)
       croak_xs_usage(cv,  "THIS, ...");
    PERL_UNUSED_VAR(ax); /* -Wall */
    SP -= items;
    {
	wxWindow *    THIS = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Window" )
;
    BEGIN_OVERLOAD()
        MATCH_REDISP_COUNT_ALLOWMORE( wxPliOvl_n_n_n_n_n, SetSizeXYWHF, 4 )
        MATCH_REDISP( wxPliOvl_n_n, SetSizeWH )
        MATCH_REDISP( wxPliOvl_wsiz, SetSizeSize )
        MATCH_REDISP( wxPliOvl_wrec, SetSizeRect )
    END_OVERLOAD( Wx::Window::SetSize )
	PUTBACK;
	return;
    }
}


XS_EUPXS(XS_Wx__Window_SetSizeSize); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Window_SetSizeSize)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, size");
    {
	wxSize    size = wxPli_sv_2_wxsize( aTHX_ ST(1) )
;
	wxWindow *    THIS = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Window" )
;
    THIS->SetSize( size );
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__Window_SetSizeRect); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Window_SetSizeRect)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, rect");
    {
	wxRect*    rect = (wxRect *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::Rect" )
;
	wxWindow *    THIS = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Window" )
;
    THIS->SetSize( *rect );
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__Window_SetSizeWH); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Window_SetSizeWH)
{
    dVAR; dXSARGS;
    if (items != 3)
       croak_xs_usage(cv,  "THIS, width, height");
    {
	int	width = (int)SvIV(ST(1))
;
	int	height = (int)SvIV(ST(2))
;
	wxWindow *    THIS = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Window" )
;
    THIS->SetSize( width, height );
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__Window_SetSizeXYWHF); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Window_SetSizeXYWHF)
{
    dVAR; dXSARGS;
    if (items < 5 || items > 6)
       croak_xs_usage(cv,  "THIS, x, y, width, height, flags = wxSIZE_AUTO");
    {
	int	x = (int)SvIV(ST(1))
;
	int	y = (int)SvIV(ST(2))
;
	int	width = (int)SvIV(ST(3))
;
	int	height = (int)SvIV(ST(4))
;
	int	flags;
	wxWindow *    THIS = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Window" )
;

	if (items < 6)
	    flags = wxSIZE_AUTO;
	else {
	    flags = (int)SvIV(ST(5))
;
	}
    THIS->SetSize( x, y, width, height, flags );
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__Window_SetSizeHints); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Window_SetSizeHints)
{
    dVAR; dXSARGS;
    if (items < 3 || items > 7)
       croak_xs_usage(cv,  "THIS, minW, minH, maxW = -1, maxH = -1, incW = -1, incH = -1");
    {
	int	minW = (int)SvIV(ST(1))
;
	int	minH = (int)SvIV(ST(2))
;
	int	maxW;
	int	maxH;
	int	incW;
	int	incH;
	wxWindow *    THIS = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Window" )
;

	if (items < 4)
	    maxW = -1;
	else {
	    maxW = (int)SvIV(ST(3))
;
	}

	if (items < 5)
	    maxH = -1;
	else {
	    maxH = (int)SvIV(ST(4))
;
	}

	if (items < 6)
	    incW = -1;
	else {
	    incW = (int)SvIV(ST(5))
;
	}

	if (items < 7)
	    incH = -1;
	else {
	    incH = (int)SvIV(ST(6))
;
	}

	THIS->SetSizeHints(minW, minH, maxW, maxH, incW, incH);
    }
    XSRETURN_EMPTY;
}

#if WXPERL_W_VERSION_LT( 2, 9, 0 )
#define XSubPPtmpAABH 1


XS_EUPXS(XS_Wx__Window_SetVirtualSizeHints); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Window_SetVirtualSizeHints)
{
    dVAR; dXSARGS;
    if (items < 3 || items > 5)
       croak_xs_usage(cv,  "THIS, minW, minH, maxW = -1, maxH = -1");
    {
	int	minW = (int)SvIV(ST(1))
;
	int	minH = (int)SvIV(ST(2))
;
	int	maxW;
	int	maxH;
	wxWindow *    THIS = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Window" )
;

	if (items < 4)
	    maxW = -1;
	else {
	    maxW = (int)SvIV(ST(3))
;
	}

	if (items < 5)
	    maxH = -1;
	else {
	    maxH = (int)SvIV(ST(4))
;
	}

	THIS->SetVirtualSizeHints(minW, minH, maxW, maxH);
    }
    XSRETURN_EMPTY;
}

#endif

XS_EUPXS(XS_Wx__Window_SetVirtualSize); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Window_SetVirtualSize)
{
    dVAR; dXSARGS;
    if (items < 1)
       croak_xs_usage(cv,  "THIS, ...");
    PERL_UNUSED_VAR(ax); /* -Wall */
    SP -= items;
    {
	wxWindow *    THIS = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Window" )
;
    BEGIN_OVERLOAD()
        MATCH_REDISP( wxPliOvl_n_n, SetVirtualSizeXY )
        MATCH_REDISP( wxPliOvl_wsiz, SetVirtualSizeSize )
    END_OVERLOAD( Wx::Window::SetVirtualSize )
	PUTBACK;
	return;
    }
}


XS_EUPXS(XS_Wx__Window_SetVirtualSizeXY); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Window_SetVirtualSizeXY)
{
    dVAR; dXSARGS;
    if (items != 3)
       croak_xs_usage(cv,  "THIS, width, height");
    {
	int	width = (int)SvIV(ST(1))
;
	int	height = (int)SvIV(ST(2))
;
	wxWindow *    THIS = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Window" )
;
    THIS->SetVirtualSize( width, height );
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__Window_SetVirtualSizeSize); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Window_SetVirtualSizeSize)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, size");
    {
	wxSize    size = wxPli_sv_2_wxsize( aTHX_ ST(1) )
;
	wxWindow *    THIS = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Window" )
;
    THIS->SetVirtualSize( size );
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__Window_SetSizer); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Window_SetSizer)
{
    dVAR; dXSARGS;
    if (items < 2 || items > 3)
       croak_xs_usage(cv,  "THIS, sizer, deleteOld = true");
    {
	wxSizer*    sizer = (wxSizer *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::Sizer" )
;
	bool	deleteOld;
	wxWindow *    THIS = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Window" )
;

	if (items < 3)
	    deleteOld = true;
	else {
	    deleteOld = (bool)SvTRUE(ST(2))
;
	}

	THIS->SetSizer(sizer, deleteOld);
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__Window_SetSizerAndFit); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Window_SetSizerAndFit)
{
    dVAR; dXSARGS;
    if (items < 2 || items > 3)
       croak_xs_usage(cv,  "THIS, sizer, deleteOld = true");
    {
	wxSizer*    sizer = (wxSizer *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::Sizer" )
;
	bool	deleteOld;
	wxWindow *    THIS = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Window" )
;

	if (items < 3)
	    deleteOld = true;
	else {
	    deleteOld = (bool)SvTRUE(ST(2))
;
	}

	THIS->SetSizerAndFit(sizer, deleteOld);
    }
    XSRETURN_EMPTY;
}

#if WXPERL_W_VERSION_GE( 2, 7, 0 )
#define XSubPPtmpAABI 1


XS_EUPXS(XS_Wx__Window_SetTitle); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Window_SetTitle)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, title");
    {
	wxString	title;
	wxWindow *    THIS = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Window" )
;

    WXSTRING_INPUT( title, wxString, ST(1) )
;
    THIS->SetLabel( title );
    }
    XSRETURN_EMPTY;
}

#else
#define XSubPPtmpAABJ 1


XS_EUPXS(XS_Wx__Window_SetTitle); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Window_SetTitle)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, title");
    {
	wxString	title;
	wxWindow *    THIS = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Window" )
;

    WXSTRING_INPUT( title, wxString, ST(1) )
;

	THIS->SetTitle(title);
    }
    XSRETURN_EMPTY;
}

#endif
#if wxPERL_USE_TOOLTIPS
#define XSubPPtmpAABK 1


XS_EUPXS(XS_Wx__Window_SetToolTip); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Window_SetToolTip)
{
    dVAR; dXSARGS;
    if (items < 1)
       croak_xs_usage(cv,  "THIS, ...");
    PERL_UNUSED_VAR(ax); /* -Wall */
    SP -= items;
    {
	wxWindow *    THIS = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Window" )
;
    BEGIN_OVERLOAD()
        MATCH_REDISP( wxPliOvl_wtip, SetToolTipTip )
        MATCH_REDISP( wxPliOvl_s, SetToolTipString )
    END_OVERLOAD( Wx::Window::SetToolTip )
	PUTBACK;
	return;
    }
}


XS_EUPXS(XS_Wx__Window_SetToolTipTip); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Window_SetToolTipTip)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, tooltip");
    {
	wxToolTip*    tooltip = (wxToolTip *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::ToolTip" )
;
	wxWindow *    THIS = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Window" )
;
    THIS->SetToolTip( tooltip );
    }
    XSRETURN_EMPTY;
}

#endif
#if wxPERL_USE_TOOLTIPS || WXPERL_W_VERSION_GE( 2, 5, 3 )
#define XSubPPtmpAABL 1


XS_EUPXS(XS_Wx__Window_SetToolTipString); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Window_SetToolTipString)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, string");
    {
	wxString	string;
	wxWindow *    THIS = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Window" )
;

    WXSTRING_INPUT( string, wxString, ST(1) )
;
    THIS->SetToolTip( string );
    }
    XSRETURN_EMPTY;
}

#endif

XS_EUPXS(XS_Wx__Window_SetValidator); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Window_SetValidator)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, validator");
    {
	wxValidator*    validator = (wxValidator *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::Validator" )
;
	wxWindow *    THIS = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Window" )
;
    THIS->SetValidator( *validator );
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__Window_SetWindowStyle); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Window_SetWindowStyle)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, style");
    {
	long	style = (long)SvIV(ST(1))
;
	wxWindow *    THIS = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Window" )
;

	THIS->SetWindowStyle(style);
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__Window_SetWindowStyleFlag); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Window_SetWindowStyleFlag)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, style");
    {
	long	style = (long)SvIV(ST(1))
;
	wxWindow *    THIS = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Window" )
;

	THIS->SetWindowStyleFlag(style);
    }
    XSRETURN_EMPTY;
}

#if WXPERL_W_VERSION_GE( 2, 5, 3 )
#define XSubPPtmpAABM 1


XS_EUPXS(XS_Wx__Window_ShouldInheritColours); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Window_ShouldInheritColours)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxWindow *    THIS = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Window" )
;
	bool	RETVAL;

	RETVAL = THIS->ShouldInheritColours();
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}

#endif

XS_EUPXS(XS_Wx__Window_Show); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Window_Show)
{
    dVAR; dXSARGS;
    if (items < 1 || items > 2)
       croak_xs_usage(cv,  "THIS, show = true");
    {
	bool	show;
	wxWindow *    THIS = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Window" )
;
	bool	RETVAL;

	if (items < 2)
	    show = true;
	else {
	    show = (bool)SvTRUE(ST(1))
;
	}

	RETVAL = THIS->Show(show);
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}

#if WXPERL_W_VERSION_GE( 2, 7, 0 )
#define XSubPPtmpAABN 1


XS_EUPXS(XS_Wx__Window_HasMultiplePages); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Window_HasMultiplePages)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxWindow *    THIS = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Window" )
;
	bool	RETVAL;

	RETVAL = THIS->HasMultiplePages();
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}

#endif

XS_EUPXS(XS_Wx__Window_Hide); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Window_Hide)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxWindow *    THIS = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Window" )
;
	bool	RETVAL;

	RETVAL = THIS->Hide();
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__Window_Thaw); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Window_Thaw)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxWindow *    THIS = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Window" )
;

	THIS->Thaw();
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__Window_TransferDataFromWindow); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Window_TransferDataFromWindow)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxWindow *    THIS = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Window" )
;
	bool	RETVAL;
    RETVAL = THIS->wxWindow::TransferDataFromWindow();
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__Window_TransferDataToWindow); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Window_TransferDataToWindow)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxWindow *    THIS = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Window" )
;
	bool	RETVAL;
    RETVAL = THIS->wxWindow::TransferDataToWindow();
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__Window_Validate); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Window_Validate)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxWindow *    THIS = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Window" )
;
	bool	RETVAL;
    RETVAL = THIS->wxWindow::Validate();
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__Window_Update); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Window_Update)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxWindow *    THIS = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Window" )
;

	THIS->Update();
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__Window_InitDialog); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Window_InitDialog)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxWindow *    THIS = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Window" )
;

	THIS->InitDialog();
    }
    XSRETURN_EMPTY;
}

#if WXPERL_W_VERSION_GE( 2, 6, 0 )
#define XSubPPtmpAABO 1


XS_EUPXS(XS_Wx__Window_UpdateWindowUI); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Window_UpdateWindowUI)
{
    dVAR; dXSARGS;
    if (items < 1 || items > 2)
       croak_xs_usage(cv,  "THIS, flags = wxUPDATE_UI_NONE");
    {
	long	flags;
	wxWindow *    THIS = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Window" )
;

	if (items < 2)
	    flags = wxUPDATE_UI_NONE;
	else {
	    flags = (long)SvIV(ST(1))
;
	}

	THIS->UpdateWindowUI(flags);
    }
    XSRETURN_EMPTY;
}

#endif

XS_EUPXS(XS_Wx__Window_RefreshRect); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Window_RefreshRect)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, rect");
    {
	wxRect*    rect = (wxRect *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::Rect" )
;
	wxWindow *    THIS = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Window" )
;
    THIS->RefreshRect( *rect );
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__Window_WarpPointer); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Window_WarpPointer)
{
    dVAR; dXSARGS;
    if (items != 3)
       croak_xs_usage(cv,  "THIS, x, y");
    {
	int	x = (int)SvIV(ST(1))
;
	int	y = (int)SvIV(ST(2))
;
	wxWindow *    THIS = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Window" )
;

	THIS->WarpPointer(x, y);
    }
    XSRETURN_EMPTY;
}

#if WXPERL_W_VERSION_GE( 2, 7, 1 )
#define XSubPPtmpAABP 1


XS_EUPXS(XS_Wx__Window_GetLayoutDirection); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Window_GetLayoutDirection)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxWindow *    THIS = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Window" )
;
	wxLayoutDirection	RETVAL;
	dXSTARG;

	RETVAL = THIS->GetLayoutDirection();
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__Window_SetLayoutDirection); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Window_SetLayoutDirection)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, direction");
    {
	wxLayoutDirection	direction = (wxLayoutDirection)SvIV(ST(1))
;
	wxWindow *    THIS = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Window" )
;

	THIS->SetLayoutDirection(direction);
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__Window_SetTransparent); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Window_SetTransparent)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, alpha");
    {
	wxByte	alpha = (unsigned char)SvUV(ST(1))
;
	wxWindow *    THIS = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Window" )
;
	bool	RETVAL;

	RETVAL = THIS->SetTransparent(alpha);
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__Window_CanSetTransparent); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Window_CanSetTransparent)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxWindow *    THIS = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Window" )
;
	bool	RETVAL;

	RETVAL = THIS->CanSetTransparent();
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}

#endif

/* INCLUDE_COMMAND:  Including output of '/usr/bin/perl -I./ -MExtUtils::XSpp::Cmd -e xspp -- -t typemap.xsp XS/Window.xsp' from 'Window.xs' */

#include <exception>

#undef  xsp_constructor_class
#define xsp_constructor_class(c) (c)
#if WXPERL_W_VERSION_GE( 2, 9, 0 )
#define XSpp_4e75b735_000604
#define XSubPPtmpAABQ 1


XS_EUPXS(XS_Wx__Window_AlwaysShowScrollbars); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Window_AlwaysShowScrollbars)
{
    dVAR; dXSARGS;
    if (items < 1 || items > 3)
       croak_xs_usage(cv,  "THIS, horz= true, vert= true");
    {
	wxWindow *    THIS = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Window" )
;
	bool	horz;
	bool	vert;

	if (items < 2)
	    horz = true;
	else {
	    horz = (bool)SvTRUE(ST(1))
;
	}

	if (items < 3)
	    vert = true;
	else {
	    vert = (bool)SvTRUE(ST(2))
;
	}
    try {
      THIS->AlwaysShowScrollbars( horz, vert );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}

#endif

XS_EUPXS(XS_Wx__Window_AcceptsFocus); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Window_AcceptsFocus)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxWindow *    THIS = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Window" )
;
	bool	RETVAL;
    try {
      RETVAL = THIS->AcceptsFocus();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__Window_AcceptsFocusFromKeyboard); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Window_AcceptsFocusFromKeyboard)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxWindow *    THIS = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Window" )
;
	bool	RETVAL;
    try {
      RETVAL = THIS->AcceptsFocusFromKeyboard();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__Window_DestroyChildren); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Window_DestroyChildren)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxWindow *    THIS = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Window" )
;
	bool	RETVAL;
    try {
      RETVAL = THIS->DestroyChildren();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__Window_IsBeingDeleted); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Window_IsBeingDeleted)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxWindow *    THIS = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Window" )
;
	bool	RETVAL;
    try {
      RETVAL = THIS->IsBeingDeleted();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}

#if WXPERL_W_VERSION_GE( 2, 9, 0 )
#define XSpp_4e75b735_097627
#define XSubPPtmpAABR 1


XS_EUPXS(XS_Wx__Window_GetPopupMenuSelectionFromUserPoint); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Window_GetPopupMenuSelectionFromUserPoint)
{
    dVAR; dXSARGS;
    if (items != 3)
       croak_xs_usage(cv,  "THIS, menu, point");
    {
	wxWindow *    THIS = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Window" )
;
	int	RETVAL;
	dXSTARG;
	wxMenu*    menu = (wxMenu *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::Menu" )
;
	wxPoint    point = wxPli_sv_2_wxpoint( aTHX_ ST(2) )
;
    try {
      RETVAL = THIS->GetPopupMenuSelectionFromUser( *( menu ), point );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__Window_GetPopupMenuSelectionFromUserXY); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Window_GetPopupMenuSelectionFromUserXY)
{
    dVAR; dXSARGS;
    if (items != 4)
       croak_xs_usage(cv,  "THIS, menu, x, y");
    {
	wxWindow *    THIS = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Window" )
;
	int	RETVAL;
	dXSTARG;
	wxMenu*    menu = (wxMenu *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::Menu" )
;
	int	x = (int)SvIV(ST(2))
;
	int	y = (int)SvIV(ST(3))
;
    try {
      RETVAL = THIS->GetPopupMenuSelectionFromUser( *( menu ), x, y );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}

#endif
#if WXPERL_W_VERSION_LT( 2, 7, 0 )
#define XSpp_4e75b735_070238
#define XSubPPtmpAABS 1


XS_EUPXS(XS_Wx__Window_GetAdjustedBestSize); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Window_GetAdjustedBestSize)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxWindow *    THIS = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Window" )
;
	wxSize	RETVAL;
    try {
      RETVAL = THIS->GetAdjustedBestSize();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_non_object_2_sv( aTHX_ RETVALSV, new wxSize(RETVAL), "Wx::Size" );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}

#endif
#if WXPERL_W_VERSION_GE( 2, 7, 2 )
#define XSpp_4e75b735_048886
#define XSubPPtmpAABT 1


XS_EUPXS(XS_Wx__Window_GetEffectiveMinSize); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Window_GetEffectiveMinSize)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxWindow *    THIS = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Window" )
;
	wxSize	RETVAL;
    try {
      RETVAL = THIS->GetEffectiveMinSize();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_non_object_2_sv( aTHX_ RETVALSV, new wxSize(RETVAL), "Wx::Size" );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}

#endif

XS_EUPXS(XS_Wx__Window_GetCursor); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Window_GetCursor)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxWindow *    THIS = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Window" )
;
	wxCursor *	RETVAL;
    try {
      RETVAL = new wxCursor( THIS->GetCursor() );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_object_2_sv( aTHX_ RETVALSV, RETVAL );
    wxPli_thread_sv_register( aTHX_ "Wx::Cursor", RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}

#if WXPERL_W_VERSION_GE( 2, 9, 0 )
#define XSpp_4e75b735_094225
#define XSubPPtmpAABU 1


XS_EUPXS(XS_Wx__Window_GetPrevSibling); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Window_GetPrevSibling)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxWindow *    THIS = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Window" )
;
	wxWindow *	RETVAL;
    try {
      RETVAL = THIS->GetPrevSibling();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_object_2_sv( aTHX_ RETVALSV, RETVAL );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__Window_GetNextSibling); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Window_GetNextSibling)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxWindow *    THIS = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Window" )
;
	wxWindow *	RETVAL;
    try {
      RETVAL = THIS->GetNextSibling();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_object_2_sv( aTHX_ RETVALSV, RETVAL );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}

#endif

XS_EUPXS(XS_Wx__Window_GetVirtualSize); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Window_GetVirtualSize)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxWindow *    THIS = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Window" )
;
	wxSize	RETVAL;
    try {
      RETVAL = THIS->GetVirtualSize();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_non_object_2_sv( aTHX_ RETVALSV, new wxSize(RETVAL), "Wx::Size" );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__Window_GetVirtualSizeWH); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Window_GetVirtualSizeWH)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    PERL_UNUSED_VAR(ax); /* -Wall */
    SP -= items;
    {
	wxWindow *    THIS = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Window" )
;
    int x, y;
    THIS->GetVirtualSize( &x, &y );
    wxPli_push_2ints( x, y );
	PUTBACK;
	return;
    }
}

#if WXPERL_W_VERSION_GE( 2, 7, 2 )
#define XSpp_4e75b735_086562
#define XSubPPtmpAABV 1


XS_EUPXS(XS_Wx__Window_GetScreenPosition); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Window_GetScreenPosition)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxWindow *    THIS = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Window" )
;
	wxPoint *	RETVAL;
     RETVAL = new wxPoint( THIS->GetScreenPosition() ); 
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_non_object_2_sv( aTHX_ RETVALSV, RETVAL, "Wx::Point" );
    wxPli_thread_sv_register( aTHX_ "Wx::Point", RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__Window_GetScreenPositionXY); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Window_GetScreenPositionXY)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    PERL_UNUSED_VAR(ax); /* -Wall */
    SP -= items;
    {
	wxWindow *    THIS = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Window" )
;
    int x, y;
    THIS->GetPosition( &x, &y );
    EXTEND( SP, 2 );
    PUSHs( sv_2mortal( newSViv( (IV) x ) ) );
    PUSHs( sv_2mortal( newSViv( (IV) y ) ) );
	PUTBACK;
	return;
    }
}


XS_EUPXS(XS_Wx__Window_GetScreenRect); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Window_GetScreenRect)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxWindow *    THIS = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Window" )
;
	wxRect *	RETVAL;
    try {
      RETVAL = new wxRect( THIS->GetScreenRect() );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_non_object_2_sv( aTHX_ RETVALSV, RETVAL, "Wx::Rect" );
    wxPli_thread_sv_register( aTHX_ "Wx::Rect", RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}

#endif

XS_EUPXS(XS_Wx__Window_HasFlag); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Window_HasFlag)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, flag");
    {
	wxWindow *    THIS = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Window" )
;
	bool	RETVAL;
	int	flag = (int)SvIV(ST(1))
;
    try {
      RETVAL = THIS->HasFlag( flag );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}

#if WXPERL_W_VERSION_GE( 2, 9, 0 )
#define XSpp_4e75b735_096867
#define XSubPPtmpAABW 1


XS_EUPXS(XS_Wx__Window_HasExtraStyle); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Window_HasExtraStyle)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, exFlag");
    {
	wxWindow *    THIS = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Window" )
;
	bool	RETVAL;
	int	exFlag = (int)SvIV(ST(1))
;
    try {
      RETVAL = THIS->HasExtraStyle( exFlag );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}

#endif

XS_EUPXS(XS_Wx__Window_HasCapture); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Window_HasCapture)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxWindow *    THIS = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Window" )
;
	bool	RETVAL;
    try {
      RETVAL = THIS->HasCapture();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}

#if WXPERL_W_VERSION_GE( 2, 6, 0 )
#define XSpp_4e75b735_062106
#define XSubPPtmpAABX 1


XS_EUPXS(XS_Wx__Window_HasTransparentBackground); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Window_HasTransparentBackground)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxWindow *    THIS = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Window" )
;
	bool	RETVAL;
    try {
      RETVAL = THIS->HasTransparentBackground();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}

#endif

XS_EUPXS(XS_Wx__Window_HasScrollbar); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Window_HasScrollbar)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, orient");
    {
	wxWindow *    THIS = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Window" )
;
	bool	RETVAL;
	int	orient = (int)SvIV(ST(1))
;
    try {
      RETVAL = THIS->HasScrollbar( orient );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}

#if WXPERL_W_VERSION_GE( 2, 9, 0 )
#define XSpp_4e75b735_048057
#define XSubPPtmpAABY 1


XS_EUPXS(XS_Wx__Window_IsScrollbarAlwaysShown); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Window_IsScrollbarAlwaysShown)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, orient");
    {
	wxWindow *    THIS = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Window" )
;
	bool	RETVAL;
	int	orient = (int)SvIV(ST(1))
;
    try {
      RETVAL = THIS->IsScrollbarAlwaysShown( orient );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}

#endif

XS_EUPXS(XS_Wx__Window_LineUp); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Window_LineUp)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxWindow *    THIS = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Window" )
;
	bool	RETVAL;
    try {
      RETVAL = THIS->LineUp();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__Window_LineDown); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Window_LineDown)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxWindow *    THIS = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Window" )
;
	bool	RETVAL;
    try {
      RETVAL = THIS->LineDown();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__Window_PageUp); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Window_PageUp)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxWindow *    THIS = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Window" )
;
	bool	RETVAL;
    try {
      RETVAL = THIS->PageUp();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__Window_PageDown); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Window_PageDown)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxWindow *    THIS = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Window" )
;
	bool	RETVAL;
    try {
      RETVAL = THIS->PageDown();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__Window_SetBackgroundColour); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Window_SetBackgroundColour)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, colour");
    {
	wxWindow *    THIS = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Window" )
;
	wxColour*    colour = (wxColour *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::Colour" )
;
    try {
      THIS->SetBackgroundColour( *( colour ) );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__Window_SetOwnBackgroundColour); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Window_SetOwnBackgroundColour)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, colour");
    {
	wxWindow *    THIS = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Window" )
;
	wxColour*    colour = (wxColour *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::Colour" )
;
    try {
      THIS->SetOwnBackgroundColour( *( colour ) );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}

#if WXPERL_W_VERSION_GE( 2, 9, 0 )
#define XSpp_4e75b735_084310
#define XSubPPtmpAABZ 1


XS_EUPXS(XS_Wx__Window_SetCanFocus); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Window_SetCanFocus)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, canFocus");
    {
	wxWindow *    THIS = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Window" )
;
	bool	canFocus = (bool)SvTRUE(ST(1))
;
    try {
      THIS->SetCanFocus( canFocus );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}

#endif

XS_EUPXS(XS_Wx__Window_SetForegroundColour); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Window_SetForegroundColour)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, colour");
    {
	wxWindow *    THIS = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Window" )
;
	wxColour*    colour = (wxColour *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::Colour" )
;
    try {
      THIS->SetForegroundColour( *( colour ) );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__Window_SetOwnForegroundColour); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Window_SetOwnForegroundColour)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, colour");
    {
	wxWindow *    THIS = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Window" )
;
	wxColour*    colour = (wxColour *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::Colour" )
;
    try {
      THIS->SetOwnForegroundColour( *( colour ) );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__Window_SetFont); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Window_SetFont)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, font");
    {
	wxWindow *    THIS = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Window" )
;
	wxFont*    font = (wxFont *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::Font" )
;
    try {
      THIS->SetFont( *( font ) );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__Window_SetCursor); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Window_SetCursor)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, cursor");
    {
	wxWindow *    THIS = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Window" )
;
	wxCursor*    cursor = (wxCursor *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::Cursor" )
;
    try {
      THIS->SetCursor( *( cursor ) );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__Window_SetOwnFont); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Window_SetOwnFont)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, font");
    {
	wxWindow *    THIS = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Window" )
;
	wxFont*    font = (wxFont *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::Font" )
;
    try {
      THIS->SetOwnFont( *( font ) );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__Window_GetWindowVariant); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Window_GetWindowVariant)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxWindow *    THIS = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Window" )
;
	wxWindowVariant	RETVAL;
	dXSTARG;
    try {
      RETVAL = THIS->GetWindowVariant();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__Window_SetWindowVariant); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Window_SetWindowVariant)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, variant");
    {
	wxWindow *    THIS = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Window" )
;
	wxWindowVariant	variant = (wxWindowVariant)SvIV(ST(1))
;
    try {
      THIS->SetWindowVariant( variant );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}

#if WXPERL_W_VERSION_GE( 2, 8, 0 )
#define XSpp_4e75b735_083332
#define XSubPPtmpAACA 1


XS_EUPXS(XS_Wx__Window_ToggleWindowStyle); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Window_ToggleWindowStyle)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, flag");
    {
	wxWindow *    THIS = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Window" )
;
	bool	RETVAL;
	int	flag = (int)SvIV(ST(1))
;
    try {
      RETVAL = THIS->ToggleWindowStyle( flag );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}

#endif
#if WXPERL_W_VERSION_GE( 2, 9, 4 )
#define XSpp_4e75b735_023666
#define XSubPPtmpAACB 1


XS_EUPXS(XS_Wx__Window_AcceptsFocusRecursively); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Window_AcceptsFocusRecursively)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxWindow *    THIS = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Window" )
;
	bool	RETVAL;
    try {
      RETVAL = THIS->AcceptsFocusRecursively();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__Window_HasFocus); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Window_HasFocus)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxWindow *    THIS = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Window" )
;
	bool	RETVAL;
    try {
      RETVAL = THIS->HasFocus();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__Window_SetFocusFromKbd); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Window_SetFocusFromKbd)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxWindow *    THIS = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Window" )
;
    try {
      THIS->SetFocusFromKbd();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__Window_IsDescendant); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Window_IsDescendant)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, win");
    {
	wxWindow *    THIS = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Window" )
;
	bool	RETVAL;
	wxWindow*    win = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::Window" )
;
    try {
      RETVAL = THIS->IsDescendant( win );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}

#endif
#include "cpp/overload.h"
#if 1
#define XSubPPtmpAACC 1


XS_EUPXS(XS_Wx__Window_GetPopupMenuSelectionFromUser); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Window_GetPopupMenuSelectionFromUser)
{
    dVAR; dXSARGS;
    if (items < 1)
       croak_xs_usage(cv,  "THIS, ...");
    PERL_UNUSED_VAR(ax); /* -Wall */
    SP -= items;
    {
	wxWindow *    THIS = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Window" )
;
#if defined( XSpp_4e75b735_097627 )
    static const char *GetPopupMenuSelectionFromUserPoint_types[] = { "Wx::Menu", wxPliOvlwpoi };
    static wxPliPrototype GetPopupMenuSelectionFromUserPoint_proto( GetPopupMenuSelectionFromUserPoint_types, sizeof( GetPopupMenuSelectionFromUserPoint_types ) / sizeof( GetPopupMenuSelectionFromUserPoint_types[0] ) );
#endif // defined( XSpp_4e75b735_097627 )
#if defined( XSpp_4e75b735_097627 )
    static const char *GetPopupMenuSelectionFromUserXY_types[] = { "Wx::Menu", wxPliOvlnum, wxPliOvlnum };
    static wxPliPrototype GetPopupMenuSelectionFromUserXY_proto( GetPopupMenuSelectionFromUserXY_types, sizeof( GetPopupMenuSelectionFromUserXY_types ) / sizeof( GetPopupMenuSelectionFromUserXY_types[0] ) );
#endif // defined( XSpp_4e75b735_097627 )
    static wxPliPrototype *wxPliOvl_all_prototypes[] = {
#if defined( XSpp_4e75b735_097627 )
        &GetPopupMenuSelectionFromUserPoint_proto,
#endif // defined( XSpp_4e75b735_097627 )
#if defined( XSpp_4e75b735_097627 )
        &GetPopupMenuSelectionFromUserXY_proto,
#endif // defined( XSpp_4e75b735_097627 )
        NULL };
    BEGIN_OVERLOAD()
#if defined( XSpp_4e75b735_097627 )
        MATCH_REDISP_COUNT( GetPopupMenuSelectionFromUserPoint_proto, GetPopupMenuSelectionFromUserPoint, 2 )
#endif // defined( XSpp_4e75b735_097627 )
#if defined( XSpp_4e75b735_097627 )
        MATCH_REDISP_COUNT( GetPopupMenuSelectionFromUserXY_proto, GetPopupMenuSelectionFromUserXY, 3 )
#endif // defined( XSpp_4e75b735_097627 )
    END_OVERLOAD_MESSAGE( Wx::Window::GetPopupMenuSelectionFromUser, wxPliOvl_all_prototypes )
	PUTBACK;
	return;
    }
}

#endif // 1
#if WXPERL_W_VERSION_GE( 2, 9, 0 )
#define XSpp_4e75b735_003755
#undef  xsp_constructor_class
#define xsp_constructor_class(c) (CLASS)
#define XSubPPtmpAACD 1


XS_EUPXS(XS_Wx__EventBlocker_new); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__EventBlocker_new)
{
    dVAR; dXSARGS;
    if (items < 2 || items > 3)
       croak_xs_usage(cv,  "CLASS, win, type= wxEVT_ANY");
    {
	char *	CLASS = (char *)SvPV_nolen(ST(0))
;
	wxEventBlocker *	RETVAL;
	wxWindow*    win = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::Window" )
;
	wxEventType	type;

	if (items < 3)
	    type = wxEVT_ANY;
	else {
	    type = (wxEventType)SvIV(ST(2))
;
	}
    try {
      RETVAL = new wxEventBlocker( win, type );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_non_object_2_sv( aTHX_ RETVALSV, RETVAL, "Wx::EventBlocker" );
    wxPli_thread_sv_register( aTHX_ "Wx::EventBlocker", RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}

#undef  xsp_constructor_class
#define xsp_constructor_class(c) (c)

XS_EUPXS(XS_Wx__EventBlocker_CLONE); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__EventBlocker_CLONE)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "CLASS");
    {
	char *	CLASS = (char *)SvPV_nolen(ST(0))
;
    wxPli_thread_sv_clone( aTHX_ CLASS, (wxPliCloneSV)wxPli_detach_object );
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__EventBlocker_DESTROY); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__EventBlocker_DESTROY)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxEventBlocker *    THIS = (wxEventBlocker *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::EventBlocker" )
;
      wxPli_thread_sv_unregister( aTHX_ "Wx::EventBlocker", THIS, ST(0) );
                 delete THIS;
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__EventBlocker_Block); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__EventBlocker_Block)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, eventType");
    {
	wxEventBlocker *    THIS = (wxEventBlocker *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::EventBlocker" )
;
	wxEventType	eventType = (wxEventType)SvIV(ST(1))
;
    try {
      THIS->Block( eventType );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}

#endif
#if WXPERL_W_VERSION_GE( 2, 7, 2 )
#define XSpp_4e75b735_070593
#include <wx/wupdlock.h>
#undef  xsp_constructor_class
#define xsp_constructor_class(c) (CLASS)
#define XSubPPtmpAACE 1


XS_EUPXS(XS_Wx__WindowUpdateLocker_new); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__WindowUpdateLocker_new)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "CLASS, win");
    {
	char *	CLASS = (char *)SvPV_nolen(ST(0))
;
	wxWindowUpdateLocker *	RETVAL;
	wxWindow*    win = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::Window" )
;
    try {
      RETVAL = new wxWindowUpdateLocker( win );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_non_object_2_sv( aTHX_ RETVALSV, RETVAL, "Wx::WindowUpdateLocker" );
    wxPli_thread_sv_register( aTHX_ "Wx::WindowUpdateLocker", RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}

#undef  xsp_constructor_class
#define xsp_constructor_class(c) (c)

XS_EUPXS(XS_Wx__WindowUpdateLocker_CLONE); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__WindowUpdateLocker_CLONE)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "CLASS");
    {
	char *	CLASS = (char *)SvPV_nolen(ST(0))
;
    wxPli_thread_sv_clone( aTHX_ CLASS, (wxPliCloneSV)wxPli_detach_object );
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__WindowUpdateLocker_DESTROY); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__WindowUpdateLocker_DESTROY)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxWindowUpdateLocker *    THIS = (wxWindowUpdateLocker *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::WindowUpdateLocker" )
;
      wxPli_thread_sv_unregister( aTHX_ "Wx::WindowUpdateLocker", THIS, ST(0) );
                 delete THIS;
    }
    XSRETURN_EMPTY;
}

#endif

/* INCLUDE: Returning to 'Window.xs' from '/usr/bin/perl -I./ -MExtUtils::XSpp::Cmd -e xspp -- -t typemap.xsp XS/Window.xsp' */


/* INCLUDE:  Including 'XS/Accelerators.xs' from 'Window.xs' */

#include <wx/accel.h>

XS_EUPXS(XS_Wx__AcceleratorEntry_new); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__AcceleratorEntry_new)
{
    dVAR; dXSARGS;
    if (items != 4)
       croak_xs_usage(cv,  "CLASS, flags, code, cmd");
    {
	int	flags = (int)SvIV(ST(1))
;
	wxKeyCode    code = wxPli_sv_2_keycode( aTHX_ ST(2) )
;
	int	cmd = (int)SvIV(ST(3))
;
	char *	CLASS = (char *)SvPV_nolen(ST(0))
;
	wxAcceleratorEntry *	RETVAL;

	RETVAL = new wxAcceleratorEntry(flags, code, cmd);
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_non_object_2_sv( aTHX_ RETVALSV, RETVAL, "Wx::AcceleratorEntry" );
    wxPli_thread_sv_register( aTHX_ "Wx::AcceleratorEntry", RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}

#if WXPERL_W_VERSION_GE( 2, 7, 1 )
#define XSubPPtmpAACF 1


XS_EUPXS(XS_Wx__AcceleratorEntry_Create); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__AcceleratorEntry_Create)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "str");
    {
	wxString	str;
	wxAcceleratorEntry *	RETVAL;

    WXSTRING_INPUT( str, wxString, ST(0) )
;
    RETVAL = wxAcceleratorEntry::Create( str );
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_non_object_2_sv( aTHX_ RETVALSV, RETVAL, "Wx::AcceleratorEntry" );
    wxPli_thread_sv_register( aTHX_ "Wx::AcceleratorEntry", RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}

#endif

XS_EUPXS(XS_Wx__AcceleratorEntry_CLONE); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__AcceleratorEntry_CLONE)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "CLASS");
    {
	char *	CLASS = (char *)SvPV_nolen(ST(0))
;
    wxPli_thread_sv_clone( aTHX_ CLASS, (wxPliCloneSV)wxPli_detach_object );
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__AcceleratorEntry_DESTROY); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__AcceleratorEntry_DESTROY)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxAcceleratorEntry *    THIS = (wxAcceleratorEntry *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::AcceleratorEntry" )
;
    wxPli_thread_sv_unregister( aTHX_ "Wx::AcceleratorEntry", THIS, ST(0) );
    delete THIS;
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__AcceleratorEntry_GetCommand); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__AcceleratorEntry_GetCommand)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxAcceleratorEntry *    THIS = (wxAcceleratorEntry *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::AcceleratorEntry" )
;
	int	RETVAL;
	dXSTARG;

	RETVAL = THIS->GetCommand();
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__AcceleratorEntry_GetFlags); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__AcceleratorEntry_GetFlags)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxAcceleratorEntry *    THIS = (wxAcceleratorEntry *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::AcceleratorEntry" )
;
	int	RETVAL;
	dXSTARG;

	RETVAL = THIS->GetFlags();
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__AcceleratorEntry_GetKeyCode); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__AcceleratorEntry_GetKeyCode)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxAcceleratorEntry *    THIS = (wxAcceleratorEntry *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::AcceleratorEntry" )
;
	int	RETVAL;
	dXSTARG;

	RETVAL = THIS->GetKeyCode();
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__AcceleratorEntry_Set); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__AcceleratorEntry_Set)
{
    dVAR; dXSARGS;
    if (items != 4)
       croak_xs_usage(cv,  "THIS, flags, code, cmd");
    {
	int	flags = (int)SvIV(ST(1))
;
	wxKeyCode    code = wxPli_sv_2_keycode( aTHX_ ST(2) )
;
	int	cmd = (int)SvIV(ST(3))
;
	wxAcceleratorEntry *    THIS = (wxAcceleratorEntry *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::AcceleratorEntry" )
;

	THIS->Set(flags, code, cmd);
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__AcceleratorTable_new); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__AcceleratorTable_new)
{
    dVAR; dXSARGS;
    if (items < 1)
       croak_xs_usage(cv,  "CLASS, ...");
    {
	char *	CLASS = (char *)SvPV_nolen(ST(0))
;
	wxAcceleratorTable *	RETVAL;
    if( items == 1 )
    {
        RETVAL = new wxAcceleratorTable;
    }
    else
    {
        int num = items - 1;
        wxAcceleratorEntry* entries = new wxAcceleratorEntry[ num ];

        for( int i = 0; i < num; ++i )
        {
            SV* rv = ST( i + 1 );

            if( SvROK( rv ) )
            {
                if( sv_derived_from( rv, CHAR_P "Wx::AcceleratorEntry" ) )
                {
                    entries[i] = *(wxAcceleratorEntry*)
                        wxPli_sv_2_object( aTHX_ rv,
                                           "Wx::AcceleratorEntry" );
                }
                else if( SvTYPE( SvRV( rv ) ) == SVt_PVAV )
                {
                    AV* av = (AV*) SvRV( rv );
                    I32 len = av_len( av ) + 1;

                    if( len != 3 )
                    {
                        delete[] entries;
                        croak( "the %d-th value does not have three"
                               " elements", i + 1 );
                    }

                    entries[i].Set( SvIV( *av_fetch( av, 0, 0 ) ),
                                    wxPli_sv_2_keycode( aTHX_
                                            *av_fetch( av, 1, 0 ) ),
                                    SvIV( *av_fetch( av, 2, 0 ) ) );
                }
                else
                {
                    delete[] entries;
                    croak( "the %d-th value is not an object"
                           " or array reference", i + 1 );
                }
            }
            else
            {
                delete[] entries;
                croak( "the %d-th value is not an object"
                       " or array reference", i + 1 );
            }
        }

        RETVAL = new wxAcceleratorTable( num, entries );
        delete[] entries;
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_object_2_sv( aTHX_ RETVALSV, RETVAL );
    wxPli_thread_sv_register( aTHX_ "Wx::AcceleratorTable", RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__AcceleratorTable_CLONE); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__AcceleratorTable_CLONE)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "CLASS");
    {
	char *	CLASS = (char *)SvPV_nolen(ST(0))
;
    wxPli_thread_sv_clone( aTHX_ CLASS, (wxPliCloneSV)wxPli_detach_object );
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__AcceleratorTable_DESTROY); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__AcceleratorTable_DESTROY)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxAcceleratorTable *    THIS = (wxAcceleratorTable *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::AcceleratorTable" )
;
    wxPli_thread_sv_unregister( aTHX_ "Wx::AcceleratorTable", THIS, ST(0) );
    delete THIS;
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__AcceleratorTable_Ok); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__AcceleratorTable_Ok)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxAcceleratorTable *    THIS = (wxAcceleratorTable *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::AcceleratorTable" )
;
	bool	RETVAL;

	RETVAL = THIS->Ok();
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}

#if WXPERL_W_VERSION_GE( 2, 8, 0 )
#define XSubPPtmpAACG 1


XS_EUPXS(XS_Wx__AcceleratorTable_IsOk); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__AcceleratorTable_IsOk)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxAcceleratorTable *    THIS = (wxAcceleratorTable *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::AcceleratorTable" )
;
	bool	RETVAL;

	RETVAL = THIS->IsOk();
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}

#endif

/* INCLUDE: Returning to 'Window.xs' from 'XS/Accelerators.xs' */


/* INCLUDE_COMMAND:  Including output of '/usr/bin/perl -I./ -MExtUtils::XSpp::Cmd -e xspp -- -t typemap.xsp XS/PlWindow.xsp' from 'Window.xs' */

#include <exception>

#undef  xsp_constructor_class
#define xsp_constructor_class(c) (c)
#include "xspp/plwindow.h"
#define GetMaxSize wxWindow::GetMaxSize
#define GetMinSize wxWindow::GetMinSize
#define AcceptsFocus wxWindow::AcceptsFocus
#define AcceptsFocusRecursively wxWindow::AcceptsFocusRecursively
#define AcceptsFocusFromKeyboard wxWindow::AcceptsFocusFromKeyboard
#undef  xsp_constructor_class
#define xsp_constructor_class(c) (CLASS)

XS_EUPXS(XS_Wx__PlWindow_newDefault); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__PlWindow_newDefault)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "CLASS");
    {
	char *	CLASS = (char *)SvPV_nolen(ST(0))
;
	wxPlWindow *	RETVAL;
     RETVAL = new wxPlWindow( CLASS );
                // wxPli_create_evthandler( aTHX_ RETVAL, CLASS );
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_object_2_sv( aTHX_ RETVALSV, RETVAL );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}

#undef  xsp_constructor_class
#define xsp_constructor_class(c) (c)
#undef  xsp_constructor_class
#define xsp_constructor_class(c) (CLASS)

XS_EUPXS(XS_Wx__PlWindow_newFull); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__PlWindow_newFull)
{
    dVAR; dXSARGS;
    if (items < 2 || items > 7)
       croak_xs_usage(cv,  "CLASS, parent, id= wxID_ANY, pos= wxDefaultPosition, size= wxDefaultSize, style= 0, name= wxEmptyString");
    {
	char *	CLASS = (char *)SvPV_nolen(ST(0))
;
	wxPlWindow *	RETVAL;
	wxWindow*    parent = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::Window" )
;
	wxWindowID	id;
	wxPoint	pos;
	wxSize	size;
	long	style;
	wxString	name;

	if (items < 3)
	    id = wxID_ANY;
	else {
    id = wxPli_get_wxwindowid( aTHX_ ST(2) )
;
	}

	if (items < 4)
	    pos = wxDefaultPosition;
	else {
    pos = wxPli_sv_2_wxpoint( aTHX_ ST(3) )
;
	}

	if (items < 5)
	    size = wxDefaultSize;
	else {
    size = wxPli_sv_2_wxsize( aTHX_ ST(4) )
;
	}

	if (items < 6)
	    style = 0;
	else {
	    style = (long)SvIV(ST(5))
;
	}

	if (items < 7)
	    name = wxEmptyString;
	else {
    WXSTRING_INPUT( name, wxString, ST(6) )
;
	}
     RETVAL = new wxPlWindow( CLASS, parent, id, pos, size,
                                         style, name );
                // wxPli_create_evthandler( aTHX_ RETVAL, CLASS );
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_object_2_sv( aTHX_ RETVALSV, RETVAL );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}

#undef  xsp_constructor_class
#define xsp_constructor_class(c) (c)

XS_EUPXS(XS_Wx__PlWindow_Create); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__PlWindow_Create)
{
    dVAR; dXSARGS;
    if (items < 2 || items > 7)
       croak_xs_usage(cv,  "THIS, parent, id= wxID_ANY, pos= wxDefaultPosition, size= wxDefaultSize, style= 0, name= wxEmptyString");
    {
	wxPlWindow *    THIS = (wxPlWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::PlWindow" )
;
	bool	RETVAL;
	wxWindow*    parent = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::Window" )
;
	wxWindowID	id;
	wxPoint	pos;
	wxSize	size;
	long	style;
	wxString	name;

	if (items < 3)
	    id = wxID_ANY;
	else {
    id = wxPli_get_wxwindowid( aTHX_ ST(2) )
;
	}

	if (items < 4)
	    pos = wxDefaultPosition;
	else {
    pos = wxPli_sv_2_wxpoint( aTHX_ ST(3) )
;
	}

	if (items < 5)
	    size = wxDefaultSize;
	else {
    size = wxPli_sv_2_wxsize( aTHX_ ST(4) )
;
	}

	if (items < 6)
	    style = 0;
	else {
	    style = (long)SvIV(ST(5))
;
	}

	if (items < 7)
	    name = wxEmptyString;
	else {
    WXSTRING_INPUT( name, wxString, ST(6) )
;
	}
    try {
      RETVAL = THIS->Create( parent, id, pos, size, style, name );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__PlWindow_DoGetBestSize); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__PlWindow_DoGetBestSize)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxPlWindow *    THIS = (wxPlWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::PlWindow" )
;
	wxSize	RETVAL;
    try {
      RETVAL = THIS->base_DoGetBestSize();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_non_object_2_sv( aTHX_ RETVALSV, new wxSize(RETVAL), "Wx::Size" );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__PlWindow_DoMoveWindow); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__PlWindow_DoMoveWindow)
{
    dVAR; dXSARGS;
    if (items != 5)
       croak_xs_usage(cv,  "THIS, x, y, w, h");
    {
	wxPlWindow *    THIS = (wxPlWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::PlWindow" )
;
	int	x = (int)SvIV(ST(1))
;
	int	y = (int)SvIV(ST(2))
;
	int	w = (int)SvIV(ST(3))
;
	int	h = (int)SvIV(ST(4))
;
    try {
      THIS->base_DoMoveWindow( x, y, w, h );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__PlWindow_Enable); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__PlWindow_Enable)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, enable");
    {
	wxPlWindow *    THIS = (wxPlWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::PlWindow" )
;
	bool	RETVAL;
	bool	enable = (bool)SvTRUE(ST(1))
;
    try {
      RETVAL = THIS->base_Enable( enable );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__PlWindow_AcceptsFocus); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__PlWindow_AcceptsFocus)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxPlWindow *    THIS = (wxPlWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::PlWindow" )
;
	bool	RETVAL;
    try {
      RETVAL = THIS->AcceptsFocus();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}

#if WXPERL_W_VERSION_GE( 2, 9, 0 )
#define XSpp_fce7d1ed_030484
#define XSubPPtmpAACH 1


XS_EUPXS(XS_Wx__PlWindow_AcceptsFocusRecursively); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__PlWindow_AcceptsFocusRecursively)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxPlWindow *    THIS = (wxPlWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::PlWindow" )
;
	bool	RETVAL;
    try {
      RETVAL = THIS->AcceptsFocusRecursively();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}

#endif

XS_EUPXS(XS_Wx__PlWindow_AcceptsFocusFromKeyboard); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__PlWindow_AcceptsFocusFromKeyboard)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxPlWindow *    THIS = (wxPlWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::PlWindow" )
;
	bool	RETVAL;
    try {
      RETVAL = THIS->AcceptsFocusFromKeyboard();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}

#if WXPERL_W_VERSION_GE( 2, 5, 1 )
#define XSpp_fce7d1ed_021154
#define XSubPPtmpAACI 1


XS_EUPXS(XS_Wx__PlWindow_GetMaxSize); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__PlWindow_GetMaxSize)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxPlWindow *    THIS = (wxPlWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::PlWindow" )
;
	wxSize	RETVAL;
    try {
      RETVAL = THIS->GetMaxSize();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_non_object_2_sv( aTHX_ RETVALSV, new wxSize(RETVAL), "Wx::Size" );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__PlWindow_GetMinSize); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__PlWindow_GetMinSize)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxPlWindow *    THIS = (wxPlWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::PlWindow" )
;
	wxSize	RETVAL;
    try {
      RETVAL = THIS->GetMinSize();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_non_object_2_sv( aTHX_ RETVALSV, new wxSize(RETVAL), "Wx::Size" );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}

#endif

XS_EUPXS(XS_Wx__PlWindow_new); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__PlWindow_new)
{
    dVAR; dXSARGS;
    PERL_UNUSED_VAR(cv); /* -W */
    PERL_UNUSED_VAR(items); /* -W */
    PERL_UNUSED_VAR(ax); /* -Wall */
    SP -= items;
    {
    BEGIN_OVERLOAD()
        MATCH_VOIDM_REDISP( newDefault )
        MATCH_ANY_REDISP( newFull )
    END_OVERLOAD( "Wx::PlWindow::new" )
	PUTBACK;
	return;
    }
}

#undef GetMaxSize
#undef GetMinSize
#undef AcceptsFocus
#undef AcceptsFocusRecursively
#undef AcceptsFocusFromKeyboard

/* INCLUDE: Returning to 'Window.xs' from '/usr/bin/perl -I./ -MExtUtils::XSpp::Cmd -e xspp -- -t typemap.xsp XS/PlWindow.xsp' */


/* INCLUDE_COMMAND:  Including output of '/usr/bin/perl -I./ -MExtUtils::XSpp::Cmd -e xspp -- -t typemap.xsp XS/SplitterWindow.xsp' from 'Window.xs' */

#include <exception>

#undef  xsp_constructor_class
#define xsp_constructor_class(c) (c)
#include <wx/splitter.h>
#undef  xsp_constructor_class
#define xsp_constructor_class(c) (CLASS)

XS_EUPXS(XS_Wx__SplitterEvent_new); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__SplitterEvent_new)
{
    dVAR; dXSARGS;
    if (items < 1 || items > 3)
       croak_xs_usage(cv,  "CLASS, type= wxEVT_NULL, window= NULL");
    {
	char *	CLASS = (char *)SvPV_nolen(ST(0))
;
	wxSplitterEvent *	RETVAL;
	wxEventType	type;
	wxSplitterWindow*	window;

	if (items < 2)
	    type = wxEVT_NULL;
	else {
	    type = (wxEventType)SvIV(ST(1))
;
	}

	if (items < 3)
	    window = NULL;
	else {
    window = (wxSplitterWindow *) wxPli_sv_2_object( aTHX_ ST(2), "Wx::SplitterWindow" )
;
	}
    try {
      RETVAL = new wxSplitterEvent( type, window );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_object_2_sv( aTHX_ RETVALSV, RETVAL );
    wxPli_thread_sv_register( aTHX_ "Wx::SplitterEvent", RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}

#undef  xsp_constructor_class
#define xsp_constructor_class(c) (c)

XS_EUPXS(XS_Wx__SplitterEvent_GetSashPosition); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__SplitterEvent_GetSashPosition)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxSplitterEvent *    THIS = (wxSplitterEvent *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::SplitterEvent" )
;
	int	RETVAL;
	dXSTARG;
    try {
      RETVAL = THIS->GetSashPosition();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__SplitterEvent_GetX); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__SplitterEvent_GetX)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxSplitterEvent *    THIS = (wxSplitterEvent *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::SplitterEvent" )
;
	int	RETVAL;
	dXSTARG;
    try {
      RETVAL = THIS->GetX();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__SplitterEvent_GetY); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__SplitterEvent_GetY)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxSplitterEvent *    THIS = (wxSplitterEvent *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::SplitterEvent" )
;
	int	RETVAL;
	dXSTARG;
    try {
      RETVAL = THIS->GetY();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__SplitterEvent_GetWindowBeingRemoved); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__SplitterEvent_GetWindowBeingRemoved)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxSplitterEvent *    THIS = (wxSplitterEvent *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::SplitterEvent" )
;
	wxWindow *	RETVAL;
    try {
      RETVAL = THIS->GetWindowBeingRemoved();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_object_2_sv( aTHX_ RETVALSV, RETVAL );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__SplitterEvent_SetSashPosition); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__SplitterEvent_SetSashPosition)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, pos");
    {
	wxSplitterEvent *    THIS = (wxSplitterEvent *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::SplitterEvent" )
;
	int	pos = (int)SvIV(ST(1))
;
    try {
      THIS->SetSashPosition( pos );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}

#define wxSplitterWindowNameStr wxT("splitter")
#undef  xsp_constructor_class
#define xsp_constructor_class(c) (CLASS)

XS_EUPXS(XS_Wx__SplitterWindow_newDefault); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__SplitterWindow_newDefault)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "CLASS");
    {
	char *	CLASS = (char *)SvPV_nolen(ST(0))
;
	wxSplitterWindow *	RETVAL;
        RETVAL = new wxSplitterWindow();
                   wxPli_create_evthandler( aTHX_ RETVAL, CLASS ); 
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_evthandler_2_sv( aTHX_ RETVALSV, RETVAL );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}

#undef  xsp_constructor_class
#define xsp_constructor_class(c) (c)
#undef  xsp_constructor_class
#define xsp_constructor_class(c) (CLASS)

XS_EUPXS(XS_Wx__SplitterWindow_newFull); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__SplitterWindow_newFull)
{
    dVAR; dXSARGS;
    if (items < 2 || items > 7)
       croak_xs_usage(cv,  "CLASS, parent, id= wxID_ANY, pos= wxDefaultPosition, size= wxDefaultSize, style= wxSP_3D, name= wxSplitterWindowNameStr");
    {
	char *	CLASS = (char *)SvPV_nolen(ST(0))
;
	wxSplitterWindow *	RETVAL;
	wxWindow*    parent = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::Window" )
;
	wxWindowID	id;
	wxPoint	pos;
	wxSize	size;
	long	style;
	wxString	name;

	if (items < 3)
	    id = wxID_ANY;
	else {
    id = wxPli_get_wxwindowid( aTHX_ ST(2) )
;
	}

	if (items < 4)
	    pos = wxDefaultPosition;
	else {
    pos = wxPli_sv_2_wxpoint( aTHX_ ST(3) )
;
	}

	if (items < 5)
	    size = wxDefaultSize;
	else {
    size = wxPli_sv_2_wxsize( aTHX_ ST(4) )
;
	}

	if (items < 6)
	    style = wxSP_3D;
	else {
	    style = (long)SvIV(ST(5))
;
	}

	if (items < 7)
	    name = wxSplitterWindowNameStr;
	else {
    WXSTRING_INPUT( name, wxString, ST(6) )
;
	}
        RETVAL = new wxSplitterWindow( parent, id, pos, size,
                       style, name );
                   wxPli_create_evthandler( aTHX_ RETVAL, CLASS ); 
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_evthandler_2_sv( aTHX_ RETVALSV, RETVAL );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}

#undef  xsp_constructor_class
#define xsp_constructor_class(c) (c)

XS_EUPXS(XS_Wx__SplitterWindow_Create); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__SplitterWindow_Create)
{
    dVAR; dXSARGS;
    if (items < 2 || items > 7)
       croak_xs_usage(cv,  "THIS, parent, id= wxID_ANY, pos= wxDefaultPosition, size= wxDefaultSize, style= wxSP_3D, name= wxSplitterWindowNameStr");
    {
	wxSplitterWindow *    THIS = (wxSplitterWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::SplitterWindow" )
;
	bool	RETVAL;
	wxWindow*    parent = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::Window" )
;
	wxWindowID	id;
	wxPoint	pos;
	wxSize	size;
	long	style;
	wxString	name;

	if (items < 3)
	    id = wxID_ANY;
	else {
    id = wxPli_get_wxwindowid( aTHX_ ST(2) )
;
	}

	if (items < 4)
	    pos = wxDefaultPosition;
	else {
    pos = wxPli_sv_2_wxpoint( aTHX_ ST(3) )
;
	}

	if (items < 5)
	    size = wxDefaultSize;
	else {
    size = wxPli_sv_2_wxsize( aTHX_ ST(4) )
;
	}

	if (items < 6)
	    style = wxSP_3D;
	else {
	    style = (long)SvIV(ST(5))
;
	}

	if (items < 7)
	    name = wxSplitterWindowNameStr;
	else {
    WXSTRING_INPUT( name, wxString, ST(6) )
;
	}
    try {
      RETVAL = THIS->Create( parent, id, pos, size, style, name );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__SplitterWindow_GetMinimumPaneSize); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__SplitterWindow_GetMinimumPaneSize)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxSplitterWindow *    THIS = (wxSplitterWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::SplitterWindow" )
;
	int	RETVAL;
	dXSTARG;
    try {
      RETVAL = THIS->GetMinimumPaneSize();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__SplitterWindow_GetSashPosition); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__SplitterWindow_GetSashPosition)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxSplitterWindow *    THIS = (wxSplitterWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::SplitterWindow" )
;
	int	RETVAL;
	dXSTARG;
    try {
      RETVAL = THIS->GetSashPosition();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__SplitterWindow_GetSplitMode); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__SplitterWindow_GetSplitMode)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxSplitterWindow *    THIS = (wxSplitterWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::SplitterWindow" )
;
	int	RETVAL;
	dXSTARG;
    try {
      RETVAL = THIS->GetSplitMode();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__SplitterWindow_GetWindow1); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__SplitterWindow_GetWindow1)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxSplitterWindow *    THIS = (wxSplitterWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::SplitterWindow" )
;
	wxWindow *	RETVAL;
    try {
      RETVAL = THIS->GetWindow1();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_object_2_sv( aTHX_ RETVALSV, RETVAL );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__SplitterWindow_GetWindow2); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__SplitterWindow_GetWindow2)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxSplitterWindow *    THIS = (wxSplitterWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::SplitterWindow" )
;
	wxWindow *	RETVAL;
    try {
      RETVAL = THIS->GetWindow2();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_object_2_sv( aTHX_ RETVALSV, RETVAL );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__SplitterWindow_Initialize); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__SplitterWindow_Initialize)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, window");
    {
	wxSplitterWindow *    THIS = (wxSplitterWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::SplitterWindow" )
;
	wxWindow*    window = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::Window" )
;
    try {
      THIS->Initialize( window );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__SplitterWindow_IsSplit); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__SplitterWindow_IsSplit)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxSplitterWindow *    THIS = (wxSplitterWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::SplitterWindow" )
;
	bool	RETVAL;
    try {
      RETVAL = THIS->IsSplit();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__SplitterWindow_ReplaceWindow); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__SplitterWindow_ReplaceWindow)
{
    dVAR; dXSARGS;
    if (items != 3)
       croak_xs_usage(cv,  "THIS, winOld, winNew");
    {
	wxSplitterWindow *    THIS = (wxSplitterWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::SplitterWindow" )
;
	bool	RETVAL;
	wxWindow*    winOld = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::Window" )
;
	wxWindow*    winNew = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(2), "Wx::Window" )
;
    try {
      RETVAL = THIS->ReplaceWindow( winOld, winNew );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}

#if WXPERL_W_VERSION_GE( 2, 5, 4 )
#define XSpp_1dcf9ed5_025199
#define XSubPPtmpAACJ 1


XS_EUPXS(XS_Wx__SplitterWindow_SetFocusIgnoringChildren); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__SplitterWindow_SetFocusIgnoringChildren)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxSplitterWindow *    THIS = (wxSplitterWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::SplitterWindow" )
;
    try {
      THIS->SetFocusIgnoringChildren();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}

#endif

XS_EUPXS(XS_Wx__SplitterWindow_SetSashPosition); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__SplitterWindow_SetSashPosition)
{
    dVAR; dXSARGS;
    if (items < 2 || items > 3)
       croak_xs_usage(cv,  "THIS, position, redraw= true");
    {
	wxSplitterWindow *    THIS = (wxSplitterWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::SplitterWindow" )
;
	int	position = (int)SvIV(ST(1))
;
	bool	redraw;

	if (items < 3)
	    redraw = true;
	else {
	    redraw = (bool)SvTRUE(ST(2))
;
	}
    try {
      THIS->SetSashPosition( position, redraw );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__SplitterWindow_SetMinimumPaneSize); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__SplitterWindow_SetMinimumPaneSize)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, paneSize");
    {
	wxSplitterWindow *    THIS = (wxSplitterWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::SplitterWindow" )
;
	int	paneSize = (int)SvIV(ST(1))
;
    try {
      THIS->SetMinimumPaneSize( paneSize );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__SplitterWindow_SetSplitMode); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__SplitterWindow_SetSplitMode)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, mode");
    {
	wxSplitterWindow *    THIS = (wxSplitterWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::SplitterWindow" )
;
	int	mode = (int)SvIV(ST(1))
;
    try {
      THIS->SetSplitMode( mode );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__SplitterWindow_SplitHorizontally); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__SplitterWindow_SplitHorizontally)
{
    dVAR; dXSARGS;
    if (items < 3 || items > 4)
       croak_xs_usage(cv,  "THIS, window1, window2, sashPosition= 0");
    {
	wxSplitterWindow *    THIS = (wxSplitterWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::SplitterWindow" )
;
	bool	RETVAL;
	wxWindow*    window1 = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::Window" )
;
	wxWindow*    window2 = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(2), "Wx::Window" )
;
	int	sashPosition;

	if (items < 4)
	    sashPosition = 0;
	else {
	    sashPosition = (int)SvIV(ST(3))
;
	}
    try {
      RETVAL = THIS->SplitHorizontally( window1, window2, sashPosition );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__SplitterWindow_SplitVertically); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__SplitterWindow_SplitVertically)
{
    dVAR; dXSARGS;
    if (items < 3 || items > 4)
       croak_xs_usage(cv,  "THIS, window1, window2, sashPosition= 0");
    {
	wxSplitterWindow *    THIS = (wxSplitterWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::SplitterWindow" )
;
	bool	RETVAL;
	wxWindow*    window1 = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::Window" )
;
	wxWindow*    window2 = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(2), "Wx::Window" )
;
	int	sashPosition;

	if (items < 4)
	    sashPosition = 0;
	else {
	    sashPosition = (int)SvIV(ST(3))
;
	}
    try {
      RETVAL = THIS->SplitVertically( window1, window2, sashPosition );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__SplitterWindow_Unsplit); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__SplitterWindow_Unsplit)
{
    dVAR; dXSARGS;
    if (items < 1 || items > 2)
       croak_xs_usage(cv,  "THIS, toRemove= NULL");
    {
	wxSplitterWindow *    THIS = (wxSplitterWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::SplitterWindow" )
;
	bool	RETVAL;
	wxWindow*	toRemove;

	if (items < 2)
	    toRemove = NULL;
	else {
    toRemove = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::Window" )
;
	}
    try {
      RETVAL = THIS->Unsplit( toRemove );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}

#if WXPERL_W_VERSION_GE( 2, 6, 0 )
#define XSpp_1dcf9ed5_031951
#define XSubPPtmpAACK 1


XS_EUPXS(XS_Wx__SplitterWindow_SetSashGravity); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__SplitterWindow_SetSashGravity)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, gravity");
    {
	wxSplitterWindow *    THIS = (wxSplitterWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::SplitterWindow" )
;
	double	gravity = (double)SvNV(ST(1))
;
    try {
      THIS->SetSashGravity( gravity );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__SplitterWindow_GetSashGravity); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__SplitterWindow_GetSashGravity)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxSplitterWindow *    THIS = (wxSplitterWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::SplitterWindow" )
;
	double	RETVAL;
	dXSTARG;
    try {
      RETVAL = THIS->GetSashGravity();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	XSprePUSH;
	PUSHn((double)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__SplitterWindow_UpdateSize); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__SplitterWindow_UpdateSize)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxSplitterWindow *    THIS = (wxSplitterWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::SplitterWindow" )
;
    try {
      THIS->UpdateSize();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}

#endif
#if WXPERL_W_VERSION_GE( 2, 5, 3 )
#define XSpp_1dcf9ed5_029956
#define XSubPPtmpAACL 1


XS_EUPXS(XS_Wx__SplitterWindow_GetSashSize); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__SplitterWindow_GetSashSize)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxSplitterWindow *    THIS = (wxSplitterWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::SplitterWindow" )
;
	int	RETVAL;
	dXSTARG;
    try {
      RETVAL = THIS->GetSashSize();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__SplitterWindow_SetSashSize); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__SplitterWindow_SetSashSize)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, width");
    {
	wxSplitterWindow *    THIS = (wxSplitterWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::SplitterWindow" )
;
	int	width = (int)SvIV(ST(1))
;
    try {
      THIS->SetSashSize( width );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}

#endif

XS_EUPXS(XS_Wx__SplitterWindow_new); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__SplitterWindow_new)
{
    dVAR; dXSARGS;
    PERL_UNUSED_VAR(cv); /* -W */
    PERL_UNUSED_VAR(items); /* -W */
    PERL_UNUSED_VAR(ax); /* -Wall */
    SP -= items;
    {
    BEGIN_OVERLOAD()
        MATCH_VOIDM_REDISP( newDefault )
        MATCH_ANY_REDISP( newFull )
    END_OVERLOAD( "Wx::SplitterWindow::new" )
	PUTBACK;
	return;
    }
}


/* INCLUDE: Returning to 'Window.xs' from '/usr/bin/perl -I./ -MExtUtils::XSpp::Cmd -e xspp -- -t typemap.xsp XS/SplitterWindow.xsp' */


/* INCLUDE_COMMAND:  Including output of '/usr/bin/perl -I./ -MExtUtils::XSpp::Cmd -e xspp -- -t typemap.xsp XS/VScrolledWindow.xsp' from 'Window.xs' */

#include <exception>

#undef  xsp_constructor_class
#define xsp_constructor_class(c) (c)
#if WXPERL_W_VERSION_GE( 2, 5, 0 )
#define XSpp_ae855b18_094201
#include <wx/vscroll.h>
#if WXPERL_W_VERSION_GE( 2, 9, 0 )
#define XSpp_ae855b18_047032
#define XSubPPtmpAACM 1


XS_EUPXS(XS_Wx__HScrolledWindow_Create); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__HScrolledWindow_Create)
{
    dVAR; dXSARGS;
    if (items < 2 || items > 7)
       croak_xs_usage(cv,  "THIS, parent, id= wxID_ANY, pos= wxDefaultPosition, size= wxDefaultSize, style= 0, name= wxPanelNameStr");
    {
	wxHScrolledWindow *    THIS = (wxHScrolledWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::HScrolledWindow" )
;
	bool	RETVAL;
	wxWindow*    parent = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::Window" )
;
	wxWindowID	id;
	wxPoint	pos;
	wxSize	size;
	long	style;
	wxString	name;

	if (items < 3)
	    id = wxID_ANY;
	else {
    id = wxPli_get_wxwindowid( aTHX_ ST(2) )
;
	}

	if (items < 4)
	    pos = wxDefaultPosition;
	else {
    pos = wxPli_sv_2_wxpoint( aTHX_ ST(3) )
;
	}

	if (items < 5)
	    size = wxDefaultSize;
	else {
    size = wxPli_sv_2_wxsize( aTHX_ ST(4) )
;
	}

	if (items < 6)
	    style = 0;
	else {
	    style = (long)SvIV(ST(5))
;
	}

	if (items < 7)
	    name = wxPanelNameStr;
	else {
    WXSTRING_INPUT( name, wxString, ST(6) )
;
	}
    try {
      RETVAL = THIS->Create( parent, id, pos, size, style, name );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


/* INCLUDE_COMMAND:  Including output of '/usr/bin/perl -pe "s/VarScrollHelperBase/HScrolledWindow/g" XS/VarScrollHelperBase.xs' from '/usr/bin/perl -I./ -MExtUtils::XSpp::Cmd -e xspp -- -t typemap.xsp XS/VScrolledWindow.xsp' */

#include <exception>

#undef  xsp_constructor_class
#define xsp_constructor_class(c) (c)

XS_EUPXS(XS_Wx__HScrolledWindow_EnablePhysicalScrolling); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__HScrolledWindow_EnablePhysicalScrolling)
{
    dVAR; dXSARGS;
    if (items < 1 || items > 2)
       croak_xs_usage(cv,  "THIS, scrolling= true");
    {
	wxHScrolledWindow *    THIS = (wxHScrolledWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::HScrolledWindow" )
;
	bool	scrolling;

	if (items < 2)
	    scrolling = true;
	else {
	    scrolling = (bool)SvTRUE(ST(1))
;
	}
    try {
      THIS->EnablePhysicalScrolling( scrolling );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__HScrolledWindow_VirtualHitTest); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__HScrolledWindow_VirtualHitTest)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, coord");
    {
	wxHScrolledWindow *    THIS = (wxHScrolledWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::HScrolledWindow" )
;
	int	RETVAL;
	dXSTARG;
	wxCoord	coord = (wxCoord)SvIV(ST(1))
;
    try {
      RETVAL = THIS->VirtualHitTest( coord );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__HScrolledWindow_RefreshAll); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__HScrolledWindow_RefreshAll)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxHScrolledWindow *    THIS = (wxHScrolledWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::HScrolledWindow" )
;
    try {
      THIS->RefreshAll();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__HScrolledWindow_GetVisibleBegin); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__HScrolledWindow_GetVisibleBegin)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxHScrolledWindow *    THIS = (wxHScrolledWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::HScrolledWindow" )
;
	size_t	RETVAL;
	dXSTARG;
    try {
      RETVAL = THIS->GetVisibleBegin();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	XSprePUSH;
	PUSHu((UV)RETVAL );
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__HScrolledWindow_GetVisibleEnd); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__HScrolledWindow_GetVisibleEnd)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxHScrolledWindow *    THIS = (wxHScrolledWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::HScrolledWindow" )
;
	size_t	RETVAL;
	dXSTARG;
    try {
      RETVAL = THIS->GetVisibleEnd();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	XSprePUSH;
	PUSHu((UV)RETVAL );
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__HScrolledWindow_IsVisible); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__HScrolledWindow_IsVisible)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, unit");
    {
	wxHScrolledWindow *    THIS = (wxHScrolledWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::HScrolledWindow" )
;
	bool	RETVAL;
	size_t    unit = (size_t)SvUV( ST(1) )
;
    try {
      RETVAL = THIS->IsVisible( unit );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__HScrolledWindow_CalcScrolledPosition); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__HScrolledWindow_CalcScrolledPosition)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, coord");
    {
	wxHScrolledWindow *    THIS = (wxHScrolledWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::HScrolledWindow" )
;
	int	RETVAL;
	dXSTARG;
	int	coord = (int)SvIV(ST(1))
;
    try {
      RETVAL = THIS->CalcScrolledPosition( coord );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__HScrolledWindow_CalcUnscrolledPosition); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__HScrolledWindow_CalcUnscrolledPosition)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, coord");
    {
	wxHScrolledWindow *    THIS = (wxHScrolledWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::HScrolledWindow" )
;
	int	RETVAL;
	dXSTARG;
	int	coord = (int)SvIV(ST(1))
;
    try {
      RETVAL = THIS->CalcUnscrolledPosition( coord );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__HScrolledWindow_UpdateScrollbar); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__HScrolledWindow_UpdateScrollbar)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxHScrolledWindow *    THIS = (wxHScrolledWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::HScrolledWindow" )
;
    try {
      THIS->UpdateScrollbar();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__HScrolledWindow_RemoveScrollbar); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__HScrolledWindow_RemoveScrollbar)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxHScrolledWindow *    THIS = (wxHScrolledWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::HScrolledWindow" )
;
    try {
      THIS->RemoveScrollbar();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__HScrolledWindow_SetTargetWindow); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__HScrolledWindow_SetTargetWindow)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, target");
    {
	wxHScrolledWindow *    THIS = (wxHScrolledWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::HScrolledWindow" )
;
	wxWindow*    target = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::Window" )
;
    try {
      THIS->SetTargetWindow( target );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__HScrolledWindow_GetTargetWindow); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__HScrolledWindow_GetTargetWindow)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxHScrolledWindow *    THIS = (wxHScrolledWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::HScrolledWindow" )
;
	wxWindow *	RETVAL;
    try {
      RETVAL = THIS->GetTargetWindow();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_object_2_sv( aTHX_ RETVALSV, RETVAL );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


/* INCLUDE: Returning to '/usr/bin/perl -I./ -MExtUtils::XSpp::Cmd -e xspp -- -t typemap.xsp XS/VScrolledWindow.xsp' from '/usr/bin/perl -pe "s/VarScrollHelperBase/HScrolledWindow/g" XS/VarScrollHelperBase.xs' */


/* INCLUDE_COMMAND:  Including output of '/usr/bin/perl -pe "s/VarHScrollHelper/HScrolledWindow/g" XS/VarHScrollHelper.xs' from '/usr/bin/perl -I./ -MExtUtils::XSpp::Cmd -e xspp -- -t typemap.xsp XS/VScrolledWindow.xsp' */

#include <exception>

#undef  xsp_constructor_class
#define xsp_constructor_class(c) (c)

XS_EUPXS(XS_Wx__HScrolledWindow_SetColumnCount); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__HScrolledWindow_SetColumnCount)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, columnCount");
    {
	wxHScrolledWindow *    THIS = (wxHScrolledWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::HScrolledWindow" )
;
	size_t    columnCount = (size_t)SvUV( ST(1) )
;
    try {
      THIS->SetColumnCount( columnCount );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__HScrolledWindow_ScrollToColumn); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__HScrolledWindow_ScrollToColumn)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, column");
    {
	wxHScrolledWindow *    THIS = (wxHScrolledWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::HScrolledWindow" )
;
	bool	RETVAL;
	size_t    column = (size_t)SvUV( ST(1) )
;
    try {
      RETVAL = THIS->ScrollToColumn( column );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__HScrolledWindow_ScrollColumns); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__HScrolledWindow_ScrollColumns)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, columns");
    {
	wxHScrolledWindow *    THIS = (wxHScrolledWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::HScrolledWindow" )
;
	bool	RETVAL;
	int	columns = (int)SvIV(ST(1))
;
    try {
      RETVAL = THIS->ScrollColumns( columns );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__HScrolledWindow_ScrollColumnPages); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__HScrolledWindow_ScrollColumnPages)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, pages");
    {
	wxHScrolledWindow *    THIS = (wxHScrolledWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::HScrolledWindow" )
;
	bool	RETVAL;
	int	pages = (int)SvIV(ST(1))
;
    try {
      RETVAL = THIS->ScrollColumnPages( pages );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__HScrolledWindow_RefreshColumn); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__HScrolledWindow_RefreshColumn)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, column");
    {
	wxHScrolledWindow *    THIS = (wxHScrolledWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::HScrolledWindow" )
;
	size_t    column = (size_t)SvUV( ST(1) )
;
    try {
      THIS->RefreshColumn( column );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__HScrolledWindow_RefreshColumns); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__HScrolledWindow_RefreshColumns)
{
    dVAR; dXSARGS;
    if (items != 3)
       croak_xs_usage(cv,  "THIS, from, to");
    {
	wxHScrolledWindow *    THIS = (wxHScrolledWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::HScrolledWindow" )
;
	size_t    from = (size_t)SvUV( ST(1) )
;
	size_t    to = (size_t)SvUV( ST(2) )
;
    try {
      THIS->RefreshColumns( from, to );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__HScrolledWindow_GetColumnCount); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__HScrolledWindow_GetColumnCount)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxHScrolledWindow *    THIS = (wxHScrolledWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::HScrolledWindow" )
;
	size_t	RETVAL;
	dXSTARG;
    try {
      RETVAL = THIS->GetColumnCount();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	XSprePUSH;
	PUSHu((UV)RETVAL );
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__HScrolledWindow_GetVisibleColumnsBegin); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__HScrolledWindow_GetVisibleColumnsBegin)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxHScrolledWindow *    THIS = (wxHScrolledWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::HScrolledWindow" )
;
	size_t	RETVAL;
	dXSTARG;
    try {
      RETVAL = THIS->GetVisibleColumnsBegin();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	XSprePUSH;
	PUSHu((UV)RETVAL );
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__HScrolledWindow_GetVisibleColumnsEnd); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__HScrolledWindow_GetVisibleColumnsEnd)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxHScrolledWindow *    THIS = (wxHScrolledWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::HScrolledWindow" )
;
	size_t	RETVAL;
	dXSTARG;
    try {
      RETVAL = THIS->GetVisibleColumnsEnd();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	XSprePUSH;
	PUSHu((UV)RETVAL );
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__HScrolledWindow_IsColumnVisible); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__HScrolledWindow_IsColumnVisible)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, column");
    {
	wxHScrolledWindow *    THIS = (wxHScrolledWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::HScrolledWindow" )
;
	bool	RETVAL;
	size_t    column = (size_t)SvUV( ST(1) )
;
    try {
      RETVAL = THIS->IsColumnVisible( column );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


/* INCLUDE: Returning to '/usr/bin/perl -I./ -MExtUtils::XSpp::Cmd -e xspp -- -t typemap.xsp XS/VScrolledWindow.xsp' from '/usr/bin/perl -pe "s/VarHScrollHelper/HScrolledWindow/g" XS/VarHScrollHelper.xs' */

#endif
#define XSubPPtmpAACN 1


XS_EUPXS(XS_Wx__VScrolledWindow_Create); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__VScrolledWindow_Create)
{
    dVAR; dXSARGS;
    if (items < 2 || items > 7)
       croak_xs_usage(cv,  "THIS, parent, id= wxID_ANY, pos= wxDefaultPosition, size= wxDefaultSize, style= 0, name= wxPanelNameStr");
    {
	wxVScrolledWindow *    THIS = (wxVScrolledWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::VScrolledWindow" )
;
	bool	RETVAL;
	wxWindow*    parent = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::Window" )
;
	wxWindowID	id;
	wxPoint	pos;
	wxSize	size;
	long	style;
	wxString	name;

	if (items < 3)
	    id = wxID_ANY;
	else {
    id = wxPli_get_wxwindowid( aTHX_ ST(2) )
;
	}

	if (items < 4)
	    pos = wxDefaultPosition;
	else {
    pos = wxPli_sv_2_wxpoint( aTHX_ ST(3) )
;
	}

	if (items < 5)
	    size = wxDefaultSize;
	else {
    size = wxPli_sv_2_wxsize( aTHX_ ST(4) )
;
	}

	if (items < 6)
	    style = 0;
	else {
	    style = (long)SvIV(ST(5))
;
	}

	if (items < 7)
	    name = wxPanelNameStr;
	else {
    WXSTRING_INPUT( name, wxString, ST(6) )
;
	}
    try {
      RETVAL = THIS->Create( parent, id, pos, size, style, name );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}

#if WXPERL_W_VERSION_GE( 2, 9, 0 )
#define XSpp_ae855b18_007294
#define XSubPPtmpAACO 1


XS_EUPXS(XS_Wx__VScrolledWindow_SetLineCount); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__VScrolledWindow_SetLineCount)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, count");
    {
	wxVScrolledWindow *    THIS = (wxVScrolledWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::VScrolledWindow" )
;
	size_t    count = (size_t)SvUV( ST(1) )
;
    try {
      THIS->SetRowCount( count );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__VScrolledWindow_ScrollToLine); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__VScrolledWindow_ScrollToLine)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, line");
    {
	wxVScrolledWindow *    THIS = (wxVScrolledWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::VScrolledWindow" )
;
	bool	RETVAL;
	size_t    line = (size_t)SvUV( ST(1) )
;
    try {
      RETVAL = THIS->ScrollToRow( line );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__VScrolledWindow_RefreshLine); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__VScrolledWindow_RefreshLine)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, line");
    {
	wxVScrolledWindow *    THIS = (wxVScrolledWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::VScrolledWindow" )
;
	size_t    line = (size_t)SvUV( ST(1) )
;
    try {
      THIS->RefreshRow( line );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__VScrolledWindow_RefreshLines); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__VScrolledWindow_RefreshLines)
{
    dVAR; dXSARGS;
    if (items != 3)
       croak_xs_usage(cv,  "THIS, from, to");
    {
	wxVScrolledWindow *    THIS = (wxVScrolledWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::VScrolledWindow" )
;
	size_t    from = (size_t)SvUV( ST(1) )
;
	size_t    to = (size_t)SvUV( ST(2) )
;
    try {
      THIS->RefreshRows( from, to );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__VScrolledWindow_GetLineCount); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__VScrolledWindow_GetLineCount)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxVScrolledWindow *    THIS = (wxVScrolledWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::VScrolledWindow" )
;
	size_t	RETVAL;
	dXSTARG;
    try {
      RETVAL = THIS->GetRowCount();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	XSprePUSH;
	PUSHu((UV)RETVAL );
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__VScrolledWindow_GetFirstVisibleLine); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__VScrolledWindow_GetFirstVisibleLine)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxVScrolledWindow *    THIS = (wxVScrolledWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::VScrolledWindow" )
;
	size_t	RETVAL;
	dXSTARG;
    try {
      RETVAL = THIS->GetVisibleRowsBegin();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	XSprePUSH;
	PUSHu((UV)RETVAL );
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__VScrolledWindow_GetLastVisibleLine); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__VScrolledWindow_GetLastVisibleLine)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxVScrolledWindow *    THIS = (wxVScrolledWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::VScrolledWindow" )
;
	size_t	RETVAL;
	dXSTARG;
    try {
      RETVAL = THIS->GetVisibleRowsEnd();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	XSprePUSH;
	PUSHu((UV)RETVAL );
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__VScrolledWindow_ScrollLines); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__VScrolledWindow_ScrollLines)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, lines");
    {
	wxVScrolledWindow *    THIS = (wxVScrolledWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::VScrolledWindow" )
;
	bool	RETVAL;
	int	lines = (int)SvIV(ST(1))
;
    try {
      RETVAL = THIS->ScrollRows( lines );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__VScrolledWindow_ScrollPages); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__VScrolledWindow_ScrollPages)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, pages");
    {
	wxVScrolledWindow *    THIS = (wxVScrolledWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::VScrolledWindow" )
;
	bool	RETVAL;
	int	pages = (int)SvIV(ST(1))
;
    try {
      RETVAL = THIS->ScrollRowPages( pages );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


/* INCLUDE_COMMAND:  Including output of '/usr/bin/perl -pe "s/VarScrollHelperBase/VScrolledWindow/g" XS/VarScrollHelperBase.xs' from '/usr/bin/perl -I./ -MExtUtils::XSpp::Cmd -e xspp -- -t typemap.xsp XS/VScrolledWindow.xsp' */

#include <exception>

#undef  xsp_constructor_class
#define xsp_constructor_class(c) (c)

XS_EUPXS(XS_Wx__VScrolledWindow_EnablePhysicalScrolling); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__VScrolledWindow_EnablePhysicalScrolling)
{
    dVAR; dXSARGS;
    if (items < 1 || items > 2)
       croak_xs_usage(cv,  "THIS, scrolling= true");
    {
	wxVScrolledWindow *    THIS = (wxVScrolledWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::VScrolledWindow" )
;
	bool	scrolling;

	if (items < 2)
	    scrolling = true;
	else {
	    scrolling = (bool)SvTRUE(ST(1))
;
	}
    try {
      THIS->EnablePhysicalScrolling( scrolling );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__VScrolledWindow_VirtualHitTest); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__VScrolledWindow_VirtualHitTest)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, coord");
    {
	wxVScrolledWindow *    THIS = (wxVScrolledWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::VScrolledWindow" )
;
	int	RETVAL;
	dXSTARG;
	wxCoord	coord = (wxCoord)SvIV(ST(1))
;
    try {
      RETVAL = THIS->VirtualHitTest( coord );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__VScrolledWindow_RefreshAll); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__VScrolledWindow_RefreshAll)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxVScrolledWindow *    THIS = (wxVScrolledWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::VScrolledWindow" )
;
    try {
      THIS->RefreshAll();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__VScrolledWindow_GetVisibleBegin); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__VScrolledWindow_GetVisibleBegin)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxVScrolledWindow *    THIS = (wxVScrolledWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::VScrolledWindow" )
;
	size_t	RETVAL;
	dXSTARG;
    try {
      RETVAL = THIS->GetVisibleBegin();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	XSprePUSH;
	PUSHu((UV)RETVAL );
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__VScrolledWindow_GetVisibleEnd); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__VScrolledWindow_GetVisibleEnd)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxVScrolledWindow *    THIS = (wxVScrolledWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::VScrolledWindow" )
;
	size_t	RETVAL;
	dXSTARG;
    try {
      RETVAL = THIS->GetVisibleEnd();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	XSprePUSH;
	PUSHu((UV)RETVAL );
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__VScrolledWindow_IsVisible); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__VScrolledWindow_IsVisible)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, unit");
    {
	wxVScrolledWindow *    THIS = (wxVScrolledWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::VScrolledWindow" )
;
	bool	RETVAL;
	size_t    unit = (size_t)SvUV( ST(1) )
;
    try {
      RETVAL = THIS->IsVisible( unit );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__VScrolledWindow_CalcScrolledPosition); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__VScrolledWindow_CalcScrolledPosition)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, coord");
    {
	wxVScrolledWindow *    THIS = (wxVScrolledWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::VScrolledWindow" )
;
	int	RETVAL;
	dXSTARG;
	int	coord = (int)SvIV(ST(1))
;
    try {
      RETVAL = THIS->CalcScrolledPosition( coord );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__VScrolledWindow_CalcUnscrolledPosition); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__VScrolledWindow_CalcUnscrolledPosition)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, coord");
    {
	wxVScrolledWindow *    THIS = (wxVScrolledWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::VScrolledWindow" )
;
	int	RETVAL;
	dXSTARG;
	int	coord = (int)SvIV(ST(1))
;
    try {
      RETVAL = THIS->CalcUnscrolledPosition( coord );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__VScrolledWindow_UpdateScrollbar); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__VScrolledWindow_UpdateScrollbar)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxVScrolledWindow *    THIS = (wxVScrolledWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::VScrolledWindow" )
;
    try {
      THIS->UpdateScrollbar();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__VScrolledWindow_RemoveScrollbar); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__VScrolledWindow_RemoveScrollbar)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxVScrolledWindow *    THIS = (wxVScrolledWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::VScrolledWindow" )
;
    try {
      THIS->RemoveScrollbar();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__VScrolledWindow_SetTargetWindow); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__VScrolledWindow_SetTargetWindow)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, target");
    {
	wxVScrolledWindow *    THIS = (wxVScrolledWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::VScrolledWindow" )
;
	wxWindow*    target = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::Window" )
;
    try {
      THIS->SetTargetWindow( target );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__VScrolledWindow_GetTargetWindow); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__VScrolledWindow_GetTargetWindow)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxVScrolledWindow *    THIS = (wxVScrolledWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::VScrolledWindow" )
;
	wxWindow *	RETVAL;
    try {
      RETVAL = THIS->GetTargetWindow();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_object_2_sv( aTHX_ RETVALSV, RETVAL );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


/* INCLUDE: Returning to '/usr/bin/perl -I./ -MExtUtils::XSpp::Cmd -e xspp -- -t typemap.xsp XS/VScrolledWindow.xsp' from '/usr/bin/perl -pe "s/VarScrollHelperBase/VScrolledWindow/g" XS/VarScrollHelperBase.xs' */


/* INCLUDE_COMMAND:  Including output of '/usr/bin/perl -pe "s/VarVScrollHelper/VScrolledWindow/g" XS/VarVScrollHelper.xs' from '/usr/bin/perl -I./ -MExtUtils::XSpp::Cmd -e xspp -- -t typemap.xsp XS/VScrolledWindow.xsp' */

#include <exception>

#undef  xsp_constructor_class
#define xsp_constructor_class(c) (c)

XS_EUPXS(XS_Wx__VScrolledWindow_SetRowCount); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__VScrolledWindow_SetRowCount)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, count");
    {
	wxVScrolledWindow *    THIS = (wxVScrolledWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::VScrolledWindow" )
;
	size_t    count = (size_t)SvUV( ST(1) )
;
    try {
      THIS->SetRowCount( count );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__VScrolledWindow_ScrollToRow); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__VScrolledWindow_ScrollToRow)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, line");
    {
	wxVScrolledWindow *    THIS = (wxVScrolledWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::VScrolledWindow" )
;
	bool	RETVAL;
	size_t    line = (size_t)SvUV( ST(1) )
;
    try {
      RETVAL = THIS->ScrollToRow( line );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__VScrolledWindow_RefreshRow); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__VScrolledWindow_RefreshRow)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, line");
    {
	wxVScrolledWindow *    THIS = (wxVScrolledWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::VScrolledWindow" )
;
	size_t    line = (size_t)SvUV( ST(1) )
;
    try {
      THIS->RefreshRow( line );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__VScrolledWindow_RefreshRows); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__VScrolledWindow_RefreshRows)
{
    dVAR; dXSARGS;
    if (items != 3)
       croak_xs_usage(cv,  "THIS, from, to");
    {
	wxVScrolledWindow *    THIS = (wxVScrolledWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::VScrolledWindow" )
;
	size_t    from = (size_t)SvUV( ST(1) )
;
	size_t    to = (size_t)SvUV( ST(2) )
;
    try {
      THIS->RefreshRows( from, to );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__VScrolledWindow_GetRowCount); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__VScrolledWindow_GetRowCount)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxVScrolledWindow *    THIS = (wxVScrolledWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::VScrolledWindow" )
;
	size_t	RETVAL;
	dXSTARG;
    try {
      RETVAL = THIS->GetRowCount();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	XSprePUSH;
	PUSHu((UV)RETVAL );
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__VScrolledWindow_GetVisibleRowsBegin); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__VScrolledWindow_GetVisibleRowsBegin)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxVScrolledWindow *    THIS = (wxVScrolledWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::VScrolledWindow" )
;
	size_t	RETVAL;
	dXSTARG;
    try {
      RETVAL = THIS->GetVisibleRowsBegin();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	XSprePUSH;
	PUSHu((UV)RETVAL );
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__VScrolledWindow_GetVisibleRowsEnd); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__VScrolledWindow_GetVisibleRowsEnd)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxVScrolledWindow *    THIS = (wxVScrolledWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::VScrolledWindow" )
;
	size_t	RETVAL;
	dXSTARG;
    try {
      RETVAL = THIS->GetVisibleRowsEnd();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	XSprePUSH;
	PUSHu((UV)RETVAL );
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__VScrolledWindow_ScrollRows); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__VScrolledWindow_ScrollRows)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, lines");
    {
	wxVScrolledWindow *    THIS = (wxVScrolledWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::VScrolledWindow" )
;
	bool	RETVAL;
	int	lines = (int)SvIV(ST(1))
;
    try {
      RETVAL = THIS->ScrollRows( lines );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__VScrolledWindow_ScrollRowPages); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__VScrolledWindow_ScrollRowPages)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, pages");
    {
	wxVScrolledWindow *    THIS = (wxVScrolledWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::VScrolledWindow" )
;
	bool	RETVAL;
	int	pages = (int)SvIV(ST(1))
;
    try {
      RETVAL = THIS->ScrollRowPages( pages );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__VScrolledWindow_IsRowVisible); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__VScrolledWindow_IsRowVisible)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, line");
    {
	wxVScrolledWindow *    THIS = (wxVScrolledWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::VScrolledWindow" )
;
	bool	RETVAL;
	size_t    line = (size_t)SvUV( ST(1) )
;
    try {
      RETVAL = THIS->IsRowVisible( line );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


/* INCLUDE: Returning to '/usr/bin/perl -I./ -MExtUtils::XSpp::Cmd -e xspp -- -t typemap.xsp XS/VScrolledWindow.xsp' from '/usr/bin/perl -pe "s/VarVScrollHelper/VScrolledWindow/g" XS/VarVScrollHelper.xs' */

#else
#define XSpp_ae855b18_099973
#define XSubPPtmpAACP 1


XS_EUPXS(XS_Wx__VScrolledWindow_SetLineCount); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__VScrolledWindow_SetLineCount)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, count");
    {
	wxVScrolledWindow *    THIS = (wxVScrolledWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::VScrolledWindow" )
;
	size_t    count = (size_t)SvUV( ST(1) )
;
    try {
      THIS->SetLineCount( count );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__VScrolledWindow_ScrollToLine); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__VScrolledWindow_ScrollToLine)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, line");
    {
	wxVScrolledWindow *    THIS = (wxVScrolledWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::VScrolledWindow" )
;
	bool	RETVAL;
	size_t    line = (size_t)SvUV( ST(1) )
;
    try {
      RETVAL = THIS->ScrollToLine( line );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__VScrolledWindow_RefreshLine); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__VScrolledWindow_RefreshLine)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, line");
    {
	wxVScrolledWindow *    THIS = (wxVScrolledWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::VScrolledWindow" )
;
	size_t    line = (size_t)SvUV( ST(1) )
;
    try {
      THIS->RefreshLine( line );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__VScrolledWindow_RefreshLines); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__VScrolledWindow_RefreshLines)
{
    dVAR; dXSARGS;
    if (items != 3)
       croak_xs_usage(cv,  "THIS, from, to");
    {
	wxVScrolledWindow *    THIS = (wxVScrolledWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::VScrolledWindow" )
;
	size_t    from = (size_t)SvUV( ST(1) )
;
	size_t    to = (size_t)SvUV( ST(2) )
;
    try {
      THIS->RefreshLines( from, to );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__VScrolledWindow_GetLineCount); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__VScrolledWindow_GetLineCount)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxVScrolledWindow *    THIS = (wxVScrolledWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::VScrolledWindow" )
;
	size_t	RETVAL;
	dXSTARG;
    try {
      RETVAL = THIS->GetLineCount();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	XSprePUSH;
	PUSHu((UV)RETVAL );
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__VScrolledWindow_GetFirstVisibleLine); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__VScrolledWindow_GetFirstVisibleLine)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxVScrolledWindow *    THIS = (wxVScrolledWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::VScrolledWindow" )
;
	size_t	RETVAL;
	dXSTARG;
    try {
      RETVAL = THIS->GetFirstVisibleLine();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	XSprePUSH;
	PUSHu((UV)RETVAL );
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__VScrolledWindow_GetLastVisibleLine); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__VScrolledWindow_GetLastVisibleLine)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxVScrolledWindow *    THIS = (wxVScrolledWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::VScrolledWindow" )
;
	size_t	RETVAL;
	dXSTARG;
    try {
      RETVAL = THIS->GetLastVisibleLine();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	XSprePUSH;
	PUSHu((UV)RETVAL );
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__VScrolledWindow_ScrollLines); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__VScrolledWindow_ScrollLines)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, lines");
    {
	wxVScrolledWindow *    THIS = (wxVScrolledWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::VScrolledWindow" )
;
	bool	RETVAL;
	int	lines = (int)SvIV(ST(1))
;
    try {
      RETVAL = THIS->ScrollLines( lines );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__VScrolledWindow_ScrollPages); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__VScrolledWindow_ScrollPages)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, pages");
    {
	wxVScrolledWindow *    THIS = (wxVScrolledWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::VScrolledWindow" )
;
	bool	RETVAL;
	int	pages = (int)SvIV(ST(1))
;
    try {
      RETVAL = THIS->ScrollPages( pages );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__VScrolledWindow_SetRowCount); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__VScrolledWindow_SetRowCount)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, count");
    {
	wxVScrolledWindow *    THIS = (wxVScrolledWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::VScrolledWindow" )
;
	size_t    count = (size_t)SvUV( ST(1) )
;
    try {
      THIS->SetLineCount( count );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__VScrolledWindow_ScrollToRow); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__VScrolledWindow_ScrollToRow)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, line");
    {
	wxVScrolledWindow *    THIS = (wxVScrolledWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::VScrolledWindow" )
;
	bool	RETVAL;
	size_t    line = (size_t)SvUV( ST(1) )
;
    try {
      RETVAL = THIS->ScrollToLine( line );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__VScrolledWindow_RefreshRow); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__VScrolledWindow_RefreshRow)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, line");
    {
	wxVScrolledWindow *    THIS = (wxVScrolledWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::VScrolledWindow" )
;
	size_t    line = (size_t)SvUV( ST(1) )
;
    try {
      THIS->RefreshLine( line );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__VScrolledWindow_RefreshRows); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__VScrolledWindow_RefreshRows)
{
    dVAR; dXSARGS;
    if (items != 3)
       croak_xs_usage(cv,  "THIS, from, to");
    {
	wxVScrolledWindow *    THIS = (wxVScrolledWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::VScrolledWindow" )
;
	size_t    from = (size_t)SvUV( ST(1) )
;
	size_t    to = (size_t)SvUV( ST(2) )
;
    try {
      THIS->RefreshLines( from, to );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__VScrolledWindow_GetRowCount); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__VScrolledWindow_GetRowCount)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxVScrolledWindow *    THIS = (wxVScrolledWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::VScrolledWindow" )
;
	size_t	RETVAL;
	dXSTARG;
    try {
      RETVAL = THIS->GetLineCount();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	XSprePUSH;
	PUSHu((UV)RETVAL );
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__VScrolledWindow_GetVisibleRowsBegin); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__VScrolledWindow_GetVisibleRowsBegin)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxVScrolledWindow *    THIS = (wxVScrolledWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::VScrolledWindow" )
;
	size_t	RETVAL;
	dXSTARG;
    try {
      RETVAL = THIS->GetFirstVisibleLine();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	XSprePUSH;
	PUSHu((UV)RETVAL );
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__VScrolledWindow_GetVisibleRowsEnd); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__VScrolledWindow_GetVisibleRowsEnd)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxVScrolledWindow *    THIS = (wxVScrolledWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::VScrolledWindow" )
;
	size_t	RETVAL;
	dXSTARG;
    try {
      RETVAL = THIS->GetLastVisibleLine();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	XSprePUSH;
	PUSHu((UV)RETVAL );
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__VScrolledWindow_ScrollRows); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__VScrolledWindow_ScrollRows)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, lines");
    {
	wxVScrolledWindow *    THIS = (wxVScrolledWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::VScrolledWindow" )
;
	bool	RETVAL;
	int	lines = (int)SvIV(ST(1))
;
    try {
      RETVAL = THIS->ScrollLines( lines );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__VScrolledWindow_ScrollRowPages); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__VScrolledWindow_ScrollRowPages)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, pages");
    {
	wxVScrolledWindow *    THIS = (wxVScrolledWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::VScrolledWindow" )
;
	bool	RETVAL;
	int	pages = (int)SvIV(ST(1))
;
    try {
      RETVAL = THIS->ScrollPages( pages );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__VScrolledWindow_RefreshAll); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__VScrolledWindow_RefreshAll)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxVScrolledWindow *    THIS = (wxVScrolledWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::VScrolledWindow" )
;
    try {
      THIS->RefreshAll();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}

#if WXPERL_W_VERSION_GE( 2, 6, 0 )
#define XSpp_ae855b18_032403
#define XSubPPtmpAACQ 1


XS_EUPXS(XS_Wx__VScrolledWindow_GetVisibleBegin); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__VScrolledWindow_GetVisibleBegin)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxVScrolledWindow *    THIS = (wxVScrolledWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::VScrolledWindow" )
;
	size_t	RETVAL;
	dXSTARG;
    try {
      RETVAL = THIS->GetVisibleBegin();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	XSprePUSH;
	PUSHu((UV)RETVAL );
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__VScrolledWindow_GetVisibleEnd); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__VScrolledWindow_GetVisibleEnd)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxVScrolledWindow *    THIS = (wxVScrolledWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::VScrolledWindow" )
;
	size_t	RETVAL;
	dXSTARG;
    try {
      RETVAL = THIS->GetVisibleEnd();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	XSprePUSH;
	PUSHu((UV)RETVAL );
    }
    XSRETURN(1);
}

#endif

XS_EUPXS(XS_Wx__VScrolledWindow_IsVisible); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__VScrolledWindow_IsVisible)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, line");
    {
	wxVScrolledWindow *    THIS = (wxVScrolledWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::VScrolledWindow" )
;
	bool	RETVAL;
	size_t    line = (size_t)SvUV( ST(1) )
;
    try {
      RETVAL = THIS->IsVisible( line );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__VScrolledWindow_IsRowVisible); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__VScrolledWindow_IsRowVisible)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, line");
    {
	wxVScrolledWindow *    THIS = (wxVScrolledWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::VScrolledWindow" )
;
	bool	RETVAL;
	size_t    line = (size_t)SvUV( ST(1) )
;
    try {
      RETVAL = THIS->IsVisible( line );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}

#endif

XS_EUPXS(XS_Wx__VScrolledWindow_HitTest); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__VScrolledWindow_HitTest)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, pt");
    {
	wxVScrolledWindow *    THIS = (wxVScrolledWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::VScrolledWindow" )
;
	int	RETVAL;
	dXSTARG;
	wxPoint    pt = wxPli_sv_2_wxpoint( aTHX_ ST(1) )
;
    try {
      RETVAL = THIS->HitTest( pt );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__VScrolledWindow_Layout); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__VScrolledWindow_Layout)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxVScrolledWindow *    THIS = (wxVScrolledWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::VScrolledWindow" )
;
	bool	RETVAL;
    try {
      RETVAL = THIS->Layout();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}

#if WXPERL_W_VERSION_GE( 2, 9, 0 )
#define XSpp_ae855b18_063169
#define XSubPPtmpAACR 1


XS_EUPXS(XS_Wx__HVScrolledWindow_Create); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__HVScrolledWindow_Create)
{
    dVAR; dXSARGS;
    if (items < 2 || items > 7)
       croak_xs_usage(cv,  "THIS, parent, id= wxID_ANY, pos= wxDefaultPosition, size= wxDefaultSize, style= 0, name= wxPanelNameStr");
    {
	wxHVScrolledWindow *    THIS = (wxHVScrolledWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::HVScrolledWindow" )
;
	bool	RETVAL;
	wxWindow*    parent = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::Window" )
;
	wxWindowID	id;
	wxPoint	pos;
	wxSize	size;
	long	style;
	wxString	name;

	if (items < 3)
	    id = wxID_ANY;
	else {
    id = wxPli_get_wxwindowid( aTHX_ ST(2) )
;
	}

	if (items < 4)
	    pos = wxDefaultPosition;
	else {
    pos = wxPli_sv_2_wxpoint( aTHX_ ST(3) )
;
	}

	if (items < 5)
	    size = wxDefaultSize;
	else {
    size = wxPli_sv_2_wxsize( aTHX_ ST(4) )
;
	}

	if (items < 6)
	    style = 0;
	else {
	    style = (long)SvIV(ST(5))
;
	}

	if (items < 7)
	    name = wxPanelNameStr;
	else {
    WXSTRING_INPUT( name, wxString, ST(6) )
;
	}
    try {
      RETVAL = THIS->Create( parent, id, pos, size, style, name );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


/* INCLUDE_COMMAND:  Including output of '/usr/bin/perl -pe "s/VarHScrollHelper/HVScrolledWindow/g" XS/VarHScrollHelper.xs' from '/usr/bin/perl -I./ -MExtUtils::XSpp::Cmd -e xspp -- -t typemap.xsp XS/VScrolledWindow.xsp' */

#include <exception>

#undef  xsp_constructor_class
#define xsp_constructor_class(c) (c)

XS_EUPXS(XS_Wx__HVScrolledWindow_SetColumnCount); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__HVScrolledWindow_SetColumnCount)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, columnCount");
    {
	wxHVScrolledWindow *    THIS = (wxHVScrolledWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::HVScrolledWindow" )
;
	size_t    columnCount = (size_t)SvUV( ST(1) )
;
    try {
      THIS->SetColumnCount( columnCount );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__HVScrolledWindow_ScrollToColumn); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__HVScrolledWindow_ScrollToColumn)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, column");
    {
	wxHVScrolledWindow *    THIS = (wxHVScrolledWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::HVScrolledWindow" )
;
	bool	RETVAL;
	size_t    column = (size_t)SvUV( ST(1) )
;
    try {
      RETVAL = THIS->ScrollToColumn( column );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__HVScrolledWindow_ScrollColumns); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__HVScrolledWindow_ScrollColumns)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, columns");
    {
	wxHVScrolledWindow *    THIS = (wxHVScrolledWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::HVScrolledWindow" )
;
	bool	RETVAL;
	int	columns = (int)SvIV(ST(1))
;
    try {
      RETVAL = THIS->ScrollColumns( columns );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__HVScrolledWindow_ScrollColumnPages); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__HVScrolledWindow_ScrollColumnPages)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, pages");
    {
	wxHVScrolledWindow *    THIS = (wxHVScrolledWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::HVScrolledWindow" )
;
	bool	RETVAL;
	int	pages = (int)SvIV(ST(1))
;
    try {
      RETVAL = THIS->ScrollColumnPages( pages );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__HVScrolledWindow_RefreshColumn); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__HVScrolledWindow_RefreshColumn)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, column");
    {
	wxHVScrolledWindow *    THIS = (wxHVScrolledWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::HVScrolledWindow" )
;
	size_t    column = (size_t)SvUV( ST(1) )
;
    try {
      THIS->RefreshColumn( column );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__HVScrolledWindow_RefreshColumns); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__HVScrolledWindow_RefreshColumns)
{
    dVAR; dXSARGS;
    if (items != 3)
       croak_xs_usage(cv,  "THIS, from, to");
    {
	wxHVScrolledWindow *    THIS = (wxHVScrolledWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::HVScrolledWindow" )
;
	size_t    from = (size_t)SvUV( ST(1) )
;
	size_t    to = (size_t)SvUV( ST(2) )
;
    try {
      THIS->RefreshColumns( from, to );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__HVScrolledWindow_GetColumnCount); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__HVScrolledWindow_GetColumnCount)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxHVScrolledWindow *    THIS = (wxHVScrolledWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::HVScrolledWindow" )
;
	size_t	RETVAL;
	dXSTARG;
    try {
      RETVAL = THIS->GetColumnCount();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	XSprePUSH;
	PUSHu((UV)RETVAL );
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__HVScrolledWindow_GetVisibleColumnsBegin); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__HVScrolledWindow_GetVisibleColumnsBegin)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxHVScrolledWindow *    THIS = (wxHVScrolledWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::HVScrolledWindow" )
;
	size_t	RETVAL;
	dXSTARG;
    try {
      RETVAL = THIS->GetVisibleColumnsBegin();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	XSprePUSH;
	PUSHu((UV)RETVAL );
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__HVScrolledWindow_GetVisibleColumnsEnd); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__HVScrolledWindow_GetVisibleColumnsEnd)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxHVScrolledWindow *    THIS = (wxHVScrolledWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::HVScrolledWindow" )
;
	size_t	RETVAL;
	dXSTARG;
    try {
      RETVAL = THIS->GetVisibleColumnsEnd();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	XSprePUSH;
	PUSHu((UV)RETVAL );
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__HVScrolledWindow_IsColumnVisible); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__HVScrolledWindow_IsColumnVisible)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, column");
    {
	wxHVScrolledWindow *    THIS = (wxHVScrolledWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::HVScrolledWindow" )
;
	bool	RETVAL;
	size_t    column = (size_t)SvUV( ST(1) )
;
    try {
      RETVAL = THIS->IsColumnVisible( column );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


/* INCLUDE: Returning to '/usr/bin/perl -I./ -MExtUtils::XSpp::Cmd -e xspp -- -t typemap.xsp XS/VScrolledWindow.xsp' from '/usr/bin/perl -pe "s/VarHScrollHelper/HVScrolledWindow/g" XS/VarHScrollHelper.xs' */


/* INCLUDE_COMMAND:  Including output of '/usr/bin/perl -pe "s/VarVScrollHelper/HVScrolledWindow/g" XS/VarVScrollHelper.xs' from '/usr/bin/perl -I./ -MExtUtils::XSpp::Cmd -e xspp -- -t typemap.xsp XS/VScrolledWindow.xsp' */

#include <exception>

#undef  xsp_constructor_class
#define xsp_constructor_class(c) (c)

XS_EUPXS(XS_Wx__HVScrolledWindow_SetRowCount); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__HVScrolledWindow_SetRowCount)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, count");
    {
	wxHVScrolledWindow *    THIS = (wxHVScrolledWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::HVScrolledWindow" )
;
	size_t    count = (size_t)SvUV( ST(1) )
;
    try {
      THIS->SetRowCount( count );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__HVScrolledWindow_ScrollToRow); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__HVScrolledWindow_ScrollToRow)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, line");
    {
	wxHVScrolledWindow *    THIS = (wxHVScrolledWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::HVScrolledWindow" )
;
	bool	RETVAL;
	size_t    line = (size_t)SvUV( ST(1) )
;
    try {
      RETVAL = THIS->ScrollToRow( line );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__HVScrolledWindow_RefreshRow); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__HVScrolledWindow_RefreshRow)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, line");
    {
	wxHVScrolledWindow *    THIS = (wxHVScrolledWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::HVScrolledWindow" )
;
	size_t    line = (size_t)SvUV( ST(1) )
;
    try {
      THIS->RefreshRow( line );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__HVScrolledWindow_RefreshRows); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__HVScrolledWindow_RefreshRows)
{
    dVAR; dXSARGS;
    if (items != 3)
       croak_xs_usage(cv,  "THIS, from, to");
    {
	wxHVScrolledWindow *    THIS = (wxHVScrolledWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::HVScrolledWindow" )
;
	size_t    from = (size_t)SvUV( ST(1) )
;
	size_t    to = (size_t)SvUV( ST(2) )
;
    try {
      THIS->RefreshRows( from, to );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__HVScrolledWindow_GetRowCount); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__HVScrolledWindow_GetRowCount)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxHVScrolledWindow *    THIS = (wxHVScrolledWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::HVScrolledWindow" )
;
	size_t	RETVAL;
	dXSTARG;
    try {
      RETVAL = THIS->GetRowCount();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	XSprePUSH;
	PUSHu((UV)RETVAL );
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__HVScrolledWindow_GetVisibleRowsBegin); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__HVScrolledWindow_GetVisibleRowsBegin)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxHVScrolledWindow *    THIS = (wxHVScrolledWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::HVScrolledWindow" )
;
	size_t	RETVAL;
	dXSTARG;
    try {
      RETVAL = THIS->GetVisibleRowsBegin();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	XSprePUSH;
	PUSHu((UV)RETVAL );
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__HVScrolledWindow_GetVisibleRowsEnd); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__HVScrolledWindow_GetVisibleRowsEnd)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxHVScrolledWindow *    THIS = (wxHVScrolledWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::HVScrolledWindow" )
;
	size_t	RETVAL;
	dXSTARG;
    try {
      RETVAL = THIS->GetVisibleRowsEnd();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	XSprePUSH;
	PUSHu((UV)RETVAL );
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__HVScrolledWindow_ScrollRows); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__HVScrolledWindow_ScrollRows)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, lines");
    {
	wxHVScrolledWindow *    THIS = (wxHVScrolledWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::HVScrolledWindow" )
;
	bool	RETVAL;
	int	lines = (int)SvIV(ST(1))
;
    try {
      RETVAL = THIS->ScrollRows( lines );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__HVScrolledWindow_ScrollRowPages); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__HVScrolledWindow_ScrollRowPages)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, pages");
    {
	wxHVScrolledWindow *    THIS = (wxHVScrolledWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::HVScrolledWindow" )
;
	bool	RETVAL;
	int	pages = (int)SvIV(ST(1))
;
    try {
      RETVAL = THIS->ScrollRowPages( pages );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__HVScrolledWindow_IsRowVisible); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__HVScrolledWindow_IsRowVisible)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, line");
    {
	wxHVScrolledWindow *    THIS = (wxHVScrolledWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::HVScrolledWindow" )
;
	bool	RETVAL;
	size_t    line = (size_t)SvUV( ST(1) )
;
    try {
      RETVAL = THIS->IsRowVisible( line );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


/* INCLUDE: Returning to '/usr/bin/perl -I./ -MExtUtils::XSpp::Cmd -e xspp -- -t typemap.xsp XS/VScrolledWindow.xsp' from '/usr/bin/perl -pe "s/VarVScrollHelper/HVScrolledWindow/g" XS/VarVScrollHelper.xs' */


/* INCLUDE_COMMAND:  Including output of '/usr/bin/perl -pe "s/VarHVScrollHelper/HVScrolledWindow/g" XS/VarHVScrollHelper.xs' from '/usr/bin/perl -I./ -MExtUtils::XSpp::Cmd -e xspp -- -t typemap.xsp XS/VScrolledWindow.xsp' */

#include <exception>

#undef  xsp_constructor_class
#define xsp_constructor_class(c) (c)

XS_EUPXS(XS_Wx__HVScrolledWindow_SetRowColumnCount); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__HVScrolledWindow_SetRowColumnCount)
{
    dVAR; dXSARGS;
    if (items != 3)
       croak_xs_usage(cv,  "THIS, rowCount, columnCount");
    {
	wxHVScrolledWindow *    THIS = (wxHVScrolledWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::HVScrolledWindow" )
;
	size_t    rowCount = (size_t)SvUV( ST(1) )
;
	size_t    columnCount = (size_t)SvUV( ST(2) )
;
    try {
      THIS->SetRowColumnCount( rowCount, columnCount );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__HVScrolledWindow_EnablePhysicalScrolling); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__HVScrolledWindow_EnablePhysicalScrolling)
{
    dVAR; dXSARGS;
    if (items < 1 || items > 3)
       croak_xs_usage(cv,  "THIS, vscrolling= true, hscrolling= true");
    {
	wxHVScrolledWindow *    THIS = (wxHVScrolledWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::HVScrolledWindow" )
;
	bool	vscrolling;
	bool	hscrolling;

	if (items < 2)
	    vscrolling = true;
	else {
	    vscrolling = (bool)SvTRUE(ST(1))
;
	}

	if (items < 3)
	    hscrolling = true;
	else {
	    hscrolling = (bool)SvTRUE(ST(2))
;
	}
    try {
      THIS->EnablePhysicalScrolling( vscrolling, hscrolling );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__HVScrolledWindow_ScrollToRowColumn); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__HVScrolledWindow_ScrollToRowColumn)
{
    dVAR; dXSARGS;
    if (items < 1)
       croak_xs_usage(cv,  "THIS, ...");
    PERL_UNUSED_VAR(ax); /* -Wall */
    SP -= items;
    {
	wxHVScrolledWindow *    THIS = (wxHVScrolledWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::HVScrolledWindow" )
;
    BEGIN_OVERLOAD()
        MATCH_REDISP( wxPliOvl_n_n, ScrollToRowColumnRC )
        MATCH_REDISP( wxPliOvl_wpos, ScrollToRowColumnPosition )
    END_OVERLOAD( Wx::HVScrolledWindow::ScrollToRowColumn )
	PUTBACK;
	return;
    }
}


XS_EUPXS(XS_Wx__HVScrolledWindow_ScrollToRowColumnRC); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__HVScrolledWindow_ScrollToRowColumnRC)
{
    dVAR; dXSARGS;
    if (items != 3)
       croak_xs_usage(cv,  "THIS, row, column");
    {
	wxHVScrolledWindow *    THIS = (wxHVScrolledWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::HVScrolledWindow" )
;
	bool	RETVAL;
	size_t    row = (size_t)SvUV( ST(1) )
;
	size_t    column = (size_t)SvUV( ST(2) )
;
    try {
      RETVAL = THIS->ScrollToRowColumn( row, column );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__HVScrolledWindow_ScrollToRowColumnPosition); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__HVScrolledWindow_ScrollToRowColumnPosition)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, pos");
    {
	wxHVScrolledWindow *    THIS = (wxHVScrolledWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::HVScrolledWindow" )
;
	bool	RETVAL;
	wxPosition    pos = wxPli_sv_2_wxposition( aTHX_ ST(1) )
;
    try {
      RETVAL = THIS->ScrollToRowColumn( pos );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__HVScrolledWindow_RefreshRowColumn); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__HVScrolledWindow_RefreshRowColumn)
{
    dVAR; dXSARGS;
    if (items < 1)
       croak_xs_usage(cv,  "THIS, ...");
    PERL_UNUSED_VAR(ax); /* -Wall */
    SP -= items;
    {
	wxHVScrolledWindow *    THIS = (wxHVScrolledWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::HVScrolledWindow" )
;
    BEGIN_OVERLOAD()
        MATCH_REDISP( wxPliOvl_n_n, RefreshRowColumnRC )
        MATCH_REDISP( wxPliOvl_wpos, RefreshRowColumnPosition )
    END_OVERLOAD( Wx::HVScrolledWindow::RefreshRowColumn )
	PUTBACK;
	return;
    }
}


XS_EUPXS(XS_Wx__HVScrolledWindow_RefreshRowColumnRC); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__HVScrolledWindow_RefreshRowColumnRC)
{
    dVAR; dXSARGS;
    if (items != 3)
       croak_xs_usage(cv,  "THIS, row, column");
    {
	wxHVScrolledWindow *    THIS = (wxHVScrolledWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::HVScrolledWindow" )
;
	size_t    row = (size_t)SvUV( ST(1) )
;
	size_t    column = (size_t)SvUV( ST(2) )
;
    try {
      THIS->RefreshRowColumn( row, column );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__HVScrolledWindow_RefreshRowColumnPosition); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__HVScrolledWindow_RefreshRowColumnPosition)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, pos");
    {
	wxHVScrolledWindow *    THIS = (wxHVScrolledWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::HVScrolledWindow" )
;
	wxPosition    pos = wxPli_sv_2_wxposition( aTHX_ ST(1) )
;
    try {
      THIS->RefreshRowColumn( pos );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__HVScrolledWindow_RefreshRowsColumns); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__HVScrolledWindow_RefreshRowsColumns)
{
    dVAR; dXSARGS;
    if (items < 1)
       croak_xs_usage(cv,  "THIS, ...");
    PERL_UNUSED_VAR(ax); /* -Wall */
    SP -= items;
    {
	wxHVScrolledWindow *    THIS = (wxHVScrolledWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::HVScrolledWindow" )
;
    BEGIN_OVERLOAD()
        MATCH_REDISP( wxPliOvl_n_n_n_n, RefreshRowsColumnsRC )
        MATCH_REDISP( wxPliOvl_wpos_wpos, RefreshRowsColumnsPosition )
    END_OVERLOAD( Wx::HVScrolledWindow::RefreshRowsColumns )
	PUTBACK;
	return;
    }
}


XS_EUPXS(XS_Wx__HVScrolledWindow_RefreshRowsColumnsRC); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__HVScrolledWindow_RefreshRowsColumnsRC)
{
    dVAR; dXSARGS;
    if (items != 5)
       croak_xs_usage(cv,  "THIS, fromRow, toRow, fromColumn, toColumn");
    {
	wxHVScrolledWindow *    THIS = (wxHVScrolledWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::HVScrolledWindow" )
;
	size_t    fromRow = (size_t)SvUV( ST(1) )
;
	size_t    toRow = (size_t)SvUV( ST(2) )
;
	size_t    fromColumn = (size_t)SvUV( ST(3) )
;
	size_t    toColumn = (size_t)SvUV( ST(4) )
;
    try {
      THIS->RefreshRowsColumns( fromRow, toRow, fromColumn, toColumn );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__HVScrolledWindow_RefreshRowsColumnsPosition); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__HVScrolledWindow_RefreshRowsColumnsPosition)
{
    dVAR; dXSARGS;
    if (items != 3)
       croak_xs_usage(cv,  "THIS, from, to");
    {
	wxHVScrolledWindow *    THIS = (wxHVScrolledWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::HVScrolledWindow" )
;
	wxPosition    from = wxPli_sv_2_wxposition( aTHX_ ST(1) )
;
	wxPosition    to = wxPli_sv_2_wxposition( aTHX_ ST(2) )
;
    try {
      THIS->RefreshRowsColumns( from, to );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__HVScrolledWindow_VirtualHitTest); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__HVScrolledWindow_VirtualHitTest)
{
    dVAR; dXSARGS;
    if (items < 1)
       croak_xs_usage(cv,  "THIS, ...");
    PERL_UNUSED_VAR(ax); /* -Wall */
    SP -= items;
    {
	wxHVScrolledWindow *    THIS = (wxHVScrolledWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::HVScrolledWindow" )
;
    BEGIN_OVERLOAD()
        MATCH_REDISP( wxPliOvl_n_n, VirtualHitTestXY )
        MATCH_REDISP( wxPliOvl_wpoi, VirtualHitTestPoint )
    END_OVERLOAD( Wx::HVScrolledWindow::VirtualHitTest )
	PUTBACK;
	return;
    }
}


XS_EUPXS(XS_Wx__HVScrolledWindow_VirtualHitTestXY); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__HVScrolledWindow_VirtualHitTestXY)
{
    dVAR; dXSARGS;
    if (items != 3)
       croak_xs_usage(cv,  "THIS, x, y");
    {
	wxHVScrolledWindow *    THIS = (wxHVScrolledWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::HVScrolledWindow" )
;
	wxPosition	RETVAL;
	wxCoord	x = (wxCoord)SvIV(ST(1))
;
	wxCoord	y = (wxCoord)SvIV(ST(2))
;
    try {
      RETVAL = THIS->VirtualHitTest( x, y );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_non_object_2_sv( aTHX_ RETVALSV, new wxPosition(RETVAL), "Wx::Position" );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__HVScrolledWindow_VirtualHitTestPoint); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__HVScrolledWindow_VirtualHitTestPoint)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, pos");
    {
	wxHVScrolledWindow *    THIS = (wxHVScrolledWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::HVScrolledWindow" )
;
	wxPosition	RETVAL;
	wxPoint    pos = wxPli_sv_2_wxpoint( aTHX_ ST(1) )
;
    try {
      RETVAL = THIS->VirtualHitTest( pos );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_non_object_2_sv( aTHX_ RETVALSV, new wxPosition(RETVAL), "Wx::Position" );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__HVScrolledWindow_GetRowColumnCount); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__HVScrolledWindow_GetRowColumnCount)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxHVScrolledWindow *    THIS = (wxHVScrolledWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::HVScrolledWindow" )
;
	wxSize	RETVAL;
    try {
      RETVAL = THIS->GetRowColumnCount();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_non_object_2_sv( aTHX_ RETVALSV, new wxSize(RETVAL), "Wx::Size" );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__HVScrolledWindow_GetVisibleBegin); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__HVScrolledWindow_GetVisibleBegin)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxHVScrolledWindow *    THIS = (wxHVScrolledWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::HVScrolledWindow" )
;
	wxPosition	RETVAL;
    try {
      RETVAL = THIS->GetVisibleBegin();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_non_object_2_sv( aTHX_ RETVALSV, new wxPosition(RETVAL), "Wx::Position" );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__HVScrolledWindow_GetVisibleEnd); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__HVScrolledWindow_GetVisibleEnd)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxHVScrolledWindow *    THIS = (wxHVScrolledWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::HVScrolledWindow" )
;
	wxPosition	RETVAL;
    try {
      RETVAL = THIS->GetVisibleEnd();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_non_object_2_sv( aTHX_ RETVALSV, new wxPosition(RETVAL), "Wx::Position" );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__HVScrolledWindow_IsVisible); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__HVScrolledWindow_IsVisible)
{
    dVAR; dXSARGS;
    if (items < 1)
       croak_xs_usage(cv,  "THIS, ...");
    PERL_UNUSED_VAR(ax); /* -Wall */
    SP -= items;
    {
	wxHVScrolledWindow *    THIS = (wxHVScrolledWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::HVScrolledWindow" )
;
    BEGIN_OVERLOAD()
        MATCH_REDISP( wxPliOvl_n_n, IsVisibleRC )
        MATCH_REDISP( wxPliOvl_wpos, IsVisiblePosition )
    END_OVERLOAD( Wx::HVScrolledWindow::IsVisible )
	PUTBACK;
	return;
    }
}


XS_EUPXS(XS_Wx__HVScrolledWindow_IsVisibleRC); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__HVScrolledWindow_IsVisibleRC)
{
    dVAR; dXSARGS;
    if (items != 3)
       croak_xs_usage(cv,  "THIS, row, column");
    {
	wxHVScrolledWindow *    THIS = (wxHVScrolledWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::HVScrolledWindow" )
;
	bool	RETVAL;
	size_t    row = (size_t)SvUV( ST(1) )
;
	size_t    column = (size_t)SvUV( ST(2) )
;
    try {
      RETVAL = THIS->IsVisible( row, column );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__HVScrolledWindow_IsVisiblePosition); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__HVScrolledWindow_IsVisiblePosition)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, pos");
    {
	wxHVScrolledWindow *    THIS = (wxHVScrolledWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::HVScrolledWindow" )
;
	bool	RETVAL;
	wxPosition    pos = wxPli_sv_2_wxposition( aTHX_ ST(1) )
;
    try {
      RETVAL = THIS->IsVisible( pos );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


/* INCLUDE: Returning to '/usr/bin/perl -I./ -MExtUtils::XSpp::Cmd -e xspp -- -t typemap.xsp XS/VScrolledWindow.xsp' from '/usr/bin/perl -pe "s/VarHVScrollHelper/HVScrolledWindow/g" XS/VarHVScrollHelper.xs' */

#endif
#include "cpp/overload.h"
#include "xspp/vscrl.h"
#if WXPERL_W_VERSION_GE( 2, 9, 0 )
#define XSpp_ae855b18_039018
#define XSubPPtmpAACS 1


XS_EUPXS(XS_Wx__PlHScrolledWindow_new); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__PlHScrolledWindow_new)
{
    dVAR; dXSARGS;
    PERL_UNUSED_VAR(cv); /* -W */
    PERL_UNUSED_VAR(items); /* -W */
    PERL_UNUSED_VAR(ax); /* -Wall */
    SP -= items;
    {
    BEGIN_OVERLOAD()
        MATCH_VOIDM_REDISP( newDefault )
        MATCH_ANY_REDISP( newFull )
    END_OVERLOAD( "Wx::PlHScrolledWindow::new" )
	PUTBACK;
	return;
    }
}

#undef  xsp_constructor_class
#define xsp_constructor_class(c) (CLASS)

XS_EUPXS(XS_Wx__PlHScrolledWindow_newDefault); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__PlHScrolledWindow_newDefault)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "CLASS");
    {
	char *	CLASS = (char *)SvPV_nolen(ST(0))
;
	wxPlHScrolledWindow *	RETVAL;
     RETVAL = new wxPlHScrolledWindow( CLASS ); 
                wxPli_create_evthandler( aTHX_ RETVAL, CLASS );
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_evthandler_2_sv( aTHX_ RETVALSV, RETVAL );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}

#undef  xsp_constructor_class
#define xsp_constructor_class(c) (c)
#undef  xsp_constructor_class
#define xsp_constructor_class(c) (CLASS)

XS_EUPXS(XS_Wx__PlHScrolledWindow_newFull); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__PlHScrolledWindow_newFull)
{
    dVAR; dXSARGS;
    if (items < 2 || items > 7)
       croak_xs_usage(cv,  "CLASS, parent, id= wxID_ANY, pos= wxDefaultPosition, size= wxDefaultSize, style= 0, name= wxPanelNameStr");
    {
	char *	CLASS = (char *)SvPV_nolen(ST(0))
;
	wxPlHScrolledWindow *	RETVAL;
	wxWindow*    parent = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::Window" )
;
	wxWindowID	id;
	wxPoint	pos;
	wxSize	size;
	long	style;
	wxString	name;

	if (items < 3)
	    id = wxID_ANY;
	else {
    id = wxPli_get_wxwindowid( aTHX_ ST(2) )
;
	}

	if (items < 4)
	    pos = wxDefaultPosition;
	else {
    pos = wxPli_sv_2_wxpoint( aTHX_ ST(3) )
;
	}

	if (items < 5)
	    size = wxDefaultSize;
	else {
    size = wxPli_sv_2_wxsize( aTHX_ ST(4) )
;
	}

	if (items < 6)
	    style = 0;
	else {
	    style = (long)SvIV(ST(5))
;
	}

	if (items < 7)
	    name = wxPanelNameStr;
	else {
    WXSTRING_INPUT( name, wxString, ST(6) )
;
	}
     RETVAL = new wxPlHScrolledWindow( CLASS, parent, id, pos, size,
                                                  style, name );
                wxPli_create_evthandler( aTHX_ RETVAL, CLASS );
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_evthandler_2_sv( aTHX_ RETVALSV, RETVAL );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}

#undef  xsp_constructor_class
#define xsp_constructor_class(c) (c)
#endif

XS_EUPXS(XS_Wx__PlVScrolledWindow_new); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__PlVScrolledWindow_new)
{
    dVAR; dXSARGS;
    PERL_UNUSED_VAR(cv); /* -W */
    PERL_UNUSED_VAR(items); /* -W */
    PERL_UNUSED_VAR(ax); /* -Wall */
    SP -= items;
    {
    BEGIN_OVERLOAD()
        MATCH_VOIDM_REDISP( newDefault )
        MATCH_ANY_REDISP( newFull )
    END_OVERLOAD( "Wx::PlVScrolledWindow::new" )
	PUTBACK;
	return;
    }
}

#undef  xsp_constructor_class
#define xsp_constructor_class(c) (CLASS)

XS_EUPXS(XS_Wx__PlVScrolledWindow_newDefault); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__PlVScrolledWindow_newDefault)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "CLASS");
    {
	char *	CLASS = (char *)SvPV_nolen(ST(0))
;
	wxPlVScrolledWindow *	RETVAL;
     RETVAL = new wxPlVScrolledWindow( CLASS ); 
                wxPli_create_evthandler( aTHX_ RETVAL, CLASS );
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_evthandler_2_sv( aTHX_ RETVALSV, RETVAL );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}

#undef  xsp_constructor_class
#define xsp_constructor_class(c) (c)
#undef  xsp_constructor_class
#define xsp_constructor_class(c) (CLASS)

XS_EUPXS(XS_Wx__PlVScrolledWindow_newFull); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__PlVScrolledWindow_newFull)
{
    dVAR; dXSARGS;
    if (items < 2 || items > 7)
       croak_xs_usage(cv,  "CLASS, parent, id= wxID_ANY, pos= wxDefaultPosition, size= wxDefaultSize, style= 0, name= wxPanelNameStr");
    {
	char *	CLASS = (char *)SvPV_nolen(ST(0))
;
	wxPlVScrolledWindow *	RETVAL;
	wxWindow*    parent = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::Window" )
;
	wxWindowID	id;
	wxPoint	pos;
	wxSize	size;
	long	style;
	wxString	name;

	if (items < 3)
	    id = wxID_ANY;
	else {
    id = wxPli_get_wxwindowid( aTHX_ ST(2) )
;
	}

	if (items < 4)
	    pos = wxDefaultPosition;
	else {
    pos = wxPli_sv_2_wxpoint( aTHX_ ST(3) )
;
	}

	if (items < 5)
	    size = wxDefaultSize;
	else {
    size = wxPli_sv_2_wxsize( aTHX_ ST(4) )
;
	}

	if (items < 6)
	    style = 0;
	else {
	    style = (long)SvIV(ST(5))
;
	}

	if (items < 7)
	    name = wxPanelNameStr;
	else {
    WXSTRING_INPUT( name, wxString, ST(6) )
;
	}
     RETVAL = new wxPlVScrolledWindow( CLASS, parent, id, pos, size,
                                                  style, name );
                 wxPli_create_evthandler( aTHX_ RETVAL, CLASS );
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_evthandler_2_sv( aTHX_ RETVALSV, RETVAL );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}

#undef  xsp_constructor_class
#define xsp_constructor_class(c) (c)
#if WXPERL_W_VERSION_GE( 2, 9, 0 )
#define XSpp_ae855b18_095523
#define XSubPPtmpAACT 1


XS_EUPXS(XS_Wx__PlHVScrolledWindow_new); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__PlHVScrolledWindow_new)
{
    dVAR; dXSARGS;
    PERL_UNUSED_VAR(cv); /* -W */
    PERL_UNUSED_VAR(items); /* -W */
    PERL_UNUSED_VAR(ax); /* -Wall */
    SP -= items;
    {
    BEGIN_OVERLOAD()
        MATCH_VOIDM_REDISP( newDefault )
        MATCH_ANY_REDISP( newFull )
    END_OVERLOAD( "Wx::PlHVScrolledWindow::new" )
	PUTBACK;
	return;
    }
}

#undef  xsp_constructor_class
#define xsp_constructor_class(c) (CLASS)

XS_EUPXS(XS_Wx__PlHVScrolledWindow_newDefault); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__PlHVScrolledWindow_newDefault)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "CLASS");
    {
	char *	CLASS = (char *)SvPV_nolen(ST(0))
;
	wxPlHVScrolledWindow *	RETVAL;
     RETVAL = new wxPlHVScrolledWindow( CLASS ); 
                wxPli_create_evthandler( aTHX_ RETVAL, CLASS );
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_evthandler_2_sv( aTHX_ RETVALSV, RETVAL );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}

#undef  xsp_constructor_class
#define xsp_constructor_class(c) (c)
#undef  xsp_constructor_class
#define xsp_constructor_class(c) (CLASS)

XS_EUPXS(XS_Wx__PlHVScrolledWindow_newFull); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__PlHVScrolledWindow_newFull)
{
    dVAR; dXSARGS;
    if (items < 2 || items > 7)
       croak_xs_usage(cv,  "CLASS, parent, id= wxID_ANY, pos= wxDefaultPosition, size= wxDefaultSize, style= 0, name= wxPanelNameStr");
    {
	char *	CLASS = (char *)SvPV_nolen(ST(0))
;
	wxPlHVScrolledWindow *	RETVAL;
	wxWindow*    parent = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::Window" )
;
	wxWindowID	id;
	wxPoint	pos;
	wxSize	size;
	long	style;
	wxString	name;

	if (items < 3)
	    id = wxID_ANY;
	else {
    id = wxPli_get_wxwindowid( aTHX_ ST(2) )
;
	}

	if (items < 4)
	    pos = wxDefaultPosition;
	else {
    pos = wxPli_sv_2_wxpoint( aTHX_ ST(3) )
;
	}

	if (items < 5)
	    size = wxDefaultSize;
	else {
    size = wxPli_sv_2_wxsize( aTHX_ ST(4) )
;
	}

	if (items < 6)
	    style = 0;
	else {
	    style = (long)SvIV(ST(5))
;
	}

	if (items < 7)
	    name = wxPanelNameStr;
	else {
    WXSTRING_INPUT( name, wxString, ST(6) )
;
	}
     RETVAL = new wxPlHVScrolledWindow( CLASS, parent, id, pos,
                                                   size, style, name );
                wxPli_create_evthandler( aTHX_ RETVAL, CLASS );
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_evthandler_2_sv( aTHX_ RETVALSV, RETVAL );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}

#undef  xsp_constructor_class
#define xsp_constructor_class(c) (c)
#endif
#endif

/* INCLUDE: Returning to 'Window.xs' from '/usr/bin/perl -I./ -MExtUtils::XSpp::Cmd -e xspp -- -t typemap.xsp XS/VScrolledWindow.xsp' */


/* INCLUDE:  Including 'XS/ScrolledWindow.xs' from 'Window.xs' */


/* INCLUDE:  Including 'XS/Validators.xs' from 'XS/ScrolledWindow.xs' */


/* INCLUDE:  Including 'XS/Constraint.xs' from 'XS/Validators.xs' */

#include <wx/layout.h>

XS_EUPXS(XS_Wx__IndividualLayoutConstraint_Above); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__IndividualLayoutConstraint_Above)
{
    dVAR; dXSARGS;
    if (items < 2 || items > 3)
       croak_xs_usage(cv,  "THIS, otherWin, margin = 0");
    {
	wxWindow*    otherWin = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::Window" )
;
	int	margin;
	wxIndividualLayoutConstraint *    THIS = (wxIndividualLayoutConstraint *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::IndividualLayoutConstraint" )
;

	if (items < 3)
	    margin = 0;
	else {
	    margin = (int)SvIV(ST(2))
;
	}

	THIS->Above(otherWin, margin);
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__IndividualLayoutConstraint_Absolute); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__IndividualLayoutConstraint_Absolute)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, value");
    {
	int	value = (int)SvIV(ST(1))
;
	wxIndividualLayoutConstraint *    THIS = (wxIndividualLayoutConstraint *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::IndividualLayoutConstraint" )
;

	THIS->Absolute(value);
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__IndividualLayoutConstraint_AsIs); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__IndividualLayoutConstraint_AsIs)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxIndividualLayoutConstraint *    THIS = (wxIndividualLayoutConstraint *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::IndividualLayoutConstraint" )
;

	THIS->AsIs();
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__IndividualLayoutConstraint_Below); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__IndividualLayoutConstraint_Below)
{
    dVAR; dXSARGS;
    if (items < 2 || items > 3)
       croak_xs_usage(cv,  "THIS, otherWin, margin = 0");
    {
	wxWindow*    otherWin = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::Window" )
;
	int	margin;
	wxIndividualLayoutConstraint *    THIS = (wxIndividualLayoutConstraint *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::IndividualLayoutConstraint" )
;

	if (items < 3)
	    margin = 0;
	else {
	    margin = (int)SvIV(ST(2))
;
	}

	THIS->Below(otherWin, margin);
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__IndividualLayoutConstraint_Unconstrained); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__IndividualLayoutConstraint_Unconstrained)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxIndividualLayoutConstraint *    THIS = (wxIndividualLayoutConstraint *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::IndividualLayoutConstraint" )
;

	THIS->Unconstrained();
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__IndividualLayoutConstraint_LeftOf); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__IndividualLayoutConstraint_LeftOf)
{
    dVAR; dXSARGS;
    if (items < 2 || items > 3)
       croak_xs_usage(cv,  "THIS, otherWin, margin = 0");
    {
	wxWindow*    otherWin = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::Window" )
;
	int	margin;
	wxIndividualLayoutConstraint *    THIS = (wxIndividualLayoutConstraint *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::IndividualLayoutConstraint" )
;

	if (items < 3)
	    margin = 0;
	else {
	    margin = (int)SvIV(ST(2))
;
	}

	THIS->LeftOf(otherWin, margin);
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__IndividualLayoutConstraint_PercentOf); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__IndividualLayoutConstraint_PercentOf)
{
    dVAR; dXSARGS;
    if (items != 4)
       croak_xs_usage(cv,  "THIS, otherWin, edge, per");
    {
	wxWindow*    otherWin = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::Window" )
;
	wxEdge	edge = (wxEdge)SvIV(ST(2))
;
	int	per = (int)SvIV(ST(3))
;
	wxIndividualLayoutConstraint *    THIS = (wxIndividualLayoutConstraint *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::IndividualLayoutConstraint" )
;

	THIS->PercentOf(otherWin, edge, per);
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__IndividualLayoutConstraint_RightOf); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__IndividualLayoutConstraint_RightOf)
{
    dVAR; dXSARGS;
    if (items < 2 || items > 3)
       croak_xs_usage(cv,  "THIS, otherWin, margin = 0");
    {
	wxWindow*    otherWin = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::Window" )
;
	int	margin;
	wxIndividualLayoutConstraint *    THIS = (wxIndividualLayoutConstraint *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::IndividualLayoutConstraint" )
;

	if (items < 3)
	    margin = 0;
	else {
	    margin = (int)SvIV(ST(2))
;
	}

	THIS->RightOf(otherWin, margin);
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__IndividualLayoutConstraint_SameAs); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__IndividualLayoutConstraint_SameAs)
{
    dVAR; dXSARGS;
    if (items < 3 || items > 4)
       croak_xs_usage(cv,  "THIS, otherWin, edge, margin = 0");
    {
	wxWindow*    otherWin = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::Window" )
;
	wxEdge	edge = (wxEdge)SvIV(ST(2))
;
	int	margin;
	wxIndividualLayoutConstraint *    THIS = (wxIndividualLayoutConstraint *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::IndividualLayoutConstraint" )
;

	if (items < 4)
	    margin = 0;
	else {
	    margin = (int)SvIV(ST(3))
;
	}

	THIS->SameAs(otherWin, edge, margin);
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__IndividualLayoutConstraint_Set); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__IndividualLayoutConstraint_Set)
{
    dVAR; dXSARGS;
    if (items < 4 || items > 6)
       croak_xs_usage(cv,  "THIS, rel, otherWin, otherEdge, value = 0, margin = 0");
    {
	wxRelationship	rel = (wxRelationship)SvIV(ST(1))
;
	wxWindow*    otherWin = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(2), "Wx::Window" )
;
	wxEdge	otherEdge = (wxEdge)SvIV(ST(3))
;
	int	value;
	int	margin;
	wxIndividualLayoutConstraint *    THIS = (wxIndividualLayoutConstraint *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::IndividualLayoutConstraint" )
;

	if (items < 5)
	    value = 0;
	else {
	    value = (int)SvIV(ST(4))
;
	}

	if (items < 6)
	    margin = 0;
	else {
	    margin = (int)SvIV(ST(5))
;
	}

	THIS->Set(rel, otherWin, otherEdge, value, margin);
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__LayoutConstraints_new); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__LayoutConstraints_new)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "CLASS");
    {
	char *	CLASS = (char *)SvPV_nolen(ST(0))
;
	wxLayoutConstraints *	RETVAL;

	RETVAL = new wxLayoutConstraints();
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_object_2_sv( aTHX_ RETVALSV, RETVAL );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__LayoutConstraints_bottom); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__LayoutConstraints_bottom)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxLayoutConstraints *    THIS = (wxLayoutConstraints *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::LayoutConstraints" )
;
	wxIndividualLayoutConstraint *	RETVAL;
    RETVAL = &THIS->bottom;
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_object_2_sv( aTHX_ RETVALSV, RETVAL );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__LayoutConstraints_centreX); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__LayoutConstraints_centreX)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxLayoutConstraints *    THIS = (wxLayoutConstraints *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::LayoutConstraints" )
;
	wxIndividualLayoutConstraint *	RETVAL;
    RETVAL = &THIS->centreX;
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_object_2_sv( aTHX_ RETVALSV, RETVAL );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__LayoutConstraints_centreY); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__LayoutConstraints_centreY)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxLayoutConstraints *    THIS = (wxLayoutConstraints *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::LayoutConstraints" )
;
	wxIndividualLayoutConstraint *	RETVAL;
    RETVAL = &THIS->centreY;
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_object_2_sv( aTHX_ RETVALSV, RETVAL );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__LayoutConstraints_height); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__LayoutConstraints_height)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxLayoutConstraints *    THIS = (wxLayoutConstraints *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::LayoutConstraints" )
;
	wxIndividualLayoutConstraint *	RETVAL;
    RETVAL = &THIS->height;
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_object_2_sv( aTHX_ RETVALSV, RETVAL );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__LayoutConstraints_left); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__LayoutConstraints_left)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxLayoutConstraints *    THIS = (wxLayoutConstraints *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::LayoutConstraints" )
;
	wxIndividualLayoutConstraint *	RETVAL;
    RETVAL = &THIS->left;
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_object_2_sv( aTHX_ RETVALSV, RETVAL );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__LayoutConstraints_right); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__LayoutConstraints_right)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxLayoutConstraints *    THIS = (wxLayoutConstraints *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::LayoutConstraints" )
;
	wxIndividualLayoutConstraint *	RETVAL;
    RETVAL = &THIS->right;
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_object_2_sv( aTHX_ RETVALSV, RETVAL );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__LayoutConstraints_top); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__LayoutConstraints_top)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxLayoutConstraints *    THIS = (wxLayoutConstraints *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::LayoutConstraints" )
;
	wxIndividualLayoutConstraint *	RETVAL;
    RETVAL = &THIS->top;
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_object_2_sv( aTHX_ RETVALSV, RETVAL );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__LayoutConstraints_width); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__LayoutConstraints_width)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxLayoutConstraints *    THIS = (wxLayoutConstraints *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::LayoutConstraints" )
;
	wxIndividualLayoutConstraint *	RETVAL;
    RETVAL = &THIS->width;
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_object_2_sv( aTHX_ RETVALSV, RETVAL );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


/* INCLUDE: Returning to 'XS/Validators.xs' from 'XS/Constraint.xs' */

#include <wx/validate.h>
#include "cpp/validators.h"

XS_EUPXS(XS_Wx__Validator_GetWindow); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Validator_GetWindow)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxValidator *    THIS = (wxValidator *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Validator" )
;
	wxWindow *	RETVAL;

	RETVAL = THIS->GetWindow();
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_object_2_sv( aTHX_ RETVALSV, RETVAL );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__Validator_SetBellOnError); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Validator_SetBellOnError)
{
    dVAR; dXSARGS;
    if (items < 1 || items > 2)
       croak_xs_usage(cv,  "THIS, doit = true");
    {
	bool	doit;
	wxValidator *    THIS = (wxValidator *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Validator" )
;

	if (items < 2)
	    doit = true;
	else {
	    doit = (bool)SvTRUE(ST(1))
;
	}

	THIS->SetBellOnError(doit);
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__Validator_SetWindow); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Validator_SetWindow)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, window");
    {
	wxWindow*    window = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::Window" )
;
	wxValidator *    THIS = (wxValidator *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Validator" )
;

	THIS->SetWindow(window);
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__PlValidator_new); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__PlValidator_new)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "CLASS");
    {
	char *	CLASS = (char *)SvPV_nolen(ST(0))
;
	wxPlValidator *	RETVAL;
    RETVAL = new wxPlValidator( CLASS );
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_object_2_sv( aTHX_ RETVALSV, RETVAL );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__PlValidator_DESTROY); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__PlValidator_DESTROY)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
    static char wxPlPlValidatorName[] = "Wx::PlValidator";
	wxPlValidator *    THIS = (wxPlValidator *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::PlValidator" )
;
    // nothing
    }
    XSRETURN_EMPTY;
}


/* INCLUDE: Returning to 'XS/ScrolledWindow.xs' from 'XS/Validators.xs' */

#include <wx/scrolwin.h>
#include <wx/dc.h>
#include "cpp/scrolledwindow.h"

XS_EUPXS(XS_Wx__ScrolledWindow_new); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ScrolledWindow_new)
{
    dVAR; dXSARGS;
    PERL_UNUSED_VAR(cv); /* -W */
    PERL_UNUSED_VAR(items); /* -W */
    PERL_UNUSED_VAR(ax); /* -Wall */
    SP -= items;
    {
    BEGIN_OVERLOAD()
        MATCH_VOIDM_REDISP( newDefault )
        MATCH_ANY_REDISP( newFull )
    END_OVERLOAD( "Wx::ScrolledWindow::new" )
	PUTBACK;
	return;
    }
}


XS_EUPXS(XS_Wx__ScrolledWindow_newDefault); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ScrolledWindow_newDefault)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "CLASS");
    {
	PlClassName    CLASS = wxPli_get_class( aTHX_ ST(0) )
;
	wxScrolledWindow *	RETVAL;
    RETVAL = new wxPliScrolledWindow( CLASS );
    wxPli_create_evthandler( aTHX_ RETVAL, CLASS );
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_object_2_sv( aTHX_ RETVALSV, RETVAL );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__ScrolledWindow_newFull); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ScrolledWindow_newFull)
{
    dVAR; dXSARGS;
    if (items < 2 || items > 7)
       croak_xs_usage(cv,  "CLASS, parent, id = wxID_ANY, pos = wxDefaultPosition, size = wxDefaultSize, style = wxHSCROLL|wxVSCROLL, name = wxPanelNameStr");
    {
	PlClassName    CLASS = wxPli_get_class( aTHX_ ST(0) )
;
	wxWindow*    parent = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::Window" )
;
	wxWindowID	id;
	wxPoint	pos;
	wxSize	size;
	long	style;
	wxString	name;
	wxScrolledWindow *	RETVAL;

	if (items < 3)
	    id = wxID_ANY;
	else {
    id = wxPli_get_wxwindowid( aTHX_ ST(2) )
;
	}

	if (items < 4)
	    pos = wxDefaultPosition;
	else {
    pos = wxPli_sv_2_wxpoint( aTHX_ ST(3) )
;
	}

	if (items < 5)
	    size = wxDefaultSize;
	else {
    size = wxPli_sv_2_wxsize( aTHX_ ST(4) )
;
	}

	if (items < 6)
	    style = wxHSCROLL|wxVSCROLL;
	else {
	    style = (long)SvIV(ST(5))
;
	}

	if (items < 7)
	    name = wxPanelNameStr;
	else {
    WXSTRING_INPUT( name, wxString, ST(6) )
;
	}
    RETVAL = new wxPliScrolledWindow( CLASS, parent, id, pos, size, style,
        name );
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_object_2_sv( aTHX_ RETVALSV, RETVAL );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__ScrolledWindow_Create); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ScrolledWindow_Create)
{
    dVAR; dXSARGS;
    if (items < 2 || items > 7)
       croak_xs_usage(cv,  "THIS, parent, id = wxID_ANY, pos = wxDefaultPosition, size = wxDefaultSize, style = wxHSCROLL|wxVSCROLL, name = wxPanelNameStr");
    {
	wxWindow*    parent = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::Window" )
;
	wxWindowID	id;
	wxPoint	pos;
	wxSize	size;
	long	style;
	wxString	name;
	wxScrolledWindow *    THIS = (wxScrolledWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::ScrolledWindow" )
;
	bool	RETVAL;

	if (items < 3)
	    id = wxID_ANY;
	else {
    id = wxPli_get_wxwindowid( aTHX_ ST(2) )
;
	}

	if (items < 4)
	    pos = wxDefaultPosition;
	else {
    pos = wxPli_sv_2_wxpoint( aTHX_ ST(3) )
;
	}

	if (items < 5)
	    size = wxDefaultSize;
	else {
    size = wxPli_sv_2_wxsize( aTHX_ ST(4) )
;
	}

	if (items < 6)
	    style = wxHSCROLL|wxVSCROLL;
	else {
	    style = (long)SvIV(ST(5))
;
	}

	if (items < 7)
	    name = wxPanelNameStr;
	else {
    WXSTRING_INPUT( name, wxString, ST(6) )
;
	}

	RETVAL = THIS->Create(parent, id, pos, size, style, name);
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__ScrolledWindow_CalcScrolledPosition); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ScrolledWindow_CalcScrolledPosition)
{
    dVAR; dXSARGS;
    if (items != 3)
       croak_xs_usage(cv,  "THIS, x, y");
    PERL_UNUSED_VAR(ax); /* -Wall */
    SP -= items;
    {
	int	x = (int)SvIV(ST(1))
;
	int	y = (int)SvIV(ST(2))
;
    int xx;
    int yy;
	wxScrolledWindow *    THIS = (wxScrolledWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::ScrolledWindow" )
;
    THIS->CalcScrolledPosition( x, y, &xx, &yy );
    EXTEND( SP, 2 );
    PUSHs( sv_2mortal( newSViv( xx ) ) );
    PUSHs( sv_2mortal( newSViv( yy ) ) );
	PUTBACK;
	return;
    }
}


XS_EUPXS(XS_Wx__ScrolledWindow_CalcUnscrolledPosition); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ScrolledWindow_CalcUnscrolledPosition)
{
    dVAR; dXSARGS;
    if (items != 3)
       croak_xs_usage(cv,  "THIS, x, y");
    PERL_UNUSED_VAR(ax); /* -Wall */
    SP -= items;
    {
	int	x = (int)SvIV(ST(1))
;
	int	y = (int)SvIV(ST(2))
;
    int xx;
    int yy;
	wxScrolledWindow *    THIS = (wxScrolledWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::ScrolledWindow" )
;
    THIS->CalcUnscrolledPosition( x, y, &xx, &yy );
    EXTEND( SP, 2 );
    PUSHs( sv_2mortal( newSViv( xx ) ) );
    PUSHs( sv_2mortal( newSViv( yy ) ) );
	PUTBACK;
	return;
    }
}


XS_EUPXS(XS_Wx__ScrolledWindow_EnableScrolling); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ScrolledWindow_EnableScrolling)
{
    dVAR; dXSARGS;
    if (items != 3)
       croak_xs_usage(cv,  "THIS, xScrolling, yScrolling");
    {
	bool	xScrolling = (bool)SvTRUE(ST(1))
;
	bool	yScrolling = (bool)SvTRUE(ST(2))
;
	wxScrolledWindow *    THIS = (wxScrolledWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::ScrolledWindow" )
;

	THIS->EnableScrolling(xScrolling, yScrolling);
    }
    XSRETURN_EMPTY;
}

#if WXPERL_W_VERSION_GE( 2, 9, 0 )
#define XSubPPtmpAACU 1


XS_EUPXS(XS_Wx__ScrolledWindow_ShowScrollbars); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ScrolledWindow_ShowScrollbars)
{
    dVAR; dXSARGS;
    if (items != 3)
       croak_xs_usage(cv,  "THIS, horz, vert");
    {
	wxScrollbarVisibility	horz = (wxScrollbarVisibility)SvIV(ST(1))
;
	wxScrollbarVisibility	vert = (wxScrollbarVisibility)SvIV(ST(2))
;
	wxScrolledWindow *    THIS = (wxScrolledWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::ScrolledWindow" )
;

	THIS->ShowScrollbars(horz, vert);
    }
    XSRETURN_EMPTY;
}

#endif

XS_EUPXS(XS_Wx__ScrolledWindow_GetScrollPixelsPerUnit); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ScrolledWindow_GetScrollPixelsPerUnit)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    PERL_UNUSED_VAR(ax); /* -Wall */
    SP -= items;
    {
    int xUnit;
    int yUnit;
	wxScrolledWindow *    THIS = (wxScrolledWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::ScrolledWindow" )
;
    THIS->GetScrollPixelsPerUnit( &xUnit, &yUnit );
    EXTEND( SP, 2 );
    PUSHs( sv_2mortal( newSViv( xUnit ) ) );
    PUSHs( sv_2mortal( newSViv( yUnit ) ) );
	PUTBACK;
	return;
    }
}


XS_EUPXS(XS_Wx__ScrolledWindow_GetVirtualSize); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ScrolledWindow_GetVirtualSize)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    PERL_UNUSED_VAR(ax); /* -Wall */
    SP -= items;
    {
    int x;
    int y;
	wxScrolledWindow *    THIS = (wxScrolledWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::ScrolledWindow" )
;
    THIS->GetVirtualSize( &x, &y );
    EXTEND( SP, 2 );
    PUSHs( sv_2mortal( newSViv( x ) ) );
    PUSHs( sv_2mortal( newSViv( y ) ) );
	PUTBACK;
	return;
    }
}


XS_EUPXS(XS_Wx__ScrolledWindow_IsRetained); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ScrolledWindow_IsRetained)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxScrolledWindow *    THIS = (wxScrolledWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::ScrolledWindow" )
;
	bool	RETVAL;

	RETVAL = THIS->IsRetained();
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__ScrolledWindow_PrepareDC); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ScrolledWindow_PrepareDC)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, dc");
    {
	wxDC*    dc = (wxDC *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::DC" )
;
	wxScrolledWindow *    THIS = (wxScrolledWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::ScrolledWindow" )
;
    THIS->PrepareDC( *dc );
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__ScrolledWindow_DoPrepareDC); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ScrolledWindow_DoPrepareDC)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, dc");
    {
	wxDC*    dc = (wxDC *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::DC" )
;
	wxScrolledWindow *    THIS = (wxScrolledWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::ScrolledWindow" )
;

	THIS->DoPrepareDC(*dc);
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__ScrolledWindow_Scroll); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ScrolledWindow_Scroll)
{
    dVAR; dXSARGS;
    if (items != 3)
       croak_xs_usage(cv,  "THIS, x, y");
    {
	int	x = (int)SvIV(ST(1))
;
	int	y = (int)SvIV(ST(2))
;
	wxScrolledWindow *    THIS = (wxScrolledWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::ScrolledWindow" )
;

	THIS->Scroll(x, y);
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__ScrolledWindow_SetScrollbars); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ScrolledWindow_SetScrollbars)
{
    dVAR; dXSARGS;
    if (items < 5 || items > 8)
       croak_xs_usage(cv,  "THIS, ppuX, ppuY, nX, nY, xPos = 0, yPos = 0, noRefresh = false");
    {
	int	ppuX = (int)SvIV(ST(1))
;
	int	ppuY = (int)SvIV(ST(2))
;
	int	nX = (int)SvIV(ST(3))
;
	int	nY = (int)SvIV(ST(4))
;
	int	xPos;
	int	yPos;
	bool	noRefresh;
	wxScrolledWindow *    THIS = (wxScrolledWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::ScrolledWindow" )
;

	if (items < 6)
	    xPos = 0;
	else {
	    xPos = (int)SvIV(ST(5))
;
	}

	if (items < 7)
	    yPos = 0;
	else {
	    yPos = (int)SvIV(ST(6))
;
	}

	if (items < 8)
	    noRefresh = false;
	else {
	    noRefresh = (bool)SvTRUE(ST(7))
;
	}

	THIS->SetScrollbars(ppuX, ppuY, nX, nY, xPos, yPos, noRefresh);
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__ScrolledWindow_SetScrollRate); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ScrolledWindow_SetScrollRate)
{
    dVAR; dXSARGS;
    if (items != 3)
       croak_xs_usage(cv,  "THIS, xstep, ystep");
    {
	int	xstep = (int)SvIV(ST(1))
;
	int	ystep = (int)SvIV(ST(2))
;
	wxScrolledWindow *    THIS = (wxScrolledWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::ScrolledWindow" )
;

	THIS->SetScrollRate(xstep, ystep);
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__ScrolledWindow_SetTargetWindow); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ScrolledWindow_SetTargetWindow)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, window");
    {
	wxWindow*    window = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::Window" )
;
	wxScrolledWindow *    THIS = (wxScrolledWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::ScrolledWindow" )
;

	THIS->SetTargetWindow(window);
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__ScrolledWindow_GetViewStart); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__ScrolledWindow_GetViewStart)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    PERL_UNUSED_VAR(ax); /* -Wall */
    SP -= items;
    {
    int x;
    int y;
	wxScrolledWindow *    THIS = (wxScrolledWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::ScrolledWindow" )
;
    THIS->GetViewStart( &x, &y );
    EXTEND( SP, 2 );
    PUSHs( sv_2mortal( newSViv( x ) ) );
    PUSHs( sv_2mortal( newSViv( y ) ) );
	PUTBACK;
	return;
    }
}


/* INCLUDE: Returning to 'Window.xs' from 'XS/ScrolledWindow.xs' */


/* INCLUDE_COMMAND:  Including output of '/usr/bin/perl -I./ -MExtUtils::XSpp::Cmd -e xspp -- -t typemap.xsp XS/Sizer.xsp' from 'Window.xs' */

#include <exception>

#undef  xsp_constructor_class
#define xsp_constructor_class(c) (c)
#include <wx/sizer.h>
#include <wx/statbox.h>
#include "cpp/sizer.h"
#if WXPERL_W_VERSION_GE( 2, 5, 4 )
#define XSpp_a9bbfcda_067750
#define XSubPPtmpAACV 1


XS_EUPXS(XS_Wx__Sizer_AddWindow); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Sizer_AddWindow)
{
    dVAR; dXSARGS;
    if (items < 2 || items > 6)
       croak_xs_usage(cv,  "THIS, window, option= 0, flag= 0, border= 0, data= NULL");
    {
	wxSizer *    THIS = (wxSizer *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Sizer" )
;
	wxSizerItem *	RETVAL;
	wxWindow*    window = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::Window" )
;
	int	option;
	int	flag;
	int	border;
	Wx_UserDataO*	data;

	if (items < 3)
	    option = 0;
	else {
	    option = (int)SvIV(ST(2))
;
	}

	if (items < 4)
	    flag = 0;
	else {
	    flag = (int)SvIV(ST(3))
;
	}

	if (items < 5)
	    border = 0;
	else {
	    border = (int)SvIV(ST(4))
;
	}

	if (items < 6)
	    data = NULL;
	else {
    if( SvOK( ST(5) ) )
    {
	data = new wxPliUserDataO( ST(5) );
    }
    else
	data = 0
;
	}
    try {
      RETVAL = THIS->Add( window, option, flag, border, data );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_object_2_sv( aTHX_ RETVALSV, RETVAL );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__Sizer_AddSizer); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Sizer_AddSizer)
{
    dVAR; dXSARGS;
    if (items < 2 || items > 6)
       croak_xs_usage(cv,  "THIS, sizer, option= 0, flag= 0, border= 0, data= NULL");
    {
	wxSizer *    THIS = (wxSizer *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Sizer" )
;
	wxSizerItem *	RETVAL;
	wxSizer*    sizer = (wxSizer *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::Sizer" )
;
	int	option;
	int	flag;
	int	border;
	Wx_UserDataO*	data;

	if (items < 3)
	    option = 0;
	else {
	    option = (int)SvIV(ST(2))
;
	}

	if (items < 4)
	    flag = 0;
	else {
	    flag = (int)SvIV(ST(3))
;
	}

	if (items < 5)
	    border = 0;
	else {
	    border = (int)SvIV(ST(4))
;
	}

	if (items < 6)
	    data = NULL;
	else {
    if( SvOK( ST(5) ) )
    {
	data = new wxPliUserDataO( ST(5) );
    }
    else
	data = 0
;
	}
    try {
      RETVAL = THIS->Add( sizer, option, flag, border, data );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_object_2_sv( aTHX_ RETVALSV, RETVAL );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__Sizer_AddSpace); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Sizer_AddSpace)
{
    dVAR; dXSARGS;
    if (items < 3 || items > 7)
       croak_xs_usage(cv,  "THIS, width, height, option= 0, flag= 0, border= 0, data= NULL");
    {
	wxSizer *    THIS = (wxSizer *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Sizer" )
;
	wxSizerItem *	RETVAL;
	int	width = (int)SvIV(ST(1))
;
	int	height = (int)SvIV(ST(2))
;
	int	option;
	int	flag;
	int	border;
	Wx_UserDataO*	data;

	if (items < 4)
	    option = 0;
	else {
	    option = (int)SvIV(ST(3))
;
	}

	if (items < 5)
	    flag = 0;
	else {
	    flag = (int)SvIV(ST(4))
;
	}

	if (items < 6)
	    border = 0;
	else {
	    border = (int)SvIV(ST(5))
;
	}

	if (items < 7)
	    data = NULL;
	else {
    if( SvOK( ST(6) ) )
    {
	data = new wxPliUserDataO( ST(6) );
    }
    else
	data = 0
;
	}
    try {
      RETVAL = THIS->Add( width, height, option, flag, border, data );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_object_2_sv( aTHX_ RETVALSV, RETVAL );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__Sizer_PrependWindow); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Sizer_PrependWindow)
{
    dVAR; dXSARGS;
    if (items < 2 || items > 6)
       croak_xs_usage(cv,  "THIS, window, option= 0, flag= 0, border= 0, data= NULL");
    {
	wxSizer *    THIS = (wxSizer *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Sizer" )
;
	wxSizerItem *	RETVAL;
	wxWindow*    window = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::Window" )
;
	int	option;
	int	flag;
	int	border;
	Wx_UserDataO*	data;

	if (items < 3)
	    option = 0;
	else {
	    option = (int)SvIV(ST(2))
;
	}

	if (items < 4)
	    flag = 0;
	else {
	    flag = (int)SvIV(ST(3))
;
	}

	if (items < 5)
	    border = 0;
	else {
	    border = (int)SvIV(ST(4))
;
	}

	if (items < 6)
	    data = NULL;
	else {
    if( SvOK( ST(5) ) )
    {
	data = new wxPliUserDataO( ST(5) );
    }
    else
	data = 0
;
	}
    try {
      RETVAL = THIS->Prepend( window, option, flag, border, data );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_object_2_sv( aTHX_ RETVALSV, RETVAL );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__Sizer_PrependSizer); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Sizer_PrependSizer)
{
    dVAR; dXSARGS;
    if (items < 2 || items > 6)
       croak_xs_usage(cv,  "THIS, sizer, option= 0, flag= 0, border= 0, data= NULL");
    {
	wxSizer *    THIS = (wxSizer *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Sizer" )
;
	wxSizerItem *	RETVAL;
	wxSizer*    sizer = (wxSizer *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::Sizer" )
;
	int	option;
	int	flag;
	int	border;
	Wx_UserDataO*	data;

	if (items < 3)
	    option = 0;
	else {
	    option = (int)SvIV(ST(2))
;
	}

	if (items < 4)
	    flag = 0;
	else {
	    flag = (int)SvIV(ST(3))
;
	}

	if (items < 5)
	    border = 0;
	else {
	    border = (int)SvIV(ST(4))
;
	}

	if (items < 6)
	    data = NULL;
	else {
    if( SvOK( ST(5) ) )
    {
	data = new wxPliUserDataO( ST(5) );
    }
    else
	data = 0
;
	}
    try {
      RETVAL = THIS->Prepend( sizer, option, flag, border, data );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_object_2_sv( aTHX_ RETVALSV, RETVAL );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__Sizer_PrependSpace); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Sizer_PrependSpace)
{
    dVAR; dXSARGS;
    if (items < 3 || items > 7)
       croak_xs_usage(cv,  "THIS, width, height, option= 0, flag= 0, border= 0, data= NULL");
    {
	wxSizer *    THIS = (wxSizer *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Sizer" )
;
	wxSizerItem *	RETVAL;
	int	width = (int)SvIV(ST(1))
;
	int	height = (int)SvIV(ST(2))
;
	int	option;
	int	flag;
	int	border;
	Wx_UserDataO*	data;

	if (items < 4)
	    option = 0;
	else {
	    option = (int)SvIV(ST(3))
;
	}

	if (items < 5)
	    flag = 0;
	else {
	    flag = (int)SvIV(ST(4))
;
	}

	if (items < 6)
	    border = 0;
	else {
	    border = (int)SvIV(ST(5))
;
	}

	if (items < 7)
	    data = NULL;
	else {
    if( SvOK( ST(6) ) )
    {
	data = new wxPliUserDataO( ST(6) );
    }
    else
	data = 0
;
	}
    try {
      RETVAL = THIS->Prepend( width, height, option, flag, border, data );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_object_2_sv( aTHX_ RETVALSV, RETVAL );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__Sizer_InsertWindow); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Sizer_InsertWindow)
{
    dVAR; dXSARGS;
    if (items < 3 || items > 7)
       croak_xs_usage(cv,  "THIS, pos, window, option= 0, flag= 0, border= 0, data= NULL");
    {
	wxSizer *    THIS = (wxSizer *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Sizer" )
;
	wxSizerItem *	RETVAL;
	int	pos = (int)SvIV(ST(1))
;
	wxWindow*    window = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(2), "Wx::Window" )
;
	int	option;
	int	flag;
	int	border;
	Wx_UserDataO*	data;

	if (items < 4)
	    option = 0;
	else {
	    option = (int)SvIV(ST(3))
;
	}

	if (items < 5)
	    flag = 0;
	else {
	    flag = (int)SvIV(ST(4))
;
	}

	if (items < 6)
	    border = 0;
	else {
	    border = (int)SvIV(ST(5))
;
	}

	if (items < 7)
	    data = NULL;
	else {
    if( SvOK( ST(6) ) )
    {
	data = new wxPliUserDataO( ST(6) );
    }
    else
	data = 0
;
	}
    try {
      RETVAL = THIS->Insert( pos, window, option, flag, border, data );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_object_2_sv( aTHX_ RETVALSV, RETVAL );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__Sizer_InsertSizer); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Sizer_InsertSizer)
{
    dVAR; dXSARGS;
    if (items < 3 || items > 7)
       croak_xs_usage(cv,  "THIS, pos, sizer, option= 0, flag= 0, border= 0, data= NULL");
    {
	wxSizer *    THIS = (wxSizer *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Sizer" )
;
	wxSizerItem *	RETVAL;
	int	pos = (int)SvIV(ST(1))
;
	wxSizer*    sizer = (wxSizer *) wxPli_sv_2_object( aTHX_ ST(2), "Wx::Sizer" )
;
	int	option;
	int	flag;
	int	border;
	Wx_UserDataO*	data;

	if (items < 4)
	    option = 0;
	else {
	    option = (int)SvIV(ST(3))
;
	}

	if (items < 5)
	    flag = 0;
	else {
	    flag = (int)SvIV(ST(4))
;
	}

	if (items < 6)
	    border = 0;
	else {
	    border = (int)SvIV(ST(5))
;
	}

	if (items < 7)
	    data = NULL;
	else {
    if( SvOK( ST(6) ) )
    {
	data = new wxPliUserDataO( ST(6) );
    }
    else
	data = 0
;
	}
    try {
      RETVAL = THIS->Insert( pos, sizer, option, flag, border, data );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_object_2_sv( aTHX_ RETVALSV, RETVAL );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__Sizer_InsertSpace); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Sizer_InsertSpace)
{
    dVAR; dXSARGS;
    if (items < 4 || items > 8)
       croak_xs_usage(cv,  "THIS, pos, width, height, option= 0, flag= 0, border= 0, data= NULL");
    {
	wxSizer *    THIS = (wxSizer *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Sizer" )
;
	wxSizerItem *	RETVAL;
	int	pos = (int)SvIV(ST(1))
;
	int	width = (int)SvIV(ST(2))
;
	int	height = (int)SvIV(ST(3))
;
	int	option;
	int	flag;
	int	border;
	Wx_UserDataO*	data;

	if (items < 5)
	    option = 0;
	else {
	    option = (int)SvIV(ST(4))
;
	}

	if (items < 6)
	    flag = 0;
	else {
	    flag = (int)SvIV(ST(5))
;
	}

	if (items < 7)
	    border = 0;
	else {
	    border = (int)SvIV(ST(6))
;
	}

	if (items < 8)
	    data = NULL;
	else {
    if( SvOK( ST(7) ) )
    {
	data = new wxPliUserDataO( ST(7) );
    }
    else
	data = 0
;
	}
    try {
      RETVAL = THIS->Insert( pos, width, height, option, flag, border, data );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_object_2_sv( aTHX_ RETVALSV, RETVAL );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}

#else
#define XSpp_a9bbfcda_023879
#define XSubPPtmpAACW 1


XS_EUPXS(XS_Wx__Sizer_AddWindow); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Sizer_AddWindow)
{
    dVAR; dXSARGS;
    if (items < 2 || items > 6)
       croak_xs_usage(cv,  "THIS, window, option= 0, flag= 0, border= 0, data= NULL");
    {
	wxSizer *    THIS = (wxSizer *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Sizer" )
;
	wxWindow*    window = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::Window" )
;
	int	option;
	int	flag;
	int	border;
	Wx_UserDataO*	data;

	if (items < 3)
	    option = 0;
	else {
	    option = (int)SvIV(ST(2))
;
	}

	if (items < 4)
	    flag = 0;
	else {
	    flag = (int)SvIV(ST(3))
;
	}

	if (items < 5)
	    border = 0;
	else {
	    border = (int)SvIV(ST(4))
;
	}

	if (items < 6)
	    data = NULL;
	else {
    if( SvOK( ST(5) ) )
    {
	data = new wxPliUserDataO( ST(5) );
    }
    else
	data = 0
;
	}
    try {
      THIS->Add( window, option, flag, border, data );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__Sizer_AddSizer); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Sizer_AddSizer)
{
    dVAR; dXSARGS;
    if (items < 2 || items > 6)
       croak_xs_usage(cv,  "THIS, sizer, option= 0, flag= 0, border= 0, data= NULL");
    {
	wxSizer *    THIS = (wxSizer *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Sizer" )
;
	wxSizer*    sizer = (wxSizer *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::Sizer" )
;
	int	option;
	int	flag;
	int	border;
	Wx_UserDataO*	data;

	if (items < 3)
	    option = 0;
	else {
	    option = (int)SvIV(ST(2))
;
	}

	if (items < 4)
	    flag = 0;
	else {
	    flag = (int)SvIV(ST(3))
;
	}

	if (items < 5)
	    border = 0;
	else {
	    border = (int)SvIV(ST(4))
;
	}

	if (items < 6)
	    data = NULL;
	else {
    if( SvOK( ST(5) ) )
    {
	data = new wxPliUserDataO( ST(5) );
    }
    else
	data = 0
;
	}
    try {
      THIS->Add( sizer, option, flag, border, data );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__Sizer_AddSpace); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Sizer_AddSpace)
{
    dVAR; dXSARGS;
    if (items < 3 || items > 7)
       croak_xs_usage(cv,  "THIS, width, height, option= 0, flag= 0, border= 0, data= NULL");
    {
	wxSizer *    THIS = (wxSizer *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Sizer" )
;
	int	width = (int)SvIV(ST(1))
;
	int	height = (int)SvIV(ST(2))
;
	int	option;
	int	flag;
	int	border;
	Wx_UserDataO*	data;

	if (items < 4)
	    option = 0;
	else {
	    option = (int)SvIV(ST(3))
;
	}

	if (items < 5)
	    flag = 0;
	else {
	    flag = (int)SvIV(ST(4))
;
	}

	if (items < 6)
	    border = 0;
	else {
	    border = (int)SvIV(ST(5))
;
	}

	if (items < 7)
	    data = NULL;
	else {
    if( SvOK( ST(6) ) )
    {
	data = new wxPliUserDataO( ST(6) );
    }
    else
	data = 0
;
	}
    try {
      THIS->Add( width, height, option, flag, border, data );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__Sizer_PrependWindow); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Sizer_PrependWindow)
{
    dVAR; dXSARGS;
    if (items < 2 || items > 6)
       croak_xs_usage(cv,  "THIS, window, option= 0, flag= 0, border= 0, data= NULL");
    {
	wxSizer *    THIS = (wxSizer *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Sizer" )
;
	wxWindow*    window = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::Window" )
;
	int	option;
	int	flag;
	int	border;
	Wx_UserDataO*	data;

	if (items < 3)
	    option = 0;
	else {
	    option = (int)SvIV(ST(2))
;
	}

	if (items < 4)
	    flag = 0;
	else {
	    flag = (int)SvIV(ST(3))
;
	}

	if (items < 5)
	    border = 0;
	else {
	    border = (int)SvIV(ST(4))
;
	}

	if (items < 6)
	    data = NULL;
	else {
    if( SvOK( ST(5) ) )
    {
	data = new wxPliUserDataO( ST(5) );
    }
    else
	data = 0
;
	}
    try {
      THIS->Prepend( window, option, flag, border, data );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__Sizer_PrependSizer); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Sizer_PrependSizer)
{
    dVAR; dXSARGS;
    if (items < 2 || items > 6)
       croak_xs_usage(cv,  "THIS, sizer, option= 0, flag= 0, border= 0, data= NULL");
    {
	wxSizer *    THIS = (wxSizer *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Sizer" )
;
	wxSizer*    sizer = (wxSizer *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::Sizer" )
;
	int	option;
	int	flag;
	int	border;
	Wx_UserDataO*	data;

	if (items < 3)
	    option = 0;
	else {
	    option = (int)SvIV(ST(2))
;
	}

	if (items < 4)
	    flag = 0;
	else {
	    flag = (int)SvIV(ST(3))
;
	}

	if (items < 5)
	    border = 0;
	else {
	    border = (int)SvIV(ST(4))
;
	}

	if (items < 6)
	    data = NULL;
	else {
    if( SvOK( ST(5) ) )
    {
	data = new wxPliUserDataO( ST(5) );
    }
    else
	data = 0
;
	}
    try {
      THIS->Prepend( sizer, option, flag, border, data );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__Sizer_PrependSpace); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Sizer_PrependSpace)
{
    dVAR; dXSARGS;
    if (items < 3 || items > 7)
       croak_xs_usage(cv,  "THIS, width, height, option= 0, flag= 0, border= 0, data= NULL");
    {
	wxSizer *    THIS = (wxSizer *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Sizer" )
;
	int	width = (int)SvIV(ST(1))
;
	int	height = (int)SvIV(ST(2))
;
	int	option;
	int	flag;
	int	border;
	Wx_UserDataO*	data;

	if (items < 4)
	    option = 0;
	else {
	    option = (int)SvIV(ST(3))
;
	}

	if (items < 5)
	    flag = 0;
	else {
	    flag = (int)SvIV(ST(4))
;
	}

	if (items < 6)
	    border = 0;
	else {
	    border = (int)SvIV(ST(5))
;
	}

	if (items < 7)
	    data = NULL;
	else {
    if( SvOK( ST(6) ) )
    {
	data = new wxPliUserDataO( ST(6) );
    }
    else
	data = 0
;
	}
    try {
      THIS->Prepend( width, height, option, flag, border, data );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__Sizer_InsertWindow); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Sizer_InsertWindow)
{
    dVAR; dXSARGS;
    if (items < 3 || items > 7)
       croak_xs_usage(cv,  "THIS, pos, window, option= 0, flag= 0, border= 0, data= NULL");
    {
	wxSizer *    THIS = (wxSizer *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Sizer" )
;
	int	pos = (int)SvIV(ST(1))
;
	wxWindow*    window = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(2), "Wx::Window" )
;
	int	option;
	int	flag;
	int	border;
	Wx_UserDataO*	data;

	if (items < 4)
	    option = 0;
	else {
	    option = (int)SvIV(ST(3))
;
	}

	if (items < 5)
	    flag = 0;
	else {
	    flag = (int)SvIV(ST(4))
;
	}

	if (items < 6)
	    border = 0;
	else {
	    border = (int)SvIV(ST(5))
;
	}

	if (items < 7)
	    data = NULL;
	else {
    if( SvOK( ST(6) ) )
    {
	data = new wxPliUserDataO( ST(6) );
    }
    else
	data = 0
;
	}
    try {
      THIS->Insert( pos, window, option, flag, border, data );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__Sizer_InsertSizer); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Sizer_InsertSizer)
{
    dVAR; dXSARGS;
    if (items < 3 || items > 7)
       croak_xs_usage(cv,  "THIS, pos, sizer, option= 0, flag= 0, border= 0, data= NULL");
    {
	wxSizer *    THIS = (wxSizer *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Sizer" )
;
	int	pos = (int)SvIV(ST(1))
;
	wxSizer*    sizer = (wxSizer *) wxPli_sv_2_object( aTHX_ ST(2), "Wx::Sizer" )
;
	int	option;
	int	flag;
	int	border;
	Wx_UserDataO*	data;

	if (items < 4)
	    option = 0;
	else {
	    option = (int)SvIV(ST(3))
;
	}

	if (items < 5)
	    flag = 0;
	else {
	    flag = (int)SvIV(ST(4))
;
	}

	if (items < 6)
	    border = 0;
	else {
	    border = (int)SvIV(ST(5))
;
	}

	if (items < 7)
	    data = NULL;
	else {
    if( SvOK( ST(6) ) )
    {
	data = new wxPliUserDataO( ST(6) );
    }
    else
	data = 0
;
	}
    try {
      THIS->Insert( pos, sizer, option, flag, border, data );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__Sizer_InsertSpace); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Sizer_InsertSpace)
{
    dVAR; dXSARGS;
    if (items < 4 || items > 8)
       croak_xs_usage(cv,  "THIS, pos, width, height, option= 0, flag= 0, border= 0, data= NULL");
    {
	wxSizer *    THIS = (wxSizer *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Sizer" )
;
	int	pos = (int)SvIV(ST(1))
;
	int	width = (int)SvIV(ST(2))
;
	int	height = (int)SvIV(ST(3))
;
	int	option;
	int	flag;
	int	border;
	Wx_UserDataO*	data;

	if (items < 5)
	    option = 0;
	else {
	    option = (int)SvIV(ST(4))
;
	}

	if (items < 6)
	    flag = 0;
	else {
	    flag = (int)SvIV(ST(5))
;
	}

	if (items < 7)
	    border = 0;
	else {
	    border = (int)SvIV(ST(6))
;
	}

	if (items < 8)
	    data = NULL;
	else {
    if( SvOK( ST(7) ) )
    {
	data = new wxPliUserDataO( ST(7) );
    }
    else
	data = 0
;
	}
    try {
      THIS->Insert( pos, width, height, option, flag, border, data );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}

#endif
#if WXPERL_W_VERSION_GE( 2, 5, 4 )
#define XSpp_a9bbfcda_062895
#define XSubPPtmpAACX 1


XS_EUPXS(XS_Wx__Sizer_GetItemWindow); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Sizer_GetItemWindow)
{
    dVAR; dXSARGS;
    if (items < 2 || items > 3)
       croak_xs_usage(cv,  "THIS, window, recursive= false");
    {
	wxSizer *    THIS = (wxSizer *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Sizer" )
;
	wxSizerItem *	RETVAL;
	wxWindow*    window = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::Window" )
;
	bool	recursive;

	if (items < 3)
	    recursive = false;
	else {
	    recursive = (bool)SvTRUE(ST(2))
;
	}
    try {
      RETVAL = THIS->GetItem( window, recursive );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_object_2_sv( aTHX_ RETVALSV, RETVAL );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__Sizer_GetItemSizer); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Sizer_GetItemSizer)
{
    dVAR; dXSARGS;
    if (items < 2 || items > 3)
       croak_xs_usage(cv,  "THIS, sizer, recursive= false");
    {
	wxSizer *    THIS = (wxSizer *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Sizer" )
;
	wxSizerItem *	RETVAL;
	wxSizer*    sizer = (wxSizer *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::Sizer" )
;
	bool	recursive;

	if (items < 3)
	    recursive = false;
	else {
	    recursive = (bool)SvTRUE(ST(2))
;
	}
    try {
      RETVAL = THIS->GetItem( sizer, recursive );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_object_2_sv( aTHX_ RETVALSV, RETVAL );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__Sizer_GetItemNth); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Sizer_GetItemNth)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, index");
    {
	wxSizer *    THIS = (wxSizer *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Sizer" )
;
	wxSizerItem *	RETVAL;
	size_t    index = (size_t)SvUV( ST(1) )
;
    try {
      RETVAL = THIS->GetItem( index );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_object_2_sv( aTHX_ RETVALSV, RETVAL );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}

#else
#define XSpp_a9bbfcda_055426
#define XSubPPtmpAACY 1


XS_EUPXS(XS_Wx__Sizer_GetItemNth); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Sizer_GetItemNth)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, index");
    {
	size_t    index = (size_t)SvUV( ST(1) )
;
	wxSizer *    THIS = (wxSizer *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Sizer" )
;
	wxSizerItem *	RETVAL;
    RETVAL = index >= THIS->GetChildren().GetCount() ? NULL :
                 THIS->GetChildren().Item( index )->GetData();
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_object_2_sv( aTHX_ RETVALSV, RETVAL );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}

#endif
#if WXPERL_W_VERSION_GE( 2, 9, 0 )
#define XSpp_a9bbfcda_023405
#define XSubPPtmpAACZ 1


XS_EUPXS(XS_Wx__Sizer_GetItemById); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Sizer_GetItemById)
{
    dVAR; dXSARGS;
    if (items < 2 || items > 3)
       croak_xs_usage(cv,  "THIS, id, recursive= false");
    {
	wxSizer *    THIS = (wxSizer *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Sizer" )
;
	wxSizerItem *	RETVAL;
	int	id = (int)SvIV(ST(1))
;
	bool	recursive;

	if (items < 3)
	    recursive = false;
	else {
	    recursive = (bool)SvTRUE(ST(2))
;
	}
    try {
      RETVAL = THIS->GetItemById( id, recursive );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_object_2_sv( aTHX_ RETVALSV, RETVAL );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}

#endif

XS_EUPXS(XS_Wx__Sizer_HideSizer); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Sizer_HideSizer)
{
    dVAR; dXSARGS;
    if (items < 2 || items > 3)
       croak_xs_usage(cv,  "THIS, sizer, recursive= false");
    {
	wxSizer *    THIS = (wxSizer *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Sizer" )
;
	bool	RETVAL;
	wxSizer*    sizer = (wxSizer *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::Sizer" )
;
	bool	recursive;

	if (items < 3)
	    recursive = false;
	else {
	    recursive = (bool)SvTRUE(ST(2))
;
	}
    try {
      RETVAL = THIS->Hide( sizer, recursive );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__Sizer_HideWindow); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Sizer_HideWindow)
{
    dVAR; dXSARGS;
    if (items < 2 || items > 3)
       croak_xs_usage(cv,  "THIS, window, recursive= false");
    {
	wxSizer *    THIS = (wxSizer *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Sizer" )
;
	bool	RETVAL;
	wxWindow*    window = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::Window" )
;
	bool	recursive;

	if (items < 3)
	    recursive = false;
	else {
	    recursive = (bool)SvTRUE(ST(2))
;
	}
    try {
      RETVAL = THIS->Hide( window, recursive );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__Sizer_HideIndex); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Sizer_HideIndex)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, index");
    {
	wxSizer *    THIS = (wxSizer *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Sizer" )
;
	bool	RETVAL;
	size_t    index = (size_t)SvUV( ST(1) )
;
    try {
      RETVAL = THIS->Hide( index );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__Sizer_IsShownWindow); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Sizer_IsShownWindow)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, window");
    {
	wxSizer *    THIS = (wxSizer *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Sizer" )
;
	bool	RETVAL;
	wxWindow*    window = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::Window" )
;
    try {
      RETVAL = THIS->IsShown( window );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__Sizer_IsShownSizer); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Sizer_IsShownSizer)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, sizer");
    {
	wxSizer *    THIS = (wxSizer *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Sizer" )
;
	bool	RETVAL;
	wxSizer*    sizer = (wxSizer *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::Sizer" )
;
    try {
      RETVAL = THIS->IsShown( sizer );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__Sizer_IsShownIndex); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Sizer_IsShownIndex)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, index");
    {
	wxSizer *    THIS = (wxSizer *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Sizer" )
;
	bool	RETVAL;
	size_t    index = (size_t)SvUV( ST(1) )
;
    try {
      RETVAL = THIS->IsShown( index );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}

#if WXPERL_W_VERSION_GE( 2, 7, 2 )
#define XSpp_a9bbfcda_081877
#define XSubPPtmpAADA 1


XS_EUPXS(XS_Wx__Sizer_ReplaceWindow); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Sizer_ReplaceWindow)
{
    dVAR; dXSARGS;
    if (items < 3 || items > 4)
       croak_xs_usage(cv,  "THIS, oldwin, newwin, recursive= false");
    {
	wxSizer *    THIS = (wxSizer *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Sizer" )
;
	bool	RETVAL;
	wxWindow*    oldwin = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::Window" )
;
	wxWindow*    newwin = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(2), "Wx::Window" )
;
	bool	recursive;

	if (items < 4)
	    recursive = false;
	else {
	    recursive = (bool)SvTRUE(ST(3))
;
	}
    try {
      RETVAL = THIS->Replace( oldwin, newwin, recursive );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__Sizer_ReplaceSizer); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Sizer_ReplaceSizer)
{
    dVAR; dXSARGS;
    if (items < 3 || items > 4)
       croak_xs_usage(cv,  "THIS, oldsz, newsz, recursive= false");
    {
	wxSizer *    THIS = (wxSizer *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Sizer" )
;
	bool	RETVAL;
	wxSizer*    oldsz = (wxSizer *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::Sizer" )
;
	wxSizer*    newsz = (wxSizer *) wxPli_sv_2_object( aTHX_ ST(2), "Wx::Sizer" )
;
	bool	recursive;

	if (items < 4)
	    recursive = false;
	else {
	    recursive = (bool)SvTRUE(ST(3))
;
	}
    try {
      RETVAL = THIS->Replace( oldsz, newsz, recursive );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__Sizer_ReplaceIndex); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Sizer_ReplaceIndex)
{
    dVAR; dXSARGS;
    if (items != 3)
       croak_xs_usage(cv,  "THIS, index, newitem");
    {
	wxSizer *    THIS = (wxSizer *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Sizer" )
;
	bool	RETVAL;
	size_t    index = (size_t)SvUV( ST(1) )
;
	wxSizerItem*    newitem = (wxSizerItem *) wxPli_sv_2_object( aTHX_ ST(2), "Wx::SizerItem" )
;
    try {
      RETVAL = THIS->Replace( index, newitem );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}

#endif

XS_EUPXS(XS_Wx__Sizer_RecalcSizes); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Sizer_RecalcSizes)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxSizer *    THIS = (wxSizer *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Sizer" )
;
    try {
      THIS->RecalcSizes();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__Sizer_Clear); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Sizer_Clear)
{
    dVAR; dXSARGS;
    if (items < 1 || items > 2)
       croak_xs_usage(cv,  "THIS, deleteWindows= false");
    {
	wxSizer *    THIS = (wxSizer *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Sizer" )
;
	bool	deleteWindows;

	if (items < 2)
	    deleteWindows = false;
	else {
	    deleteWindows = (bool)SvTRUE(ST(1))
;
	}
    try {
      THIS->Clear( deleteWindows );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__Sizer_DeleteWindows); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Sizer_DeleteWindows)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxSizer *    THIS = (wxSizer *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Sizer" )
;
    try {
      THIS->DeleteWindows();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__Sizer_CalcMin); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Sizer_CalcMin)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxSizer *    THIS = (wxSizer *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Sizer" )
;
	wxSize	RETVAL;
    try {
      RETVAL = THIS->CalcMin();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_non_object_2_sv( aTHX_ RETVALSV, new wxSize(RETVAL), "Wx::Size" );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__Sizer_Fit); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Sizer_Fit)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, window");
    {
	wxSizer *    THIS = (wxSizer *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Sizer" )
;
	wxSize	RETVAL;
	wxWindow*    window = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::Window" )
;
    try {
      RETVAL = THIS->Fit( window );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_non_object_2_sv( aTHX_ RETVALSV, new wxSize(RETVAL), "Wx::Size" );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__Sizer_FitInside); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Sizer_FitInside)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, window");
    {
	wxSizer *    THIS = (wxSizer *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Sizer" )
;
	wxWindow*    window = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::Window" )
;
    try {
      THIS->FitInside( window );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__Sizer_GetSize); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Sizer_GetSize)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxSizer *    THIS = (wxSizer *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Sizer" )
;
	wxSize	RETVAL;
    try {
      RETVAL = THIS->GetSize();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_non_object_2_sv( aTHX_ RETVALSV, new wxSize(RETVAL), "Wx::Size" );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__Sizer_GetPosition); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Sizer_GetPosition)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxSizer *    THIS = (wxSizer *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Sizer" )
;
	wxPoint	RETVAL;
    try {
      RETVAL = THIS->GetPosition();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_non_object_2_sv( aTHX_ RETVALSV, new wxPoint(RETVAL), "Wx::Point" );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__Sizer_GetMinSize); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Sizer_GetMinSize)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxSizer *    THIS = (wxSizer *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Sizer" )
;
	wxSize	RETVAL;
    try {
      RETVAL = THIS->GetMinSize();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_non_object_2_sv( aTHX_ RETVALSV, new wxSize(RETVAL), "Wx::Size" );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__Sizer_Layout); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Sizer_Layout)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxSizer *    THIS = (wxSizer *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Sizer" )
;
    try {
      THIS->Layout();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}

#if WXPERL_W_VERSION_LT( 2, 7, 0 ) || WXWIN_COMPATIBILITY_2_6
#define XSpp_a9bbfcda_086940
#define XSubPPtmpAADB 1


XS_EUPXS(XS_Wx__Sizer_RemoveWindow); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Sizer_RemoveWindow)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, window");
    {
	wxSizer *    THIS = (wxSizer *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Sizer" )
;
	bool	RETVAL;
	wxWindow*    window = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::Window" )
;
    try {
      RETVAL = THIS->Remove( window );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}

#endif

XS_EUPXS(XS_Wx__Sizer_RemoveSizer); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Sizer_RemoveSizer)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, window");
    {
	wxSizer *    THIS = (wxSizer *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Sizer" )
;
	bool	RETVAL;
	wxSizer*    window = (wxSizer *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::Sizer" )
;
    try {
      RETVAL = THIS->Remove( window );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__Sizer_RemoveNth); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Sizer_RemoveNth)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, nth");
    {
	wxSizer *    THIS = (wxSizer *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Sizer" )
;
	bool	RETVAL;
	int	nth = (int)SvIV(ST(1))
;
    try {
      RETVAL = THIS->Remove( nth );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}

#if WXPERL_W_VERSION_GE( 2, 5, 3 )
#define XSpp_a9bbfcda_082145
#define XSubPPtmpAADC 1


XS_EUPXS(XS_Wx__Sizer_DetachWindow); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Sizer_DetachWindow)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, window");
    {
	wxSizer *    THIS = (wxSizer *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Sizer" )
;
	bool	RETVAL;
	wxWindow*    window = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::Window" )
;
    try {
      RETVAL = THIS->Detach( window );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__Sizer_DetachSizer); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Sizer_DetachSizer)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, window");
    {
	wxSizer *    THIS = (wxSizer *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Sizer" )
;
	bool	RETVAL;
	wxSizer*    window = (wxSizer *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::Sizer" )
;
    try {
      RETVAL = THIS->Detach( window );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__Sizer_DetachNth); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Sizer_DetachNth)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, nth");
    {
	wxSizer *    THIS = (wxSizer *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Sizer" )
;
	bool	RETVAL;
	int	nth = (int)SvIV(ST(1))
;
    try {
      RETVAL = THIS->Detach( nth );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}

#endif
#if WXPERL_W_VERSION_GE( 2, 7, 1 )
#define XSpp_a9bbfcda_047994
#define XSubPPtmpAADD 1


XS_EUPXS(XS_Wx__Sizer_GetContainingWindow); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Sizer_GetContainingWindow)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxSizer *    THIS = (wxSizer *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Sizer" )
;
	wxWindow *	RETVAL;
    try {
      RETVAL = THIS->GetContainingWindow();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_object_2_sv( aTHX_ RETVALSV, RETVAL );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__Sizer_SetContainingWindow); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Sizer_SetContainingWindow)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, window");
    {
	wxSizer *    THIS = (wxSizer *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Sizer" )
;
	wxWindow*    window = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::Window" )
;
    try {
      THIS->SetContainingWindow( window );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}

#endif

XS_EUPXS(XS_Wx__Sizer_SetDimension); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Sizer_SetDimension)
{
    dVAR; dXSARGS;
    if (items != 5)
       croak_xs_usage(cv,  "THIS, x, y, width, height");
    {
	wxSizer *    THIS = (wxSizer *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Sizer" )
;
	int	x = (int)SvIV(ST(1))
;
	int	y = (int)SvIV(ST(2))
;
	int	width = (int)SvIV(ST(3))
;
	int	height = (int)SvIV(ST(4))
;
    try {
      THIS->SetDimension( x, y, width, height );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__Sizer_SetItemMinSizeWindow); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Sizer_SetItemMinSizeWindow)
{
    dVAR; dXSARGS;
    if (items != 4)
       croak_xs_usage(cv,  "THIS, window, width, height");
    {
	wxSizer *    THIS = (wxSizer *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Sizer" )
;
	wxWindow*    window = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::Window" )
;
	int	width = (int)SvIV(ST(2))
;
	int	height = (int)SvIV(ST(3))
;
    try {
      THIS->SetItemMinSize( window, width, height );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__Sizer_SetItemMinSizeSizer); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Sizer_SetItemMinSizeSizer)
{
    dVAR; dXSARGS;
    if (items != 4)
       croak_xs_usage(cv,  "THIS, window, width, height");
    {
	wxSizer *    THIS = (wxSizer *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Sizer" )
;
	wxSizer*    window = (wxSizer *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::Sizer" )
;
	int	width = (int)SvIV(ST(2))
;
	int	height = (int)SvIV(ST(3))
;
    try {
      THIS->SetItemMinSize( window, width, height );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__Sizer_SetItemMinSizeNth); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Sizer_SetItemMinSizeNth)
{
    dVAR; dXSARGS;
    if (items != 4)
       croak_xs_usage(cv,  "THIS, pos, width, height");
    {
	wxSizer *    THIS = (wxSizer *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Sizer" )
;
	int	pos = (int)SvIV(ST(1))
;
	int	width = (int)SvIV(ST(2))
;
	int	height = (int)SvIV(ST(3))
;
    try {
      THIS->SetItemMinSize( pos, width, height );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__Sizer_SetMinSizeSize); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Sizer_SetMinSizeSize)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, size");
    {
	wxSizer *    THIS = (wxSizer *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Sizer" )
;
	wxSize    size = wxPli_sv_2_wxsize( aTHX_ ST(1) )
;
    try {
      THIS->SetMinSize( size );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__Sizer_SetMinSizeXY); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Sizer_SetMinSizeXY)
{
    dVAR; dXSARGS;
    if (items != 3)
       croak_xs_usage(cv,  "THIS, x, y");
    {
	wxSizer *    THIS = (wxSizer *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Sizer" )
;
	int	x = (int)SvIV(ST(1))
;
	int	y = (int)SvIV(ST(2))
;
    try {
      THIS->SetMinSize( x, y );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__Sizer_SetSizeHints); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Sizer_SetSizeHints)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, window");
    {
	wxSizer *    THIS = (wxSizer *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Sizer" )
;
	wxWindow*    window = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::Window" )
;
    try {
      THIS->SetSizeHints( window );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}

#if WXPERL_W_VERSION_LT( 2, 9, 0 )
#define XSpp_a9bbfcda_073567
#define XSubPPtmpAADE 1


XS_EUPXS(XS_Wx__Sizer_SetVirtualSizeHints); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Sizer_SetVirtualSizeHints)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, window");
    {
	wxSizer *    THIS = (wxSizer *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Sizer" )
;
	wxWindow*    window = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::Window" )
;
    try {
      THIS->SetVirtualSizeHints( window );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}

#endif
#if WXPERL_W_VERSION_GE( 2, 6, 2 )
#define XSpp_a9bbfcda_031235
#define XSubPPtmpAADF 1


XS_EUPXS(XS_Wx__Sizer_ShowWindow); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Sizer_ShowWindow)
{
    dVAR; dXSARGS;
    if (items < 2 || items > 4)
       croak_xs_usage(cv,  "THIS, window, show= true, recursive= false");
    {
	wxSizer *    THIS = (wxSizer *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Sizer" )
;
	bool	RETVAL;
	wxWindow*    window = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::Window" )
;
	bool	show;
	bool	recursive;

	if (items < 3)
	    show = true;
	else {
	    show = (bool)SvTRUE(ST(2))
;
	}

	if (items < 4)
	    recursive = false;
	else {
	    recursive = (bool)SvTRUE(ST(3))
;
	}
    try {
      RETVAL = THIS->Show( window, show, recursive );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__Sizer_ShowSizer); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Sizer_ShowSizer)
{
    dVAR; dXSARGS;
    if (items < 2 || items > 4)
       croak_xs_usage(cv,  "THIS, sizer, show= true, recursive= false");
    {
	wxSizer *    THIS = (wxSizer *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Sizer" )
;
	bool	RETVAL;
	wxSizer*    sizer = (wxSizer *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::Sizer" )
;
	bool	show;
	bool	recursive;

	if (items < 3)
	    show = true;
	else {
	    show = (bool)SvTRUE(ST(2))
;
	}

	if (items < 4)
	    recursive = false;
	else {
	    recursive = (bool)SvTRUE(ST(3))
;
	}
    try {
      RETVAL = THIS->Show( sizer, show, recursive );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__Sizer_ShowIndex); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Sizer_ShowIndex)
{
    dVAR; dXSARGS;
    if (items < 2 || items > 3)
       croak_xs_usage(cv,  "THIS, index, show= true");
    {
	wxSizer *    THIS = (wxSizer *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Sizer" )
;
	bool	RETVAL;
	size_t    index = (size_t)SvUV( ST(1) )
;
	bool	show;

	if (items < 3)
	    show = true;
	else {
	    show = (bool)SvTRUE(ST(2))
;
	}
    try {
      RETVAL = THIS->Show( index, show );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}

#else
#define XSpp_a9bbfcda_022931
#if WXPERL_W_VERSION_GE( 2, 5, 3 )
#define XSpp_a9bbfcda_090383
#define XSubPPtmpAADG 1


XS_EUPXS(XS_Wx__Sizer_ShowWindow); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Sizer_ShowWindow)
{
    dVAR; dXSARGS;
    if (items < 2 || items > 3)
       croak_xs_usage(cv,  "THIS, window, show= true");
    {
	wxSizer *    THIS = (wxSizer *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Sizer" )
;
	bool	RETVAL;
	wxWindow*    window = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::Window" )
;
	bool	show;

	if (items < 3)
	    show = true;
	else {
	    show = (bool)SvTRUE(ST(2))
;
	}
    try {
      RETVAL = THIS->Show( window, show );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__Sizer_ShowSizer); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Sizer_ShowSizer)
{
    dVAR; dXSARGS;
    if (items < 2 || items > 3)
       croak_xs_usage(cv,  "THIS, sizer, show= true");
    {
	wxSizer *    THIS = (wxSizer *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Sizer" )
;
	bool	RETVAL;
	wxSizer*    sizer = (wxSizer *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::Sizer" )
;
	bool	show;

	if (items < 3)
	    show = true;
	else {
	    show = (bool)SvTRUE(ST(2))
;
	}
    try {
      RETVAL = THIS->Show( sizer, show );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__Sizer_ShowIndex); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Sizer_ShowIndex)
{
    dVAR; dXSARGS;
    if (items < 2 || items > 3)
       croak_xs_usage(cv,  "THIS, index, show= true");
    {
	wxSizer *    THIS = (wxSizer *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Sizer" )
;
	bool	RETVAL;
	size_t    index = (size_t)SvUV( ST(1) )
;
	bool	show;

	if (items < 3)
	    show = true;
	else {
	    show = (bool)SvTRUE(ST(2))
;
	}
    try {
      RETVAL = THIS->Show( index, show );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}

#else
#define XSpp_a9bbfcda_073128
#define XSubPPtmpAADH 1


XS_EUPXS(XS_Wx__Sizer_ShowWindow); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Sizer_ShowWindow)
{
    dVAR; dXSARGS;
    if (items < 2 || items > 3)
       croak_xs_usage(cv,  "THIS, window, show= true");
    {
	wxSizer *    THIS = (wxSizer *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Sizer" )
;
	wxWindow*    window = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::Window" )
;
	bool	show;

	if (items < 3)
	    show = true;
	else {
	    show = (bool)SvTRUE(ST(2))
;
	}
    try {
      THIS->Show( window, show );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__Sizer_ShowSizer); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Sizer_ShowSizer)
{
    dVAR; dXSARGS;
    if (items < 2 || items > 3)
       croak_xs_usage(cv,  "THIS, sizer, show= true");
    {
	wxSizer *    THIS = (wxSizer *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Sizer" )
;
	wxSizer*    sizer = (wxSizer *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::Sizer" )
;
	bool	show;

	if (items < 3)
	    show = true;
	else {
	    show = (bool)SvTRUE(ST(2))
;
	}
    try {
      THIS->Show( sizer, show );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}

#endif
#endif
#if WXPERL_W_VERSION_GE( 2, 5, 4 )
#define XSpp_a9bbfcda_065972
#define XSubPPtmpAADI 1


XS_EUPXS(XS_Wx__Sizer_AddSpacer0); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Sizer_AddSpacer0)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, size");
    {
	wxSizer *    THIS = (wxSizer *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Sizer" )
;
	wxSizerItem *	RETVAL;
	int	size = (int)SvIV(ST(1))
;
    try {
      RETVAL = THIS->AddSpacer( size );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_object_2_sv( aTHX_ RETVALSV, RETVAL );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__Sizer_AddStretchSpacer0); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Sizer_AddStretchSpacer0)
{
    dVAR; dXSARGS;
    if (items < 1 || items > 2)
       croak_xs_usage(cv,  "THIS, prop= 1");
    {
	wxSizer *    THIS = (wxSizer *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Sizer" )
;
	wxSizerItem *	RETVAL;
	int	prop;

	if (items < 2)
	    prop = 1;
	else {
	    prop = (int)SvIV(ST(1))
;
	}
    try {
      RETVAL = THIS->AddStretchSpacer( prop );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_object_2_sv( aTHX_ RETVALSV, RETVAL );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__Sizer_InsertSpacer0); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Sizer_InsertSpacer0)
{
    dVAR; dXSARGS;
    if (items != 3)
       croak_xs_usage(cv,  "THIS, index, size");
    {
	wxSizer *    THIS = (wxSizer *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Sizer" )
;
	wxSizerItem *	RETVAL;
	size_t    index = (size_t)SvUV( ST(1) )
;
	int	size = (int)SvIV(ST(2))
;
    try {
      RETVAL = THIS->InsertSpacer( index, size );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_object_2_sv( aTHX_ RETVALSV, RETVAL );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__Sizer_InsertStretchSpacer0); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Sizer_InsertStretchSpacer0)
{
    dVAR; dXSARGS;
    if (items < 2 || items > 3)
       croak_xs_usage(cv,  "THIS, index, prop= 1");
    {
	wxSizer *    THIS = (wxSizer *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Sizer" )
;
	wxSizerItem *	RETVAL;
	size_t    index = (size_t)SvUV( ST(1) )
;
	int	prop;

	if (items < 3)
	    prop = 1;
	else {
	    prop = (int)SvIV(ST(2))
;
	}
    try {
      RETVAL = THIS->InsertStretchSpacer( index, prop );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_object_2_sv( aTHX_ RETVALSV, RETVAL );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__Sizer_PrependSpacer0); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Sizer_PrependSpacer0)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, size");
    {
	wxSizer *    THIS = (wxSizer *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Sizer" )
;
	wxSizerItem *	RETVAL;
	int	size = (int)SvIV(ST(1))
;
    try {
      RETVAL = THIS->PrependSpacer( size );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_object_2_sv( aTHX_ RETVALSV, RETVAL );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__Sizer_PrependStretchSpacer0); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Sizer_PrependStretchSpacer0)
{
    dVAR; dXSARGS;
    if (items < 1 || items > 2)
       croak_xs_usage(cv,  "THIS, prop= 1");
    {
	wxSizer *    THIS = (wxSizer *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Sizer" )
;
	wxSizerItem *	RETVAL;
	int	prop;

	if (items < 2)
	    prop = 1;
	else {
	    prop = (int)SvIV(ST(1))
;
	}
    try {
      RETVAL = THIS->PrependStretchSpacer( prop );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_object_2_sv( aTHX_ RETVALSV, RETVAL );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}

#else // for xsubpp
#define XSpp_a9bbfcda_019075
#if WXPERL_W_VERSION_GE( 2, 5, 3 )
#define XSpp_a9bbfcda_093726
#define XSubPPtmpAADJ 1


XS_EUPXS(XS_Wx__Sizer_AddSpacer1); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Sizer_AddSpacer1)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, size");
    {
	wxSizer *    THIS = (wxSizer *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Sizer" )
;
	int	size = (int)SvIV(ST(1))
;
    try {
      THIS->AddSpacer( size );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__Sizer_AddStretchSpacer1); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Sizer_AddStretchSpacer1)
{
    dVAR; dXSARGS;
    if (items < 1 || items > 2)
       croak_xs_usage(cv,  "THIS, prop= 1");
    {
	wxSizer *    THIS = (wxSizer *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Sizer" )
;
	int	prop;

	if (items < 2)
	    prop = 1;
	else {
	    prop = (int)SvIV(ST(1))
;
	}
    try {
      THIS->AddStretchSpacer( prop );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__Sizer_InsertSpacer1); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Sizer_InsertSpacer1)
{
    dVAR; dXSARGS;
    if (items != 3)
       croak_xs_usage(cv,  "THIS, index, size");
    {
	wxSizer *    THIS = (wxSizer *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Sizer" )
;
	size_t    index = (size_t)SvUV( ST(1) )
;
	int	size = (int)SvIV(ST(2))
;
    try {
      THIS->InsertSpacer( index, size );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__Sizer_InsertStretchSpacer1); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Sizer_InsertStretchSpacer1)
{
    dVAR; dXSARGS;
    if (items < 2 || items > 3)
       croak_xs_usage(cv,  "THIS, index, prop= 1");
    {
	wxSizer *    THIS = (wxSizer *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Sizer" )
;
	size_t    index = (size_t)SvUV( ST(1) )
;
	int	prop;

	if (items < 3)
	    prop = 1;
	else {
	    prop = (int)SvIV(ST(2))
;
	}
    try {
      THIS->InsertStretchSpacer( index, prop );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__Sizer_PrependSpacer1); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Sizer_PrependSpacer1)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, size");
    {
	wxSizer *    THIS = (wxSizer *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Sizer" )
;
	int	size = (int)SvIV(ST(1))
;
    try {
      THIS->PrependSpacer( size );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__Sizer_PrependStretchSpacer1); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Sizer_PrependStretchSpacer1)
{
    dVAR; dXSARGS;
    if (items < 1 || items > 2)
       croak_xs_usage(cv,  "THIS, prop= 1");
    {
	wxSizer *    THIS = (wxSizer *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Sizer" )
;
	int	prop;

	if (items < 2)
	    prop = 1;
	else {
	    prop = (int)SvIV(ST(1))
;
	}
    try {
      THIS->PrependStretchSpacer( prop );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}

#endif
#endif
#include "cpp/overload.h"
#if 1
#define XSubPPtmpAADK 1


XS_EUPXS(XS_Wx__Sizer_Replace); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Sizer_Replace)
{
    dVAR; dXSARGS;
    if (items < 1)
       croak_xs_usage(cv,  "THIS, ...");
    PERL_UNUSED_VAR(ax); /* -Wall */
    SP -= items;
    {
	wxSizer *    THIS = (wxSizer *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Sizer" )
;
#if defined( XSpp_a9bbfcda_081877 )
    static const char *ReplaceWindow_types[] = { "Wx::Window", "Wx::Window", wxPliOvlbool };
    static wxPliPrototype ReplaceWindow_proto( ReplaceWindow_types, sizeof( ReplaceWindow_types ) / sizeof( ReplaceWindow_types[0] ) );
#endif // defined( XSpp_a9bbfcda_081877 )
#if defined( XSpp_a9bbfcda_081877 )
    static const char *ReplaceSizer_types[] = { "Wx::Sizer", "Wx::Sizer", wxPliOvlbool };
    static wxPliPrototype ReplaceSizer_proto( ReplaceSizer_types, sizeof( ReplaceSizer_types ) / sizeof( ReplaceSizer_types[0] ) );
#endif // defined( XSpp_a9bbfcda_081877 )
#if defined( XSpp_a9bbfcda_081877 )
    static const char *ReplaceIndex_types[] = { wxPliOvlnum, "Wx::SizerItem" };
    static wxPliPrototype ReplaceIndex_proto( ReplaceIndex_types, sizeof( ReplaceIndex_types ) / sizeof( ReplaceIndex_types[0] ) );
#endif // defined( XSpp_a9bbfcda_081877 )
    static wxPliPrototype *wxPliOvl_all_prototypes[] = {
#if defined( XSpp_a9bbfcda_081877 )
        &ReplaceWindow_proto,
#endif // defined( XSpp_a9bbfcda_081877 )
#if defined( XSpp_a9bbfcda_081877 )
        &ReplaceSizer_proto,
#endif // defined( XSpp_a9bbfcda_081877 )
#if defined( XSpp_a9bbfcda_081877 )
        &ReplaceIndex_proto,
#endif // defined( XSpp_a9bbfcda_081877 )
        NULL };
    BEGIN_OVERLOAD()
#if defined( XSpp_a9bbfcda_081877 )
        MATCH_REDISP_COUNT_ALLOWMORE( ReplaceWindow_proto, ReplaceWindow, 2 )
#endif // defined( XSpp_a9bbfcda_081877 )
#if defined( XSpp_a9bbfcda_081877 )
        MATCH_REDISP_COUNT_ALLOWMORE( ReplaceSizer_proto, ReplaceSizer, 2 )
#endif // defined( XSpp_a9bbfcda_081877 )
#if defined( XSpp_a9bbfcda_081877 )
        MATCH_REDISP_COUNT( ReplaceIndex_proto, ReplaceIndex, 2 )
#endif // defined( XSpp_a9bbfcda_081877 )
    END_OVERLOAD_MESSAGE( Wx::Sizer::Replace, wxPliOvl_all_prototypes )
	PUTBACK;
	return;
    }
}

#endif // 1
#if 1
#define XSubPPtmpAADL 1


XS_EUPXS(XS_Wx__Sizer_Detach); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Sizer_Detach)
{
    dVAR; dXSARGS;
    if (items < 1)
       croak_xs_usage(cv,  "THIS, ...");
    PERL_UNUSED_VAR(ax); /* -Wall */
    SP -= items;
    {
	wxSizer *    THIS = (wxSizer *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Sizer" )
;
#if defined( XSpp_a9bbfcda_082145 )
    static const char *DetachWindow_types[] = { "Wx::Window" };
    static wxPliPrototype DetachWindow_proto( DetachWindow_types, sizeof( DetachWindow_types ) / sizeof( DetachWindow_types[0] ) );
#endif // defined( XSpp_a9bbfcda_082145 )
#if defined( XSpp_a9bbfcda_082145 )
    static const char *DetachSizer_types[] = { "Wx::Sizer" };
    static wxPliPrototype DetachSizer_proto( DetachSizer_types, sizeof( DetachSizer_types ) / sizeof( DetachSizer_types[0] ) );
#endif // defined( XSpp_a9bbfcda_082145 )
#if defined( XSpp_a9bbfcda_082145 )
    static const char *DetachNth_types[] = { wxPliOvlnum };
    static wxPliPrototype DetachNth_proto( DetachNth_types, sizeof( DetachNth_types ) / sizeof( DetachNth_types[0] ) );
#endif // defined( XSpp_a9bbfcda_082145 )
    static wxPliPrototype *wxPliOvl_all_prototypes[] = {
#if defined( XSpp_a9bbfcda_082145 )
        &DetachWindow_proto,
#endif // defined( XSpp_a9bbfcda_082145 )
#if defined( XSpp_a9bbfcda_082145 )
        &DetachSizer_proto,
#endif // defined( XSpp_a9bbfcda_082145 )
#if defined( XSpp_a9bbfcda_082145 )
        &DetachNth_proto,
#endif // defined( XSpp_a9bbfcda_082145 )
        NULL };
    BEGIN_OVERLOAD()
#if defined( XSpp_a9bbfcda_082145 )
        MATCH_REDISP_COUNT( DetachWindow_proto, DetachWindow, 1 )
#endif // defined( XSpp_a9bbfcda_082145 )
#if defined( XSpp_a9bbfcda_082145 )
        MATCH_REDISP_COUNT( DetachSizer_proto, DetachSizer, 1 )
#endif // defined( XSpp_a9bbfcda_082145 )
#if defined( XSpp_a9bbfcda_082145 )
        MATCH_REDISP_COUNT( DetachNth_proto, DetachNth, 1 )
#endif // defined( XSpp_a9bbfcda_082145 )
    END_OVERLOAD_MESSAGE( Wx::Sizer::Detach, wxPliOvl_all_prototypes )
	PUTBACK;
	return;
    }
}

#endif // 1
#if 1
#define XSubPPtmpAADM 1


XS_EUPXS(XS_Wx__Sizer_SetItemMinSize); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Sizer_SetItemMinSize)
{
    dVAR; dXSARGS;
    if (items < 1)
       croak_xs_usage(cv,  "THIS, ...");
    PERL_UNUSED_VAR(ax); /* -Wall */
    SP -= items;
    {
	wxSizer *    THIS = (wxSizer *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Sizer" )
;
#if 1
    static const char *SetItemMinSizeWindow_types[] = { "Wx::Window", wxPliOvlnum, wxPliOvlnum };
    static wxPliPrototype SetItemMinSizeWindow_proto( SetItemMinSizeWindow_types, sizeof( SetItemMinSizeWindow_types ) / sizeof( SetItemMinSizeWindow_types[0] ) );
#endif // 1
#if 1
    static const char *SetItemMinSizeSizer_types[] = { "Wx::Sizer", wxPliOvlnum, wxPliOvlnum };
    static wxPliPrototype SetItemMinSizeSizer_proto( SetItemMinSizeSizer_types, sizeof( SetItemMinSizeSizer_types ) / sizeof( SetItemMinSizeSizer_types[0] ) );
#endif // 1
#if 1
    static const char *SetItemMinSizeNth_types[] = { wxPliOvlnum, wxPliOvlnum, wxPliOvlnum };
    static wxPliPrototype SetItemMinSizeNth_proto( SetItemMinSizeNth_types, sizeof( SetItemMinSizeNth_types ) / sizeof( SetItemMinSizeNth_types[0] ) );
#endif // 1
    static wxPliPrototype *wxPliOvl_all_prototypes[] = {
#if 1
        &SetItemMinSizeWindow_proto,
#endif // 1
#if 1
        &SetItemMinSizeSizer_proto,
#endif // 1
#if 1
        &SetItemMinSizeNth_proto,
#endif // 1
        NULL };
    BEGIN_OVERLOAD()
#if 1
        MATCH_REDISP_COUNT( SetItemMinSizeWindow_proto, SetItemMinSizeWindow, 3 )
#endif // 1
#if 1
        MATCH_REDISP_COUNT( SetItemMinSizeSizer_proto, SetItemMinSizeSizer, 3 )
#endif // 1
#if 1
        MATCH_REDISP_COUNT( SetItemMinSizeNth_proto, SetItemMinSizeNth, 3 )
#endif // 1
    END_OVERLOAD_MESSAGE( Wx::Sizer::SetItemMinSize, wxPliOvl_all_prototypes )
	PUTBACK;
	return;
    }
}

#endif // 1
#if 1
#define XSubPPtmpAADN 1


XS_EUPXS(XS_Wx__Sizer_Show); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Sizer_Show)
{
    dVAR; dXSARGS;
    if (items < 1)
       croak_xs_usage(cv,  "THIS, ...");
    PERL_UNUSED_VAR(ax); /* -Wall */
    SP -= items;
    {
	wxSizer *    THIS = (wxSizer *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Sizer" )
;
#if defined( XSpp_a9bbfcda_031235 )
    static const char *ShowWindow_types[] = { "Wx::Window", wxPliOvlbool, wxPliOvlbool };
    static wxPliPrototype ShowWindow_proto( ShowWindow_types, sizeof( ShowWindow_types ) / sizeof( ShowWindow_types[0] ) );
#endif // defined( XSpp_a9bbfcda_031235 )
#if defined( XSpp_a9bbfcda_090383 )
    static const char *ShowSizer_types[] = { "Wx::Sizer", wxPliOvlbool };
    static wxPliPrototype ShowSizer_proto( ShowSizer_types, sizeof( ShowSizer_types ) / sizeof( ShowSizer_types[0] ) );
#endif // defined( XSpp_a9bbfcda_090383 )
#if defined( XSpp_a9bbfcda_090383 )
    static const char *ShowWindow_types[] = { "Wx::Window", wxPliOvlbool };
    static wxPliPrototype ShowWindow_proto( ShowWindow_types, sizeof( ShowWindow_types ) / sizeof( ShowWindow_types[0] ) );
#endif // defined( XSpp_a9bbfcda_090383 )
#if defined( XSpp_a9bbfcda_073128 )
    static const char *ShowWindow_types[] = { "Wx::Window", wxPliOvlbool };
    static wxPliPrototype ShowWindow_proto( ShowWindow_types, sizeof( ShowWindow_types ) / sizeof( ShowWindow_types[0] ) );
#endif // defined( XSpp_a9bbfcda_073128 )
#if defined( XSpp_a9bbfcda_031235 )
    static const char *ShowSizer_types[] = { "Wx::Sizer", wxPliOvlbool, wxPliOvlbool };
    static wxPliPrototype ShowSizer_proto( ShowSizer_types, sizeof( ShowSizer_types ) / sizeof( ShowSizer_types[0] ) );
#endif // defined( XSpp_a9bbfcda_031235 )
#if defined( XSpp_a9bbfcda_073128 )
    static const char *ShowSizer_types[] = { "Wx::Sizer", wxPliOvlbool };
    static wxPliPrototype ShowSizer_proto( ShowSizer_types, sizeof( ShowSizer_types ) / sizeof( ShowSizer_types[0] ) );
#endif // defined( XSpp_a9bbfcda_073128 )
#if defined( XSpp_a9bbfcda_031235 )
    static const char *ShowIndex_types[] = { wxPliOvlnum, wxPliOvlbool };
    static wxPliPrototype ShowIndex_proto( ShowIndex_types, sizeof( ShowIndex_types ) / sizeof( ShowIndex_types[0] ) );
#endif // defined( XSpp_a9bbfcda_031235 )
#if defined( XSpp_a9bbfcda_090383 )
    static const char *ShowIndex_types[] = { wxPliOvlnum, wxPliOvlbool };
    static wxPliPrototype ShowIndex_proto( ShowIndex_types, sizeof( ShowIndex_types ) / sizeof( ShowIndex_types[0] ) );
#endif // defined( XSpp_a9bbfcda_090383 )
    static wxPliPrototype *wxPliOvl_all_prototypes[] = {
#if defined( XSpp_a9bbfcda_031235 )
        &ShowWindow_proto,
#endif // defined( XSpp_a9bbfcda_031235 )
#if defined( XSpp_a9bbfcda_090383 )
        &ShowSizer_proto,
#endif // defined( XSpp_a9bbfcda_090383 )
#if defined( XSpp_a9bbfcda_090383 )
        &ShowWindow_proto,
#endif // defined( XSpp_a9bbfcda_090383 )
#if defined( XSpp_a9bbfcda_073128 )
        &ShowWindow_proto,
#endif // defined( XSpp_a9bbfcda_073128 )
#if defined( XSpp_a9bbfcda_031235 )
        &ShowSizer_proto,
#endif // defined( XSpp_a9bbfcda_031235 )
#if defined( XSpp_a9bbfcda_073128 )
        &ShowSizer_proto,
#endif // defined( XSpp_a9bbfcda_073128 )
#if defined( XSpp_a9bbfcda_031235 )
        &ShowIndex_proto,
#endif // defined( XSpp_a9bbfcda_031235 )
#if defined( XSpp_a9bbfcda_090383 )
        &ShowIndex_proto,
#endif // defined( XSpp_a9bbfcda_090383 )
        NULL };
    BEGIN_OVERLOAD()
#if defined( XSpp_a9bbfcda_031235 )
        MATCH_REDISP_COUNT_ALLOWMORE( ShowWindow_proto, ShowWindow, 1 )
#endif // defined( XSpp_a9bbfcda_031235 )
#if defined( XSpp_a9bbfcda_090383 )
        MATCH_REDISP_COUNT_ALLOWMORE( ShowSizer_proto, ShowSizer, 1 )
#endif // defined( XSpp_a9bbfcda_090383 )
#if defined( XSpp_a9bbfcda_090383 )
        MATCH_REDISP_COUNT_ALLOWMORE( ShowWindow_proto, ShowWindow, 1 )
#endif // defined( XSpp_a9bbfcda_090383 )
#if defined( XSpp_a9bbfcda_073128 )
        MATCH_REDISP_COUNT_ALLOWMORE( ShowWindow_proto, ShowWindow, 1 )
#endif // defined( XSpp_a9bbfcda_073128 )
#if defined( XSpp_a9bbfcda_031235 )
        MATCH_REDISP_COUNT_ALLOWMORE( ShowSizer_proto, ShowSizer, 1 )
#endif // defined( XSpp_a9bbfcda_031235 )
#if defined( XSpp_a9bbfcda_073128 )
        MATCH_REDISP_COUNT_ALLOWMORE( ShowSizer_proto, ShowSizer, 1 )
#endif // defined( XSpp_a9bbfcda_073128 )
#if defined( XSpp_a9bbfcda_031235 )
        MATCH_REDISP_COUNT_ALLOWMORE( ShowIndex_proto, ShowIndex, 1 )
#endif // defined( XSpp_a9bbfcda_031235 )
#if defined( XSpp_a9bbfcda_090383 )
        MATCH_REDISP_COUNT_ALLOWMORE( ShowIndex_proto, ShowIndex, 1 )
#endif // defined( XSpp_a9bbfcda_090383 )
    END_OVERLOAD_MESSAGE( Wx::Sizer::Show, wxPliOvl_all_prototypes )
	PUTBACK;
	return;
    }
}

#endif // 1
#if 1
#define XSubPPtmpAADO 1


XS_EUPXS(XS_Wx__Sizer_GetItem); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Sizer_GetItem)
{
    dVAR; dXSARGS;
    if (items < 1)
       croak_xs_usage(cv,  "THIS, ...");
    PERL_UNUSED_VAR(ax); /* -Wall */
    SP -= items;
    {
	wxSizer *    THIS = (wxSizer *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Sizer" )
;
#if defined( XSpp_a9bbfcda_062895 )
    static const char *GetItemWindow_types[] = { "Wx::Window", wxPliOvlbool };
    static wxPliPrototype GetItemWindow_proto( GetItemWindow_types, sizeof( GetItemWindow_types ) / sizeof( GetItemWindow_types[0] ) );
#endif // defined( XSpp_a9bbfcda_062895 )
#if defined( XSpp_a9bbfcda_062895 )
    static const char *GetItemSizer_types[] = { "Wx::Sizer", wxPliOvlbool };
    static wxPliPrototype GetItemSizer_proto( GetItemSizer_types, sizeof( GetItemSizer_types ) / sizeof( GetItemSizer_types[0] ) );
#endif // defined( XSpp_a9bbfcda_062895 )
#if defined( XSpp_a9bbfcda_062895 )
    static const char *GetItemNth_types[] = { wxPliOvlnum };
    static wxPliPrototype GetItemNth_proto( GetItemNth_types, sizeof( GetItemNth_types ) / sizeof( GetItemNth_types[0] ) );
#endif // defined( XSpp_a9bbfcda_062895 )
    static wxPliPrototype *wxPliOvl_all_prototypes[] = {
#if defined( XSpp_a9bbfcda_062895 )
        &GetItemWindow_proto,
#endif // defined( XSpp_a9bbfcda_062895 )
#if defined( XSpp_a9bbfcda_062895 )
        &GetItemSizer_proto,
#endif // defined( XSpp_a9bbfcda_062895 )
#if defined( XSpp_a9bbfcda_062895 )
        &GetItemNth_proto,
#endif // defined( XSpp_a9bbfcda_062895 )
        NULL };
    BEGIN_OVERLOAD()
#if defined( XSpp_a9bbfcda_062895 )
        MATCH_REDISP_COUNT_ALLOWMORE( GetItemWindow_proto, GetItemWindow, 1 )
#endif // defined( XSpp_a9bbfcda_062895 )
#if defined( XSpp_a9bbfcda_062895 )
        MATCH_REDISP_COUNT_ALLOWMORE( GetItemSizer_proto, GetItemSizer, 1 )
#endif // defined( XSpp_a9bbfcda_062895 )
#if defined( XSpp_a9bbfcda_062895 )
        MATCH_REDISP_COUNT( GetItemNth_proto, GetItemNth, 1 )
#endif // defined( XSpp_a9bbfcda_062895 )
    END_OVERLOAD_MESSAGE( Wx::Sizer::GetItem, wxPliOvl_all_prototypes )
	PUTBACK;
	return;
    }
}

#endif // 1
#if 1
#define XSubPPtmpAADP 1


XS_EUPXS(XS_Wx__Sizer_IsShown); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Sizer_IsShown)
{
    dVAR; dXSARGS;
    if (items < 1)
       croak_xs_usage(cv,  "THIS, ...");
    PERL_UNUSED_VAR(ax); /* -Wall */
    SP -= items;
    {
	wxSizer *    THIS = (wxSizer *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Sizer" )
;
#if 1
    static const char *IsShownWindow_types[] = { "Wx::Window" };
    static wxPliPrototype IsShownWindow_proto( IsShownWindow_types, sizeof( IsShownWindow_types ) / sizeof( IsShownWindow_types[0] ) );
#endif // 1
#if 1
    static const char *IsShownSizer_types[] = { "Wx::Sizer" };
    static wxPliPrototype IsShownSizer_proto( IsShownSizer_types, sizeof( IsShownSizer_types ) / sizeof( IsShownSizer_types[0] ) );
#endif // 1
#if 1
    static const char *IsShownIndex_types[] = { wxPliOvlnum };
    static wxPliPrototype IsShownIndex_proto( IsShownIndex_types, sizeof( IsShownIndex_types ) / sizeof( IsShownIndex_types[0] ) );
#endif // 1
    static wxPliPrototype *wxPliOvl_all_prototypes[] = {
#if 1
        &IsShownWindow_proto,
#endif // 1
#if 1
        &IsShownSizer_proto,
#endif // 1
#if 1
        &IsShownIndex_proto,
#endif // 1
        NULL };
    BEGIN_OVERLOAD()
#if 1
        MATCH_REDISP_COUNT( IsShownWindow_proto, IsShownWindow, 1 )
#endif // 1
#if 1
        MATCH_REDISP_COUNT( IsShownSizer_proto, IsShownSizer, 1 )
#endif // 1
#if 1
        MATCH_REDISP_COUNT( IsShownIndex_proto, IsShownIndex, 1 )
#endif // 1
    END_OVERLOAD_MESSAGE( Wx::Sizer::IsShown, wxPliOvl_all_prototypes )
	PUTBACK;
	return;
    }
}

#endif // 1
#if 1
#define XSubPPtmpAADQ 1


XS_EUPXS(XS_Wx__Sizer_Prepend); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Sizer_Prepend)
{
    dVAR; dXSARGS;
    if (items < 1)
       croak_xs_usage(cv,  "THIS, ...");
    PERL_UNUSED_VAR(ax); /* -Wall */
    SP -= items;
    {
	wxSizer *    THIS = (wxSizer *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Sizer" )
;
#if defined( XSpp_a9bbfcda_067750 )
    static const char *PrependWindow_types[] = { "Wx::Window", wxPliOvlnum, wxPliOvlnum, wxPliOvlnum, wxPliOvlstr };
    static wxPliPrototype PrependWindow_proto( PrependWindow_types, sizeof( PrependWindow_types ) / sizeof( PrependWindow_types[0] ) );
#endif // defined( XSpp_a9bbfcda_067750 )
#if defined( XSpp_a9bbfcda_023879 )
    static const char *PrependSizer_types[] = { "Wx::Sizer", wxPliOvlnum, wxPliOvlnum, wxPliOvlnum, wxPliOvlstr };
    static wxPliPrototype PrependSizer_proto( PrependSizer_types, sizeof( PrependSizer_types ) / sizeof( PrependSizer_types[0] ) );
#endif // defined( XSpp_a9bbfcda_023879 )
#if defined( XSpp_a9bbfcda_023879 )
    static const char *PrependWindow_types[] = { "Wx::Window", wxPliOvlnum, wxPliOvlnum, wxPliOvlnum, wxPliOvlstr };
    static wxPliPrototype PrependWindow_proto( PrependWindow_types, sizeof( PrependWindow_types ) / sizeof( PrependWindow_types[0] ) );
#endif // defined( XSpp_a9bbfcda_023879 )
#if defined( XSpp_a9bbfcda_067750 )
    static const char *PrependSizer_types[] = { "Wx::Sizer", wxPliOvlnum, wxPliOvlnum, wxPliOvlnum, wxPliOvlstr };
    static wxPliPrototype PrependSizer_proto( PrependSizer_types, sizeof( PrependSizer_types ) / sizeof( PrependSizer_types[0] ) );
#endif // defined( XSpp_a9bbfcda_067750 )
#if defined( XSpp_a9bbfcda_067750 )
    static const char *PrependSpace_types[] = { wxPliOvlnum, wxPliOvlnum, wxPliOvlnum, wxPliOvlnum, wxPliOvlnum, wxPliOvlstr };
    static wxPliPrototype PrependSpace_proto( PrependSpace_types, sizeof( PrependSpace_types ) / sizeof( PrependSpace_types[0] ) );
#endif // defined( XSpp_a9bbfcda_067750 )
#if defined( XSpp_a9bbfcda_023879 )
    static const char *PrependSpace_types[] = { wxPliOvlnum, wxPliOvlnum, wxPliOvlnum, wxPliOvlnum, wxPliOvlnum, wxPliOvlstr };
    static wxPliPrototype PrependSpace_proto( PrependSpace_types, sizeof( PrependSpace_types ) / sizeof( PrependSpace_types[0] ) );
#endif // defined( XSpp_a9bbfcda_023879 )
    static wxPliPrototype *wxPliOvl_all_prototypes[] = {
#if defined( XSpp_a9bbfcda_067750 )
        &PrependWindow_proto,
#endif // defined( XSpp_a9bbfcda_067750 )
#if defined( XSpp_a9bbfcda_023879 )
        &PrependSizer_proto,
#endif // defined( XSpp_a9bbfcda_023879 )
#if defined( XSpp_a9bbfcda_023879 )
        &PrependWindow_proto,
#endif // defined( XSpp_a9bbfcda_023879 )
#if defined( XSpp_a9bbfcda_067750 )
        &PrependSizer_proto,
#endif // defined( XSpp_a9bbfcda_067750 )
#if defined( XSpp_a9bbfcda_067750 )
        &PrependSpace_proto,
#endif // defined( XSpp_a9bbfcda_067750 )
#if defined( XSpp_a9bbfcda_023879 )
        &PrependSpace_proto,
#endif // defined( XSpp_a9bbfcda_023879 )
        NULL };
    BEGIN_OVERLOAD()
#if defined( XSpp_a9bbfcda_067750 )
        MATCH_REDISP_COUNT_ALLOWMORE( PrependWindow_proto, PrependWindow, 1 )
#endif // defined( XSpp_a9bbfcda_067750 )
#if defined( XSpp_a9bbfcda_023879 )
        MATCH_REDISP_COUNT_ALLOWMORE( PrependSizer_proto, PrependSizer, 1 )
#endif // defined( XSpp_a9bbfcda_023879 )
#if defined( XSpp_a9bbfcda_023879 )
        MATCH_REDISP_COUNT_ALLOWMORE( PrependWindow_proto, PrependWindow, 1 )
#endif // defined( XSpp_a9bbfcda_023879 )
#if defined( XSpp_a9bbfcda_067750 )
        MATCH_REDISP_COUNT_ALLOWMORE( PrependSizer_proto, PrependSizer, 1 )
#endif // defined( XSpp_a9bbfcda_067750 )
#if defined( XSpp_a9bbfcda_067750 )
        MATCH_REDISP_COUNT_ALLOWMORE( PrependSpace_proto, PrependSpace, 2 )
#endif // defined( XSpp_a9bbfcda_067750 )
#if defined( XSpp_a9bbfcda_023879 )
        MATCH_REDISP_COUNT_ALLOWMORE( PrependSpace_proto, PrependSpace, 2 )
#endif // defined( XSpp_a9bbfcda_023879 )
    END_OVERLOAD_MESSAGE( Wx::Sizer::Prepend, wxPliOvl_all_prototypes )
	PUTBACK;
	return;
    }
}

#endif // 1
#if 1
#define XSubPPtmpAADR 1


XS_EUPXS(XS_Wx__Sizer_Add); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Sizer_Add)
{
    dVAR; dXSARGS;
    if (items < 1)
       croak_xs_usage(cv,  "THIS, ...");
    PERL_UNUSED_VAR(ax); /* -Wall */
    SP -= items;
    {
	wxSizer *    THIS = (wxSizer *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Sizer" )
;
#if defined( XSpp_a9bbfcda_067750 )
    static const char *AddWindow_types[] = { "Wx::Window", wxPliOvlnum, wxPliOvlnum, wxPliOvlnum, wxPliOvlstr };
    static wxPliPrototype AddWindow_proto( AddWindow_types, sizeof( AddWindow_types ) / sizeof( AddWindow_types[0] ) );
#endif // defined( XSpp_a9bbfcda_067750 )
#if defined( XSpp_a9bbfcda_023879 )
    static const char *AddSizer_types[] = { "Wx::Sizer", wxPliOvlnum, wxPliOvlnum, wxPliOvlnum, wxPliOvlstr };
    static wxPliPrototype AddSizer_proto( AddSizer_types, sizeof( AddSizer_types ) / sizeof( AddSizer_types[0] ) );
#endif // defined( XSpp_a9bbfcda_023879 )
#if defined( XSpp_a9bbfcda_023879 )
    static const char *AddWindow_types[] = { "Wx::Window", wxPliOvlnum, wxPliOvlnum, wxPliOvlnum, wxPliOvlstr };
    static wxPliPrototype AddWindow_proto( AddWindow_types, sizeof( AddWindow_types ) / sizeof( AddWindow_types[0] ) );
#endif // defined( XSpp_a9bbfcda_023879 )
#if defined( XSpp_a9bbfcda_067750 )
    static const char *AddSizer_types[] = { "Wx::Sizer", wxPliOvlnum, wxPliOvlnum, wxPliOvlnum, wxPliOvlstr };
    static wxPliPrototype AddSizer_proto( AddSizer_types, sizeof( AddSizer_types ) / sizeof( AddSizer_types[0] ) );
#endif // defined( XSpp_a9bbfcda_067750 )
#if defined( XSpp_a9bbfcda_067750 )
    static const char *AddSpace_types[] = { wxPliOvlnum, wxPliOvlnum, wxPliOvlnum, wxPliOvlnum, wxPliOvlnum, wxPliOvlstr };
    static wxPliPrototype AddSpace_proto( AddSpace_types, sizeof( AddSpace_types ) / sizeof( AddSpace_types[0] ) );
#endif // defined( XSpp_a9bbfcda_067750 )
#if defined( XSpp_a9bbfcda_023879 )
    static const char *AddSpace_types[] = { wxPliOvlnum, wxPliOvlnum, wxPliOvlnum, wxPliOvlnum, wxPliOvlnum, wxPliOvlstr };
    static wxPliPrototype AddSpace_proto( AddSpace_types, sizeof( AddSpace_types ) / sizeof( AddSpace_types[0] ) );
#endif // defined( XSpp_a9bbfcda_023879 )
    static wxPliPrototype *wxPliOvl_all_prototypes[] = {
#if defined( XSpp_a9bbfcda_067750 )
        &AddWindow_proto,
#endif // defined( XSpp_a9bbfcda_067750 )
#if defined( XSpp_a9bbfcda_023879 )
        &AddSizer_proto,
#endif // defined( XSpp_a9bbfcda_023879 )
#if defined( XSpp_a9bbfcda_023879 )
        &AddWindow_proto,
#endif // defined( XSpp_a9bbfcda_023879 )
#if defined( XSpp_a9bbfcda_067750 )
        &AddSizer_proto,
#endif // defined( XSpp_a9bbfcda_067750 )
#if defined( XSpp_a9bbfcda_067750 )
        &AddSpace_proto,
#endif // defined( XSpp_a9bbfcda_067750 )
#if defined( XSpp_a9bbfcda_023879 )
        &AddSpace_proto,
#endif // defined( XSpp_a9bbfcda_023879 )
        NULL };
    BEGIN_OVERLOAD()
#if defined( XSpp_a9bbfcda_067750 )
        MATCH_REDISP_COUNT_ALLOWMORE( AddWindow_proto, AddWindow, 1 )
#endif // defined( XSpp_a9bbfcda_067750 )
#if defined( XSpp_a9bbfcda_023879 )
        MATCH_REDISP_COUNT_ALLOWMORE( AddSizer_proto, AddSizer, 1 )
#endif // defined( XSpp_a9bbfcda_023879 )
#if defined( XSpp_a9bbfcda_023879 )
        MATCH_REDISP_COUNT_ALLOWMORE( AddWindow_proto, AddWindow, 1 )
#endif // defined( XSpp_a9bbfcda_023879 )
#if defined( XSpp_a9bbfcda_067750 )
        MATCH_REDISP_COUNT_ALLOWMORE( AddSizer_proto, AddSizer, 1 )
#endif // defined( XSpp_a9bbfcda_067750 )
#if defined( XSpp_a9bbfcda_067750 )
        MATCH_REDISP_COUNT_ALLOWMORE( AddSpace_proto, AddSpace, 2 )
#endif // defined( XSpp_a9bbfcda_067750 )
#if defined( XSpp_a9bbfcda_023879 )
        MATCH_REDISP_COUNT_ALLOWMORE( AddSpace_proto, AddSpace, 2 )
#endif // defined( XSpp_a9bbfcda_023879 )
    END_OVERLOAD_MESSAGE( Wx::Sizer::Add, wxPliOvl_all_prototypes )
	PUTBACK;
	return;
    }
}

#endif // 1
#if 1
#define XSubPPtmpAADS 1


XS_EUPXS(XS_Wx__Sizer_Remove); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Sizer_Remove)
{
    dVAR; dXSARGS;
    if (items < 1)
       croak_xs_usage(cv,  "THIS, ...");
    PERL_UNUSED_VAR(ax); /* -Wall */
    SP -= items;
    {
	wxSizer *    THIS = (wxSizer *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Sizer" )
;
#if defined( XSpp_a9bbfcda_086940 )
    static const char *RemoveWindow_types[] = { "Wx::Window" };
    static wxPliPrototype RemoveWindow_proto( RemoveWindow_types, sizeof( RemoveWindow_types ) / sizeof( RemoveWindow_types[0] ) );
#endif // defined( XSpp_a9bbfcda_086940 )
#if 1
    static const char *RemoveSizer_types[] = { "Wx::Sizer" };
    static wxPliPrototype RemoveSizer_proto( RemoveSizer_types, sizeof( RemoveSizer_types ) / sizeof( RemoveSizer_types[0] ) );
#endif // 1
#if 1
    static const char *RemoveNth_types[] = { wxPliOvlnum };
    static wxPliPrototype RemoveNth_proto( RemoveNth_types, sizeof( RemoveNth_types ) / sizeof( RemoveNth_types[0] ) );
#endif // 1
    static wxPliPrototype *wxPliOvl_all_prototypes[] = {
#if defined( XSpp_a9bbfcda_086940 )
        &RemoveWindow_proto,
#endif // defined( XSpp_a9bbfcda_086940 )
#if 1
        &RemoveSizer_proto,
#endif // 1
#if 1
        &RemoveNth_proto,
#endif // 1
        NULL };
    BEGIN_OVERLOAD()
#if defined( XSpp_a9bbfcda_086940 )
        MATCH_REDISP_COUNT( RemoveWindow_proto, RemoveWindow, 1 )
#endif // defined( XSpp_a9bbfcda_086940 )
#if 1
        MATCH_REDISP_COUNT( RemoveSizer_proto, RemoveSizer, 1 )
#endif // 1
#if 1
        MATCH_REDISP_COUNT( RemoveNth_proto, RemoveNth, 1 )
#endif // 1
    END_OVERLOAD_MESSAGE( Wx::Sizer::Remove, wxPliOvl_all_prototypes )
	PUTBACK;
	return;
    }
}

#endif // 1
#if 1
#define XSubPPtmpAADT 1


XS_EUPXS(XS_Wx__Sizer_InsertSpacer); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Sizer_InsertSpacer)
{
    dVAR; dXSARGS;
    if (items < 1)
       croak_xs_usage(cv,  "THIS, ...");
    PERL_UNUSED_VAR(ax); /* -Wall */
    SP -= items;
    {
	wxSizer *    THIS = (wxSizer *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Sizer" )
;
#if defined( XSpp_a9bbfcda_065972 )
    static const char *InsertSpacer0_types[] = { wxPliOvlnum, wxPliOvlnum };
    static wxPliPrototype InsertSpacer0_proto( InsertSpacer0_types, sizeof( InsertSpacer0_types ) / sizeof( InsertSpacer0_types[0] ) );
#endif // defined( XSpp_a9bbfcda_065972 )
#if defined( XSpp_a9bbfcda_093726 )
    static const char *InsertSpacer1_types[] = { wxPliOvlnum, wxPliOvlnum };
    static wxPliPrototype InsertSpacer1_proto( InsertSpacer1_types, sizeof( InsertSpacer1_types ) / sizeof( InsertSpacer1_types[0] ) );
#endif // defined( XSpp_a9bbfcda_093726 )
    static wxPliPrototype *wxPliOvl_all_prototypes[] = {
#if defined( XSpp_a9bbfcda_065972 )
        &InsertSpacer0_proto,
#endif // defined( XSpp_a9bbfcda_065972 )
#if defined( XSpp_a9bbfcda_093726 )
        &InsertSpacer1_proto,
#endif // defined( XSpp_a9bbfcda_093726 )
        NULL };
    BEGIN_OVERLOAD()
#if defined( XSpp_a9bbfcda_065972 )
        MATCH_REDISP_COUNT( InsertSpacer0_proto, InsertSpacer0, 2 )
#endif // defined( XSpp_a9bbfcda_065972 )
#if defined( XSpp_a9bbfcda_093726 )
        MATCH_REDISP_COUNT( InsertSpacer1_proto, InsertSpacer1, 2 )
#endif // defined( XSpp_a9bbfcda_093726 )
    END_OVERLOAD_MESSAGE( Wx::Sizer::InsertSpacer, wxPliOvl_all_prototypes )
	PUTBACK;
	return;
    }
}

#endif // 1
#if 1
#define XSubPPtmpAADU 1


XS_EUPXS(XS_Wx__Sizer_SetMinSize); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Sizer_SetMinSize)
{
    dVAR; dXSARGS;
    if (items < 1)
       croak_xs_usage(cv,  "THIS, ...");
    PERL_UNUSED_VAR(ax); /* -Wall */
    SP -= items;
    {
	wxSizer *    THIS = (wxSizer *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Sizer" )
;
#if 1
    static const char *SetMinSizeSize_types[] = { wxPliOvlwsiz };
    static wxPliPrototype SetMinSizeSize_proto( SetMinSizeSize_types, sizeof( SetMinSizeSize_types ) / sizeof( SetMinSizeSize_types[0] ) );
#endif // 1
#if 1
    static const char *SetMinSizeXY_types[] = { wxPliOvlnum, wxPliOvlnum };
    static wxPliPrototype SetMinSizeXY_proto( SetMinSizeXY_types, sizeof( SetMinSizeXY_types ) / sizeof( SetMinSizeXY_types[0] ) );
#endif // 1
    static wxPliPrototype *wxPliOvl_all_prototypes[] = {
#if 1
        &SetMinSizeSize_proto,
#endif // 1
#if 1
        &SetMinSizeXY_proto,
#endif // 1
        NULL };
    BEGIN_OVERLOAD()
#if 1
        MATCH_REDISP_COUNT( SetMinSizeSize_proto, SetMinSizeSize, 1 )
#endif // 1
#if 1
        MATCH_REDISP_COUNT( SetMinSizeXY_proto, SetMinSizeXY, 2 )
#endif // 1
    END_OVERLOAD_MESSAGE( Wx::Sizer::SetMinSize, wxPliOvl_all_prototypes )
	PUTBACK;
	return;
    }
}

#endif // 1
#if 1
#define XSubPPtmpAADV 1


XS_EUPXS(XS_Wx__Sizer_AddSpacer); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Sizer_AddSpacer)
{
    dVAR; dXSARGS;
    if (items < 1)
       croak_xs_usage(cv,  "THIS, ...");
    PERL_UNUSED_VAR(ax); /* -Wall */
    SP -= items;
    {
	wxSizer *    THIS = (wxSizer *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Sizer" )
;
#if defined( XSpp_a9bbfcda_065972 )
    static const char *AddSpacer0_types[] = { wxPliOvlnum };
    static wxPliPrototype AddSpacer0_proto( AddSpacer0_types, sizeof( AddSpacer0_types ) / sizeof( AddSpacer0_types[0] ) );
#endif // defined( XSpp_a9bbfcda_065972 )
#if defined( XSpp_a9bbfcda_093726 )
    static const char *AddSpacer1_types[] = { wxPliOvlnum };
    static wxPliPrototype AddSpacer1_proto( AddSpacer1_types, sizeof( AddSpacer1_types ) / sizeof( AddSpacer1_types[0] ) );
#endif // defined( XSpp_a9bbfcda_093726 )
    static wxPliPrototype *wxPliOvl_all_prototypes[] = {
#if defined( XSpp_a9bbfcda_065972 )
        &AddSpacer0_proto,
#endif // defined( XSpp_a9bbfcda_065972 )
#if defined( XSpp_a9bbfcda_093726 )
        &AddSpacer1_proto,
#endif // defined( XSpp_a9bbfcda_093726 )
        NULL };
    BEGIN_OVERLOAD()
#if defined( XSpp_a9bbfcda_065972 )
        MATCH_REDISP_COUNT( AddSpacer0_proto, AddSpacer0, 1 )
#endif // defined( XSpp_a9bbfcda_065972 )
#if defined( XSpp_a9bbfcda_093726 )
        MATCH_REDISP_COUNT( AddSpacer1_proto, AddSpacer1, 1 )
#endif // defined( XSpp_a9bbfcda_093726 )
    END_OVERLOAD_MESSAGE( Wx::Sizer::AddSpacer, wxPliOvl_all_prototypes )
	PUTBACK;
	return;
    }
}

#endif // 1
#if 1
#define XSubPPtmpAADW 1


XS_EUPXS(XS_Wx__Sizer_PrependSpacer); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Sizer_PrependSpacer)
{
    dVAR; dXSARGS;
    if (items < 1)
       croak_xs_usage(cv,  "THIS, ...");
    PERL_UNUSED_VAR(ax); /* -Wall */
    SP -= items;
    {
	wxSizer *    THIS = (wxSizer *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Sizer" )
;
#if defined( XSpp_a9bbfcda_065972 )
    static const char *PrependSpacer0_types[] = { wxPliOvlnum };
    static wxPliPrototype PrependSpacer0_proto( PrependSpacer0_types, sizeof( PrependSpacer0_types ) / sizeof( PrependSpacer0_types[0] ) );
#endif // defined( XSpp_a9bbfcda_065972 )
#if defined( XSpp_a9bbfcda_093726 )
    static const char *PrependSpacer1_types[] = { wxPliOvlnum };
    static wxPliPrototype PrependSpacer1_proto( PrependSpacer1_types, sizeof( PrependSpacer1_types ) / sizeof( PrependSpacer1_types[0] ) );
#endif // defined( XSpp_a9bbfcda_093726 )
    static wxPliPrototype *wxPliOvl_all_prototypes[] = {
#if defined( XSpp_a9bbfcda_065972 )
        &PrependSpacer0_proto,
#endif // defined( XSpp_a9bbfcda_065972 )
#if defined( XSpp_a9bbfcda_093726 )
        &PrependSpacer1_proto,
#endif // defined( XSpp_a9bbfcda_093726 )
        NULL };
    BEGIN_OVERLOAD()
#if defined( XSpp_a9bbfcda_065972 )
        MATCH_REDISP_COUNT( PrependSpacer0_proto, PrependSpacer0, 1 )
#endif // defined( XSpp_a9bbfcda_065972 )
#if defined( XSpp_a9bbfcda_093726 )
        MATCH_REDISP_COUNT( PrependSpacer1_proto, PrependSpacer1, 1 )
#endif // defined( XSpp_a9bbfcda_093726 )
    END_OVERLOAD_MESSAGE( Wx::Sizer::PrependSpacer, wxPliOvl_all_prototypes )
	PUTBACK;
	return;
    }
}

#endif // 1
#if 1
#define XSubPPtmpAADX 1


XS_EUPXS(XS_Wx__Sizer_Insert); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Sizer_Insert)
{
    dVAR; dXSARGS;
    if (items < 1)
       croak_xs_usage(cv,  "THIS, ...");
    PERL_UNUSED_VAR(ax); /* -Wall */
    SP -= items;
    {
	wxSizer *    THIS = (wxSizer *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Sizer" )
;
#if defined( XSpp_a9bbfcda_067750 )
    static const char *InsertWindow_types[] = { wxPliOvlnum, "Wx::Window", wxPliOvlnum, wxPliOvlnum, wxPliOvlnum, wxPliOvlstr };
    static wxPliPrototype InsertWindow_proto( InsertWindow_types, sizeof( InsertWindow_types ) / sizeof( InsertWindow_types[0] ) );
#endif // defined( XSpp_a9bbfcda_067750 )
#if defined( XSpp_a9bbfcda_023879 )
    static const char *InsertSizer_types[] = { wxPliOvlnum, "Wx::Sizer", wxPliOvlnum, wxPliOvlnum, wxPliOvlnum, wxPliOvlstr };
    static wxPliPrototype InsertSizer_proto( InsertSizer_types, sizeof( InsertSizer_types ) / sizeof( InsertSizer_types[0] ) );
#endif // defined( XSpp_a9bbfcda_023879 )
#if defined( XSpp_a9bbfcda_023879 )
    static const char *InsertWindow_types[] = { wxPliOvlnum, "Wx::Window", wxPliOvlnum, wxPliOvlnum, wxPliOvlnum, wxPliOvlstr };
    static wxPliPrototype InsertWindow_proto( InsertWindow_types, sizeof( InsertWindow_types ) / sizeof( InsertWindow_types[0] ) );
#endif // defined( XSpp_a9bbfcda_023879 )
#if defined( XSpp_a9bbfcda_067750 )
    static const char *InsertSizer_types[] = { wxPliOvlnum, "Wx::Sizer", wxPliOvlnum, wxPliOvlnum, wxPliOvlnum, wxPliOvlstr };
    static wxPliPrototype InsertSizer_proto( InsertSizer_types, sizeof( InsertSizer_types ) / sizeof( InsertSizer_types[0] ) );
#endif // defined( XSpp_a9bbfcda_067750 )
#if defined( XSpp_a9bbfcda_067750 )
    static const char *InsertSpace_types[] = { wxPliOvlnum, wxPliOvlnum, wxPliOvlnum, wxPliOvlnum, wxPliOvlnum, wxPliOvlnum, wxPliOvlstr };
    static wxPliPrototype InsertSpace_proto( InsertSpace_types, sizeof( InsertSpace_types ) / sizeof( InsertSpace_types[0] ) );
#endif // defined( XSpp_a9bbfcda_067750 )
#if defined( XSpp_a9bbfcda_023879 )
    static const char *InsertSpace_types[] = { wxPliOvlnum, wxPliOvlnum, wxPliOvlnum, wxPliOvlnum, wxPliOvlnum, wxPliOvlnum, wxPliOvlstr };
    static wxPliPrototype InsertSpace_proto( InsertSpace_types, sizeof( InsertSpace_types ) / sizeof( InsertSpace_types[0] ) );
#endif // defined( XSpp_a9bbfcda_023879 )
    static wxPliPrototype *wxPliOvl_all_prototypes[] = {
#if defined( XSpp_a9bbfcda_067750 )
        &InsertWindow_proto,
#endif // defined( XSpp_a9bbfcda_067750 )
#if defined( XSpp_a9bbfcda_023879 )
        &InsertSizer_proto,
#endif // defined( XSpp_a9bbfcda_023879 )
#if defined( XSpp_a9bbfcda_023879 )
        &InsertWindow_proto,
#endif // defined( XSpp_a9bbfcda_023879 )
#if defined( XSpp_a9bbfcda_067750 )
        &InsertSizer_proto,
#endif // defined( XSpp_a9bbfcda_067750 )
#if defined( XSpp_a9bbfcda_067750 )
        &InsertSpace_proto,
#endif // defined( XSpp_a9bbfcda_067750 )
#if defined( XSpp_a9bbfcda_023879 )
        &InsertSpace_proto,
#endif // defined( XSpp_a9bbfcda_023879 )
        NULL };
    BEGIN_OVERLOAD()
#if defined( XSpp_a9bbfcda_067750 )
        MATCH_REDISP_COUNT_ALLOWMORE( InsertWindow_proto, InsertWindow, 2 )
#endif // defined( XSpp_a9bbfcda_067750 )
#if defined( XSpp_a9bbfcda_023879 )
        MATCH_REDISP_COUNT_ALLOWMORE( InsertSizer_proto, InsertSizer, 2 )
#endif // defined( XSpp_a9bbfcda_023879 )
#if defined( XSpp_a9bbfcda_023879 )
        MATCH_REDISP_COUNT_ALLOWMORE( InsertWindow_proto, InsertWindow, 2 )
#endif // defined( XSpp_a9bbfcda_023879 )
#if defined( XSpp_a9bbfcda_067750 )
        MATCH_REDISP_COUNT_ALLOWMORE( InsertSizer_proto, InsertSizer, 2 )
#endif // defined( XSpp_a9bbfcda_067750 )
#if defined( XSpp_a9bbfcda_067750 )
        MATCH_REDISP_COUNT_ALLOWMORE( InsertSpace_proto, InsertSpace, 3 )
#endif // defined( XSpp_a9bbfcda_067750 )
#if defined( XSpp_a9bbfcda_023879 )
        MATCH_REDISP_COUNT_ALLOWMORE( InsertSpace_proto, InsertSpace, 3 )
#endif // defined( XSpp_a9bbfcda_023879 )
    END_OVERLOAD_MESSAGE( Wx::Sizer::Insert, wxPliOvl_all_prototypes )
	PUTBACK;
	return;
    }
}

#endif // 1
#if 1
#define XSubPPtmpAADY 1


XS_EUPXS(XS_Wx__Sizer_PrependStretchSpacer); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Sizer_PrependStretchSpacer)
{
    dVAR; dXSARGS;
    if (items < 1)
       croak_xs_usage(cv,  "THIS, ...");
    PERL_UNUSED_VAR(ax); /* -Wall */
    SP -= items;
    {
	wxSizer *    THIS = (wxSizer *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Sizer" )
;
#if defined( XSpp_a9bbfcda_065972 )
    static const char *PrependStretchSpacer0_types[] = { wxPliOvlnum };
    static wxPliPrototype PrependStretchSpacer0_proto( PrependStretchSpacer0_types, sizeof( PrependStretchSpacer0_types ) / sizeof( PrependStretchSpacer0_types[0] ) );
#endif // defined( XSpp_a9bbfcda_065972 )
#if defined( XSpp_a9bbfcda_093726 )
    static const char *PrependStretchSpacer1_types[] = { wxPliOvlnum };
    static wxPliPrototype PrependStretchSpacer1_proto( PrependStretchSpacer1_types, sizeof( PrependStretchSpacer1_types ) / sizeof( PrependStretchSpacer1_types[0] ) );
#endif // defined( XSpp_a9bbfcda_093726 )
    static wxPliPrototype *wxPliOvl_all_prototypes[] = {
#if defined( XSpp_a9bbfcda_065972 )
        &PrependStretchSpacer0_proto,
#endif // defined( XSpp_a9bbfcda_065972 )
#if defined( XSpp_a9bbfcda_093726 )
        &PrependStretchSpacer1_proto,
#endif // defined( XSpp_a9bbfcda_093726 )
        NULL };
    BEGIN_OVERLOAD()
#if defined( XSpp_a9bbfcda_065972 )
        MATCH_REDISP_COUNT_ALLOWMORE( PrependStretchSpacer0_proto, PrependStretchSpacer0, 0 )
#endif // defined( XSpp_a9bbfcda_065972 )
#if defined( XSpp_a9bbfcda_093726 )
        MATCH_REDISP_COUNT_ALLOWMORE( PrependStretchSpacer1_proto, PrependStretchSpacer1, 0 )
#endif // defined( XSpp_a9bbfcda_093726 )
    END_OVERLOAD_MESSAGE( Wx::Sizer::PrependStretchSpacer, wxPliOvl_all_prototypes )
	PUTBACK;
	return;
    }
}

#endif // 1
#if 1
#define XSubPPtmpAADZ 1


XS_EUPXS(XS_Wx__Sizer_AddStretchSpacer); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Sizer_AddStretchSpacer)
{
    dVAR; dXSARGS;
    if (items < 1)
       croak_xs_usage(cv,  "THIS, ...");
    PERL_UNUSED_VAR(ax); /* -Wall */
    SP -= items;
    {
	wxSizer *    THIS = (wxSizer *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Sizer" )
;
#if defined( XSpp_a9bbfcda_065972 )
    static const char *AddStretchSpacer0_types[] = { wxPliOvlnum };
    static wxPliPrototype AddStretchSpacer0_proto( AddStretchSpacer0_types, sizeof( AddStretchSpacer0_types ) / sizeof( AddStretchSpacer0_types[0] ) );
#endif // defined( XSpp_a9bbfcda_065972 )
#if defined( XSpp_a9bbfcda_093726 )
    static const char *AddStretchSpacer1_types[] = { wxPliOvlnum };
    static wxPliPrototype AddStretchSpacer1_proto( AddStretchSpacer1_types, sizeof( AddStretchSpacer1_types ) / sizeof( AddStretchSpacer1_types[0] ) );
#endif // defined( XSpp_a9bbfcda_093726 )
    static wxPliPrototype *wxPliOvl_all_prototypes[] = {
#if defined( XSpp_a9bbfcda_065972 )
        &AddStretchSpacer0_proto,
#endif // defined( XSpp_a9bbfcda_065972 )
#if defined( XSpp_a9bbfcda_093726 )
        &AddStretchSpacer1_proto,
#endif // defined( XSpp_a9bbfcda_093726 )
        NULL };
    BEGIN_OVERLOAD()
#if defined( XSpp_a9bbfcda_065972 )
        MATCH_REDISP_COUNT_ALLOWMORE( AddStretchSpacer0_proto, AddStretchSpacer0, 0 )
#endif // defined( XSpp_a9bbfcda_065972 )
#if defined( XSpp_a9bbfcda_093726 )
        MATCH_REDISP_COUNT_ALLOWMORE( AddStretchSpacer1_proto, AddStretchSpacer1, 0 )
#endif // defined( XSpp_a9bbfcda_093726 )
    END_OVERLOAD_MESSAGE( Wx::Sizer::AddStretchSpacer, wxPliOvl_all_prototypes )
	PUTBACK;
	return;
    }
}

#endif // 1
#if 1
#define XSubPPtmpAAEA 1


XS_EUPXS(XS_Wx__Sizer_Hide); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Sizer_Hide)
{
    dVAR; dXSARGS;
    if (items < 1)
       croak_xs_usage(cv,  "THIS, ...");
    PERL_UNUSED_VAR(ax); /* -Wall */
    SP -= items;
    {
	wxSizer *    THIS = (wxSizer *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Sizer" )
;
#if 1
    static const char *HideSizer_types[] = { "Wx::Sizer", wxPliOvlbool };
    static wxPliPrototype HideSizer_proto( HideSizer_types, sizeof( HideSizer_types ) / sizeof( HideSizer_types[0] ) );
#endif // 1
#if 1
    static const char *HideWindow_types[] = { "Wx::Window", wxPliOvlbool };
    static wxPliPrototype HideWindow_proto( HideWindow_types, sizeof( HideWindow_types ) / sizeof( HideWindow_types[0] ) );
#endif // 1
#if 1
    static const char *HideIndex_types[] = { wxPliOvlnum };
    static wxPliPrototype HideIndex_proto( HideIndex_types, sizeof( HideIndex_types ) / sizeof( HideIndex_types[0] ) );
#endif // 1
    static wxPliPrototype *wxPliOvl_all_prototypes[] = {
#if 1
        &HideSizer_proto,
#endif // 1
#if 1
        &HideWindow_proto,
#endif // 1
#if 1
        &HideIndex_proto,
#endif // 1
        NULL };
    BEGIN_OVERLOAD()
#if 1
        MATCH_REDISP_COUNT_ALLOWMORE( HideSizer_proto, HideSizer, 1 )
#endif // 1
#if 1
        MATCH_REDISP_COUNT_ALLOWMORE( HideWindow_proto, HideWindow, 1 )
#endif // 1
#if 1
        MATCH_REDISP_COUNT( HideIndex_proto, HideIndex, 1 )
#endif // 1
    END_OVERLOAD_MESSAGE( Wx::Sizer::Hide, wxPliOvl_all_prototypes )
	PUTBACK;
	return;
    }
}

#endif // 1
#if 1
#define XSubPPtmpAAEB 1


XS_EUPXS(XS_Wx__Sizer_InsertStretchSpacer); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Sizer_InsertStretchSpacer)
{
    dVAR; dXSARGS;
    if (items < 1)
       croak_xs_usage(cv,  "THIS, ...");
    PERL_UNUSED_VAR(ax); /* -Wall */
    SP -= items;
    {
	wxSizer *    THIS = (wxSizer *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Sizer" )
;
#if defined( XSpp_a9bbfcda_065972 )
    static const char *InsertStretchSpacer0_types[] = { wxPliOvlnum, wxPliOvlnum };
    static wxPliPrototype InsertStretchSpacer0_proto( InsertStretchSpacer0_types, sizeof( InsertStretchSpacer0_types ) / sizeof( InsertStretchSpacer0_types[0] ) );
#endif // defined( XSpp_a9bbfcda_065972 )
#if defined( XSpp_a9bbfcda_093726 )
    static const char *InsertStretchSpacer1_types[] = { wxPliOvlnum, wxPliOvlnum };
    static wxPliPrototype InsertStretchSpacer1_proto( InsertStretchSpacer1_types, sizeof( InsertStretchSpacer1_types ) / sizeof( InsertStretchSpacer1_types[0] ) );
#endif // defined( XSpp_a9bbfcda_093726 )
    static wxPliPrototype *wxPliOvl_all_prototypes[] = {
#if defined( XSpp_a9bbfcda_065972 )
        &InsertStretchSpacer0_proto,
#endif // defined( XSpp_a9bbfcda_065972 )
#if defined( XSpp_a9bbfcda_093726 )
        &InsertStretchSpacer1_proto,
#endif // defined( XSpp_a9bbfcda_093726 )
        NULL };
    BEGIN_OVERLOAD()
#if defined( XSpp_a9bbfcda_065972 )
        MATCH_REDISP_COUNT_ALLOWMORE( InsertStretchSpacer0_proto, InsertStretchSpacer0, 1 )
#endif // defined( XSpp_a9bbfcda_065972 )
#if defined( XSpp_a9bbfcda_093726 )
        MATCH_REDISP_COUNT_ALLOWMORE( InsertStretchSpacer1_proto, InsertStretchSpacer1, 1 )
#endif // defined( XSpp_a9bbfcda_093726 )
    END_OVERLOAD_MESSAGE( Wx::Sizer::InsertStretchSpacer, wxPliOvl_all_prototypes )
	PUTBACK;
	return;
    }
}

#endif // 1
#if WXPERL_W_VERSION_GE( 2, 5, 1 )
#define XSpp_a9bbfcda_095071
#define XSubPPtmpAAEC 1


XS_EUPXS(XS_Wx__FlexGridSizer_AddGrowableCol0); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__FlexGridSizer_AddGrowableCol0)
{
    dVAR; dXSARGS;
    if (items < 2 || items > 3)
       croak_xs_usage(cv,  "THIS, index, proportion= 0");
    {
	wxFlexGridSizer *    THIS = (wxFlexGridSizer *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::FlexGridSizer" )
;
	size_t    index = (size_t)SvUV( ST(1) )
;
	int	proportion;

	if (items < 3)
	    proportion = 0;
	else {
	    proportion = (int)SvIV(ST(2))
;
	}
    try {
      THIS->AddGrowableCol( index, proportion );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__FlexGridSizer_AddGrowableRow0); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__FlexGridSizer_AddGrowableRow0)
{
    dVAR; dXSARGS;
    if (items < 2 || items > 3)
       croak_xs_usage(cv,  "THIS, index, proportion= 0");
    {
	wxFlexGridSizer *    THIS = (wxFlexGridSizer *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::FlexGridSizer" )
;
	size_t    index = (size_t)SvUV( ST(1) )
;
	int	proportion;

	if (items < 3)
	    proportion = 0;
	else {
	    proportion = (int)SvIV(ST(2))
;
	}
    try {
      THIS->AddGrowableRow( index, proportion );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__FlexGridSizer_SetFlexibleDirection); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__FlexGridSizer_SetFlexibleDirection)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, direction");
    {
	wxFlexGridSizer *    THIS = (wxFlexGridSizer *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::FlexGridSizer" )
;
	int	direction = (int)SvIV(ST(1))
;
    try {
      THIS->SetFlexibleDirection( direction );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__FlexGridSizer_GetFlexibleDirection); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__FlexGridSizer_GetFlexibleDirection)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxFlexGridSizer *    THIS = (wxFlexGridSizer *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::FlexGridSizer" )
;
	int	RETVAL;
	dXSTARG;
    try {
      RETVAL = THIS->GetFlexibleDirection();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__FlexGridSizer_SetNonFlexibleGrowMode); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__FlexGridSizer_SetNonFlexibleGrowMode)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, mode");
    {
	wxFlexGridSizer *    THIS = (wxFlexGridSizer *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::FlexGridSizer" )
;
	wxFlexSizerGrowMode	mode = (wxFlexSizerGrowMode)SvIV(ST(1))
;
    try {
      THIS->SetNonFlexibleGrowMode( mode );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__FlexGridSizer_GetNonFlexibleGrowMode); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__FlexGridSizer_GetNonFlexibleGrowMode)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxFlexGridSizer *    THIS = (wxFlexGridSizer *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::FlexGridSizer" )
;
	wxFlexSizerGrowMode	RETVAL;
	dXSTARG;
    try {
      RETVAL = THIS->GetNonFlexibleGrowMode();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}

#else
#define XSpp_a9bbfcda_027709
#define XSubPPtmpAAED 1


XS_EUPXS(XS_Wx__FlexGridSizer_AddGrowableCol1); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__FlexGridSizer_AddGrowableCol1)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, index");
    {
	wxFlexGridSizer *    THIS = (wxFlexGridSizer *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::FlexGridSizer" )
;
	size_t    index = (size_t)SvUV( ST(1) )
;
    try {
      THIS->AddGrowableCol( index );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__FlexGridSizer_AddGrowableRow1); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__FlexGridSizer_AddGrowableRow1)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, index");
    {
	wxFlexGridSizer *    THIS = (wxFlexGridSizer *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::FlexGridSizer" )
;
	size_t    index = (size_t)SvUV( ST(1) )
;
    try {
      THIS->AddGrowableRow( index );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}

#endif
#include "cpp/overload.h"
#if 1
#define XSubPPtmpAAEE 1


XS_EUPXS(XS_Wx__FlexGridSizer_AddGrowableCol); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__FlexGridSizer_AddGrowableCol)
{
    dVAR; dXSARGS;
    if (items < 1)
       croak_xs_usage(cv,  "THIS, ...");
    PERL_UNUSED_VAR(ax); /* -Wall */
    SP -= items;
    {
	wxFlexGridSizer *    THIS = (wxFlexGridSizer *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::FlexGridSizer" )
;
#if defined( XSpp_a9bbfcda_095071 )
    static const char *AddGrowableCol0_types[] = { wxPliOvlnum, wxPliOvlnum };
    static wxPliPrototype AddGrowableCol0_proto( AddGrowableCol0_types, sizeof( AddGrowableCol0_types ) / sizeof( AddGrowableCol0_types[0] ) );
#endif // defined( XSpp_a9bbfcda_095071 )
#if defined( XSpp_a9bbfcda_027709 )
    static const char *AddGrowableCol1_types[] = { wxPliOvlnum };
    static wxPliPrototype AddGrowableCol1_proto( AddGrowableCol1_types, sizeof( AddGrowableCol1_types ) / sizeof( AddGrowableCol1_types[0] ) );
#endif // defined( XSpp_a9bbfcda_027709 )
    static wxPliPrototype *wxPliOvl_all_prototypes[] = {
#if defined( XSpp_a9bbfcda_095071 )
        &AddGrowableCol0_proto,
#endif // defined( XSpp_a9bbfcda_095071 )
#if defined( XSpp_a9bbfcda_027709 )
        &AddGrowableCol1_proto,
#endif // defined( XSpp_a9bbfcda_027709 )
        NULL };
    BEGIN_OVERLOAD()
#if defined( XSpp_a9bbfcda_095071 )
        MATCH_REDISP_COUNT_ALLOWMORE( AddGrowableCol0_proto, AddGrowableCol0, 1 )
#endif // defined( XSpp_a9bbfcda_095071 )
#if defined( XSpp_a9bbfcda_027709 )
        MATCH_REDISP_COUNT( AddGrowableCol1_proto, AddGrowableCol1, 1 )
#endif // defined( XSpp_a9bbfcda_027709 )
    END_OVERLOAD_MESSAGE( Wx::FlexGridSizer::AddGrowableCol, wxPliOvl_all_prototypes )
	PUTBACK;
	return;
    }
}

#endif // 1
#if 1
#define XSubPPtmpAAEF 1


XS_EUPXS(XS_Wx__FlexGridSizer_AddGrowableRow); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__FlexGridSizer_AddGrowableRow)
{
    dVAR; dXSARGS;
    if (items < 1)
       croak_xs_usage(cv,  "THIS, ...");
    PERL_UNUSED_VAR(ax); /* -Wall */
    SP -= items;
    {
	wxFlexGridSizer *    THIS = (wxFlexGridSizer *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::FlexGridSizer" )
;
#if defined( XSpp_a9bbfcda_095071 )
    static const char *AddGrowableRow0_types[] = { wxPliOvlnum, wxPliOvlnum };
    static wxPliPrototype AddGrowableRow0_proto( AddGrowableRow0_types, sizeof( AddGrowableRow0_types ) / sizeof( AddGrowableRow0_types[0] ) );
#endif // defined( XSpp_a9bbfcda_095071 )
#if defined( XSpp_a9bbfcda_027709 )
    static const char *AddGrowableRow1_types[] = { wxPliOvlnum };
    static wxPliPrototype AddGrowableRow1_proto( AddGrowableRow1_types, sizeof( AddGrowableRow1_types ) / sizeof( AddGrowableRow1_types[0] ) );
#endif // defined( XSpp_a9bbfcda_027709 )
    static wxPliPrototype *wxPliOvl_all_prototypes[] = {
#if defined( XSpp_a9bbfcda_095071 )
        &AddGrowableRow0_proto,
#endif // defined( XSpp_a9bbfcda_095071 )
#if defined( XSpp_a9bbfcda_027709 )
        &AddGrowableRow1_proto,
#endif // defined( XSpp_a9bbfcda_027709 )
        NULL };
    BEGIN_OVERLOAD()
#if defined( XSpp_a9bbfcda_095071 )
        MATCH_REDISP_COUNT_ALLOWMORE( AddGrowableRow0_proto, AddGrowableRow0, 1 )
#endif // defined( XSpp_a9bbfcda_095071 )
#if defined( XSpp_a9bbfcda_027709 )
        MATCH_REDISP_COUNT( AddGrowableRow1_proto, AddGrowableRow1, 1 )
#endif // defined( XSpp_a9bbfcda_027709 )
    END_OVERLOAD_MESSAGE( Wx::FlexGridSizer::AddGrowableRow, wxPliOvl_all_prototypes )
	PUTBACK;
	return;
    }
}

#endif // 1

XS_EUPXS(XS_Wx__SizerItem_SetRatioWH); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__SizerItem_SetRatioWH)
{
    dVAR; dXSARGS;
    if (items != 3)
       croak_xs_usage(cv,  "THIS, width, height");
    {
	wxSizerItem *    THIS = (wxSizerItem *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::SizerItem" )
;
	int	width = (int)SvIV(ST(1))
;
	int	height = (int)SvIV(ST(2))
;
    try {
      THIS->SetRatio( width, height );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__SizerItem_SetRatioSize); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__SizerItem_SetRatioSize)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, size");
    {
	wxSizerItem *    THIS = (wxSizerItem *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::SizerItem" )
;
	wxSize    size = wxPli_sv_2_wxsize( aTHX_ ST(1) )
;
    try {
      THIS->SetRatio( size );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__SizerItem_SetRatioFloat); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__SizerItem_SetRatioFloat)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, ratio");
    {
	wxSizerItem *    THIS = (wxSizerItem *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::SizerItem" )
;
	float	ratio = (float)SvNV(ST(1))
;
    try {
      THIS->SetRatio( ratio );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}

#if WXPERL_W_VERSION_GE( 2, 5, 1 )
#define XSpp_a9bbfcda_095365
#define XSubPPtmpAAEG 1


XS_EUPXS(XS_Wx__SizerItem_GetOption); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__SizerItem_GetOption)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxSizerItem *    THIS = (wxSizerItem *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::SizerItem" )
;
	int	RETVAL;
	dXSTARG;
    try {
      RETVAL = THIS->GetProportion();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__SizerItem_SetOption); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__SizerItem_SetOption)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, option");
    {
	wxSizerItem *    THIS = (wxSizerItem *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::SizerItem" )
;
	int	option = (int)SvIV(ST(1))
;
    try {
      THIS->SetProportion( option );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__SizerItem_GetProportion); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__SizerItem_GetProportion)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxSizerItem *    THIS = (wxSizerItem *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::SizerItem" )
;
	int	RETVAL;
	dXSTARG;
    try {
      RETVAL = THIS->GetProportion();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__SizerItem_SetProportion); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__SizerItem_SetProportion)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, proportion");
    {
	wxSizerItem *    THIS = (wxSizerItem *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::SizerItem" )
;
	int	proportion = (int)SvIV(ST(1))
;
    try {
      THIS->SetProportion( proportion );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}

#else
#define XSpp_a9bbfcda_011679
#define XSubPPtmpAAEH 1


XS_EUPXS(XS_Wx__SizerItem_GetProportion); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__SizerItem_GetProportion)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxSizerItem *    THIS = (wxSizerItem *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::SizerItem" )
;
	int	RETVAL;
	dXSTARG;
    try {
      RETVAL = THIS->GetOption();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__SizerItem_SetProportion); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__SizerItem_SetProportion)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, proportion");
    {
	wxSizerItem *    THIS = (wxSizerItem *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::SizerItem" )
;
	int	proportion = (int)SvIV(ST(1))
;
    try {
      THIS->SetOption( proportion );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__SizerItem_GetOption); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__SizerItem_GetOption)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxSizerItem *    THIS = (wxSizerItem *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::SizerItem" )
;
	int	RETVAL;
	dXSTARG;
    try {
      RETVAL = THIS->GetOption();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__SizerItem_SetOption); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__SizerItem_SetOption)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, option");
    {
	wxSizerItem *    THIS = (wxSizerItem *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::SizerItem" )
;
	int	option = (int)SvIV(ST(1))
;
    try {
      THIS->SetOption( option );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}

#endif
#if WXPERL_W_VERSION_GE( 2, 5, 3 )
#define XSpp_a9bbfcda_025934
#define XSubPPtmpAAEI 1


XS_EUPXS(XS_Wx__SizerItem_SetMinSizeWH); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__SizerItem_SetMinSizeWH)
{
    dVAR; dXSARGS;
    if (items != 3)
       croak_xs_usage(cv,  "THIS, x, y");
    {
	wxSizerItem *    THIS = (wxSizerItem *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::SizerItem" )
;
	int	x = (int)SvIV(ST(1))
;
	int	y = (int)SvIV(ST(2))
;
    try {
      THIS->SetMinSize( x, y );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__SizerItem_SetMinSizeSize); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__SizerItem_SetMinSizeSize)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, size");
    {
	wxSizerItem *    THIS = (wxSizerItem *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::SizerItem" )
;
	wxSize    size = wxPli_sv_2_wxsize( aTHX_ ST(1) )
;
    try {
      THIS->SetMinSize( size );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}

#endif

XS_EUPXS(XS_Wx__SizerItem_DeleteWindows); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__SizerItem_DeleteWindows)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxSizerItem *    THIS = (wxSizerItem *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::SizerItem" )
;
    try {
      THIS->DeleteWindows();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__SizerItem_DetachSizer); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__SizerItem_DetachSizer)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxSizerItem *    THIS = (wxSizerItem *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::SizerItem" )
;
    try {
      THIS->DetachSizer();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}

#if WXPERL_W_VERSION_GE( 2, 9, 0 )
#define XSpp_a9bbfcda_099537
#define XSubPPtmpAAEJ 1


XS_EUPXS(XS_Wx__SizerItem_SetId); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__SizerItem_SetId)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, id");
    {
	wxSizerItem *    THIS = (wxSizerItem *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::SizerItem" )
;
	int	id = (int)SvIV(ST(1))
;
    try {
      THIS->SetId( id );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__SizerItem_GetId); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__SizerItem_GetId)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxSizerItem *    THIS = (wxSizerItem *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::SizerItem" )
;
	int	RETVAL;
	dXSTARG;
    try {
      RETVAL = THIS->GetId();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}

#endif
#if WXPERL_W_VERSION_GE( 2, 6, 0 )
#define XSpp_a9bbfcda_049499
#define XSubPPtmpAAEK 1


XS_EUPXS(XS_Wx__SizerItem_GetRect); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__SizerItem_GetRect)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxSizerItem *    THIS = (wxSizerItem *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::SizerItem" )
;
	wxRect *	RETVAL;
    try {
      RETVAL = new wxRect( THIS->GetRect() );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_non_object_2_sv( aTHX_ RETVALSV, RETVAL, "Wx::Rect" );
    wxPli_thread_sv_register( aTHX_ "Wx::Rect", RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}

#endif

XS_EUPXS(XS_Wx__SizerItem_Show); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__SizerItem_Show)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, show");
    {
	wxSizerItem *    THIS = (wxSizerItem *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::SizerItem" )
;
	bool	show = (bool)SvTRUE(ST(1))
;
    try {
      THIS->Show( show );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}

#if WXPERL_W_VERSION_GE( 2, 9, 0 )
#define XSpp_a9bbfcda_080721
#define XSubPPtmpAAEL 1


XS_EUPXS(XS_Wx__SizerItem_AssignSpacer); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__SizerItem_AssignSpacer)
{
    dVAR; dXSARGS;
    if (items != 3)
       croak_xs_usage(cv,  "THIS, width, height");
    {
	wxSizerItem *    THIS = (wxSizerItem *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::SizerItem" )
;
	int	width = (int)SvIV(ST(1))
;
	int	height = (int)SvIV(ST(2))
;
    try {
      THIS->AssignSpacer( width, height );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}

#else
#define XSpp_a9bbfcda_015544
#if WXPERL_W_VERSION_GE( 2, 6, 0 )
#define XSpp_a9bbfcda_009533
#define XSubPPtmpAAEM 1


XS_EUPXS(XS_Wx__SizerItem_SetSpacer); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__SizerItem_SetSpacer)
{
    dVAR; dXSARGS;
    if (items != 3)
       croak_xs_usage(cv,  "THIS, width, height");
    {
	wxSizerItem *    THIS = (wxSizerItem *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::SizerItem" )
;
	int	width = (int)SvIV(ST(1))
;
	int	height = (int)SvIV(ST(2))
;
    try {
      THIS->SetSpacer( width, height );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}

#endif
#endif

XS_EUPXS(XS_Wx__SizerItem_GetSpacer); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__SizerItem_GetSpacer)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxSizerItem *    THIS = (wxSizerItem *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::SizerItem" )
;
	wxSize	RETVAL;
    try {
      RETVAL = THIS->GetSpacer();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_non_object_2_sv( aTHX_ RETVALSV, new wxSize(RETVAL), "Wx::Size" );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}

#include "cpp/overload.h"
#if 1
#define XSubPPtmpAAEN 1


XS_EUPXS(XS_Wx__SizerItem_SetMinSize); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__SizerItem_SetMinSize)
{
    dVAR; dXSARGS;
    if (items < 1)
       croak_xs_usage(cv,  "THIS, ...");
    PERL_UNUSED_VAR(ax); /* -Wall */
    SP -= items;
    {
	wxSizerItem *    THIS = (wxSizerItem *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::SizerItem" )
;
#if defined( XSpp_a9bbfcda_025934 )
    static const char *SetMinSizeSize_types[] = { wxPliOvlwsiz };
    static wxPliPrototype SetMinSizeSize_proto( SetMinSizeSize_types, sizeof( SetMinSizeSize_types ) / sizeof( SetMinSizeSize_types[0] ) );
#endif // defined( XSpp_a9bbfcda_025934 )
#if defined( XSpp_a9bbfcda_025934 )
    static const char *SetMinSizeWH_types[] = { wxPliOvlnum, wxPliOvlnum };
    static wxPliPrototype SetMinSizeWH_proto( SetMinSizeWH_types, sizeof( SetMinSizeWH_types ) / sizeof( SetMinSizeWH_types[0] ) );
#endif // defined( XSpp_a9bbfcda_025934 )
    static wxPliPrototype *wxPliOvl_all_prototypes[] = {
#if defined( XSpp_a9bbfcda_025934 )
        &SetMinSizeSize_proto,
#endif // defined( XSpp_a9bbfcda_025934 )
#if defined( XSpp_a9bbfcda_025934 )
        &SetMinSizeWH_proto,
#endif // defined( XSpp_a9bbfcda_025934 )
        NULL };
    BEGIN_OVERLOAD()
#if defined( XSpp_a9bbfcda_025934 )
        MATCH_REDISP_COUNT( SetMinSizeSize_proto, SetMinSizeSize, 1 )
#endif // defined( XSpp_a9bbfcda_025934 )
#if defined( XSpp_a9bbfcda_025934 )
        MATCH_REDISP_COUNT( SetMinSizeWH_proto, SetMinSizeWH, 2 )
#endif // defined( XSpp_a9bbfcda_025934 )
    END_OVERLOAD_MESSAGE( Wx::SizerItem::SetMinSize, wxPliOvl_all_prototypes )
	PUTBACK;
	return;
    }
}

#endif // 1
#if 1
#define XSubPPtmpAAEO 1


XS_EUPXS(XS_Wx__SizerItem_SetRatio); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__SizerItem_SetRatio)
{
    dVAR; dXSARGS;
    if (items < 1)
       croak_xs_usage(cv,  "THIS, ...");
    PERL_UNUSED_VAR(ax); /* -Wall */
    SP -= items;
    {
	wxSizerItem *    THIS = (wxSizerItem *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::SizerItem" )
;
#if 1
    static const char *SetRatioFloat_types[] = { wxPliOvlnum };
    static wxPliPrototype SetRatioFloat_proto( SetRatioFloat_types, sizeof( SetRatioFloat_types ) / sizeof( SetRatioFloat_types[0] ) );
#endif // 1
#if 1
    static const char *SetRatioSize_types[] = { wxPliOvlwsiz };
    static wxPliPrototype SetRatioSize_proto( SetRatioSize_types, sizeof( SetRatioSize_types ) / sizeof( SetRatioSize_types[0] ) );
#endif // 1
#if 1
    static const char *SetRatioWH_types[] = { wxPliOvlnum, wxPliOvlnum };
    static wxPliPrototype SetRatioWH_proto( SetRatioWH_types, sizeof( SetRatioWH_types ) / sizeof( SetRatioWH_types[0] ) );
#endif // 1
    static wxPliPrototype *wxPliOvl_all_prototypes[] = {
#if 1
        &SetRatioFloat_proto,
#endif // 1
#if 1
        &SetRatioSize_proto,
#endif // 1
#if 1
        &SetRatioWH_proto,
#endif // 1
        NULL };
    BEGIN_OVERLOAD()
#if 1
        MATCH_REDISP_COUNT( SetRatioFloat_proto, SetRatioFloat, 1 )
#endif // 1
#if 1
        MATCH_REDISP_COUNT( SetRatioSize_proto, SetRatioSize, 1 )
#endif // 1
#if 1
        MATCH_REDISP_COUNT( SetRatioWH_proto, SetRatioWH, 2 )
#endif // 1
    END_OVERLOAD_MESSAGE( Wx::SizerItem::SetRatio, wxPliOvl_all_prototypes )
	PUTBACK;
	return;
    }
}

#endif // 1
#if WXPERL_W_VERSION_GE( 2, 6, 1 )
#define XSpp_a9bbfcda_040340
#include <wx/button.h>
#undef  xsp_constructor_class
#define xsp_constructor_class(c) (CLASS)
#define XSubPPtmpAAEP 1


XS_EUPXS(XS_Wx__StdDialogButtonSizer_new); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StdDialogButtonSizer_new)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "CLASS");
    {
	char *	CLASS = (char *)SvPV_nolen(ST(0))
;
	wxStdDialogButtonSizer *	RETVAL;
    try {
      RETVAL = new wxStdDialogButtonSizer();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_object_2_sv( aTHX_ RETVALSV, RETVAL );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}

#undef  xsp_constructor_class
#define xsp_constructor_class(c) (c)

XS_EUPXS(XS_Wx__StdDialogButtonSizer_AddButton); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StdDialogButtonSizer_AddButton)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, button");
    {
	wxStdDialogButtonSizer *    THIS = (wxStdDialogButtonSizer *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StdDialogButtonSizer" )
;
	wxButton*    button = (wxButton *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::Button" )
;
    try {
      THIS->AddButton( button );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__StdDialogButtonSizer_SetAffirmativeButton); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StdDialogButtonSizer_SetAffirmativeButton)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, button");
    {
	wxStdDialogButtonSizer *    THIS = (wxStdDialogButtonSizer *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StdDialogButtonSizer" )
;
	wxButton*    button = (wxButton *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::Button" )
;
    try {
      THIS->SetAffirmativeButton( button );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__StdDialogButtonSizer_SetNegativeButton); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StdDialogButtonSizer_SetNegativeButton)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, button");
    {
	wxStdDialogButtonSizer *    THIS = (wxStdDialogButtonSizer *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StdDialogButtonSizer" )
;
	wxButton*    button = (wxButton *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::Button" )
;
    try {
      THIS->SetNegativeButton( button );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__StdDialogButtonSizer_SetCancelButton); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StdDialogButtonSizer_SetCancelButton)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, button");
    {
	wxStdDialogButtonSizer *    THIS = (wxStdDialogButtonSizer *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StdDialogButtonSizer" )
;
	wxButton*    button = (wxButton *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::Button" )
;
    try {
      THIS->SetCancelButton( button );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__StdDialogButtonSizer_Realize); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StdDialogButtonSizer_Realize)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxStdDialogButtonSizer *    THIS = (wxStdDialogButtonSizer *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StdDialogButtonSizer" )
;
    try {
      THIS->Realize();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__StdDialogButtonSizer_GetAffirmativeButton); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StdDialogButtonSizer_GetAffirmativeButton)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxStdDialogButtonSizer *    THIS = (wxStdDialogButtonSizer *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StdDialogButtonSizer" )
;
	wxButton *	RETVAL;
    try {
      RETVAL = THIS->GetAffirmativeButton();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_evthandler_2_sv( aTHX_ RETVALSV, RETVAL );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__StdDialogButtonSizer_GetApplyButton); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StdDialogButtonSizer_GetApplyButton)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxStdDialogButtonSizer *    THIS = (wxStdDialogButtonSizer *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StdDialogButtonSizer" )
;
	wxButton *	RETVAL;
    try {
      RETVAL = THIS->GetApplyButton();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_evthandler_2_sv( aTHX_ RETVALSV, RETVAL );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__StdDialogButtonSizer_GetNegativeButton); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StdDialogButtonSizer_GetNegativeButton)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxStdDialogButtonSizer *    THIS = (wxStdDialogButtonSizer *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StdDialogButtonSizer" )
;
	wxButton *	RETVAL;
    try {
      RETVAL = THIS->GetNegativeButton();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_evthandler_2_sv( aTHX_ RETVALSV, RETVAL );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__StdDialogButtonSizer_GetCancelButton); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StdDialogButtonSizer_GetCancelButton)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxStdDialogButtonSizer *    THIS = (wxStdDialogButtonSizer *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StdDialogButtonSizer" )
;
	wxButton *	RETVAL;
    try {
      RETVAL = THIS->GetCancelButton();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_evthandler_2_sv( aTHX_ RETVALSV, RETVAL );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__StdDialogButtonSizer_GetHelpButton); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StdDialogButtonSizer_GetHelpButton)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxStdDialogButtonSizer *    THIS = (wxStdDialogButtonSizer *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StdDialogButtonSizer" )
;
	wxButton *	RETVAL;
    try {
      RETVAL = THIS->GetHelpButton();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_evthandler_2_sv( aTHX_ RETVALSV, RETVAL );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}

#endif
#if WXPERL_W_VERSION_GE( 2, 9, 0 )
#define XSpp_a9bbfcda_012126
#include <wx/wrapsizer.h>
#undef  xsp_constructor_class
#define xsp_constructor_class(c) (CLASS)
#define XSubPPtmpAAEQ 1


XS_EUPXS(XS_Wx__WrapSizer_new); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__WrapSizer_new)
{
    dVAR; dXSARGS;
    if (items < 1 || items > 3)
       croak_xs_usage(cv,  "CLASS, orient= wxHORIZONTAL, flags= wxEXTEND_LAST_ON_EACH_LINE");
    {
	char *	CLASS = (char *)SvPV_nolen(ST(0))
;
	wxWrapSizer *	RETVAL;
	int	orient;
	int	flags;

	if (items < 2)
	    orient = wxHORIZONTAL;
	else {
	    orient = (int)SvIV(ST(1))
;
	}

	if (items < 3)
	    flags = wxEXTEND_LAST_ON_EACH_LINE;
	else {
	    flags = (int)SvIV(ST(2))
;
	}
    try {
      RETVAL = new wxWrapSizer( orient, flags );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_object_2_sv( aTHX_ RETVALSV, RETVAL );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}

#undef  xsp_constructor_class
#define xsp_constructor_class(c) (c)

XS_EUPXS(XS_Wx__WrapSizer_InformFirstDirection); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__WrapSizer_InformFirstDirection)
{
    dVAR; dXSARGS;
    if (items != 4)
       croak_xs_usage(cv,  "THIS, direction, size, availableOtherDir");
    {
	wxWrapSizer *    THIS = (wxWrapSizer *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::WrapSizer" )
;
	bool	RETVAL;
	int	direction = (int)SvIV(ST(1))
;
	int	size = (int)SvIV(ST(2))
;
	int	availableOtherDir = (int)SvIV(ST(3))
;
    try {
      RETVAL = THIS->InformFirstDirection( direction, size, availableOtherDir );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}

#endif

XS_EUPXS(XS_Wx__Sizer_Destroy); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Sizer_Destroy)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxSizer *    THIS = (wxSizer *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Sizer" )
;
    delete THIS;
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__Sizer_GetChildren); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__Sizer_GetChildren)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    PERL_UNUSED_VAR(ax); /* -Wall */
    SP -= items;
    {
	wxSizer *    THIS = (wxSizer *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::Sizer" )
;
#if WXPERL_W_VERSION_GE( 2, 5, 1 )
    wxSizerItemList::compatibility_iterator node;
    const wxSizerItemList& list
#else
    wxList::compatibility_iterator node;
    const wxList& list
#endif
        = THIS->GetChildren();

    EXTEND( SP, (IV) list.GetCount() );

    for( node = list.GetFirst(); node; node = node->GetNext() )
      PUSHs( wxPli_object_2_sv( aTHX_ sv_newmortal(), node->GetData() ) );
	PUTBACK;
	return;
    }
}


XS_EUPXS(XS_Wx__BoxSizer_new); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__BoxSizer_new)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "CLASS, orientation");
    {
	int	orientation = (int)SvIV(ST(1))
;
	char *	CLASS = (char *)SvPV_nolen(ST(0))
;
	wxBoxSizer *	RETVAL;

	RETVAL = new wxBoxSizer(orientation);
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_object_2_sv( aTHX_ RETVALSV, RETVAL );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__BoxSizer_GetOrientation); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__BoxSizer_GetOrientation)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxBoxSizer *    THIS = (wxBoxSizer *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::BoxSizer" )
;
	int	RETVAL;
	dXSTARG;

	RETVAL = THIS->GetOrientation();
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}

#if WXPERL_W_VERSION_GE( 2, 8, 0 )
#define XSubPPtmpAAER 1


XS_EUPXS(XS_Wx__BoxSizer_SetOrientation); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__BoxSizer_SetOrientation)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, orientation");
    {
	int	orientation = (int)SvIV(ST(1))
;
	wxBoxSizer *    THIS = (wxBoxSizer *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::BoxSizer" )
;

	THIS->SetOrientation(orientation);
    }
    XSRETURN_EMPTY;
}

#endif
#if WXPERL_W_VERSION_GE( 2, 9, 0 )
#define XSubPPtmpAAES 1


XS_EUPXS(XS_Wx__BoxSizer_IsVertical); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__BoxSizer_IsVertical)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxBoxSizer *    THIS = (wxBoxSizer *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::BoxSizer" )
;
	bool	RETVAL;

	RETVAL = THIS->IsVertical();
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}

#endif

XS_EUPXS(XS_Wx__StaticBoxSizer_new); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StaticBoxSizer_new)
{
    dVAR; dXSARGS;
    if (items != 3)
       croak_xs_usage(cv,  "CLASS, box, orient");
    {
	wxStaticBox*    box = (wxStaticBox *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::StaticBox" )
;
	int	orient = (int)SvIV(ST(2))
;
	char *	CLASS = (char *)SvPV_nolen(ST(0))
;
	wxStaticBoxSizer *	RETVAL;

	RETVAL = new wxStaticBoxSizer(box, orient);
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_object_2_sv( aTHX_ RETVALSV, RETVAL );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__StaticBoxSizer_GetStaticBox); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__StaticBoxSizer_GetStaticBox)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxStaticBoxSizer *    THIS = (wxStaticBoxSizer *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::StaticBoxSizer" )
;
	wxStaticBox *	RETVAL;

	RETVAL = THIS->GetStaticBox();
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_evthandler_2_sv( aTHX_ RETVALSV, RETVAL );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}

#include <wx/notebook.h>

XS_EUPXS(XS_Wx__NotebookSizer_new); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__NotebookSizer_new)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "CLASS, notebook");
    {
	wxNotebook*    notebook = (wxNotebook *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::Notebook" )
;
	char *	CLASS = (char *)SvPV_nolen(ST(0))
;
	wxNotebookSizer *	RETVAL;

	RETVAL = new wxNotebookSizer(notebook);
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_object_2_sv( aTHX_ RETVALSV, RETVAL );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__NotebookSizer_GetNotebook); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__NotebookSizer_GetNotebook)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxNotebookSizer *    THIS = (wxNotebookSizer *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::NotebookSizer" )
;
	wxNotebook *	RETVAL;

	RETVAL = THIS->GetNotebook();
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_evthandler_2_sv( aTHX_ RETVALSV, RETVAL );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__GridSizer_new); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__GridSizer_new)
{
    dVAR; dXSARGS;
    if (items < 3 || items > 5)
       croak_xs_usage(cv,  "CLASS, rows, cols, vgap = 0, hgap = 0");
    {
	int	rows = (int)SvIV(ST(1))
;
	int	cols = (int)SvIV(ST(2))
;
	int	vgap;
	int	hgap;
	char *	CLASS = (char *)SvPV_nolen(ST(0))
;
	wxGridSizer *	RETVAL;

	if (items < 4)
	    vgap = 0;
	else {
	    vgap = (int)SvIV(ST(3))
;
	}

	if (items < 5)
	    hgap = 0;
	else {
	    hgap = (int)SvIV(ST(4))
;
	}

	RETVAL = new wxGridSizer(rows, cols, vgap, hgap);
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_object_2_sv( aTHX_ RETVALSV, RETVAL );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__GridSizer_GetCols); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__GridSizer_GetCols)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxGridSizer *    THIS = (wxGridSizer *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::GridSizer" )
;
	int	RETVAL;
	dXSTARG;

	RETVAL = THIS->GetCols();
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__GridSizer_GetHGap); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__GridSizer_GetHGap)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxGridSizer *    THIS = (wxGridSizer *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::GridSizer" )
;
	int	RETVAL;
	dXSTARG;

	RETVAL = THIS->GetHGap();
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__GridSizer_GetRows); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__GridSizer_GetRows)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxGridSizer *    THIS = (wxGridSizer *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::GridSizer" )
;
	int	RETVAL;
	dXSTARG;

	RETVAL = THIS->GetRows();
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__GridSizer_GetVGap); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__GridSizer_GetVGap)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxGridSizer *    THIS = (wxGridSizer *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::GridSizer" )
;
	int	RETVAL;
	dXSTARG;

	RETVAL = THIS->GetVGap();
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__GridSizer_SetCols); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__GridSizer_SetCols)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, cols");
    {
	int	cols = (int)SvIV(ST(1))
;
	wxGridSizer *    THIS = (wxGridSizer *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::GridSizer" )
;

	THIS->SetCols(cols);
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__GridSizer_SetHGap); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__GridSizer_SetHGap)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, gap");
    {
	int	gap = (int)SvIV(ST(1))
;
	wxGridSizer *    THIS = (wxGridSizer *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::GridSizer" )
;

	THIS->SetHGap(gap);
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__GridSizer_SetRows); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__GridSizer_SetRows)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, rows");
    {
	int	rows = (int)SvIV(ST(1))
;
	wxGridSizer *    THIS = (wxGridSizer *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::GridSizer" )
;

	THIS->SetRows(rows);
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__GridSizer_SetVGap); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__GridSizer_SetVGap)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, gap");
    {
	int	gap = (int)SvIV(ST(1))
;
	wxGridSizer *    THIS = (wxGridSizer *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::GridSizer" )
;

	THIS->SetVGap(gap);
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__FlexGridSizer_new); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__FlexGridSizer_new)
{
    dVAR; dXSARGS;
    if (items < 3 || items > 5)
       croak_xs_usage(cv,  "CLASS, rows, cols, vgap = 0, hgap = 0");
    {
	int	rows = (int)SvIV(ST(1))
;
	int	cols = (int)SvIV(ST(2))
;
	int	vgap;
	int	hgap;
	char *	CLASS = (char *)SvPV_nolen(ST(0))
;
	wxFlexGridSizer *	RETVAL;

	if (items < 4)
	    vgap = 0;
	else {
	    vgap = (int)SvIV(ST(3))
;
	}

	if (items < 5)
	    hgap = 0;
	else {
	    hgap = (int)SvIV(ST(4))
;
	}

	RETVAL = new wxFlexGridSizer(rows, cols, vgap, hgap);
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_object_2_sv( aTHX_ RETVALSV, RETVAL );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__FlexGridSizer_RemoveGrowableCol); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__FlexGridSizer_RemoveGrowableCol)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, index");
    {
	size_t    index = (size_t)SvUV( ST(1) )
;
	wxFlexGridSizer *    THIS = (wxFlexGridSizer *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::FlexGridSizer" )
;

	THIS->RemoveGrowableCol(index);
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__FlexGridSizer_RemoveGrowableRow); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__FlexGridSizer_RemoveGrowableRow)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, index");
    {
	int	index = (int)SvIV(ST(1))
;
	wxFlexGridSizer *    THIS = (wxFlexGridSizer *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::FlexGridSizer" )
;

	THIS->RemoveGrowableRow(index);
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__SizerItem_GetSize); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__SizerItem_GetSize)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxSizerItem *    THIS = (wxSizerItem *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::SizerItem" )
;
	wxSize *	RETVAL;
    RETVAL = new wxSize( THIS->GetSize() );
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_non_object_2_sv( aTHX_ RETVALSV, RETVAL, "Wx::Size" );
    wxPli_thread_sv_register( aTHX_ "Wx::Size", RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__SizerItem_CalcMin); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__SizerItem_CalcMin)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxSizerItem *    THIS = (wxSizerItem *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::SizerItem" )
;
	wxSize *	RETVAL;
    RETVAL = new wxSize( THIS->GetSize() );
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_non_object_2_sv( aTHX_ RETVALSV, RETVAL, "Wx::Size" );
    wxPli_thread_sv_register( aTHX_ "Wx::Size", RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__SizerItem_SetDimension); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__SizerItem_SetDimension)
{
    dVAR; dXSARGS;
    if (items != 3)
       croak_xs_usage(cv,  "THIS, pos, size");
    {
	wxPoint    pos = wxPli_sv_2_wxpoint( aTHX_ ST(1) )
;
	wxSize    size = wxPli_sv_2_wxsize( aTHX_ ST(2) )
;
	wxSizerItem *    THIS = (wxSizerItem *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::SizerItem" )
;

	THIS->SetDimension(pos, size);
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__SizerItem_GetMinSize); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__SizerItem_GetMinSize)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxSizerItem *    THIS = (wxSizerItem *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::SizerItem" )
;
	wxSize *	RETVAL;
    RETVAL = new wxSize( THIS->GetMinSize() );
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_non_object_2_sv( aTHX_ RETVALSV, RETVAL, "Wx::Size" );
    wxPli_thread_sv_register( aTHX_ "Wx::Size", RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__SizerItem_GetRatio); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__SizerItem_GetRatio)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxSizerItem *    THIS = (wxSizerItem *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::SizerItem" )
;
	float	RETVAL;
	dXSTARG;

	RETVAL = THIS->GetRatio();
	XSprePUSH;
	PUSHn((NV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__SizerItem_IsWindow); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__SizerItem_IsWindow)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxSizerItem *    THIS = (wxSizerItem *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::SizerItem" )
;
	bool	RETVAL;

	RETVAL = THIS->IsWindow();
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__SizerItem_IsShown); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__SizerItem_IsShown)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxSizerItem *    THIS = (wxSizerItem *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::SizerItem" )
;
	bool	RETVAL;

	RETVAL = THIS->IsShown();
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__SizerItem_IsSizer); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__SizerItem_IsSizer)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxSizerItem *    THIS = (wxSizerItem *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::SizerItem" )
;
	bool	RETVAL;

	RETVAL = THIS->IsSizer();
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__SizerItem_IsSpacer); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__SizerItem_IsSpacer)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxSizerItem *    THIS = (wxSizerItem *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::SizerItem" )
;
	bool	RETVAL;

	RETVAL = THIS->IsSpacer();
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__SizerItem_SetInitSize); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__SizerItem_SetInitSize)
{
    dVAR; dXSARGS;
    if (items != 3)
       croak_xs_usage(cv,  "THIS, x, y");
    {
	int	x = (int)SvIV(ST(1))
;
	int	y = (int)SvIV(ST(2))
;
	wxSizerItem *    THIS = (wxSizerItem *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::SizerItem" )
;

	THIS->SetInitSize(x, y);
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__SizerItem_SetFlag); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__SizerItem_SetFlag)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, flag");
    {
	int	flag = (int)SvIV(ST(1))
;
	wxSizerItem *    THIS = (wxSizerItem *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::SizerItem" )
;

	THIS->SetFlag(flag);
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__SizerItem_SetBorder); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__SizerItem_SetBorder)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, border");
    {
	int	border = (int)SvIV(ST(1))
;
	wxSizerItem *    THIS = (wxSizerItem *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::SizerItem" )
;

	THIS->SetBorder(border);
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__SizerItem_GetWindow); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__SizerItem_GetWindow)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxSizerItem *    THIS = (wxSizerItem *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::SizerItem" )
;
	wxWindow *	RETVAL;

	RETVAL = THIS->GetWindow();
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_object_2_sv( aTHX_ RETVALSV, RETVAL );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}

#if WXPERL_W_VERSION_GE( 2, 9, 0 )
#define XSubPPtmpAAET 1


XS_EUPXS(XS_Wx__SizerItem_AssignWindow); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__SizerItem_AssignWindow)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, window");
    {
	wxWindow*    window = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::Window" )
;
	wxSizerItem *    THIS = (wxSizerItem *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::SizerItem" )
;

	THIS->AssignWindow(window);
    }
    XSRETURN_EMPTY;
}

#else
#define XSubPPtmpAAEU 1


XS_EUPXS(XS_Wx__SizerItem_SetWindow); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__SizerItem_SetWindow)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, window");
    {
	wxWindow*    window = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::Window" )
;
	wxSizerItem *    THIS = (wxSizerItem *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::SizerItem" )
;

	THIS->SetWindow(window);
    }
    XSRETURN_EMPTY;
}

#endif

XS_EUPXS(XS_Wx__SizerItem_GetSizer); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__SizerItem_GetSizer)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxSizerItem *    THIS = (wxSizerItem *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::SizerItem" )
;
	wxSizer *	RETVAL;

	RETVAL = THIS->GetSizer();
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_object_2_sv( aTHX_ RETVALSV, RETVAL );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}

#if WXPERL_W_VERSION_GE( 2, 9, 0 )
#define XSubPPtmpAAEV 1


XS_EUPXS(XS_Wx__SizerItem_AssignSizer); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__SizerItem_AssignSizer)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, sizer");
    {
	wxSizer*    sizer = (wxSizer *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::Sizer" )
;
	wxSizerItem *    THIS = (wxSizerItem *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::SizerItem" )
;

	THIS->AssignSizer(sizer);
    }
    XSRETURN_EMPTY;
}

#else
#define XSubPPtmpAAEW 1


XS_EUPXS(XS_Wx__SizerItem_SetSizer); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__SizerItem_SetSizer)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, sizer");
    {
	wxSizer*    sizer = (wxSizer *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::Sizer" )
;
	wxSizerItem *    THIS = (wxSizerItem *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::SizerItem" )
;

	THIS->SetSizer(sizer);
    }
    XSRETURN_EMPTY;
}

#endif

XS_EUPXS(XS_Wx__SizerItem_GetFlag); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__SizerItem_GetFlag)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxSizerItem *    THIS = (wxSizerItem *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::SizerItem" )
;
	int	RETVAL;
	dXSTARG;

	RETVAL = THIS->GetFlag();
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__SizerItem_GetBorder); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__SizerItem_GetBorder)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxSizerItem *    THIS = (wxSizerItem *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::SizerItem" )
;
	int	RETVAL;
	dXSTARG;

	RETVAL = THIS->GetBorder();
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__SizerItem_GetPosition); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__SizerItem_GetPosition)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxSizerItem *    THIS = (wxSizerItem *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::SizerItem" )
;
	wxPoint *	RETVAL;
    RETVAL = new wxPoint( THIS->GetPosition() );
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_non_object_2_sv( aTHX_ RETVALSV, RETVAL, "Wx::Point" );
    wxPli_thread_sv_register( aTHX_ "Wx::Point", RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__SizerItem_GetUserData); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__SizerItem_GetUserData)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxSizerItem *    THIS = (wxSizerItem *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::SizerItem" )
;
	Wx_UserDataO *	RETVAL;
    RETVAL = (Wx_UserDataO*) THIS->GetUserData();
	{
	    SV * RETVALSV;
    RETVALSV = ( RETVAL == 0 ) ? &PL_sv_undef : RETVAL->GetData();
    SvREFCNT_inc( RETVALSV ); // xsubpp mortalizes it...
	    RETVALSV = sv_2mortal(RETVALSV);
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}

#if WXPERL_W_VERSION_GE( 2, 6, 3 )
#define XSubPPtmpAAEX 1


XS_EUPXS(XS_Wx__SizerItem_SetUserData); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__SizerItem_SetUserData)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, data");
    {
	Wx_UserDataO*	data;
	wxSizerItem *    THIS = (wxSizerItem *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::SizerItem" )
;

    if( SvOK( ST(1) ) )
    {
        data = new wxPliUserDataO( ST(1) );
    }
    else
        data = 0
;

	THIS->SetUserData(data);
    }
    XSRETURN_EMPTY;
}

#endif

XS_EUPXS(XS_Wx__PlSizer_new); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__PlSizer_new)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "CLASS");
    {
	char *	CLASS = (char *)SvPV_nolen(ST(0))
;
	wxPlSizer *	RETVAL;
    RETVAL = new wxPlSizer( CLASS );
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_object_2_sv( aTHX_ RETVALSV, RETVAL );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


/* INCLUDE: Returning to 'Window.xs' from '/usr/bin/perl -I./ -MExtUtils::XSpp::Cmd -e xspp -- -t typemap.xsp XS/Sizer.xsp' */


/* INCLUDE_COMMAND:  Including output of '/usr/bin/perl -I./ -MExtUtils::XSpp::Cmd -e xspp -- -t typemap.xsp XS/GridBagSizer.xsp' from 'Window.xs' */

#include <exception>

#undef  xsp_constructor_class
#define xsp_constructor_class(c) (c)
#if WXPERL_W_VERSION_GE( 2, 5, 1 )
#define XSpp_83ead300_002609
#define wxPlDefaultSpan (wxGBSpan*)&wxDefaultSpan
#include <wx/gbsizer.h>
#undef  xsp_constructor_class
#define xsp_constructor_class(c) (CLASS)
#define XSubPPtmpAAEY 1


XS_EUPXS(XS_Wx__GBPosition_new); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__GBPosition_new)
{
    dVAR; dXSARGS;
    if (items < 1 || items > 3)
       croak_xs_usage(cv,  "CLASS, row= 0, col= 0");
    {
	char *	CLASS = (char *)SvPV_nolen(ST(0))
;
	wxGBPosition *	RETVAL;
	int	row;
	int	col;

	if (items < 2)
	    row = 0;
	else {
	    row = (int)SvIV(ST(1))
;
	}

	if (items < 3)
	    col = 0;
	else {
	    col = (int)SvIV(ST(2))
;
	}
    try {
      RETVAL = new wxGBPosition( row, col );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_non_object_2_sv( aTHX_ RETVALSV, RETVAL, "Wx::GBPosition" );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}

#undef  xsp_constructor_class
#define xsp_constructor_class(c) (c)

XS_EUPXS(XS_Wx__GBPosition_GetRow); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__GBPosition_GetRow)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxGBPosition *    THIS = (wxGBPosition *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::GBPosition" )
;
	int	RETVAL;
	dXSTARG;
    try {
      RETVAL = THIS->GetRow();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__GBPosition_GetCol); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__GBPosition_GetCol)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxGBPosition *    THIS = (wxGBPosition *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::GBPosition" )
;
	int	RETVAL;
	dXSTARG;
    try {
      RETVAL = THIS->GetCol();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__GBPosition_SetRow); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__GBPosition_SetRow)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, row");
    {
	wxGBPosition *    THIS = (wxGBPosition *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::GBPosition" )
;
	int	row = (int)SvIV(ST(1))
;
    try {
      THIS->SetRow( row );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__GBPosition_SetCol); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__GBPosition_SetCol)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, col");
    {
	wxGBPosition *    THIS = (wxGBPosition *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::GBPosition" )
;
	int	col = (int)SvIV(ST(1))
;
    try {
      THIS->SetCol( col );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}

#undef  xsp_constructor_class
#define xsp_constructor_class(c) (CLASS)

XS_EUPXS(XS_Wx__GBSpan_new); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__GBSpan_new)
{
    dVAR; dXSARGS;
    if (items < 1 || items > 3)
       croak_xs_usage(cv,  "CLASS, rowspan= 1, colspan= 1");
    {
	char *	CLASS = (char *)SvPV_nolen(ST(0))
;
	wxGBSpan *	RETVAL;
	int	rowspan;
	int	colspan;

	if (items < 2)
	    rowspan = 1;
	else {
	    rowspan = (int)SvIV(ST(1))
;
	}

	if (items < 3)
	    colspan = 1;
	else {
	    colspan = (int)SvIV(ST(2))
;
	}
    try {
      RETVAL = new wxGBSpan( rowspan, colspan );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_non_object_2_sv( aTHX_ RETVALSV, RETVAL, "Wx::GBSpan" );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}

#undef  xsp_constructor_class
#define xsp_constructor_class(c) (c)

XS_EUPXS(XS_Wx__GBSpan_GetRowspan); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__GBSpan_GetRowspan)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxGBSpan *    THIS = (wxGBSpan *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::GBSpan" )
;
	int	RETVAL;
	dXSTARG;
    try {
      RETVAL = THIS->GetRowspan();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__GBSpan_GetColspan); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__GBSpan_GetColspan)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxGBSpan *    THIS = (wxGBSpan *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::GBSpan" )
;
	int	RETVAL;
	dXSTARG;
    try {
      RETVAL = THIS->GetColspan();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__GBSpan_SetRowspan); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__GBSpan_SetRowspan)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, rowspan");
    {
	wxGBSpan *    THIS = (wxGBSpan *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::GBSpan" )
;
	int	rowspan = (int)SvIV(ST(1))
;
    try {
      THIS->SetRowspan( rowspan );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__GBSpan_SetColspan); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__GBSpan_SetColspan)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, colspan");
    {
	wxGBSpan *    THIS = (wxGBSpan *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::GBSpan" )
;
	int	colspan = (int)SvIV(ST(1))
;
    try {
      THIS->SetColspan( colspan );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__GBSizerItem_GetPos); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__GBSizerItem_GetPos)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxGBSizerItem *    THIS = (wxGBSizerItem *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::GBSizerItem" )
;
	wxGBPosition *	RETVAL;
    try {
      RETVAL = new wxGBPosition( THIS->GetPos() );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_non_object_2_sv( aTHX_ RETVALSV, RETVAL, "Wx::GBPosition" );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__GBSizerItem_GetPosXY); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__GBSizerItem_GetPosXY)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    PERL_UNUSED_VAR(ax); /* -Wall */
    SP -= items;
    {
	wxGBSizerItem *    THIS = (wxGBSizerItem *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::GBSizerItem" )
;
    int x, y;
    THIS->GetPos( x, y );
    wxPli_push_2ints( x, y );
	PUTBACK;
	return;
    }
}


XS_EUPXS(XS_Wx__GBSizerItem_GetSpan); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__GBSizerItem_GetSpan)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxGBSizerItem *    THIS = (wxGBSizerItem *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::GBSizerItem" )
;
	wxGBSpan *	RETVAL;
    try {
      RETVAL = new wxGBSpan( THIS->GetSpan() );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_non_object_2_sv( aTHX_ RETVALSV, RETVAL, "Wx::GBSpan" );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__GBSizerItem_GetSpanWH); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__GBSizerItem_GetSpanWH)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    PERL_UNUSED_VAR(ax); /* -Wall */
    SP -= items;
    {
	wxGBSizerItem *    THIS = (wxGBSizerItem *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::GBSizerItem" )
;
    int x, y;
    THIS->GetSpan( x, y );
    wxPli_push_2ints( x, y );
	PUTBACK;
	return;
    }
}


XS_EUPXS(XS_Wx__GBSizerItem_SetPos); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__GBSizerItem_SetPos)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, pos");
    {
	wxGBSizerItem *    THIS = (wxGBSizerItem *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::GBSizerItem" )
;
	bool	RETVAL;
	wxGBPosition*    pos = (wxGBPosition *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::GBPosition" )
;
    try {
      RETVAL = THIS->SetPos( *( pos ) );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__GBSizerItem_SetSpan); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__GBSizerItem_SetSpan)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, span");
    {
	wxGBSizerItem *    THIS = (wxGBSizerItem *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::GBSizerItem" )
;
	bool	RETVAL;
	wxGBSpan*    span = (wxGBSpan *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::GBSpan" )
;
    try {
      RETVAL = THIS->SetSpan( *( span ) );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__GBSizerItem_IntersectsItem); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__GBSizerItem_IntersectsItem)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, other");
    {
	wxGBSizerItem *    THIS = (wxGBSizerItem *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::GBSizerItem" )
;
	bool	RETVAL;
	wxGBSizerItem*    other = (wxGBSizerItem *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::GBSizerItem" )
;
    try {
      RETVAL = THIS->Intersects( *( other ) );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__GBSizerItem_IntersectsPosition); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__GBSizerItem_IntersectsPosition)
{
    dVAR; dXSARGS;
    if (items != 3)
       croak_xs_usage(cv,  "THIS, pos, span");
    {
	wxGBSizerItem *    THIS = (wxGBSizerItem *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::GBSizerItem" )
;
	bool	RETVAL;
	wxGBPosition*    pos = (wxGBPosition *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::GBPosition" )
;
	wxGBSpan*    span = (wxGBSpan *) wxPli_sv_2_object( aTHX_ ST(2), "Wx::GBSpan" )
;
    try {
      RETVAL = THIS->Intersects( *( pos ), *( span ) );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__GBSizerItem_Intersects); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__GBSizerItem_Intersects)
{
    dVAR; dXSARGS;
    if (items < 1)
       croak_xs_usage(cv,  "THIS, ...");
    PERL_UNUSED_VAR(ax); /* -Wall */
    SP -= items;
    {
	wxGBSizerItem *    THIS = (wxGBSizerItem *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::GBSizerItem" )
;
    BEGIN_OVERLOAD()
        MATCH_REDISP( wxPliOvl_wgbi, IntersectsItem )
        MATCH_REDISP( wxPliOvl_wgbp_wgbs, IntersectsPosition )
    END_OVERLOAD( Wx::GridBagSizer::Intersects )
	PUTBACK;
	return;
    }
}


XS_EUPXS(XS_Wx__GBSizerItem_GetEndPos); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__GBSizerItem_GetEndPos)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    PERL_UNUSED_VAR(ax); /* -Wall */
    SP -= items;
    {
	wxGBSizerItem *    THIS = (wxGBSizerItem *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::GBSizerItem" )
;
    int x, y;
    THIS->GetEndPos( x, y );
    wxPli_push_2ints( x, y );
	PUTBACK;
	return;
    }
}


XS_EUPXS(XS_Wx__GBSizerItem_GetGBSizer); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__GBSizerItem_GetGBSizer)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxGBSizerItem *    THIS = (wxGBSizerItem *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::GBSizerItem" )
;
	wxGridBagSizer *	RETVAL;
    try {
      RETVAL = THIS->GetGBSizer();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_object_2_sv( aTHX_ RETVALSV, RETVAL );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__GBSizerItem_SetGBSizer); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__GBSizerItem_SetGBSizer)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, sizer");
    {
	wxGBSizerItem *    THIS = (wxGBSizerItem *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::GBSizerItem" )
;
	wxGridBagSizer*    sizer = (wxGridBagSizer *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::GridBagSizer" )
;
    try {
      THIS->SetGBSizer( sizer );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}

#undef  xsp_constructor_class
#define xsp_constructor_class(c) (CLASS)

XS_EUPXS(XS_Wx__GridBagSizer_new); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__GridBagSizer_new)
{
    dVAR; dXSARGS;
    if (items < 1 || items > 3)
       croak_xs_usage(cv,  "CLASS, vgap= 0, hgap= 0");
    {
	char *	CLASS = (char *)SvPV_nolen(ST(0))
;
	wxGridBagSizer *	RETVAL;
	int	vgap;
	int	hgap;

	if (items < 2)
	    vgap = 0;
	else {
	    vgap = (int)SvIV(ST(1))
;
	}

	if (items < 3)
	    hgap = 0;
	else {
	    hgap = (int)SvIV(ST(2))
;
	}
    try {
      RETVAL = new wxGridBagSizer( vgap, hgap );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_object_2_sv( aTHX_ RETVALSV, RETVAL );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}

#undef  xsp_constructor_class
#define xsp_constructor_class(c) (c)

XS_EUPXS(XS_Wx__GridBagSizer_AddWindow); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__GridBagSizer_AddWindow)
{
    dVAR; dXSARGS;
    if (items < 3 || items > 7)
       croak_xs_usage(cv,  "THIS, window, pos, span= wxPlDefaultSpan, flag= 0, border= 0, userData= NULL");
    {
	wxGridBagSizer *    THIS = (wxGridBagSizer *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::GridBagSizer" )
;
	bool	RETVAL;
	wxWindow*    window = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::Window" )
;
	wxGBPosition*    pos = (wxGBPosition *) wxPli_sv_2_object( aTHX_ ST(2), "Wx::GBPosition" )
;
	wxGBSpan*	span;
	int	flag;
	int	border;
	wxObject*	userData;

	if (items < 4)
	    span = wxPlDefaultSpan;
	else {
    span = (wxGBSpan *) wxPli_sv_2_object( aTHX_ ST(3), "Wx::GBSpan" )
;
	}

	if (items < 5)
	    flag = 0;
	else {
	    flag = (int)SvIV(ST(4))
;
	}

	if (items < 6)
	    border = 0;
	else {
	    border = (int)SvIV(ST(5))
;
	}

	if (items < 7)
	    userData = NULL;
	else {
    userData = (wxObject *) wxPli_sv_2_object( aTHX_ ST(6), "Wx::Object" )
;
	}
    try {
      RETVAL = THIS->Add( window, *( pos ), *( span ), flag, border, userData );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__GridBagSizer_AddSizer); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__GridBagSizer_AddSizer)
{
    dVAR; dXSARGS;
    if (items < 3 || items > 7)
       croak_xs_usage(cv,  "THIS, sizer, pos, span= wxPlDefaultSpan, flag= 0, border= 0, userData= NULL");
    {
	wxGridBagSizer *    THIS = (wxGridBagSizer *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::GridBagSizer" )
;
	bool	RETVAL;
	wxSizer*    sizer = (wxSizer *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::Sizer" )
;
	wxGBPosition*    pos = (wxGBPosition *) wxPli_sv_2_object( aTHX_ ST(2), "Wx::GBPosition" )
;
	wxGBSpan*	span;
	int	flag;
	int	border;
	wxObject*	userData;

	if (items < 4)
	    span = wxPlDefaultSpan;
	else {
    span = (wxGBSpan *) wxPli_sv_2_object( aTHX_ ST(3), "Wx::GBSpan" )
;
	}

	if (items < 5)
	    flag = 0;
	else {
	    flag = (int)SvIV(ST(4))
;
	}

	if (items < 6)
	    border = 0;
	else {
	    border = (int)SvIV(ST(5))
;
	}

	if (items < 7)
	    userData = NULL;
	else {
    userData = (wxObject *) wxPli_sv_2_object( aTHX_ ST(6), "Wx::Object" )
;
	}
    try {
      RETVAL = THIS->Add( sizer, *( pos ), *( span ), flag, border, userData );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__GridBagSizer_AddSpace); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__GridBagSizer_AddSpace)
{
    dVAR; dXSARGS;
    if (items < 4 || items > 8)
       croak_xs_usage(cv,  "THIS, width, height, pos, span= wxPlDefaultSpan, flag= 0, border= 0, userData= NULL");
    {
	wxGridBagSizer *    THIS = (wxGridBagSizer *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::GridBagSizer" )
;
	bool	RETVAL;
	int	width = (int)SvIV(ST(1))
;
	int	height = (int)SvIV(ST(2))
;
	wxGBPosition*    pos = (wxGBPosition *) wxPli_sv_2_object( aTHX_ ST(3), "Wx::GBPosition" )
;
	wxGBSpan*	span;
	int	flag;
	int	border;
	wxObject*	userData;

	if (items < 5)
	    span = wxPlDefaultSpan;
	else {
    span = (wxGBSpan *) wxPli_sv_2_object( aTHX_ ST(4), "Wx::GBSpan" )
;
	}

	if (items < 6)
	    flag = 0;
	else {
	    flag = (int)SvIV(ST(5))
;
	}

	if (items < 7)
	    border = 0;
	else {
	    border = (int)SvIV(ST(6))
;
	}

	if (items < 8)
	    userData = NULL;
	else {
    userData = (wxObject *) wxPli_sv_2_object( aTHX_ ST(7), "Wx::Object" )
;
	}
    try {
      RETVAL = THIS->Add( width, height, *( pos ), *( span ), flag, border, userData );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__GridBagSizer_AddItem); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__GridBagSizer_AddItem)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, item");
    {
	wxGridBagSizer *    THIS = (wxGridBagSizer *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::GridBagSizer" )
;
	bool	RETVAL;
	wxGBSizerItem*    item = (wxGBSizerItem *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::GBSizerItem" )
;
    try {
      RETVAL = THIS->Add( item );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__GridBagSizer_GetEmptyCellSize); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__GridBagSizer_GetEmptyCellSize)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxGridBagSizer *    THIS = (wxGridBagSizer *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::GridBagSizer" )
;
	wxSize	RETVAL;
    try {
      RETVAL = THIS->GetEmptyCellSize();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_non_object_2_sv( aTHX_ RETVALSV, new wxSize(RETVAL), "Wx::Size" );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__GridBagSizer_SetEmptyCellSize); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__GridBagSizer_SetEmptyCellSize)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, sz");
    {
	wxGridBagSizer *    THIS = (wxGridBagSizer *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::GridBagSizer" )
;
	wxSize    sz = wxPli_sv_2_wxsize( aTHX_ ST(1) )
;
    try {
      THIS->SetEmptyCellSize( sz );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__GridBagSizer_GetCellSize); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__GridBagSizer_GetCellSize)
{
    dVAR; dXSARGS;
    if (items != 3)
       croak_xs_usage(cv,  "THIS, row, col");
    {
	wxGridBagSizer *    THIS = (wxGridBagSizer *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::GridBagSizer" )
;
	wxSize	RETVAL;
	int	row = (int)SvIV(ST(1))
;
	int	col = (int)SvIV(ST(2))
;
    try {
      RETVAL = THIS->GetCellSize( row, col );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_non_object_2_sv( aTHX_ RETVALSV, new wxSize(RETVAL), "Wx::Size" );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__GridBagSizer_GetItemPositionWindow); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__GridBagSizer_GetItemPositionWindow)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, window");
    {
	wxGridBagSizer *    THIS = (wxGridBagSizer *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::GridBagSizer" )
;
	wxGBPosition *	RETVAL;
	wxWindow*    window = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::Window" )
;
    try {
      RETVAL = new wxGBPosition( THIS->GetItemPosition( window ) );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_non_object_2_sv( aTHX_ RETVALSV, RETVAL, "Wx::GBPosition" );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__GridBagSizer_GetItemPositionSizer); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__GridBagSizer_GetItemPositionSizer)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, sizer");
    {
	wxGridBagSizer *    THIS = (wxGridBagSizer *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::GridBagSizer" )
;
	wxGBPosition *	RETVAL;
	wxSizer*    sizer = (wxSizer *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::Sizer" )
;
    try {
      RETVAL = new wxGBPosition( THIS->GetItemPosition( sizer ) );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_non_object_2_sv( aTHX_ RETVALSV, RETVAL, "Wx::GBPosition" );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__GridBagSizer_GetItemPositionIndex); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__GridBagSizer_GetItemPositionIndex)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, index");
    {
	wxGridBagSizer *    THIS = (wxGridBagSizer *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::GridBagSizer" )
;
	wxGBPosition *	RETVAL;
	size_t    index = (size_t)SvUV( ST(1) )
;
    try {
      RETVAL = new wxGBPosition( THIS->GetItemPosition( index ) );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_non_object_2_sv( aTHX_ RETVALSV, RETVAL, "Wx::GBPosition" );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__GridBagSizer_GetItemPosition); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__GridBagSizer_GetItemPosition)
{
    dVAR; dXSARGS;
    if (items < 1)
       croak_xs_usage(cv,  "THIS, ...");
    PERL_UNUSED_VAR(ax); /* -Wall */
    SP -= items;
    {
	wxGridBagSizer *    THIS = (wxGridBagSizer *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::GridBagSizer" )
;
    BEGIN_OVERLOAD()
        MATCH_REDISP( wxPliOvl_wwin, GetItemPositionWindow )
        MATCH_REDISP( wxPliOvl_wszr, GetItemPositionSizer )
        MATCH_REDISP( wxPliOvl_n, GetItemPositionIndex )
    END_OVERLOAD( Wx::GridBagSizer::GetItemPosition )
	PUTBACK;
	return;
    }
}


XS_EUPXS(XS_Wx__GridBagSizer_SetItemPositionWindow); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__GridBagSizer_SetItemPositionWindow)
{
    dVAR; dXSARGS;
    if (items != 3)
       croak_xs_usage(cv,  "THIS, window, pos");
    {
	wxGridBagSizer *    THIS = (wxGridBagSizer *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::GridBagSizer" )
;
	bool	RETVAL;
	wxWindow*    window = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::Window" )
;
	wxGBPosition*    pos = (wxGBPosition *) wxPli_sv_2_object( aTHX_ ST(2), "Wx::GBPosition" )
;
    try {
      RETVAL = THIS->SetItemPosition( window, *( pos ) );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__GridBagSizer_SetItemPositionSizer); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__GridBagSizer_SetItemPositionSizer)
{
    dVAR; dXSARGS;
    if (items != 3)
       croak_xs_usage(cv,  "THIS, sizer, pos");
    {
	wxGridBagSizer *    THIS = (wxGridBagSizer *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::GridBagSizer" )
;
	bool	RETVAL;
	wxSizer*    sizer = (wxSizer *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::Sizer" )
;
	wxGBPosition*    pos = (wxGBPosition *) wxPli_sv_2_object( aTHX_ ST(2), "Wx::GBPosition" )
;
    try {
      RETVAL = THIS->SetItemPosition( sizer, *( pos ) );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__GridBagSizer_SetItemPositionIndex); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__GridBagSizer_SetItemPositionIndex)
{
    dVAR; dXSARGS;
    if (items != 3)
       croak_xs_usage(cv,  "THIS, index, pos");
    {
	wxGridBagSizer *    THIS = (wxGridBagSizer *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::GridBagSizer" )
;
	bool	RETVAL;
	size_t    index = (size_t)SvUV( ST(1) )
;
	wxGBPosition*    pos = (wxGBPosition *) wxPli_sv_2_object( aTHX_ ST(2), "Wx::GBPosition" )
;
    try {
      RETVAL = THIS->SetItemPosition( index, *( pos ) );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__GridBagSizer_SetItemPosition); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__GridBagSizer_SetItemPosition)
{
    dVAR; dXSARGS;
    if (items < 1)
       croak_xs_usage(cv,  "THIS, ...");
    PERL_UNUSED_VAR(ax); /* -Wall */
    SP -= items;
    {
	wxGridBagSizer *    THIS = (wxGridBagSizer *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::GridBagSizer" )
;
    BEGIN_OVERLOAD()
        MATCH_REDISP( wxPliOvl_wwin_wgbp, SetItemPositionWindow )
        MATCH_REDISP( wxPliOvl_wszr_wgbp, SetItemPositionSizer )
        MATCH_REDISP( wxPliOvl_n_wgbp, SetItemPositionIndex )
    END_OVERLOAD( Wx::GridBagSizer::SetItemPosition )
	PUTBACK;
	return;
    }
}


XS_EUPXS(XS_Wx__GridBagSizer_GetItemSpanWindow); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__GridBagSizer_GetItemSpanWindow)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, window");
    {
	wxGridBagSizer *    THIS = (wxGridBagSizer *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::GridBagSizer" )
;
	wxGBSpan *	RETVAL;
	wxWindow*    window = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::Window" )
;
    try {
      RETVAL = new wxGBSpan( THIS->GetItemSpan( window ) );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_non_object_2_sv( aTHX_ RETVALSV, RETVAL, "Wx::GBSpan" );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__GridBagSizer_GetItemSpanSizer); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__GridBagSizer_GetItemSpanSizer)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, sizer");
    {
	wxGridBagSizer *    THIS = (wxGridBagSizer *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::GridBagSizer" )
;
	wxGBSpan *	RETVAL;
	wxSizer*    sizer = (wxSizer *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::Sizer" )
;
    try {
      RETVAL = new wxGBSpan( THIS->GetItemSpan( sizer ) );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_non_object_2_sv( aTHX_ RETVALSV, RETVAL, "Wx::GBSpan" );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__GridBagSizer_GetItemSpanIndex); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__GridBagSizer_GetItemSpanIndex)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, index");
    {
	wxGridBagSizer *    THIS = (wxGridBagSizer *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::GridBagSizer" )
;
	wxGBSpan *	RETVAL;
	size_t    index = (size_t)SvUV( ST(1) )
;
    try {
      RETVAL = new wxGBSpan( THIS->GetItemSpan( index ) );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_non_object_2_sv( aTHX_ RETVALSV, RETVAL, "Wx::GBSpan" );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__GridBagSizer_GetItemSpan); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__GridBagSizer_GetItemSpan)
{
    dVAR; dXSARGS;
    if (items < 1)
       croak_xs_usage(cv,  "THIS, ...");
    PERL_UNUSED_VAR(ax); /* -Wall */
    SP -= items;
    {
	wxGridBagSizer *    THIS = (wxGridBagSizer *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::GridBagSizer" )
;
    BEGIN_OVERLOAD()
        MATCH_REDISP( wxPliOvl_wwin, GetItemSpanWindow )
        MATCH_REDISP( wxPliOvl_wszr, GetItemSpanSizer )
        MATCH_REDISP( wxPliOvl_n, GetItemSpanIndex )
    END_OVERLOAD( Wx::GridBagSizer::GetItemSpan )
	PUTBACK;
	return;
    }
}


XS_EUPXS(XS_Wx__GridBagSizer_SetItemSpanWindow); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__GridBagSizer_SetItemSpanWindow)
{
    dVAR; dXSARGS;
    if (items != 3)
       croak_xs_usage(cv,  "THIS, window, span");
    {
	wxGridBagSizer *    THIS = (wxGridBagSizer *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::GridBagSizer" )
;
	bool	RETVAL;
	wxWindow*    window = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::Window" )
;
	wxGBSpan*    span = (wxGBSpan *) wxPli_sv_2_object( aTHX_ ST(2), "Wx::GBSpan" )
;
    try {
      RETVAL = THIS->SetItemSpan( window, *( span ) );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__GridBagSizer_SetItemSpanSizer); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__GridBagSizer_SetItemSpanSizer)
{
    dVAR; dXSARGS;
    if (items != 3)
       croak_xs_usage(cv,  "THIS, sizer, span");
    {
	wxGridBagSizer *    THIS = (wxGridBagSizer *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::GridBagSizer" )
;
	bool	RETVAL;
	wxSizer*    sizer = (wxSizer *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::Sizer" )
;
	wxGBSpan*    span = (wxGBSpan *) wxPli_sv_2_object( aTHX_ ST(2), "Wx::GBSpan" )
;
    try {
      RETVAL = THIS->SetItemSpan( sizer, *( span ) );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__GridBagSizer_SetItemSpanIndex); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__GridBagSizer_SetItemSpanIndex)
{
    dVAR; dXSARGS;
    if (items != 3)
       croak_xs_usage(cv,  "THIS, index, span");
    {
	wxGridBagSizer *    THIS = (wxGridBagSizer *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::GridBagSizer" )
;
	bool	RETVAL;
	size_t    index = (size_t)SvUV( ST(1) )
;
	wxGBSpan*    span = (wxGBSpan *) wxPli_sv_2_object( aTHX_ ST(2), "Wx::GBSpan" )
;
    try {
      RETVAL = THIS->SetItemSpan( index, *( span ) );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__GridBagSizer_SetItemSpan); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__GridBagSizer_SetItemSpan)
{
    dVAR; dXSARGS;
    if (items < 1)
       croak_xs_usage(cv,  "THIS, ...");
    PERL_UNUSED_VAR(ax); /* -Wall */
    SP -= items;
    {
	wxGridBagSizer *    THIS = (wxGridBagSizer *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::GridBagSizer" )
;
    BEGIN_OVERLOAD()
        MATCH_REDISP( wxPliOvl_wwin_wgbs, SetItemSpanWindow )
        MATCH_REDISP( wxPliOvl_wszr_wgbs, SetItemSpanSizer )
        MATCH_REDISP( wxPliOvl_n_wgbs, SetItemSpanIndex )
    END_OVERLOAD( Wx::GridBagSizer::SetItemSpan )
	PUTBACK;
	return;
    }
}


XS_EUPXS(XS_Wx__GridBagSizer_FindItemWindow); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__GridBagSizer_FindItemWindow)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, window");
    {
	wxGridBagSizer *    THIS = (wxGridBagSizer *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::GridBagSizer" )
;
	wxGBSizerItem *	RETVAL;
	wxWindow*    window = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::Window" )
;
    try {
      RETVAL = THIS->FindItem( window );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_object_2_sv( aTHX_ RETVALSV, RETVAL );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__GridBagSizer_FindItemSizer); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__GridBagSizer_FindItemSizer)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, sizer");
    {
	wxGridBagSizer *    THIS = (wxGridBagSizer *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::GridBagSizer" )
;
	wxGBSizerItem *	RETVAL;
	wxSizer*    sizer = (wxSizer *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::Sizer" )
;
    try {
      RETVAL = THIS->FindItem( sizer );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_object_2_sv( aTHX_ RETVALSV, RETVAL );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__GridBagSizer_FindItem); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__GridBagSizer_FindItem)
{
    dVAR; dXSARGS;
    if (items < 1)
       croak_xs_usage(cv,  "THIS, ...");
    PERL_UNUSED_VAR(ax); /* -Wall */
    SP -= items;
    {
	wxGridBagSizer *    THIS = (wxGridBagSizer *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::GridBagSizer" )
;
    BEGIN_OVERLOAD()
        MATCH_REDISP( wxPliOvl_wwin, FindItemWindow )
        MATCH_REDISP( wxPliOvl_wszr, FindItemSizer )
    END_OVERLOAD( Wx::GridBagSizer::FindItem )
	PUTBACK;
	return;
    }
}


XS_EUPXS(XS_Wx__GridBagSizer_FindItemAtPosition); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__GridBagSizer_FindItemAtPosition)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, pos");
    {
	wxGridBagSizer *    THIS = (wxGridBagSizer *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::GridBagSizer" )
;
	wxGBSizerItem *	RETVAL;
	wxGBPosition*    pos = (wxGBPosition *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::GBPosition" )
;
    try {
      RETVAL = THIS->FindItemAtPosition( *( pos ) );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_object_2_sv( aTHX_ RETVALSV, RETVAL );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__GridBagSizer_FindItemAtPoint); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__GridBagSizer_FindItemAtPoint)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, pt");
    {
	wxGridBagSizer *    THIS = (wxGridBagSizer *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::GridBagSizer" )
;
	wxGBSizerItem *	RETVAL;
	wxPoint    pt = wxPli_sv_2_wxpoint( aTHX_ ST(1) )
;
    try {
      RETVAL = THIS->FindItemAtPoint( pt );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_object_2_sv( aTHX_ RETVALSV, RETVAL );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__GridBagSizer_CheckForIntersectionItem); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__GridBagSizer_CheckForIntersectionItem)
{
    dVAR; dXSARGS;
    if (items < 2 || items > 3)
       croak_xs_usage(cv,  "THIS, item, excludeItem= NULL");
    {
	wxGridBagSizer *    THIS = (wxGridBagSizer *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::GridBagSizer" )
;
	bool	RETVAL;
	wxGBSizerItem*    item = (wxGBSizerItem *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::GBSizerItem" )
;
	wxGBSizerItem*	excludeItem;

	if (items < 3)
	    excludeItem = NULL;
	else {
    excludeItem = (wxGBSizerItem *) wxPli_sv_2_object( aTHX_ ST(2), "Wx::GBSizerItem" )
;
	}
    try {
      RETVAL = THIS->CheckForIntersection( item, excludeItem );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__GridBagSizer_CheckForIntersectionPos); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__GridBagSizer_CheckForIntersectionPos)
{
    dVAR; dXSARGS;
    if (items < 3 || items > 4)
       croak_xs_usage(cv,  "THIS, pos, span, excludeItem= NULL");
    {
	wxGridBagSizer *    THIS = (wxGridBagSizer *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::GridBagSizer" )
;
	bool	RETVAL;
	wxGBPosition*    pos = (wxGBPosition *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::GBPosition" )
;
	wxGBSpan*    span = (wxGBSpan *) wxPli_sv_2_object( aTHX_ ST(2), "Wx::GBSpan" )
;
	wxGBSizerItem*	excludeItem;

	if (items < 4)
	    excludeItem = NULL;
	else {
    excludeItem = (wxGBSizerItem *) wxPli_sv_2_object( aTHX_ ST(3), "Wx::GBSizerItem" )
;
	}
    try {
      RETVAL = THIS->CheckForIntersection( *( pos ), *( span ), excludeItem );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__GridBagSizer_CheckForIntersection); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__GridBagSizer_CheckForIntersection)
{
    dVAR; dXSARGS;
    if (items < 1)
       croak_xs_usage(cv,  "THIS, ...");
    PERL_UNUSED_VAR(ax); /* -Wall */
    SP -= items;
    {
	wxGridBagSizer *    THIS = (wxGridBagSizer *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::GridBagSizer" )
;
    BEGIN_OVERLOAD()
        MATCH_REDISP_COUNT_ALLOWMORE( wxPliOvl_wgbi_wgbi, CheckForIntersectionItem, 1 )
        MATCH_REDISP_COUNT_ALLOWMORE( wxPliOvl_wgbp_wgbs_wgbi, CheckForIntersectionPos, 2 )
    END_OVERLOAD( Wx::GridBagSizer::CheckForIntersection )
	PUTBACK;
	return;
    }
}


XS_EUPXS(XS_Wx__GridBagSizer_Add); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__GridBagSizer_Add)
{
    dVAR; dXSARGS;
    if (items < 1)
       croak_xs_usage(cv,  "THIS, ...");
    PERL_UNUSED_VAR(ax); /* -Wall */
    SP -= items;
    {
	wxGridBagSizer *    THIS = (wxGridBagSizer *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::GridBagSizer" )
;
    BEGIN_OVERLOAD()
        MATCH_REDISP_COUNT_ALLOWMORE( wxPliOvl_wwin_wgbp_wgbs_n_n_s, AddWindow, 1 )
        MATCH_REDISP_COUNT_ALLOWMORE( wxPliOvl_wszr_wgbp_wgbs_n_n_s, AddSizer, 1 )
        MATCH_REDISP_COUNT_ALLOWMORE( wxPliOvl_n_n_wgbp_wgbs_n_n_s, AddSpace, 2 )
        MATCH_REDISP_COUNT( wxPliOvl_wgbi, AddItem, 1 )
    END_OVERLOAD( Wx::GridBagSizer::Add )
	PUTBACK;
	return;
    }
}

#endif

/* INCLUDE: Returning to 'Window.xs' from '/usr/bin/perl -I./ -MExtUtils::XSpp::Cmd -e xspp -- -t typemap.xsp XS/GridBagSizer.xsp' */


/* INCLUDE:  Including 'XS/SashWindow.xs' from 'Window.xs' */

#include <wx/sashwin.h>

XS_EUPXS(XS_Wx__SashEvent_new); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__SashEvent_new)
{
    dVAR; dXSARGS;
    if (items < 1 || items > 3)
       croak_xs_usage(cv,  "CLASS, id = 0, edge = wxSASH_NONE");
    {
	int	id;
	wxSashEdgePosition	edge;
	char *	CLASS = (char *)SvPV_nolen(ST(0))
;
	wxSashEvent *	RETVAL;

	if (items < 2)
	    id = 0;
	else {
	    id = (int)SvIV(ST(1))
;
	}

	if (items < 3)
	    edge = wxSASH_NONE;
	else {
	    edge = (wxSashEdgePosition)SvIV(ST(2))
;
	}

	RETVAL = new wxSashEvent(id, edge);
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_object_2_sv( aTHX_ RETVALSV, RETVAL );
    wxPli_thread_sv_register( aTHX_ "Wx::SashEvent", RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__SashEvent_GetEdge); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__SashEvent_GetEdge)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxSashEvent *    THIS = (wxSashEvent *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::SashEvent" )
;
	wxSashEdgePosition	RETVAL;
	dXSTARG;

	RETVAL = THIS->GetEdge();
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__SashEvent_GetDragRect); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__SashEvent_GetDragRect)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxSashEvent *    THIS = (wxSashEvent *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::SashEvent" )
;
	wxRect *	RETVAL;
    RETVAL = new wxRect( THIS->GetDragRect() );
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_non_object_2_sv( aTHX_ RETVALSV, RETVAL, "Wx::Rect" );
    wxPli_thread_sv_register( aTHX_ "Wx::Rect", RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__SashEvent_GetDragStatus); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__SashEvent_GetDragStatus)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxSashEvent *    THIS = (wxSashEvent *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::SashEvent" )
;
	wxSashDragStatus	RETVAL;
	dXSTARG;

	RETVAL = THIS->GetDragStatus();
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__SashWindow_new); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__SashWindow_new)
{
    dVAR; dXSARGS;
    PERL_UNUSED_VAR(cv); /* -W */
    PERL_UNUSED_VAR(items); /* -W */
    PERL_UNUSED_VAR(ax); /* -Wall */
    SP -= items;
    {
    BEGIN_OVERLOAD()
        MATCH_VOIDM_REDISP( newDefault )
        MATCH_ANY_REDISP( newFull )
    END_OVERLOAD( "Wx::SashWindow::new" )
	PUTBACK;
	return;
    }
}


XS_EUPXS(XS_Wx__SashWindow_newDefault); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__SashWindow_newDefault)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "CLASS");
    {
	PlClassName    CLASS = wxPli_get_class( aTHX_ ST(0) )
;
	wxSashWindow *	RETVAL;
    RETVAL = new wxSashWindow();
    wxPli_create_evthandler( aTHX_ RETVAL, CLASS );
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_evthandler_2_sv( aTHX_ RETVALSV, RETVAL );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__SashWindow_newFull); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__SashWindow_newFull)
{
    dVAR; dXSARGS;
    if (items < 2 || items > 7)
       croak_xs_usage(cv,  "CLASS, parent, id = wxID_ANY, pos = wxDefaultPosition, size = wxDefaultSize, style = wxCLIP_CHILDREN|wxSW_3D, name = wxT(\"sashWindow\")");
    {
	PlClassName    CLASS = wxPli_get_class( aTHX_ ST(0) )
;
	wxWindow*    parent = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::Window" )
;
	wxWindowID	id;
	wxPoint	pos;
	wxSize	size;
	long	style;
	wxString	name;
	wxSashWindow *	RETVAL;

	if (items < 3)
	    id = wxID_ANY;
	else {
    id = wxPli_get_wxwindowid( aTHX_ ST(2) )
;
	}

	if (items < 4)
	    pos = wxDefaultPosition;
	else {
    pos = wxPli_sv_2_wxpoint( aTHX_ ST(3) )
;
	}

	if (items < 5)
	    size = wxDefaultSize;
	else {
    size = wxPli_sv_2_wxsize( aTHX_ ST(4) )
;
	}

	if (items < 6)
	    style = wxCLIP_CHILDREN|wxSW_3D;
	else {
	    style = (long)SvIV(ST(5))
;
	}

	if (items < 7)
	    name = wxT("sashWindow");
	else {
    WXSTRING_INPUT( name, wxString, ST(6) )
;
	}
    RETVAL = new wxSashWindow( parent, id, pos, size, style, name );
    wxPli_create_evthandler( aTHX_ RETVAL, CLASS );
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_evthandler_2_sv( aTHX_ RETVALSV, RETVAL );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__SashWindow_Create); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__SashWindow_Create)
{
    dVAR; dXSARGS;
    if (items < 2 || items > 7)
       croak_xs_usage(cv,  "THIS, parent, id = wxID_ANY, pos = wxDefaultPosition, size = wxDefaultSize, style = wxCLIP_CHILDREN|wxSW_3D, name = wxT(\"sashWindow\")");
    {
	wxWindow*    parent = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::Window" )
;
	wxWindowID	id;
	wxPoint	pos;
	wxSize	size;
	long	style;
	wxString	name;
	wxSashWindow *    THIS = (wxSashWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::SashWindow" )
;
	bool	RETVAL;

	if (items < 3)
	    id = wxID_ANY;
	else {
    id = wxPli_get_wxwindowid( aTHX_ ST(2) )
;
	}

	if (items < 4)
	    pos = wxDefaultPosition;
	else {
    pos = wxPli_sv_2_wxpoint( aTHX_ ST(3) )
;
	}

	if (items < 5)
	    size = wxDefaultSize;
	else {
    size = wxPli_sv_2_wxsize( aTHX_ ST(4) )
;
	}

	if (items < 6)
	    style = wxCLIP_CHILDREN|wxSW_3D;
	else {
	    style = (long)SvIV(ST(5))
;
	}

	if (items < 7)
	    name = wxT("sashWindow");
	else {
    WXSTRING_INPUT( name, wxString, ST(6) )
;
	}

	RETVAL = THIS->Create(parent, id, pos, size, style, name);
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__SashWindow_GetSashVisible); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__SashWindow_GetSashVisible)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, edge");
    {
	wxSashEdgePosition	edge = (wxSashEdgePosition)SvIV(ST(1))
;
	wxSashWindow *    THIS = (wxSashWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::SashWindow" )
;
	bool	RETVAL;

	RETVAL = THIS->GetSashVisible(edge);
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__SashWindow_GetMaximumSizeX); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__SashWindow_GetMaximumSizeX)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxSashWindow *    THIS = (wxSashWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::SashWindow" )
;
	int	RETVAL;
	dXSTARG;

	RETVAL = THIS->GetMaximumSizeX();
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__SashWindow_GetMaximumSizeY); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__SashWindow_GetMaximumSizeY)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxSashWindow *    THIS = (wxSashWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::SashWindow" )
;
	int	RETVAL;
	dXSTARG;

	RETVAL = THIS->GetMaximumSizeY();
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__SashWindow_GetMinimumSizeX); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__SashWindow_GetMinimumSizeX)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxSashWindow *    THIS = (wxSashWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::SashWindow" )
;
	int	RETVAL;
	dXSTARG;

	RETVAL = THIS->GetMinimumSizeX();
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__SashWindow_GetMinimumSizeY); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__SashWindow_GetMinimumSizeY)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxSashWindow *    THIS = (wxSashWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::SashWindow" )
;
	int	RETVAL;
	dXSTARG;

	RETVAL = THIS->GetMinimumSizeY();
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}

#if WXPERL_W_VERSION_LT( 2, 7, 0 )
#define XSubPPtmpAAEZ 1


XS_EUPXS(XS_Wx__SashWindow_HasBorder); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__SashWindow_HasBorder)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, edge");
    {
	wxSashEdgePosition	edge = (wxSashEdgePosition)SvIV(ST(1))
;
	wxSashWindow *    THIS = (wxSashWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::SashWindow" )
;
	bool	RETVAL;

	RETVAL = THIS->HasBorder(edge);
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}

#endif

XS_EUPXS(XS_Wx__SashWindow_SetMaximumSizeX); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__SashWindow_SetMaximumSizeX)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, max");
    {
	int	max = (int)SvIV(ST(1))
;
	wxSashWindow *    THIS = (wxSashWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::SashWindow" )
;

	THIS->SetMaximumSizeX(max);
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__SashWindow_SetMaximumSizeY); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__SashWindow_SetMaximumSizeY)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, max");
    {
	int	max = (int)SvIV(ST(1))
;
	wxSashWindow *    THIS = (wxSashWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::SashWindow" )
;

	THIS->SetMaximumSizeY(max);
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__SashWindow_SetMinimumSizeX); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__SashWindow_SetMinimumSizeX)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, min");
    {
	int	min = (int)SvIV(ST(1))
;
	wxSashWindow *    THIS = (wxSashWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::SashWindow" )
;

	THIS->SetMinimumSizeX(min);
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__SashWindow_SetMinimumSizeY); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__SashWindow_SetMinimumSizeY)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, min");
    {
	int	min = (int)SvIV(ST(1))
;
	wxSashWindow *    THIS = (wxSashWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::SashWindow" )
;

	THIS->SetMinimumSizeY(min);
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__SashWindow_SetSashVisible); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__SashWindow_SetSashVisible)
{
    dVAR; dXSARGS;
    if (items != 3)
       croak_xs_usage(cv,  "THIS, edge, visible");
    {
	wxSashEdgePosition	edge = (wxSashEdgePosition)SvIV(ST(1))
;
	bool	visible = (bool)SvTRUE(ST(2))
;
	wxSashWindow *    THIS = (wxSashWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::SashWindow" )
;

	THIS->SetSashVisible(edge, visible);
    }
    XSRETURN_EMPTY;
}

#if WXPERL_W_VERSION_LT( 2, 7, 0 )
#define XSubPPtmpAAFA 1


XS_EUPXS(XS_Wx__SashWindow_SetSashBorder); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__SashWindow_SetSashBorder)
{
    dVAR; dXSARGS;
    if (items != 3)
       croak_xs_usage(cv,  "THIS, edge, border");
    {
	wxSashEdgePosition	edge = (wxSashEdgePosition)SvIV(ST(1))
;
	bool	border = (bool)SvTRUE(ST(2))
;
	wxSashWindow *    THIS = (wxSashWindow *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::SashWindow" )
;

	THIS->SetSashBorder(edge, border);
    }
    XSRETURN_EMPTY;
}

#endif

/* INCLUDE: Returning to 'Window.xs' from 'XS/SashWindow.xs' */

#ifdef __cplusplus
extern "C"
#endif
XS_EXTERNAL(boot_Wx_Win); /* prototype to pass -Wmissing-prototypes */
XS_EXTERNAL(boot_Wx_Win)
{
#if PERL_VERSION_LE(5, 21, 5)
    dVAR; dXSARGS;
#else
    dVAR; dXSBOOTARGSXSAPIVERCHK;
#endif
#if PERL_VERSION_LE(5, 8, 999) /* PERL_VERSION_LT is 5.33+ */
    char* file = __FILE__;
#else
    const char* file = __FILE__;
#endif

    PERL_UNUSED_VAR(file);

    PERL_UNUSED_VAR(cv); /* -W */
    PERL_UNUSED_VAR(items); /* -W */
#if PERL_VERSION_LE(5, 21, 5)
    XS_VERSION_BOOTCHECK;
#  ifdef XS_APIVERSION_BOOTCHECK
    XS_APIVERSION_BOOTCHECK;
#  endif
#endif

        newXS_deffile("Wx::GetMousePosition", XS_Wx_GetMousePosition);
        newXS_deffile("Wx::GetMousePositionXY", XS_Wx_GetMousePositionXY);
        newXS_deffile("Wx::GetTopLevelParent", XS_Wx_GetTopLevelParent);
        newXS_deffile("Wx::FindWindowAtPointer", XS_Wx_FindWindowAtPointer);
        newXS_deffile("Wx::GetActiveWindow", XS_Wx_GetActiveWindow);
#if XSubPPtmpAAAA
        newXS_deffile("Wx::Window::NewControlId", XS_Wx__Window_NewControlId);
        newXS_deffile("Wx::Window::NextControlId", XS_Wx__Window_NextControlId);
        newXS_deffile("Wx::Window::PrevControlId", XS_Wx__Window_PrevControlId);
#endif
#if XSubPPtmpAAAB
        newXS_deffile("Wx::Window::NewControlId", XS_Wx__Window_NewControlId);
        newXS_deffile("Wx::Window::UnreserveControlId", XS_Wx__Window_UnreserveControlId);
#endif
        newXS_deffile("Wx::Window::new", XS_Wx__Window_new);
        newXS_deffile("Wx::Window::newDefault", XS_Wx__Window_newDefault);
        newXS_deffile("Wx::Window::newFull", XS_Wx__Window_newFull);
        newXS_deffile("Wx::Window::Create", XS_Wx__Window_Create);
        newXS_deffile("Wx::Window::CaptureMouse", XS_Wx__Window_CaptureMouse);
        newXS_deffile("Wx::Window::Centre", XS_Wx__Window_Centre);
        newXS_deffile("Wx::Window::CentreOnParent", XS_Wx__Window_CentreOnParent);
#if XSubPPtmpAAAC
        newXS_deffile("Wx::Window::CentreOnScreen", XS_Wx__Window_CentreOnScreen);
#endif
#if XSubPPtmpAAAD
        newXS_deffile("Wx::Window::CentreOnScreen", XS_Wx__Window_CentreOnScreen);
#endif
#if XSubPPtmpAAAE
        newXS_deffile("Wx::Window::ClearBackground", XS_Wx__Window_ClearBackground);
#endif
#if XSubPPtmpAAAF
        newXS_deffile("Wx::Window::Clear", XS_Wx__Window_Clear);
#endif
        newXS_deffile("Wx::Window::ClientToScreen", XS_Wx__Window_ClientToScreen);
        newXS_deffile("Wx::Window::ClientToScreenPoint", XS_Wx__Window_ClientToScreenPoint);
        newXS_deffile("Wx::Window::ClientToScreenXY", XS_Wx__Window_ClientToScreenXY);
        newXS_deffile("Wx::Window::Close", XS_Wx__Window_Close);
        newXS_deffile("Wx::Window::ConvertDialogToPixels", XS_Wx__Window_ConvertDialogToPixels);
        newXS_deffile("Wx::Window::ConvertDialogPointToPixels", XS_Wx__Window_ConvertDialogPointToPixels);
        newXS_deffile("Wx::Window::ConvertDialogSizeToPixels", XS_Wx__Window_ConvertDialogSizeToPixels);
        newXS_deffile("Wx::Window::ConvertPixelsToDialog", XS_Wx__Window_ConvertPixelsToDialog);
        newXS_deffile("Wx::Window::ConvertPixelsPointToDialog", XS_Wx__Window_ConvertPixelsPointToDialog);
        newXS_deffile("Wx::Window::ConvertPixelsSizeToDialog", XS_Wx__Window_ConvertPixelsSizeToDialog);
        newXS_deffile("Wx::Window::Destroy", XS_Wx__Window_Destroy);
#if XSubPPtmpAAAG
        newXS_deffile("Wx::Window::DragAcceptFiles", XS_Wx__Window_DragAcceptFiles);
#endif
        newXS_deffile("Wx::Window::Enable", XS_Wx__Window_Enable);
        newXS_deffile("Wx::Window::Disable", XS_Wx__Window_Disable);
        newXS_deffile("Wx::Window::FindFocus", XS_Wx__Window_FindFocus);
        newXS_deffile("Wx::Window::FindWindow", XS_Wx__Window_FindWindow);
        newXS_deffile("Wx::Window::FindWindowById", XS_Wx__Window_FindWindowById);
        newXS_deffile("Wx::Window::FindWindowByName", XS_Wx__Window_FindWindowByName);
        newXS_deffile("Wx::Window::FindWindowByLabel", XS_Wx__Window_FindWindowByLabel);
        newXS_deffile("Wx::Window::Fit", XS_Wx__Window_Fit);
        newXS_deffile("Wx::Window::FitInside", XS_Wx__Window_FitInside);
        newXS_deffile("Wx::Window::Freeze", XS_Wx__Window_Freeze);
#if XSubPPtmpAAAH
        newXS_deffile("Wx::Window::IsFrozen", XS_Wx__Window_IsFrozen);
#endif
        newXS_deffile("Wx::Window::GetAcceleratorTable", XS_Wx__Window_GetAcceleratorTable);
#if XSubPPtmpAAAI
        newXS_deffile("Wx::Window::GetBackgroundStyle", XS_Wx__Window_GetBackgroundStyle);
#endif
        newXS_deffile("Wx::Window::GetBackgroundColour", XS_Wx__Window_GetBackgroundColour);
        newXS_deffile("Wx::Window::GetBestSize", XS_Wx__Window_GetBestSize);
        newXS_deffile("Wx::Window::GetCaret", XS_Wx__Window_GetCaret);
        newXS_deffile("Wx::Window::GetCharHeight", XS_Wx__Window_GetCharHeight);
        newXS_deffile("Wx::Window::GetCharWidth", XS_Wx__Window_GetCharWidth);
        newXS_deffile("Wx::Window::GetChildren", XS_Wx__Window_GetChildren);
        newXS_deffile("Wx::Window::GetClientSize", XS_Wx__Window_GetClientSize);
        newXS_deffile("Wx::Window::GetClientSizeXY", XS_Wx__Window_GetClientSizeXY);
        newXS_deffile("Wx::Window::GetContainingSizer", XS_Wx__Window_GetContainingSizer);
#if XSubPPtmpAAAJ
        newXS_deffile("Wx::Window::GetDropTarget", XS_Wx__Window_GetDropTarget);
#endif
#if XSubPPtmpAAAK
        newXS_deffile("Wx::Window::GetDefaultItem", XS_Wx__Window_GetDefaultItem);
#endif
        newXS_deffile("Wx::Window::GetEventHandler", XS_Wx__Window_GetEventHandler);
        newXS_deffile("Wx::Window::GetExtraStyle", XS_Wx__Window_GetExtraStyle);
        newXS_deffile("Wx::Window::GetFont", XS_Wx__Window_GetFont);
        newXS_deffile("Wx::Window::GetForegroundColour", XS_Wx__Window_GetForegroundColour);
        newXS_deffile("Wx::Window::GetGrandParent", XS_Wx__Window_GetGrandParent);
#if XSubPPtmpAAAL
        newXS_deffile("Wx::Window::CreateWindowFromHWND", XS_Wx__Window_CreateWindowFromHWND);
#endif
#if XSubPPtmpAAAM
        newXS_deffile("Wx::Window::GetHandle", XS_Wx__Window_GetHandle);
#endif
#if XSubPPtmpAAAN
        newXS_deffile("Wx::Window::GetHandle", XS_Wx__Window_GetHandle);
#endif
        newXS_deffile("Wx::Window::GetHelpText", XS_Wx__Window_GetHelpText);
        newXS_deffile("Wx::Window::GetId", XS_Wx__Window_GetId);
        newXS_deffile("Wx::Window::GetLabel", XS_Wx__Window_GetLabel);
        newXS_deffile("Wx::Window::GetConstraints", XS_Wx__Window_GetConstraints);
#if XSubPPtmpAAAO
        newXS_deffile("Wx::Window::GetMinSize", XS_Wx__Window_GetMinSize);
        newXS_deffile("Wx::Window::GetMaxSize", XS_Wx__Window_GetMaxSize);
#endif
        newXS_deffile("Wx::Window::GetName", XS_Wx__Window_GetName);
        newXS_deffile("Wx::Window::GetParent", XS_Wx__Window_GetParent);
        newXS_deffile("Wx::Window::GetPosition", XS_Wx__Window_GetPosition);
        newXS_deffile("Wx::Window::GetPositionXY", XS_Wx__Window_GetPositionXY);
        newXS_deffile("Wx::Window::GetRect", XS_Wx__Window_GetRect);
        newXS_deffile("Wx::Window::GetScrollThumb", XS_Wx__Window_GetScrollThumb);
        newXS_deffile("Wx::Window::GetScrollPos", XS_Wx__Window_GetScrollPos);
        newXS_deffile("Wx::Window::GetScrollRange", XS_Wx__Window_GetScrollRange);
        newXS_deffile("Wx::Window::GetSize", XS_Wx__Window_GetSize);
        newXS_deffile("Wx::Window::GetSizer", XS_Wx__Window_GetSizer);
        newXS_deffile("Wx::Window::GetSizeWH", XS_Wx__Window_GetSizeWH);
        newXS_deffile("Wx::Window::GetTextExtent", XS_Wx__Window_GetTextExtent);
#if XSubPPtmpAAAP
        newXS_deffile("Wx::Window::GetTitle", XS_Wx__Window_GetTitle);
#endif
#if XSubPPtmpAAAQ
        newXS_deffile("Wx::Window::GetTitle", XS_Wx__Window_GetTitle);
#endif
#if XSubPPtmpAAAR
        newXS_deffile("Wx::Window::GetToolTip", XS_Wx__Window_GetToolTip);
#endif
        newXS_deffile("Wx::Window::GetUpdateRegion", XS_Wx__Window_GetUpdateRegion);
        newXS_deffile("Wx::Window::GetValidator", XS_Wx__Window_GetValidator);
        newXS_deffile("Wx::Window::GetWindowStyleFlag", XS_Wx__Window_GetWindowStyleFlag);
#if XSubPPtmpAAAS
        newXS_deffile("Wx::Window::GetWindowBorderSize", XS_Wx__Window_GetWindowBorderSize);
#endif
#if XSubPPtmpAAAT
        newXS_deffile("Wx::Window::InvalidateBestSize", XS_Wx__Window_InvalidateBestSize);
        newXS_deffile("Wx::Window::InheritAttributes", XS_Wx__Window_InheritAttributes);
#endif
        newXS_deffile("Wx::Window::IsEnabled", XS_Wx__Window_IsEnabled);
#if XSubPPtmpAAAU
        newXS_deffile("Wx::Window::IsThisEnabled", XS_Wx__Window_IsThisEnabled);
#endif
#if XSubPPtmpAAAV
        newXS_deffile("Wx::Window::GetContentScaleFactor", XS_Wx__Window_GetContentScaleFactor);
#endif
        newXS_deffile("Wx::Window::IsExposed", XS_Wx__Window_IsExposed);
        newXS_deffile("Wx::Window::IsExposedXYWH", XS_Wx__Window_IsExposedXYWH);
        newXS_deffile("Wx::Window::IsExposedPoint", XS_Wx__Window_IsExposedPoint);
        newXS_deffile("Wx::Window::IsExposedRect", XS_Wx__Window_IsExposedRect);
        newXS_deffile("Wx::Window::IsRetained", XS_Wx__Window_IsRetained);
        newXS_deffile("Wx::Window::IsShown", XS_Wx__Window_IsShown);
        newXS_deffile("Wx::Window::IsTopLevel", XS_Wx__Window_IsTopLevel);
#if XSubPPtmpAAAW
        newXS_deffile("Wx::Window::IsDoubleBuffered", XS_Wx__Window_IsDoubleBuffered);
        newXS_deffile("Wx::Window::IsShownOnScreen", XS_Wx__Window_IsShownOnScreen);
#endif
        newXS_deffile("Wx::Window::Layout", XS_Wx__Window_Layout);
        newXS_deffile("Wx::Window::Lower", XS_Wx__Window_Lower);
        newXS_deffile("Wx::Window::MakeModal", XS_Wx__Window_MakeModal);
        newXS_deffile("Wx::Window::Move", XS_Wx__Window_Move);
        newXS_deffile("Wx::Window::MoveXY", XS_Wx__Window_MoveXY);
        newXS_deffile("Wx::Window::MovePoint", XS_Wx__Window_MovePoint);
#if XSubPPtmpAAAX
        newXS_deffile("Wx::Window::MoveBeforeInTabOrder", XS_Wx__Window_MoveBeforeInTabOrder);
        newXS_deffile("Wx::Window::MoveAfterInTabOrder", XS_Wx__Window_MoveAfterInTabOrder);
#endif
#if XSubPPtmpAAAY
        newXS_deffile("Wx::Window::NavigateIn", XS_Wx__Window_NavigateIn);
#endif
        newXS_deffile("Wx::Window::Navigate", XS_Wx__Window_Navigate);
        newXS_deffile("Wx::Window::PopEventHandler", XS_Wx__Window_PopEventHandler);
        newXS_deffile("Wx::Window::PopupMenu", XS_Wx__Window_PopupMenu);
        newXS_deffile("Wx::Window::PopupMenuPoint", XS_Wx__Window_PopupMenuPoint);
        newXS_deffile("Wx::Window::PopupMenuXY", XS_Wx__Window_PopupMenuXY);
        newXS_deffile("Wx::Window::PushEventHandler", XS_Wx__Window_PushEventHandler);
        newXS_deffile("Wx::Window::Raise", XS_Wx__Window_Raise);
        newXS_deffile("Wx::Window::Refresh", XS_Wx__Window_Refresh);
        newXS_deffile("Wx::Window::ReleaseMouse", XS_Wx__Window_ReleaseMouse);
        newXS_deffile("Wx::Window::RemoveEventHandler", XS_Wx__Window_RemoveEventHandler);
        newXS_deffile("Wx::Window::Reparent", XS_Wx__Window_Reparent);
        newXS_deffile("Wx::Window::ScreenToClient", XS_Wx__Window_ScreenToClient);
        newXS_deffile("Wx::Window::ScreenToClientPoint", XS_Wx__Window_ScreenToClientPoint);
        newXS_deffile("Wx::Window::ScreenToClientXY", XS_Wx__Window_ScreenToClientXY);
        newXS_deffile("Wx::Window::ScrollLines", XS_Wx__Window_ScrollLines);
        newXS_deffile("Wx::Window::ScrollPages", XS_Wx__Window_ScrollPages);
        newXS_deffile("Wx::Window::ScrollWindow", XS_Wx__Window_ScrollWindow);
        newXS_deffile("Wx::Window::SetAcceleratorTable", XS_Wx__Window_SetAcceleratorTable);
        newXS_deffile("Wx::Window::SetAutoLayout", XS_Wx__Window_SetAutoLayout);
#if XSubPPtmpAAAZ
        newXS_deffile("Wx::Window::SetThemeEnabled", XS_Wx__Window_SetThemeEnabled);
#endif
#if XSubPPtmpAABA
        newXS_deffile("Wx::Window::SetBackgroundStyle", XS_Wx__Window_SetBackgroundStyle);
#endif
#if XSubPPtmpAABB
        newXS_deffile("Wx::Window::SetBestFittingSize", XS_Wx__Window_SetBestFittingSize);
#endif
#if XSubPPtmpAABC
        newXS_deffile("Wx::Window::SetInitialSize", XS_Wx__Window_SetInitialSize);
#endif
        newXS_deffile("Wx::Window::SetCaret", XS_Wx__Window_SetCaret);
        newXS_deffile("Wx::Window::SetClientSize", XS_Wx__Window_SetClientSize);
        newXS_deffile("Wx::Window::SetClientSizeSize", XS_Wx__Window_SetClientSizeSize);
        newXS_deffile("Wx::Window::SetClientSizeWH", XS_Wx__Window_SetClientSizeWH);
        newXS_deffile("Wx::Window::SetConstraints", XS_Wx__Window_SetConstraints);
        newXS_deffile("Wx::Window::SetContainingSizer", XS_Wx__Window_SetContainingSizer);
#if XSubPPtmpAABD
        newXS_deffile("Wx::Window::SetDefaultItem", XS_Wx__Window_SetDefaultItem);
#endif
#if XSubPPtmpAABE
        newXS_deffile("Wx::Window::SetDropTarget", XS_Wx__Window_SetDropTarget);
#endif
        newXS_deffile("Wx::Window::SetEventHandler", XS_Wx__Window_SetEventHandler);
        newXS_deffile("Wx::Window::SetExtraStyle", XS_Wx__Window_SetExtraStyle);
        newXS_deffile("Wx::Window::SetFocus", XS_Wx__Window_SetFocus);
        newXS_deffile("Wx::Window::SetHelpText", XS_Wx__Window_SetHelpText);
#if XSubPPtmpAABF
        newXS_deffile("Wx::Window::SetHelpTextForId", XS_Wx__Window_SetHelpTextForId);
#endif
        newXS_deffile("Wx::Window::SetId", XS_Wx__Window_SetId);
        newXS_deffile("Wx::Window::SetLabel", XS_Wx__Window_SetLabel);
        newXS_deffile("Wx::Window::SetName", XS_Wx__Window_SetName);
        newXS_deffile("Wx::Window::SetScrollbar", XS_Wx__Window_SetScrollbar);
        newXS_deffile("Wx::Window::SetScrollPos", XS_Wx__Window_SetScrollPos);
#if XSubPPtmpAABG
        newXS_deffile("Wx::Window::SetMinSize", XS_Wx__Window_SetMinSize);
        newXS_deffile("Wx::Window::SetMaxSize", XS_Wx__Window_SetMaxSize);
#endif
        newXS_deffile("Wx::Window::SetSize", XS_Wx__Window_SetSize);
        newXS_deffile("Wx::Window::SetSizeSize", XS_Wx__Window_SetSizeSize);
        newXS_deffile("Wx::Window::SetSizeRect", XS_Wx__Window_SetSizeRect);
        newXS_deffile("Wx::Window::SetSizeWH", XS_Wx__Window_SetSizeWH);
        newXS_deffile("Wx::Window::SetSizeXYWHF", XS_Wx__Window_SetSizeXYWHF);
        newXS_deffile("Wx::Window::SetSizeHints", XS_Wx__Window_SetSizeHints);
#if XSubPPtmpAABH
        newXS_deffile("Wx::Window::SetVirtualSizeHints", XS_Wx__Window_SetVirtualSizeHints);
#endif
        newXS_deffile("Wx::Window::SetVirtualSize", XS_Wx__Window_SetVirtualSize);
        newXS_deffile("Wx::Window::SetVirtualSizeXY", XS_Wx__Window_SetVirtualSizeXY);
        newXS_deffile("Wx::Window::SetVirtualSizeSize", XS_Wx__Window_SetVirtualSizeSize);
        newXS_deffile("Wx::Window::SetSizer", XS_Wx__Window_SetSizer);
        newXS_deffile("Wx::Window::SetSizerAndFit", XS_Wx__Window_SetSizerAndFit);
#if XSubPPtmpAABI
        newXS_deffile("Wx::Window::SetTitle", XS_Wx__Window_SetTitle);
#endif
#if XSubPPtmpAABJ
        newXS_deffile("Wx::Window::SetTitle", XS_Wx__Window_SetTitle);
#endif
#if XSubPPtmpAABK
        newXS_deffile("Wx::Window::SetToolTip", XS_Wx__Window_SetToolTip);
        newXS_deffile("Wx::Window::SetToolTipTip", XS_Wx__Window_SetToolTipTip);
#endif
#if XSubPPtmpAABL
        newXS_deffile("Wx::Window::SetToolTipString", XS_Wx__Window_SetToolTipString);
#endif
        newXS_deffile("Wx::Window::SetValidator", XS_Wx__Window_SetValidator);
        newXS_deffile("Wx::Window::SetWindowStyle", XS_Wx__Window_SetWindowStyle);
        newXS_deffile("Wx::Window::SetWindowStyleFlag", XS_Wx__Window_SetWindowStyleFlag);
#if XSubPPtmpAABM
        newXS_deffile("Wx::Window::ShouldInheritColours", XS_Wx__Window_ShouldInheritColours);
#endif
        newXS_deffile("Wx::Window::Show", XS_Wx__Window_Show);
#if XSubPPtmpAABN
        newXS_deffile("Wx::Window::HasMultiplePages", XS_Wx__Window_HasMultiplePages);
#endif
        newXS_deffile("Wx::Window::Hide", XS_Wx__Window_Hide);
        newXS_deffile("Wx::Window::Thaw", XS_Wx__Window_Thaw);
        newXS_deffile("Wx::Window::TransferDataFromWindow", XS_Wx__Window_TransferDataFromWindow);
        newXS_deffile("Wx::Window::TransferDataToWindow", XS_Wx__Window_TransferDataToWindow);
        newXS_deffile("Wx::Window::Validate", XS_Wx__Window_Validate);
        newXS_deffile("Wx::Window::Update", XS_Wx__Window_Update);
        newXS_deffile("Wx::Window::InitDialog", XS_Wx__Window_InitDialog);
#if XSubPPtmpAABO
        newXS_deffile("Wx::Window::UpdateWindowUI", XS_Wx__Window_UpdateWindowUI);
#endif
        newXS_deffile("Wx::Window::RefreshRect", XS_Wx__Window_RefreshRect);
        newXS_deffile("Wx::Window::WarpPointer", XS_Wx__Window_WarpPointer);
#if XSubPPtmpAABP
        newXS_deffile("Wx::Window::GetLayoutDirection", XS_Wx__Window_GetLayoutDirection);
        newXS_deffile("Wx::Window::SetLayoutDirection", XS_Wx__Window_SetLayoutDirection);
        newXS_deffile("Wx::Window::SetTransparent", XS_Wx__Window_SetTransparent);
        newXS_deffile("Wx::Window::CanSetTransparent", XS_Wx__Window_CanSetTransparent);
#endif
#if XSubPPtmpAABQ
        newXS_deffile("Wx::Window::AlwaysShowScrollbars", XS_Wx__Window_AlwaysShowScrollbars);
#endif
        newXS_deffile("Wx::Window::AcceptsFocus", XS_Wx__Window_AcceptsFocus);
        newXS_deffile("Wx::Window::AcceptsFocusFromKeyboard", XS_Wx__Window_AcceptsFocusFromKeyboard);
        newXS_deffile("Wx::Window::DestroyChildren", XS_Wx__Window_DestroyChildren);
        newXS_deffile("Wx::Window::IsBeingDeleted", XS_Wx__Window_IsBeingDeleted);
#if XSubPPtmpAABR
        newXS_deffile("Wx::Window::GetPopupMenuSelectionFromUserPoint", XS_Wx__Window_GetPopupMenuSelectionFromUserPoint);
        newXS_deffile("Wx::Window::GetPopupMenuSelectionFromUserXY", XS_Wx__Window_GetPopupMenuSelectionFromUserXY);
#endif
#if XSubPPtmpAABS
        newXS_deffile("Wx::Window::GetAdjustedBestSize", XS_Wx__Window_GetAdjustedBestSize);
#endif
#if XSubPPtmpAABT
        newXS_deffile("Wx::Window::GetEffectiveMinSize", XS_Wx__Window_GetEffectiveMinSize);
#endif
        newXS_deffile("Wx::Window::GetCursor", XS_Wx__Window_GetCursor);
#if XSubPPtmpAABU
        newXS_deffile("Wx::Window::GetPrevSibling", XS_Wx__Window_GetPrevSibling);
        newXS_deffile("Wx::Window::GetNextSibling", XS_Wx__Window_GetNextSibling);
#endif
        newXS_deffile("Wx::Window::GetVirtualSize", XS_Wx__Window_GetVirtualSize);
        newXS_deffile("Wx::Window::GetVirtualSizeWH", XS_Wx__Window_GetVirtualSizeWH);
#if XSubPPtmpAABV
        newXS_deffile("Wx::Window::GetScreenPosition", XS_Wx__Window_GetScreenPosition);
        newXS_deffile("Wx::Window::GetScreenPositionXY", XS_Wx__Window_GetScreenPositionXY);
        newXS_deffile("Wx::Window::GetScreenRect", XS_Wx__Window_GetScreenRect);
#endif
        newXS_deffile("Wx::Window::HasFlag", XS_Wx__Window_HasFlag);
#if XSubPPtmpAABW
        newXS_deffile("Wx::Window::HasExtraStyle", XS_Wx__Window_HasExtraStyle);
#endif
        newXS_deffile("Wx::Window::HasCapture", XS_Wx__Window_HasCapture);
#if XSubPPtmpAABX
        newXS_deffile("Wx::Window::HasTransparentBackground", XS_Wx__Window_HasTransparentBackground);
#endif
        newXS_deffile("Wx::Window::HasScrollbar", XS_Wx__Window_HasScrollbar);
#if XSubPPtmpAABY
        newXS_deffile("Wx::Window::IsScrollbarAlwaysShown", XS_Wx__Window_IsScrollbarAlwaysShown);
#endif
        newXS_deffile("Wx::Window::LineUp", XS_Wx__Window_LineUp);
        newXS_deffile("Wx::Window::LineDown", XS_Wx__Window_LineDown);
        newXS_deffile("Wx::Window::PageUp", XS_Wx__Window_PageUp);
        newXS_deffile("Wx::Window::PageDown", XS_Wx__Window_PageDown);
        newXS_deffile("Wx::Window::SetBackgroundColour", XS_Wx__Window_SetBackgroundColour);
        newXS_deffile("Wx::Window::SetOwnBackgroundColour", XS_Wx__Window_SetOwnBackgroundColour);
#if XSubPPtmpAABZ
        newXS_deffile("Wx::Window::SetCanFocus", XS_Wx__Window_SetCanFocus);
#endif
        newXS_deffile("Wx::Window::SetForegroundColour", XS_Wx__Window_SetForegroundColour);
        newXS_deffile("Wx::Window::SetOwnForegroundColour", XS_Wx__Window_SetOwnForegroundColour);
        newXS_deffile("Wx::Window::SetFont", XS_Wx__Window_SetFont);
        newXS_deffile("Wx::Window::SetCursor", XS_Wx__Window_SetCursor);
        newXS_deffile("Wx::Window::SetOwnFont", XS_Wx__Window_SetOwnFont);
        newXS_deffile("Wx::Window::GetWindowVariant", XS_Wx__Window_GetWindowVariant);
        newXS_deffile("Wx::Window::SetWindowVariant", XS_Wx__Window_SetWindowVariant);
#if XSubPPtmpAACA
        newXS_deffile("Wx::Window::ToggleWindowStyle", XS_Wx__Window_ToggleWindowStyle);
#endif
#if XSubPPtmpAACB
        newXS_deffile("Wx::Window::AcceptsFocusRecursively", XS_Wx__Window_AcceptsFocusRecursively);
        newXS_deffile("Wx::Window::HasFocus", XS_Wx__Window_HasFocus);
        newXS_deffile("Wx::Window::SetFocusFromKbd", XS_Wx__Window_SetFocusFromKbd);
        newXS_deffile("Wx::Window::IsDescendant", XS_Wx__Window_IsDescendant);
#endif
#if XSubPPtmpAACC
        newXS_deffile("Wx::Window::GetPopupMenuSelectionFromUser", XS_Wx__Window_GetPopupMenuSelectionFromUser);
#endif
#if XSubPPtmpAACD
        newXS_deffile("Wx::EventBlocker::new", XS_Wx__EventBlocker_new);
        newXS_deffile("Wx::EventBlocker::CLONE", XS_Wx__EventBlocker_CLONE);
        newXS_deffile("Wx::EventBlocker::DESTROY", XS_Wx__EventBlocker_DESTROY);
        newXS_deffile("Wx::EventBlocker::Block", XS_Wx__EventBlocker_Block);
#endif
#if XSubPPtmpAACE
        newXS_deffile("Wx::WindowUpdateLocker::new", XS_Wx__WindowUpdateLocker_new);
        newXS_deffile("Wx::WindowUpdateLocker::CLONE", XS_Wx__WindowUpdateLocker_CLONE);
        newXS_deffile("Wx::WindowUpdateLocker::DESTROY", XS_Wx__WindowUpdateLocker_DESTROY);
#endif
        newXS_deffile("Wx::AcceleratorEntry::new", XS_Wx__AcceleratorEntry_new);
#if XSubPPtmpAACF
        newXS_deffile("Wx::AcceleratorEntry::Create", XS_Wx__AcceleratorEntry_Create);
#endif
        newXS_deffile("Wx::AcceleratorEntry::CLONE", XS_Wx__AcceleratorEntry_CLONE);
        newXS_deffile("Wx::AcceleratorEntry::DESTROY", XS_Wx__AcceleratorEntry_DESTROY);
        newXS_deffile("Wx::AcceleratorEntry::GetCommand", XS_Wx__AcceleratorEntry_GetCommand);
        newXS_deffile("Wx::AcceleratorEntry::GetFlags", XS_Wx__AcceleratorEntry_GetFlags);
        newXS_deffile("Wx::AcceleratorEntry::GetKeyCode", XS_Wx__AcceleratorEntry_GetKeyCode);
        newXS_deffile("Wx::AcceleratorEntry::Set", XS_Wx__AcceleratorEntry_Set);
        newXS_deffile("Wx::AcceleratorTable::new", XS_Wx__AcceleratorTable_new);
        newXS_deffile("Wx::AcceleratorTable::CLONE", XS_Wx__AcceleratorTable_CLONE);
        newXS_deffile("Wx::AcceleratorTable::DESTROY", XS_Wx__AcceleratorTable_DESTROY);
        newXS_deffile("Wx::AcceleratorTable::Ok", XS_Wx__AcceleratorTable_Ok);
#if XSubPPtmpAACG
        newXS_deffile("Wx::AcceleratorTable::IsOk", XS_Wx__AcceleratorTable_IsOk);
#endif
        newXS_deffile("Wx::PlWindow::newDefault", XS_Wx__PlWindow_newDefault);
        newXS_deffile("Wx::PlWindow::newFull", XS_Wx__PlWindow_newFull);
        newXS_deffile("Wx::PlWindow::Create", XS_Wx__PlWindow_Create);
        newXS_deffile("Wx::PlWindow::DoGetBestSize", XS_Wx__PlWindow_DoGetBestSize);
        newXS_deffile("Wx::PlWindow::DoMoveWindow", XS_Wx__PlWindow_DoMoveWindow);
        newXS_deffile("Wx::PlWindow::Enable", XS_Wx__PlWindow_Enable);
        newXS_deffile("Wx::PlWindow::AcceptsFocus", XS_Wx__PlWindow_AcceptsFocus);
#if XSubPPtmpAACH
        newXS_deffile("Wx::PlWindow::AcceptsFocusRecursively", XS_Wx__PlWindow_AcceptsFocusRecursively);
#endif
        newXS_deffile("Wx::PlWindow::AcceptsFocusFromKeyboard", XS_Wx__PlWindow_AcceptsFocusFromKeyboard);
#if XSubPPtmpAACI
        newXS_deffile("Wx::PlWindow::GetMaxSize", XS_Wx__PlWindow_GetMaxSize);
        newXS_deffile("Wx::PlWindow::GetMinSize", XS_Wx__PlWindow_GetMinSize);
#endif
        newXS_deffile("Wx::PlWindow::new", XS_Wx__PlWindow_new);
        newXS_deffile("Wx::SplitterEvent::new", XS_Wx__SplitterEvent_new);
        newXS_deffile("Wx::SplitterEvent::GetSashPosition", XS_Wx__SplitterEvent_GetSashPosition);
        newXS_deffile("Wx::SplitterEvent::GetX", XS_Wx__SplitterEvent_GetX);
        newXS_deffile("Wx::SplitterEvent::GetY", XS_Wx__SplitterEvent_GetY);
        newXS_deffile("Wx::SplitterEvent::GetWindowBeingRemoved", XS_Wx__SplitterEvent_GetWindowBeingRemoved);
        newXS_deffile("Wx::SplitterEvent::SetSashPosition", XS_Wx__SplitterEvent_SetSashPosition);
        newXS_deffile("Wx::SplitterWindow::newDefault", XS_Wx__SplitterWindow_newDefault);
        newXS_deffile("Wx::SplitterWindow::newFull", XS_Wx__SplitterWindow_newFull);
        newXS_deffile("Wx::SplitterWindow::Create", XS_Wx__SplitterWindow_Create);
        newXS_deffile("Wx::SplitterWindow::GetMinimumPaneSize", XS_Wx__SplitterWindow_GetMinimumPaneSize);
        newXS_deffile("Wx::SplitterWindow::GetSashPosition", XS_Wx__SplitterWindow_GetSashPosition);
        newXS_deffile("Wx::SplitterWindow::GetSplitMode", XS_Wx__SplitterWindow_GetSplitMode);
        newXS_deffile("Wx::SplitterWindow::GetWindow1", XS_Wx__SplitterWindow_GetWindow1);
        newXS_deffile("Wx::SplitterWindow::GetWindow2", XS_Wx__SplitterWindow_GetWindow2);
        newXS_deffile("Wx::SplitterWindow::Initialize", XS_Wx__SplitterWindow_Initialize);
        newXS_deffile("Wx::SplitterWindow::IsSplit", XS_Wx__SplitterWindow_IsSplit);
        newXS_deffile("Wx::SplitterWindow::ReplaceWindow", XS_Wx__SplitterWindow_ReplaceWindow);
#if XSubPPtmpAACJ
        newXS_deffile("Wx::SplitterWindow::SetFocusIgnoringChildren", XS_Wx__SplitterWindow_SetFocusIgnoringChildren);
#endif
        newXS_deffile("Wx::SplitterWindow::SetSashPosition", XS_Wx__SplitterWindow_SetSashPosition);
        newXS_deffile("Wx::SplitterWindow::SetMinimumPaneSize", XS_Wx__SplitterWindow_SetMinimumPaneSize);
        newXS_deffile("Wx::SplitterWindow::SetSplitMode", XS_Wx__SplitterWindow_SetSplitMode);
        newXS_deffile("Wx::SplitterWindow::SplitHorizontally", XS_Wx__SplitterWindow_SplitHorizontally);
        newXS_deffile("Wx::SplitterWindow::SplitVertically", XS_Wx__SplitterWindow_SplitVertically);
        newXS_deffile("Wx::SplitterWindow::Unsplit", XS_Wx__SplitterWindow_Unsplit);
#if XSubPPtmpAACK
        newXS_deffile("Wx::SplitterWindow::SetSashGravity", XS_Wx__SplitterWindow_SetSashGravity);
        newXS_deffile("Wx::SplitterWindow::GetSashGravity", XS_Wx__SplitterWindow_GetSashGravity);
        newXS_deffile("Wx::SplitterWindow::UpdateSize", XS_Wx__SplitterWindow_UpdateSize);
#endif
#if XSubPPtmpAACL
        newXS_deffile("Wx::SplitterWindow::GetSashSize", XS_Wx__SplitterWindow_GetSashSize);
        newXS_deffile("Wx::SplitterWindow::SetSashSize", XS_Wx__SplitterWindow_SetSashSize);
#endif
        newXS_deffile("Wx::SplitterWindow::new", XS_Wx__SplitterWindow_new);
#if XSubPPtmpAACM
        newXS_deffile("Wx::HScrolledWindow::Create", XS_Wx__HScrolledWindow_Create);
        newXS_deffile("Wx::HScrolledWindow::EnablePhysicalScrolling", XS_Wx__HScrolledWindow_EnablePhysicalScrolling);
        newXS_deffile("Wx::HScrolledWindow::VirtualHitTest", XS_Wx__HScrolledWindow_VirtualHitTest);
        newXS_deffile("Wx::HScrolledWindow::RefreshAll", XS_Wx__HScrolledWindow_RefreshAll);
        newXS_deffile("Wx::HScrolledWindow::GetVisibleBegin", XS_Wx__HScrolledWindow_GetVisibleBegin);
        newXS_deffile("Wx::HScrolledWindow::GetVisibleEnd", XS_Wx__HScrolledWindow_GetVisibleEnd);
        newXS_deffile("Wx::HScrolledWindow::IsVisible", XS_Wx__HScrolledWindow_IsVisible);
        newXS_deffile("Wx::HScrolledWindow::CalcScrolledPosition", XS_Wx__HScrolledWindow_CalcScrolledPosition);
        newXS_deffile("Wx::HScrolledWindow::CalcUnscrolledPosition", XS_Wx__HScrolledWindow_CalcUnscrolledPosition);
        newXS_deffile("Wx::HScrolledWindow::UpdateScrollbar", XS_Wx__HScrolledWindow_UpdateScrollbar);
        newXS_deffile("Wx::HScrolledWindow::RemoveScrollbar", XS_Wx__HScrolledWindow_RemoveScrollbar);
        newXS_deffile("Wx::HScrolledWindow::SetTargetWindow", XS_Wx__HScrolledWindow_SetTargetWindow);
        newXS_deffile("Wx::HScrolledWindow::GetTargetWindow", XS_Wx__HScrolledWindow_GetTargetWindow);
        newXS_deffile("Wx::HScrolledWindow::SetColumnCount", XS_Wx__HScrolledWindow_SetColumnCount);
        newXS_deffile("Wx::HScrolledWindow::ScrollToColumn", XS_Wx__HScrolledWindow_ScrollToColumn);
        newXS_deffile("Wx::HScrolledWindow::ScrollColumns", XS_Wx__HScrolledWindow_ScrollColumns);
        newXS_deffile("Wx::HScrolledWindow::ScrollColumnPages", XS_Wx__HScrolledWindow_ScrollColumnPages);
        newXS_deffile("Wx::HScrolledWindow::RefreshColumn", XS_Wx__HScrolledWindow_RefreshColumn);
        newXS_deffile("Wx::HScrolledWindow::RefreshColumns", XS_Wx__HScrolledWindow_RefreshColumns);
        newXS_deffile("Wx::HScrolledWindow::GetColumnCount", XS_Wx__HScrolledWindow_GetColumnCount);
        newXS_deffile("Wx::HScrolledWindow::GetVisibleColumnsBegin", XS_Wx__HScrolledWindow_GetVisibleColumnsBegin);
        newXS_deffile("Wx::HScrolledWindow::GetVisibleColumnsEnd", XS_Wx__HScrolledWindow_GetVisibleColumnsEnd);
        newXS_deffile("Wx::HScrolledWindow::IsColumnVisible", XS_Wx__HScrolledWindow_IsColumnVisible);
#endif
#if XSubPPtmpAACN
        newXS_deffile("Wx::VScrolledWindow::Create", XS_Wx__VScrolledWindow_Create);
#if XSubPPtmpAACO
        newXS_deffile("Wx::VScrolledWindow::SetLineCount", XS_Wx__VScrolledWindow_SetLineCount);
        newXS_deffile("Wx::VScrolledWindow::ScrollToLine", XS_Wx__VScrolledWindow_ScrollToLine);
        newXS_deffile("Wx::VScrolledWindow::RefreshLine", XS_Wx__VScrolledWindow_RefreshLine);
        newXS_deffile("Wx::VScrolledWindow::RefreshLines", XS_Wx__VScrolledWindow_RefreshLines);
        newXS_deffile("Wx::VScrolledWindow::GetLineCount", XS_Wx__VScrolledWindow_GetLineCount);
        newXS_deffile("Wx::VScrolledWindow::GetFirstVisibleLine", XS_Wx__VScrolledWindow_GetFirstVisibleLine);
        newXS_deffile("Wx::VScrolledWindow::GetLastVisibleLine", XS_Wx__VScrolledWindow_GetLastVisibleLine);
        newXS_deffile("Wx::VScrolledWindow::ScrollLines", XS_Wx__VScrolledWindow_ScrollLines);
        newXS_deffile("Wx::VScrolledWindow::ScrollPages", XS_Wx__VScrolledWindow_ScrollPages);
        newXS_deffile("Wx::VScrolledWindow::EnablePhysicalScrolling", XS_Wx__VScrolledWindow_EnablePhysicalScrolling);
        newXS_deffile("Wx::VScrolledWindow::VirtualHitTest", XS_Wx__VScrolledWindow_VirtualHitTest);
        newXS_deffile("Wx::VScrolledWindow::RefreshAll", XS_Wx__VScrolledWindow_RefreshAll);
        newXS_deffile("Wx::VScrolledWindow::GetVisibleBegin", XS_Wx__VScrolledWindow_GetVisibleBegin);
        newXS_deffile("Wx::VScrolledWindow::GetVisibleEnd", XS_Wx__VScrolledWindow_GetVisibleEnd);
        newXS_deffile("Wx::VScrolledWindow::IsVisible", XS_Wx__VScrolledWindow_IsVisible);
        newXS_deffile("Wx::VScrolledWindow::CalcScrolledPosition", XS_Wx__VScrolledWindow_CalcScrolledPosition);
        newXS_deffile("Wx::VScrolledWindow::CalcUnscrolledPosition", XS_Wx__VScrolledWindow_CalcUnscrolledPosition);
        newXS_deffile("Wx::VScrolledWindow::UpdateScrollbar", XS_Wx__VScrolledWindow_UpdateScrollbar);
        newXS_deffile("Wx::VScrolledWindow::RemoveScrollbar", XS_Wx__VScrolledWindow_RemoveScrollbar);
        newXS_deffile("Wx::VScrolledWindow::SetTargetWindow", XS_Wx__VScrolledWindow_SetTargetWindow);
        newXS_deffile("Wx::VScrolledWindow::GetTargetWindow", XS_Wx__VScrolledWindow_GetTargetWindow);
        newXS_deffile("Wx::VScrolledWindow::SetRowCount", XS_Wx__VScrolledWindow_SetRowCount);
        newXS_deffile("Wx::VScrolledWindow::ScrollToRow", XS_Wx__VScrolledWindow_ScrollToRow);
        newXS_deffile("Wx::VScrolledWindow::RefreshRow", XS_Wx__VScrolledWindow_RefreshRow);
        newXS_deffile("Wx::VScrolledWindow::RefreshRows", XS_Wx__VScrolledWindow_RefreshRows);
        newXS_deffile("Wx::VScrolledWindow::GetRowCount", XS_Wx__VScrolledWindow_GetRowCount);
        newXS_deffile("Wx::VScrolledWindow::GetVisibleRowsBegin", XS_Wx__VScrolledWindow_GetVisibleRowsBegin);
        newXS_deffile("Wx::VScrolledWindow::GetVisibleRowsEnd", XS_Wx__VScrolledWindow_GetVisibleRowsEnd);
        newXS_deffile("Wx::VScrolledWindow::ScrollRows", XS_Wx__VScrolledWindow_ScrollRows);
        newXS_deffile("Wx::VScrolledWindow::ScrollRowPages", XS_Wx__VScrolledWindow_ScrollRowPages);
        newXS_deffile("Wx::VScrolledWindow::IsRowVisible", XS_Wx__VScrolledWindow_IsRowVisible);
#endif
#if XSubPPtmpAACP
        newXS_deffile("Wx::VScrolledWindow::SetLineCount", XS_Wx__VScrolledWindow_SetLineCount);
        newXS_deffile("Wx::VScrolledWindow::ScrollToLine", XS_Wx__VScrolledWindow_ScrollToLine);
        newXS_deffile("Wx::VScrolledWindow::RefreshLine", XS_Wx__VScrolledWindow_RefreshLine);
        newXS_deffile("Wx::VScrolledWindow::RefreshLines", XS_Wx__VScrolledWindow_RefreshLines);
        newXS_deffile("Wx::VScrolledWindow::GetLineCount", XS_Wx__VScrolledWindow_GetLineCount);
        newXS_deffile("Wx::VScrolledWindow::GetFirstVisibleLine", XS_Wx__VScrolledWindow_GetFirstVisibleLine);
        newXS_deffile("Wx::VScrolledWindow::GetLastVisibleLine", XS_Wx__VScrolledWindow_GetLastVisibleLine);
        newXS_deffile("Wx::VScrolledWindow::ScrollLines", XS_Wx__VScrolledWindow_ScrollLines);
        newXS_deffile("Wx::VScrolledWindow::ScrollPages", XS_Wx__VScrolledWindow_ScrollPages);
        newXS_deffile("Wx::VScrolledWindow::SetRowCount", XS_Wx__VScrolledWindow_SetRowCount);
        newXS_deffile("Wx::VScrolledWindow::ScrollToRow", XS_Wx__VScrolledWindow_ScrollToRow);
        newXS_deffile("Wx::VScrolledWindow::RefreshRow", XS_Wx__VScrolledWindow_RefreshRow);
        newXS_deffile("Wx::VScrolledWindow::RefreshRows", XS_Wx__VScrolledWindow_RefreshRows);
        newXS_deffile("Wx::VScrolledWindow::GetRowCount", XS_Wx__VScrolledWindow_GetRowCount);
        newXS_deffile("Wx::VScrolledWindow::GetVisibleRowsBegin", XS_Wx__VScrolledWindow_GetVisibleRowsBegin);
        newXS_deffile("Wx::VScrolledWindow::GetVisibleRowsEnd", XS_Wx__VScrolledWindow_GetVisibleRowsEnd);
        newXS_deffile("Wx::VScrolledWindow::ScrollRows", XS_Wx__VScrolledWindow_ScrollRows);
        newXS_deffile("Wx::VScrolledWindow::ScrollRowPages", XS_Wx__VScrolledWindow_ScrollRowPages);
        newXS_deffile("Wx::VScrolledWindow::RefreshAll", XS_Wx__VScrolledWindow_RefreshAll);
#if XSubPPtmpAACQ
        newXS_deffile("Wx::VScrolledWindow::GetVisibleBegin", XS_Wx__VScrolledWindow_GetVisibleBegin);
        newXS_deffile("Wx::VScrolledWindow::GetVisibleEnd", XS_Wx__VScrolledWindow_GetVisibleEnd);
#endif
        newXS_deffile("Wx::VScrolledWindow::IsVisible", XS_Wx__VScrolledWindow_IsVisible);
        newXS_deffile("Wx::VScrolledWindow::IsRowVisible", XS_Wx__VScrolledWindow_IsRowVisible);
#endif
        newXS_deffile("Wx::VScrolledWindow::HitTest", XS_Wx__VScrolledWindow_HitTest);
        newXS_deffile("Wx::VScrolledWindow::Layout", XS_Wx__VScrolledWindow_Layout);
#if XSubPPtmpAACR
        newXS_deffile("Wx::HVScrolledWindow::Create", XS_Wx__HVScrolledWindow_Create);
        newXS_deffile("Wx::HVScrolledWindow::SetColumnCount", XS_Wx__HVScrolledWindow_SetColumnCount);
        newXS_deffile("Wx::HVScrolledWindow::ScrollToColumn", XS_Wx__HVScrolledWindow_ScrollToColumn);
        newXS_deffile("Wx::HVScrolledWindow::ScrollColumns", XS_Wx__HVScrolledWindow_ScrollColumns);
        newXS_deffile("Wx::HVScrolledWindow::ScrollColumnPages", XS_Wx__HVScrolledWindow_ScrollColumnPages);
        newXS_deffile("Wx::HVScrolledWindow::RefreshColumn", XS_Wx__HVScrolledWindow_RefreshColumn);
        newXS_deffile("Wx::HVScrolledWindow::RefreshColumns", XS_Wx__HVScrolledWindow_RefreshColumns);
        newXS_deffile("Wx::HVScrolledWindow::GetColumnCount", XS_Wx__HVScrolledWindow_GetColumnCount);
        newXS_deffile("Wx::HVScrolledWindow::GetVisibleColumnsBegin", XS_Wx__HVScrolledWindow_GetVisibleColumnsBegin);
        newXS_deffile("Wx::HVScrolledWindow::GetVisibleColumnsEnd", XS_Wx__HVScrolledWindow_GetVisibleColumnsEnd);
        newXS_deffile("Wx::HVScrolledWindow::IsColumnVisible", XS_Wx__HVScrolledWindow_IsColumnVisible);
        newXS_deffile("Wx::HVScrolledWindow::SetRowCount", XS_Wx__HVScrolledWindow_SetRowCount);
        newXS_deffile("Wx::HVScrolledWindow::ScrollToRow", XS_Wx__HVScrolledWindow_ScrollToRow);
        newXS_deffile("Wx::HVScrolledWindow::RefreshRow", XS_Wx__HVScrolledWindow_RefreshRow);
        newXS_deffile("Wx::HVScrolledWindow::RefreshRows", XS_Wx__HVScrolledWindow_RefreshRows);
        newXS_deffile("Wx::HVScrolledWindow::GetRowCount", XS_Wx__HVScrolledWindow_GetRowCount);
        newXS_deffile("Wx::HVScrolledWindow::GetVisibleRowsBegin", XS_Wx__HVScrolledWindow_GetVisibleRowsBegin);
        newXS_deffile("Wx::HVScrolledWindow::GetVisibleRowsEnd", XS_Wx__HVScrolledWindow_GetVisibleRowsEnd);
        newXS_deffile("Wx::HVScrolledWindow::ScrollRows", XS_Wx__HVScrolledWindow_ScrollRows);
        newXS_deffile("Wx::HVScrolledWindow::ScrollRowPages", XS_Wx__HVScrolledWindow_ScrollRowPages);
        newXS_deffile("Wx::HVScrolledWindow::IsRowVisible", XS_Wx__HVScrolledWindow_IsRowVisible);
        newXS_deffile("Wx::HVScrolledWindow::SetRowColumnCount", XS_Wx__HVScrolledWindow_SetRowColumnCount);
        newXS_deffile("Wx::HVScrolledWindow::EnablePhysicalScrolling", XS_Wx__HVScrolledWindow_EnablePhysicalScrolling);
        newXS_deffile("Wx::HVScrolledWindow::ScrollToRowColumn", XS_Wx__HVScrolledWindow_ScrollToRowColumn);
        newXS_deffile("Wx::HVScrolledWindow::ScrollToRowColumnRC", XS_Wx__HVScrolledWindow_ScrollToRowColumnRC);
        newXS_deffile("Wx::HVScrolledWindow::ScrollToRowColumnPosition", XS_Wx__HVScrolledWindow_ScrollToRowColumnPosition);
        newXS_deffile("Wx::HVScrolledWindow::RefreshRowColumn", XS_Wx__HVScrolledWindow_RefreshRowColumn);
        newXS_deffile("Wx::HVScrolledWindow::RefreshRowColumnRC", XS_Wx__HVScrolledWindow_RefreshRowColumnRC);
        newXS_deffile("Wx::HVScrolledWindow::RefreshRowColumnPosition", XS_Wx__HVScrolledWindow_RefreshRowColumnPosition);
        newXS_deffile("Wx::HVScrolledWindow::RefreshRowsColumns", XS_Wx__HVScrolledWindow_RefreshRowsColumns);
        newXS_deffile("Wx::HVScrolledWindow::RefreshRowsColumnsRC", XS_Wx__HVScrolledWindow_RefreshRowsColumnsRC);
        newXS_deffile("Wx::HVScrolledWindow::RefreshRowsColumnsPosition", XS_Wx__HVScrolledWindow_RefreshRowsColumnsPosition);
        newXS_deffile("Wx::HVScrolledWindow::VirtualHitTest", XS_Wx__HVScrolledWindow_VirtualHitTest);
        newXS_deffile("Wx::HVScrolledWindow::VirtualHitTestXY", XS_Wx__HVScrolledWindow_VirtualHitTestXY);
        newXS_deffile("Wx::HVScrolledWindow::VirtualHitTestPoint", XS_Wx__HVScrolledWindow_VirtualHitTestPoint);
        newXS_deffile("Wx::HVScrolledWindow::GetRowColumnCount", XS_Wx__HVScrolledWindow_GetRowColumnCount);
        newXS_deffile("Wx::HVScrolledWindow::GetVisibleBegin", XS_Wx__HVScrolledWindow_GetVisibleBegin);
        newXS_deffile("Wx::HVScrolledWindow::GetVisibleEnd", XS_Wx__HVScrolledWindow_GetVisibleEnd);
        newXS_deffile("Wx::HVScrolledWindow::IsVisible", XS_Wx__HVScrolledWindow_IsVisible);
        newXS_deffile("Wx::HVScrolledWindow::IsVisibleRC", XS_Wx__HVScrolledWindow_IsVisibleRC);
        newXS_deffile("Wx::HVScrolledWindow::IsVisiblePosition", XS_Wx__HVScrolledWindow_IsVisiblePosition);
#endif
#if XSubPPtmpAACS
        newXS_deffile("Wx::PlHScrolledWindow::new", XS_Wx__PlHScrolledWindow_new);
        newXS_deffile("Wx::PlHScrolledWindow::newDefault", XS_Wx__PlHScrolledWindow_newDefault);
        newXS_deffile("Wx::PlHScrolledWindow::newFull", XS_Wx__PlHScrolledWindow_newFull);
#endif
        newXS_deffile("Wx::PlVScrolledWindow::new", XS_Wx__PlVScrolledWindow_new);
        newXS_deffile("Wx::PlVScrolledWindow::newDefault", XS_Wx__PlVScrolledWindow_newDefault);
        newXS_deffile("Wx::PlVScrolledWindow::newFull", XS_Wx__PlVScrolledWindow_newFull);
#if XSubPPtmpAACT
        newXS_deffile("Wx::PlHVScrolledWindow::new", XS_Wx__PlHVScrolledWindow_new);
        newXS_deffile("Wx::PlHVScrolledWindow::newDefault", XS_Wx__PlHVScrolledWindow_newDefault);
        newXS_deffile("Wx::PlHVScrolledWindow::newFull", XS_Wx__PlHVScrolledWindow_newFull);
#endif
#endif
        newXS_deffile("Wx::IndividualLayoutConstraint::Above", XS_Wx__IndividualLayoutConstraint_Above);
        newXS_deffile("Wx::IndividualLayoutConstraint::Absolute", XS_Wx__IndividualLayoutConstraint_Absolute);
        newXS_deffile("Wx::IndividualLayoutConstraint::AsIs", XS_Wx__IndividualLayoutConstraint_AsIs);
        newXS_deffile("Wx::IndividualLayoutConstraint::Below", XS_Wx__IndividualLayoutConstraint_Below);
        newXS_deffile("Wx::IndividualLayoutConstraint::Unconstrained", XS_Wx__IndividualLayoutConstraint_Unconstrained);
        newXS_deffile("Wx::IndividualLayoutConstraint::LeftOf", XS_Wx__IndividualLayoutConstraint_LeftOf);
        newXS_deffile("Wx::IndividualLayoutConstraint::PercentOf", XS_Wx__IndividualLayoutConstraint_PercentOf);
        newXS_deffile("Wx::IndividualLayoutConstraint::RightOf", XS_Wx__IndividualLayoutConstraint_RightOf);
        newXS_deffile("Wx::IndividualLayoutConstraint::SameAs", XS_Wx__IndividualLayoutConstraint_SameAs);
        newXS_deffile("Wx::IndividualLayoutConstraint::Set", XS_Wx__IndividualLayoutConstraint_Set);
        newXS_deffile("Wx::LayoutConstraints::new", XS_Wx__LayoutConstraints_new);
        newXS_deffile("Wx::LayoutConstraints::bottom", XS_Wx__LayoutConstraints_bottom);
        newXS_deffile("Wx::LayoutConstraints::centreX", XS_Wx__LayoutConstraints_centreX);
        newXS_deffile("Wx::LayoutConstraints::centreY", XS_Wx__LayoutConstraints_centreY);
        newXS_deffile("Wx::LayoutConstraints::height", XS_Wx__LayoutConstraints_height);
        newXS_deffile("Wx::LayoutConstraints::left", XS_Wx__LayoutConstraints_left);
        newXS_deffile("Wx::LayoutConstraints::right", XS_Wx__LayoutConstraints_right);
        newXS_deffile("Wx::LayoutConstraints::top", XS_Wx__LayoutConstraints_top);
        newXS_deffile("Wx::LayoutConstraints::width", XS_Wx__LayoutConstraints_width);
        newXS_deffile("Wx::Validator::GetWindow", XS_Wx__Validator_GetWindow);
        newXS_deffile("Wx::Validator::SetBellOnError", XS_Wx__Validator_SetBellOnError);
        newXS_deffile("Wx::Validator::SetWindow", XS_Wx__Validator_SetWindow);
        newXS_deffile("Wx::PlValidator::new", XS_Wx__PlValidator_new);
        newXS_deffile("Wx::PlValidator::DESTROY", XS_Wx__PlValidator_DESTROY);
        newXS_deffile("Wx::ScrolledWindow::new", XS_Wx__ScrolledWindow_new);
        newXS_deffile("Wx::ScrolledWindow::newDefault", XS_Wx__ScrolledWindow_newDefault);
        newXS_deffile("Wx::ScrolledWindow::newFull", XS_Wx__ScrolledWindow_newFull);
        newXS_deffile("Wx::ScrolledWindow::Create", XS_Wx__ScrolledWindow_Create);
        newXS_deffile("Wx::ScrolledWindow::CalcScrolledPosition", XS_Wx__ScrolledWindow_CalcScrolledPosition);
        newXS_deffile("Wx::ScrolledWindow::CalcUnscrolledPosition", XS_Wx__ScrolledWindow_CalcUnscrolledPosition);
        newXS_deffile("Wx::ScrolledWindow::EnableScrolling", XS_Wx__ScrolledWindow_EnableScrolling);
#if XSubPPtmpAACU
        newXS_deffile("Wx::ScrolledWindow::ShowScrollbars", XS_Wx__ScrolledWindow_ShowScrollbars);
#endif
        newXS_deffile("Wx::ScrolledWindow::GetScrollPixelsPerUnit", XS_Wx__ScrolledWindow_GetScrollPixelsPerUnit);
        newXS_deffile("Wx::ScrolledWindow::GetVirtualSize", XS_Wx__ScrolledWindow_GetVirtualSize);
        newXS_deffile("Wx::ScrolledWindow::IsRetained", XS_Wx__ScrolledWindow_IsRetained);
        newXS_deffile("Wx::ScrolledWindow::PrepareDC", XS_Wx__ScrolledWindow_PrepareDC);
        newXS_deffile("Wx::ScrolledWindow::DoPrepareDC", XS_Wx__ScrolledWindow_DoPrepareDC);
        newXS_deffile("Wx::ScrolledWindow::Scroll", XS_Wx__ScrolledWindow_Scroll);
        newXS_deffile("Wx::ScrolledWindow::SetScrollbars", XS_Wx__ScrolledWindow_SetScrollbars);
        newXS_deffile("Wx::ScrolledWindow::SetScrollRate", XS_Wx__ScrolledWindow_SetScrollRate);
        newXS_deffile("Wx::ScrolledWindow::SetTargetWindow", XS_Wx__ScrolledWindow_SetTargetWindow);
        newXS_deffile("Wx::ScrolledWindow::GetViewStart", XS_Wx__ScrolledWindow_GetViewStart);
#if XSubPPtmpAACV
        newXS_deffile("Wx::Sizer::AddWindow", XS_Wx__Sizer_AddWindow);
        newXS_deffile("Wx::Sizer::AddSizer", XS_Wx__Sizer_AddSizer);
        newXS_deffile("Wx::Sizer::AddSpace", XS_Wx__Sizer_AddSpace);
        newXS_deffile("Wx::Sizer::PrependWindow", XS_Wx__Sizer_PrependWindow);
        newXS_deffile("Wx::Sizer::PrependSizer", XS_Wx__Sizer_PrependSizer);
        newXS_deffile("Wx::Sizer::PrependSpace", XS_Wx__Sizer_PrependSpace);
        newXS_deffile("Wx::Sizer::InsertWindow", XS_Wx__Sizer_InsertWindow);
        newXS_deffile("Wx::Sizer::InsertSizer", XS_Wx__Sizer_InsertSizer);
        newXS_deffile("Wx::Sizer::InsertSpace", XS_Wx__Sizer_InsertSpace);
#endif
#if XSubPPtmpAACW
        newXS_deffile("Wx::Sizer::AddWindow", XS_Wx__Sizer_AddWindow);
        newXS_deffile("Wx::Sizer::AddSizer", XS_Wx__Sizer_AddSizer);
        newXS_deffile("Wx::Sizer::AddSpace", XS_Wx__Sizer_AddSpace);
        newXS_deffile("Wx::Sizer::PrependWindow", XS_Wx__Sizer_PrependWindow);
        newXS_deffile("Wx::Sizer::PrependSizer", XS_Wx__Sizer_PrependSizer);
        newXS_deffile("Wx::Sizer::PrependSpace", XS_Wx__Sizer_PrependSpace);
        newXS_deffile("Wx::Sizer::InsertWindow", XS_Wx__Sizer_InsertWindow);
        newXS_deffile("Wx::Sizer::InsertSizer", XS_Wx__Sizer_InsertSizer);
        newXS_deffile("Wx::Sizer::InsertSpace", XS_Wx__Sizer_InsertSpace);
#endif
#if XSubPPtmpAACX
        newXS_deffile("Wx::Sizer::GetItemWindow", XS_Wx__Sizer_GetItemWindow);
        newXS_deffile("Wx::Sizer::GetItemSizer", XS_Wx__Sizer_GetItemSizer);
        newXS_deffile("Wx::Sizer::GetItemNth", XS_Wx__Sizer_GetItemNth);
#endif
#if XSubPPtmpAACY
        newXS_deffile("Wx::Sizer::GetItemNth", XS_Wx__Sizer_GetItemNth);
#endif
#if XSubPPtmpAACZ
        newXS_deffile("Wx::Sizer::GetItemById", XS_Wx__Sizer_GetItemById);
#endif
        newXS_deffile("Wx::Sizer::HideSizer", XS_Wx__Sizer_HideSizer);
        newXS_deffile("Wx::Sizer::HideWindow", XS_Wx__Sizer_HideWindow);
        newXS_deffile("Wx::Sizer::HideIndex", XS_Wx__Sizer_HideIndex);
        newXS_deffile("Wx::Sizer::IsShownWindow", XS_Wx__Sizer_IsShownWindow);
        newXS_deffile("Wx::Sizer::IsShownSizer", XS_Wx__Sizer_IsShownSizer);
        newXS_deffile("Wx::Sizer::IsShownIndex", XS_Wx__Sizer_IsShownIndex);
#if XSubPPtmpAADA
        newXS_deffile("Wx::Sizer::ReplaceWindow", XS_Wx__Sizer_ReplaceWindow);
        newXS_deffile("Wx::Sizer::ReplaceSizer", XS_Wx__Sizer_ReplaceSizer);
        newXS_deffile("Wx::Sizer::ReplaceIndex", XS_Wx__Sizer_ReplaceIndex);
#endif
        newXS_deffile("Wx::Sizer::RecalcSizes", XS_Wx__Sizer_RecalcSizes);
        newXS_deffile("Wx::Sizer::Clear", XS_Wx__Sizer_Clear);
        newXS_deffile("Wx::Sizer::DeleteWindows", XS_Wx__Sizer_DeleteWindows);
        newXS_deffile("Wx::Sizer::CalcMin", XS_Wx__Sizer_CalcMin);
        newXS_deffile("Wx::Sizer::Fit", XS_Wx__Sizer_Fit);
        newXS_deffile("Wx::Sizer::FitInside", XS_Wx__Sizer_FitInside);
        newXS_deffile("Wx::Sizer::GetSize", XS_Wx__Sizer_GetSize);
        newXS_deffile("Wx::Sizer::GetPosition", XS_Wx__Sizer_GetPosition);
        newXS_deffile("Wx::Sizer::GetMinSize", XS_Wx__Sizer_GetMinSize);
        newXS_deffile("Wx::Sizer::Layout", XS_Wx__Sizer_Layout);
#if XSubPPtmpAADB
        newXS_deffile("Wx::Sizer::RemoveWindow", XS_Wx__Sizer_RemoveWindow);
#endif
        newXS_deffile("Wx::Sizer::RemoveSizer", XS_Wx__Sizer_RemoveSizer);
        newXS_deffile("Wx::Sizer::RemoveNth", XS_Wx__Sizer_RemoveNth);
#if XSubPPtmpAADC
        newXS_deffile("Wx::Sizer::DetachWindow", XS_Wx__Sizer_DetachWindow);
        newXS_deffile("Wx::Sizer::DetachSizer", XS_Wx__Sizer_DetachSizer);
        newXS_deffile("Wx::Sizer::DetachNth", XS_Wx__Sizer_DetachNth);
#endif
#if XSubPPtmpAADD
        newXS_deffile("Wx::Sizer::GetContainingWindow", XS_Wx__Sizer_GetContainingWindow);
        newXS_deffile("Wx::Sizer::SetContainingWindow", XS_Wx__Sizer_SetContainingWindow);
#endif
        newXS_deffile("Wx::Sizer::SetDimension", XS_Wx__Sizer_SetDimension);
        newXS_deffile("Wx::Sizer::SetItemMinSizeWindow", XS_Wx__Sizer_SetItemMinSizeWindow);
        newXS_deffile("Wx::Sizer::SetItemMinSizeSizer", XS_Wx__Sizer_SetItemMinSizeSizer);
        newXS_deffile("Wx::Sizer::SetItemMinSizeNth", XS_Wx__Sizer_SetItemMinSizeNth);
        newXS_deffile("Wx::Sizer::SetMinSizeSize", XS_Wx__Sizer_SetMinSizeSize);
        newXS_deffile("Wx::Sizer::SetMinSizeXY", XS_Wx__Sizer_SetMinSizeXY);
        newXS_deffile("Wx::Sizer::SetSizeHints", XS_Wx__Sizer_SetSizeHints);
#if XSubPPtmpAADE
        newXS_deffile("Wx::Sizer::SetVirtualSizeHints", XS_Wx__Sizer_SetVirtualSizeHints);
#endif
#if XSubPPtmpAADF
        newXS_deffile("Wx::Sizer::ShowWindow", XS_Wx__Sizer_ShowWindow);
        newXS_deffile("Wx::Sizer::ShowSizer", XS_Wx__Sizer_ShowSizer);
        newXS_deffile("Wx::Sizer::ShowIndex", XS_Wx__Sizer_ShowIndex);
#endif
#if XSubPPtmpAADG
        newXS_deffile("Wx::Sizer::ShowWindow", XS_Wx__Sizer_ShowWindow);
        newXS_deffile("Wx::Sizer::ShowSizer", XS_Wx__Sizer_ShowSizer);
        newXS_deffile("Wx::Sizer::ShowIndex", XS_Wx__Sizer_ShowIndex);
#endif
#if XSubPPtmpAADH
        newXS_deffile("Wx::Sizer::ShowWindow", XS_Wx__Sizer_ShowWindow);
        newXS_deffile("Wx::Sizer::ShowSizer", XS_Wx__Sizer_ShowSizer);
#endif
#if XSubPPtmpAADI
        newXS_deffile("Wx::Sizer::AddSpacer0", XS_Wx__Sizer_AddSpacer0);
        newXS_deffile("Wx::Sizer::AddStretchSpacer0", XS_Wx__Sizer_AddStretchSpacer0);
        newXS_deffile("Wx::Sizer::InsertSpacer0", XS_Wx__Sizer_InsertSpacer0);
        newXS_deffile("Wx::Sizer::InsertStretchSpacer0", XS_Wx__Sizer_InsertStretchSpacer0);
        newXS_deffile("Wx::Sizer::PrependSpacer0", XS_Wx__Sizer_PrependSpacer0);
        newXS_deffile("Wx::Sizer::PrependStretchSpacer0", XS_Wx__Sizer_PrependStretchSpacer0);
#endif
#if XSubPPtmpAADJ
        newXS_deffile("Wx::Sizer::AddSpacer1", XS_Wx__Sizer_AddSpacer1);
        newXS_deffile("Wx::Sizer::AddStretchSpacer1", XS_Wx__Sizer_AddStretchSpacer1);
        newXS_deffile("Wx::Sizer::InsertSpacer1", XS_Wx__Sizer_InsertSpacer1);
        newXS_deffile("Wx::Sizer::InsertStretchSpacer1", XS_Wx__Sizer_InsertStretchSpacer1);
        newXS_deffile("Wx::Sizer::PrependSpacer1", XS_Wx__Sizer_PrependSpacer1);
        newXS_deffile("Wx::Sizer::PrependStretchSpacer1", XS_Wx__Sizer_PrependStretchSpacer1);
#endif
#if XSubPPtmpAADK
        newXS_deffile("Wx::Sizer::Replace", XS_Wx__Sizer_Replace);
#endif
#if XSubPPtmpAADL
        newXS_deffile("Wx::Sizer::Detach", XS_Wx__Sizer_Detach);
#endif
#if XSubPPtmpAADM
        newXS_deffile("Wx::Sizer::SetItemMinSize", XS_Wx__Sizer_SetItemMinSize);
#endif
#if XSubPPtmpAADN
        newXS_deffile("Wx::Sizer::Show", XS_Wx__Sizer_Show);
#endif
#if XSubPPtmpAADO
        newXS_deffile("Wx::Sizer::GetItem", XS_Wx__Sizer_GetItem);
#endif
#if XSubPPtmpAADP
        newXS_deffile("Wx::Sizer::IsShown", XS_Wx__Sizer_IsShown);
#endif
#if XSubPPtmpAADQ
        newXS_deffile("Wx::Sizer::Prepend", XS_Wx__Sizer_Prepend);
#endif
#if XSubPPtmpAADR
        newXS_deffile("Wx::Sizer::Add", XS_Wx__Sizer_Add);
#endif
#if XSubPPtmpAADS
        newXS_deffile("Wx::Sizer::Remove", XS_Wx__Sizer_Remove);
#endif
#if XSubPPtmpAADT
        newXS_deffile("Wx::Sizer::InsertSpacer", XS_Wx__Sizer_InsertSpacer);
#endif
#if XSubPPtmpAADU
        newXS_deffile("Wx::Sizer::SetMinSize", XS_Wx__Sizer_SetMinSize);
#endif
#if XSubPPtmpAADV
        newXS_deffile("Wx::Sizer::AddSpacer", XS_Wx__Sizer_AddSpacer);
#endif
#if XSubPPtmpAADW
        newXS_deffile("Wx::Sizer::PrependSpacer", XS_Wx__Sizer_PrependSpacer);
#endif
#if XSubPPtmpAADX
        newXS_deffile("Wx::Sizer::Insert", XS_Wx__Sizer_Insert);
#endif
#if XSubPPtmpAADY
        newXS_deffile("Wx::Sizer::PrependStretchSpacer", XS_Wx__Sizer_PrependStretchSpacer);
#endif
#if XSubPPtmpAADZ
        newXS_deffile("Wx::Sizer::AddStretchSpacer", XS_Wx__Sizer_AddStretchSpacer);
#endif
#if XSubPPtmpAAEA
        newXS_deffile("Wx::Sizer::Hide", XS_Wx__Sizer_Hide);
#endif
#if XSubPPtmpAAEB
        newXS_deffile("Wx::Sizer::InsertStretchSpacer", XS_Wx__Sizer_InsertStretchSpacer);
#endif
#if XSubPPtmpAAEC
        newXS_deffile("Wx::FlexGridSizer::AddGrowableCol0", XS_Wx__FlexGridSizer_AddGrowableCol0);
        newXS_deffile("Wx::FlexGridSizer::AddGrowableRow0", XS_Wx__FlexGridSizer_AddGrowableRow0);
        newXS_deffile("Wx::FlexGridSizer::SetFlexibleDirection", XS_Wx__FlexGridSizer_SetFlexibleDirection);
        newXS_deffile("Wx::FlexGridSizer::GetFlexibleDirection", XS_Wx__FlexGridSizer_GetFlexibleDirection);
        newXS_deffile("Wx::FlexGridSizer::SetNonFlexibleGrowMode", XS_Wx__FlexGridSizer_SetNonFlexibleGrowMode);
        newXS_deffile("Wx::FlexGridSizer::GetNonFlexibleGrowMode", XS_Wx__FlexGridSizer_GetNonFlexibleGrowMode);
#endif
#if XSubPPtmpAAED
        newXS_deffile("Wx::FlexGridSizer::AddGrowableCol1", XS_Wx__FlexGridSizer_AddGrowableCol1);
        newXS_deffile("Wx::FlexGridSizer::AddGrowableRow1", XS_Wx__FlexGridSizer_AddGrowableRow1);
#endif
#if XSubPPtmpAAEE
        newXS_deffile("Wx::FlexGridSizer::AddGrowableCol", XS_Wx__FlexGridSizer_AddGrowableCol);
#endif
#if XSubPPtmpAAEF
        newXS_deffile("Wx::FlexGridSizer::AddGrowableRow", XS_Wx__FlexGridSizer_AddGrowableRow);
#endif
        newXS_deffile("Wx::SizerItem::SetRatioWH", XS_Wx__SizerItem_SetRatioWH);
        newXS_deffile("Wx::SizerItem::SetRatioSize", XS_Wx__SizerItem_SetRatioSize);
        newXS_deffile("Wx::SizerItem::SetRatioFloat", XS_Wx__SizerItem_SetRatioFloat);
#if XSubPPtmpAAEG
        newXS_deffile("Wx::SizerItem::GetOption", XS_Wx__SizerItem_GetOption);
        newXS_deffile("Wx::SizerItem::SetOption", XS_Wx__SizerItem_SetOption);
        newXS_deffile("Wx::SizerItem::GetProportion", XS_Wx__SizerItem_GetProportion);
        newXS_deffile("Wx::SizerItem::SetProportion", XS_Wx__SizerItem_SetProportion);
#endif
#if XSubPPtmpAAEH
        newXS_deffile("Wx::SizerItem::GetProportion", XS_Wx__SizerItem_GetProportion);
        newXS_deffile("Wx::SizerItem::SetProportion", XS_Wx__SizerItem_SetProportion);
        newXS_deffile("Wx::SizerItem::GetOption", XS_Wx__SizerItem_GetOption);
        newXS_deffile("Wx::SizerItem::SetOption", XS_Wx__SizerItem_SetOption);
#endif
#if XSubPPtmpAAEI
        newXS_deffile("Wx::SizerItem::SetMinSizeWH", XS_Wx__SizerItem_SetMinSizeWH);
        newXS_deffile("Wx::SizerItem::SetMinSizeSize", XS_Wx__SizerItem_SetMinSizeSize);
#endif
        newXS_deffile("Wx::SizerItem::DeleteWindows", XS_Wx__SizerItem_DeleteWindows);
        newXS_deffile("Wx::SizerItem::DetachSizer", XS_Wx__SizerItem_DetachSizer);
#if XSubPPtmpAAEJ
        newXS_deffile("Wx::SizerItem::SetId", XS_Wx__SizerItem_SetId);
        newXS_deffile("Wx::SizerItem::GetId", XS_Wx__SizerItem_GetId);
#endif
#if XSubPPtmpAAEK
        newXS_deffile("Wx::SizerItem::GetRect", XS_Wx__SizerItem_GetRect);
#endif
        newXS_deffile("Wx::SizerItem::Show", XS_Wx__SizerItem_Show);
#if XSubPPtmpAAEL
        newXS_deffile("Wx::SizerItem::AssignSpacer", XS_Wx__SizerItem_AssignSpacer);
#endif
#if XSubPPtmpAAEM
        newXS_deffile("Wx::SizerItem::SetSpacer", XS_Wx__SizerItem_SetSpacer);
#endif
        newXS_deffile("Wx::SizerItem::GetSpacer", XS_Wx__SizerItem_GetSpacer);
#if XSubPPtmpAAEN
        newXS_deffile("Wx::SizerItem::SetMinSize", XS_Wx__SizerItem_SetMinSize);
#endif
#if XSubPPtmpAAEO
        newXS_deffile("Wx::SizerItem::SetRatio", XS_Wx__SizerItem_SetRatio);
#endif
#if XSubPPtmpAAEP
        newXS_deffile("Wx::StdDialogButtonSizer::new", XS_Wx__StdDialogButtonSizer_new);
        newXS_deffile("Wx::StdDialogButtonSizer::AddButton", XS_Wx__StdDialogButtonSizer_AddButton);
        newXS_deffile("Wx::StdDialogButtonSizer::SetAffirmativeButton", XS_Wx__StdDialogButtonSizer_SetAffirmativeButton);
        newXS_deffile("Wx::StdDialogButtonSizer::SetNegativeButton", XS_Wx__StdDialogButtonSizer_SetNegativeButton);
        newXS_deffile("Wx::StdDialogButtonSizer::SetCancelButton", XS_Wx__StdDialogButtonSizer_SetCancelButton);
        newXS_deffile("Wx::StdDialogButtonSizer::Realize", XS_Wx__StdDialogButtonSizer_Realize);
        newXS_deffile("Wx::StdDialogButtonSizer::GetAffirmativeButton", XS_Wx__StdDialogButtonSizer_GetAffirmativeButton);
        newXS_deffile("Wx::StdDialogButtonSizer::GetApplyButton", XS_Wx__StdDialogButtonSizer_GetApplyButton);
        newXS_deffile("Wx::StdDialogButtonSizer::GetNegativeButton", XS_Wx__StdDialogButtonSizer_GetNegativeButton);
        newXS_deffile("Wx::StdDialogButtonSizer::GetCancelButton", XS_Wx__StdDialogButtonSizer_GetCancelButton);
        newXS_deffile("Wx::StdDialogButtonSizer::GetHelpButton", XS_Wx__StdDialogButtonSizer_GetHelpButton);
#endif
#if XSubPPtmpAAEQ
        newXS_deffile("Wx::WrapSizer::new", XS_Wx__WrapSizer_new);
        newXS_deffile("Wx::WrapSizer::InformFirstDirection", XS_Wx__WrapSizer_InformFirstDirection);
#endif
        newXS_deffile("Wx::Sizer::Destroy", XS_Wx__Sizer_Destroy);
        newXS_deffile("Wx::Sizer::GetChildren", XS_Wx__Sizer_GetChildren);
        newXS_deffile("Wx::BoxSizer::new", XS_Wx__BoxSizer_new);
        newXS_deffile("Wx::BoxSizer::GetOrientation", XS_Wx__BoxSizer_GetOrientation);
#if XSubPPtmpAAER
        newXS_deffile("Wx::BoxSizer::SetOrientation", XS_Wx__BoxSizer_SetOrientation);
#endif
#if XSubPPtmpAAES
        newXS_deffile("Wx::BoxSizer::IsVertical", XS_Wx__BoxSizer_IsVertical);
#endif
        newXS_deffile("Wx::StaticBoxSizer::new", XS_Wx__StaticBoxSizer_new);
        newXS_deffile("Wx::StaticBoxSizer::GetStaticBox", XS_Wx__StaticBoxSizer_GetStaticBox);
        newXS_deffile("Wx::NotebookSizer::new", XS_Wx__NotebookSizer_new);
        newXS_deffile("Wx::NotebookSizer::GetNotebook", XS_Wx__NotebookSizer_GetNotebook);
        newXS_deffile("Wx::GridSizer::new", XS_Wx__GridSizer_new);
        newXS_deffile("Wx::GridSizer::GetCols", XS_Wx__GridSizer_GetCols);
        newXS_deffile("Wx::GridSizer::GetHGap", XS_Wx__GridSizer_GetHGap);
        newXS_deffile("Wx::GridSizer::GetRows", XS_Wx__GridSizer_GetRows);
        newXS_deffile("Wx::GridSizer::GetVGap", XS_Wx__GridSizer_GetVGap);
        newXS_deffile("Wx::GridSizer::SetCols", XS_Wx__GridSizer_SetCols);
        newXS_deffile("Wx::GridSizer::SetHGap", XS_Wx__GridSizer_SetHGap);
        newXS_deffile("Wx::GridSizer::SetRows", XS_Wx__GridSizer_SetRows);
        newXS_deffile("Wx::GridSizer::SetVGap", XS_Wx__GridSizer_SetVGap);
        newXS_deffile("Wx::FlexGridSizer::new", XS_Wx__FlexGridSizer_new);
        newXS_deffile("Wx::FlexGridSizer::RemoveGrowableCol", XS_Wx__FlexGridSizer_RemoveGrowableCol);
        newXS_deffile("Wx::FlexGridSizer::RemoveGrowableRow", XS_Wx__FlexGridSizer_RemoveGrowableRow);
        newXS_deffile("Wx::SizerItem::GetSize", XS_Wx__SizerItem_GetSize);
        newXS_deffile("Wx::SizerItem::CalcMin", XS_Wx__SizerItem_CalcMin);
        newXS_deffile("Wx::SizerItem::SetDimension", XS_Wx__SizerItem_SetDimension);
        newXS_deffile("Wx::SizerItem::GetMinSize", XS_Wx__SizerItem_GetMinSize);
        newXS_deffile("Wx::SizerItem::GetRatio", XS_Wx__SizerItem_GetRatio);
        newXS_deffile("Wx::SizerItem::IsWindow", XS_Wx__SizerItem_IsWindow);
        newXS_deffile("Wx::SizerItem::IsShown", XS_Wx__SizerItem_IsShown);
        newXS_deffile("Wx::SizerItem::IsSizer", XS_Wx__SizerItem_IsSizer);
        newXS_deffile("Wx::SizerItem::IsSpacer", XS_Wx__SizerItem_IsSpacer);
        newXS_deffile("Wx::SizerItem::SetInitSize", XS_Wx__SizerItem_SetInitSize);
        newXS_deffile("Wx::SizerItem::SetFlag", XS_Wx__SizerItem_SetFlag);
        newXS_deffile("Wx::SizerItem::SetBorder", XS_Wx__SizerItem_SetBorder);
        newXS_deffile("Wx::SizerItem::GetWindow", XS_Wx__SizerItem_GetWindow);
#if XSubPPtmpAAET
        newXS_deffile("Wx::SizerItem::AssignWindow", XS_Wx__SizerItem_AssignWindow);
#endif
#if XSubPPtmpAAEU
        newXS_deffile("Wx::SizerItem::SetWindow", XS_Wx__SizerItem_SetWindow);
#endif
        newXS_deffile("Wx::SizerItem::GetSizer", XS_Wx__SizerItem_GetSizer);
#if XSubPPtmpAAEV
        newXS_deffile("Wx::SizerItem::AssignSizer", XS_Wx__SizerItem_AssignSizer);
#endif
#if XSubPPtmpAAEW
        newXS_deffile("Wx::SizerItem::SetSizer", XS_Wx__SizerItem_SetSizer);
#endif
        newXS_deffile("Wx::SizerItem::GetFlag", XS_Wx__SizerItem_GetFlag);
        newXS_deffile("Wx::SizerItem::GetBorder", XS_Wx__SizerItem_GetBorder);
        newXS_deffile("Wx::SizerItem::GetPosition", XS_Wx__SizerItem_GetPosition);
        newXS_deffile("Wx::SizerItem::GetUserData", XS_Wx__SizerItem_GetUserData);
#if XSubPPtmpAAEX
        newXS_deffile("Wx::SizerItem::SetUserData", XS_Wx__SizerItem_SetUserData);
#endif
        newXS_deffile("Wx::PlSizer::new", XS_Wx__PlSizer_new);
#if XSubPPtmpAAEY
        newXS_deffile("Wx::GBPosition::new", XS_Wx__GBPosition_new);
        newXS_deffile("Wx::GBPosition::GetRow", XS_Wx__GBPosition_GetRow);
        newXS_deffile("Wx::GBPosition::GetCol", XS_Wx__GBPosition_GetCol);
        newXS_deffile("Wx::GBPosition::SetRow", XS_Wx__GBPosition_SetRow);
        newXS_deffile("Wx::GBPosition::SetCol", XS_Wx__GBPosition_SetCol);
        newXS_deffile("Wx::GBSpan::new", XS_Wx__GBSpan_new);
        newXS_deffile("Wx::GBSpan::GetRowspan", XS_Wx__GBSpan_GetRowspan);
        newXS_deffile("Wx::GBSpan::GetColspan", XS_Wx__GBSpan_GetColspan);
        newXS_deffile("Wx::GBSpan::SetRowspan", XS_Wx__GBSpan_SetRowspan);
        newXS_deffile("Wx::GBSpan::SetColspan", XS_Wx__GBSpan_SetColspan);
        newXS_deffile("Wx::GBSizerItem::GetPos", XS_Wx__GBSizerItem_GetPos);
        newXS_deffile("Wx::GBSizerItem::GetPosXY", XS_Wx__GBSizerItem_GetPosXY);
        newXS_deffile("Wx::GBSizerItem::GetSpan", XS_Wx__GBSizerItem_GetSpan);
        newXS_deffile("Wx::GBSizerItem::GetSpanWH", XS_Wx__GBSizerItem_GetSpanWH);
        newXS_deffile("Wx::GBSizerItem::SetPos", XS_Wx__GBSizerItem_SetPos);
        newXS_deffile("Wx::GBSizerItem::SetSpan", XS_Wx__GBSizerItem_SetSpan);
        newXS_deffile("Wx::GBSizerItem::IntersectsItem", XS_Wx__GBSizerItem_IntersectsItem);
        newXS_deffile("Wx::GBSizerItem::IntersectsPosition", XS_Wx__GBSizerItem_IntersectsPosition);
        newXS_deffile("Wx::GBSizerItem::Intersects", XS_Wx__GBSizerItem_Intersects);
        newXS_deffile("Wx::GBSizerItem::GetEndPos", XS_Wx__GBSizerItem_GetEndPos);
        newXS_deffile("Wx::GBSizerItem::GetGBSizer", XS_Wx__GBSizerItem_GetGBSizer);
        newXS_deffile("Wx::GBSizerItem::SetGBSizer", XS_Wx__GBSizerItem_SetGBSizer);
        newXS_deffile("Wx::GridBagSizer::new", XS_Wx__GridBagSizer_new);
        newXS_deffile("Wx::GridBagSizer::AddWindow", XS_Wx__GridBagSizer_AddWindow);
        newXS_deffile("Wx::GridBagSizer::AddSizer", XS_Wx__GridBagSizer_AddSizer);
        newXS_deffile("Wx::GridBagSizer::AddSpace", XS_Wx__GridBagSizer_AddSpace);
        newXS_deffile("Wx::GridBagSizer::AddItem", XS_Wx__GridBagSizer_AddItem);
        newXS_deffile("Wx::GridBagSizer::GetEmptyCellSize", XS_Wx__GridBagSizer_GetEmptyCellSize);
        newXS_deffile("Wx::GridBagSizer::SetEmptyCellSize", XS_Wx__GridBagSizer_SetEmptyCellSize);
        newXS_deffile("Wx::GridBagSizer::GetCellSize", XS_Wx__GridBagSizer_GetCellSize);
        newXS_deffile("Wx::GridBagSizer::GetItemPositionWindow", XS_Wx__GridBagSizer_GetItemPositionWindow);
        newXS_deffile("Wx::GridBagSizer::GetItemPositionSizer", XS_Wx__GridBagSizer_GetItemPositionSizer);
        newXS_deffile("Wx::GridBagSizer::GetItemPositionIndex", XS_Wx__GridBagSizer_GetItemPositionIndex);
        newXS_deffile("Wx::GridBagSizer::GetItemPosition", XS_Wx__GridBagSizer_GetItemPosition);
        newXS_deffile("Wx::GridBagSizer::SetItemPositionWindow", XS_Wx__GridBagSizer_SetItemPositionWindow);
        newXS_deffile("Wx::GridBagSizer::SetItemPositionSizer", XS_Wx__GridBagSizer_SetItemPositionSizer);
        newXS_deffile("Wx::GridBagSizer::SetItemPositionIndex", XS_Wx__GridBagSizer_SetItemPositionIndex);
        newXS_deffile("Wx::GridBagSizer::SetItemPosition", XS_Wx__GridBagSizer_SetItemPosition);
        newXS_deffile("Wx::GridBagSizer::GetItemSpanWindow", XS_Wx__GridBagSizer_GetItemSpanWindow);
        newXS_deffile("Wx::GridBagSizer::GetItemSpanSizer", XS_Wx__GridBagSizer_GetItemSpanSizer);
        newXS_deffile("Wx::GridBagSizer::GetItemSpanIndex", XS_Wx__GridBagSizer_GetItemSpanIndex);
        newXS_deffile("Wx::GridBagSizer::GetItemSpan", XS_Wx__GridBagSizer_GetItemSpan);
        newXS_deffile("Wx::GridBagSizer::SetItemSpanWindow", XS_Wx__GridBagSizer_SetItemSpanWindow);
        newXS_deffile("Wx::GridBagSizer::SetItemSpanSizer", XS_Wx__GridBagSizer_SetItemSpanSizer);
        newXS_deffile("Wx::GridBagSizer::SetItemSpanIndex", XS_Wx__GridBagSizer_SetItemSpanIndex);
        newXS_deffile("Wx::GridBagSizer::SetItemSpan", XS_Wx__GridBagSizer_SetItemSpan);
        newXS_deffile("Wx::GridBagSizer::FindItemWindow", XS_Wx__GridBagSizer_FindItemWindow);
        newXS_deffile("Wx::GridBagSizer::FindItemSizer", XS_Wx__GridBagSizer_FindItemSizer);
        newXS_deffile("Wx::GridBagSizer::FindItem", XS_Wx__GridBagSizer_FindItem);
        newXS_deffile("Wx::GridBagSizer::FindItemAtPosition", XS_Wx__GridBagSizer_FindItemAtPosition);
        newXS_deffile("Wx::GridBagSizer::FindItemAtPoint", XS_Wx__GridBagSizer_FindItemAtPoint);
        newXS_deffile("Wx::GridBagSizer::CheckForIntersectionItem", XS_Wx__GridBagSizer_CheckForIntersectionItem);
        newXS_deffile("Wx::GridBagSizer::CheckForIntersectionPos", XS_Wx__GridBagSizer_CheckForIntersectionPos);
        newXS_deffile("Wx::GridBagSizer::CheckForIntersection", XS_Wx__GridBagSizer_CheckForIntersection);
        newXS_deffile("Wx::GridBagSizer::Add", XS_Wx__GridBagSizer_Add);
#endif
        newXS_deffile("Wx::SashEvent::new", XS_Wx__SashEvent_new);
        newXS_deffile("Wx::SashEvent::GetEdge", XS_Wx__SashEvent_GetEdge);
        newXS_deffile("Wx::SashEvent::GetDragRect", XS_Wx__SashEvent_GetDragRect);
        newXS_deffile("Wx::SashEvent::GetDragStatus", XS_Wx__SashEvent_GetDragStatus);
        newXS_deffile("Wx::SashWindow::new", XS_Wx__SashWindow_new);
        newXS_deffile("Wx::SashWindow::newDefault", XS_Wx__SashWindow_newDefault);
        newXS_deffile("Wx::SashWindow::newFull", XS_Wx__SashWindow_newFull);
        newXS_deffile("Wx::SashWindow::Create", XS_Wx__SashWindow_Create);
        newXS_deffile("Wx::SashWindow::GetSashVisible", XS_Wx__SashWindow_GetSashVisible);
        newXS_deffile("Wx::SashWindow::GetMaximumSizeX", XS_Wx__SashWindow_GetMaximumSizeX);
        newXS_deffile("Wx::SashWindow::GetMaximumSizeY", XS_Wx__SashWindow_GetMaximumSizeY);
        newXS_deffile("Wx::SashWindow::GetMinimumSizeX", XS_Wx__SashWindow_GetMinimumSizeX);
        newXS_deffile("Wx::SashWindow::GetMinimumSizeY", XS_Wx__SashWindow_GetMinimumSizeY);
#if XSubPPtmpAAEZ
        newXS_deffile("Wx::SashWindow::HasBorder", XS_Wx__SashWindow_HasBorder);
#endif
        newXS_deffile("Wx::SashWindow::SetMaximumSizeX", XS_Wx__SashWindow_SetMaximumSizeX);
        newXS_deffile("Wx::SashWindow::SetMaximumSizeY", XS_Wx__SashWindow_SetMaximumSizeY);
        newXS_deffile("Wx::SashWindow::SetMinimumSizeX", XS_Wx__SashWindow_SetMinimumSizeX);
        newXS_deffile("Wx::SashWindow::SetMinimumSizeY", XS_Wx__SashWindow_SetMinimumSizeY);
        newXS_deffile("Wx::SashWindow::SetSashVisible", XS_Wx__SashWindow_SetSashVisible);
#if XSubPPtmpAAFA
        newXS_deffile("Wx::SashWindow::SetSashBorder", XS_Wx__SashWindow_SetSashBorder);
#endif

    /* Initialisation Section */

#if XSubPPtmpAAAA
#endif
#if XSubPPtmpAAAB
#endif
#if XSubPPtmpAAAC
#endif
#if XSubPPtmpAAAD
#endif
#if XSubPPtmpAAAE
#endif
#if XSubPPtmpAAAF
#endif
#if XSubPPtmpAAAG
#endif
#if XSubPPtmpAAAH
#endif
#if XSubPPtmpAAAI
#endif
#if XSubPPtmpAAAJ
#endif
#if XSubPPtmpAAAK
#endif
#if XSubPPtmpAAAL
#endif
#if XSubPPtmpAAAM
#endif
#if XSubPPtmpAAAN
#endif
#if XSubPPtmpAAAO
#endif
#if XSubPPtmpAAAP
#endif
#if XSubPPtmpAAAQ
#endif
#if XSubPPtmpAAAR
#endif
#if XSubPPtmpAAAS
#endif
#if XSubPPtmpAAAT
#endif
#if XSubPPtmpAAAU
#endif
#if XSubPPtmpAAAV
#endif
#if XSubPPtmpAAAW
#endif
#if XSubPPtmpAAAX
#endif
#if XSubPPtmpAAAY
#endif
#if XSubPPtmpAAAZ
#endif
#if XSubPPtmpAABA
#endif
#if XSubPPtmpAABB
#endif
#if XSubPPtmpAABC
#endif
#if XSubPPtmpAABD
#endif
#if XSubPPtmpAABE
#endif
#if XSubPPtmpAABF
#endif
#if XSubPPtmpAABG
#endif
#if XSubPPtmpAABH
#endif
#if XSubPPtmpAABI
#endif
#if XSubPPtmpAABJ
#endif
#if XSubPPtmpAABK
#endif
#if XSubPPtmpAABL
#endif
#if XSubPPtmpAABM
#endif
#if XSubPPtmpAABN
#endif
#if XSubPPtmpAABO
#endif
#if XSubPPtmpAABP
#endif
#if XSubPPtmpAABQ
#endif
#if XSubPPtmpAABR
#endif
#if XSubPPtmpAABS
#endif
#if XSubPPtmpAABT
#endif
#if XSubPPtmpAABU
#endif
#if XSubPPtmpAABV
#endif
#if XSubPPtmpAABW
#endif
#if XSubPPtmpAABX
#endif
#if XSubPPtmpAABY
#endif
#if XSubPPtmpAABZ
#endif
#if XSubPPtmpAACA
#endif
#if XSubPPtmpAACB
#endif
#if XSubPPtmpAACC
#endif
#if XSubPPtmpAACD
#endif
#if XSubPPtmpAACE
#endif
#if XSubPPtmpAACF
#endif
#if XSubPPtmpAACG
#endif
#if XSubPPtmpAACH
#endif
#if XSubPPtmpAACI
#endif
#if XSubPPtmpAACJ
#endif
#if XSubPPtmpAACK
#endif
#if XSubPPtmpAACL
#endif
#if XSubPPtmpAACM
#endif
#if XSubPPtmpAACN
#if XSubPPtmpAACO
#endif
#if XSubPPtmpAACP
#if XSubPPtmpAACQ
#endif
#endif
#if XSubPPtmpAACR
#endif
#if XSubPPtmpAACS
#endif
#if XSubPPtmpAACT
#endif
#endif
#if XSubPPtmpAACU
#endif
#if XSubPPtmpAACV
#endif
#if XSubPPtmpAACW
#endif
#if XSubPPtmpAACX
#endif
#if XSubPPtmpAACY
#endif
#if XSubPPtmpAACZ
#endif
#if XSubPPtmpAADA
#endif
#if XSubPPtmpAADB
#endif
#if XSubPPtmpAADC
#endif
#if XSubPPtmpAADD
#endif
#if XSubPPtmpAADE
#endif
#if XSubPPtmpAADF
#endif
#if XSubPPtmpAADG
#endif
#if XSubPPtmpAADH
#endif
#if XSubPPtmpAADI
#endif
#if XSubPPtmpAADJ
#endif
#if XSubPPtmpAADK
#endif
#if XSubPPtmpAADL
#endif
#if XSubPPtmpAADM
#endif
#if XSubPPtmpAADN
#endif
#if XSubPPtmpAADO
#endif
#if XSubPPtmpAADP
#endif
#if XSubPPtmpAADQ
#endif
#if XSubPPtmpAADR
#endif
#if XSubPPtmpAADS
#endif
#if XSubPPtmpAADT
#endif
#if XSubPPtmpAADU
#endif
#if XSubPPtmpAADV
#endif
#if XSubPPtmpAADW
#endif
#if XSubPPtmpAADX
#endif
#if XSubPPtmpAADY
#endif
#if XSubPPtmpAADZ
#endif
#if XSubPPtmpAAEA
#endif
#if XSubPPtmpAAEB
#endif
#if XSubPPtmpAAEC
#endif
#if XSubPPtmpAAED
#endif
#if XSubPPtmpAAEE
#endif
#if XSubPPtmpAAEF
#endif
#if XSubPPtmpAAEG
#endif
#if XSubPPtmpAAEH
#endif
#if XSubPPtmpAAEI
#endif
#if XSubPPtmpAAEJ
#endif
#if XSubPPtmpAAEK
#endif
#if XSubPPtmpAAEL
#endif
#if XSubPPtmpAAEM
#endif
#if XSubPPtmpAAEN
#endif
#if XSubPPtmpAAEO
#endif
#if XSubPPtmpAAEP
#endif
#if XSubPPtmpAAEQ
#endif
#if XSubPPtmpAAER
#endif
#if XSubPPtmpAAES
#endif
#if XSubPPtmpAAET
#endif
#if XSubPPtmpAAEU
#endif
#if XSubPPtmpAAEV
#endif
#if XSubPPtmpAAEW
#endif
#if XSubPPtmpAAEX
#endif
#if XSubPPtmpAAEY
#endif
#if XSubPPtmpAAEZ
#endif
#if XSubPPtmpAAFA
#endif

    /* End of Initialisation Section */

#if PERL_VERSION_LE(5, 21, 5)
#  if PERL_VERSION_GE(5, 9, 0)
    if (PL_unitcheckav)
        call_list(PL_scopestack_ix, PL_unitcheckav);
#  endif
    XSRETURN_YES;
#else
    Perl_xs_boot_epilog(aTHX_ ax);
#endif
}

