/*
 * This file was generated automatically by ExtUtils::ParseXS version 3.44 from the
 * contents of RichText.xs. Do not edit this file, edit RichText.xs instead.
 *
 *    ANY CHANGES MADE HERE WILL BE LOST!
 *
 */

/////////////////////////////////////////////////////////////////////////////
// Name:        ext/richtext/RichText.xs
// Purpose:     XS for Wx::RichTextCtrl
// Author:      Mattia Barbon
// Modified by:
// Created:     05/11/2006
// RCS-ID:      $Id: RichText.xs 3281 2012-05-06 07:25:12Z mdootson $
// Copyright:   (c) 2006-2010 Mattia Barbon
// Licence:     This program is free software; you can redistribute it and/or
//              modify it under the same terms as Perl itself
/////////////////////////////////////////////////////////////////////////////

#define PERL_NO_GET_CONTEXT

#include "cpp/wxapi.h"
#include "cpp/constants.h"
#include "cpp/overload.h"

#define wxNullColourPtr (wxColour*)&wxNullColour
#define wxNullFontPtr (wxFont*)&wxNullFont

#undef THIS

#include <wx/richtext/richtextctrl.h>

// event macros
#define SEVT( NAME, ARGS )    wxPli_StdEvent( NAME, ARGS )
#define EVT( NAME, ARGS, ID ) wxPli_Event( NAME, ARGS, ID )

// !package: Wx::Event
// !tag:
// !parser: sub { $_[0] =~ m<^\s*S?EVT\(\s*(\w+)\s*\,> }

static wxPliEventDescription evts[] =
{
#if WXPERL_W_VERSION_LE( 2, 7, 2 )
    EVT( EVT_RICHTEXT_ITEM_SELECTED, 3, wxEVT_COMMAND_RICHTEXT_ITEM_SELECTED )
    EVT( EVT_RICHTEXT_ITEM_DESELECTED, 3, wxEVT_COMMAND_RICHTEXT_ITEM_DESELECTED )
#endif
    EVT( EVT_RICHTEXT_LEFT_CLICK, 3, wxEVT_COMMAND_RICHTEXT_LEFT_CLICK )
    EVT( EVT_RICHTEXT_RIGHT_CLICK, 3, wxEVT_COMMAND_RICHTEXT_RIGHT_CLICK )
    EVT( EVT_RICHTEXT_MIDDLE_CLICK, 3, wxEVT_COMMAND_RICHTEXT_MIDDLE_CLICK )
    EVT( EVT_RICHTEXT_LEFT_DCLICK, 3, wxEVT_COMMAND_RICHTEXT_LEFT_DCLICK )
    EVT( EVT_RICHTEXT_RETURN, 3, wxEVT_COMMAND_RICHTEXT_RETURN )
#if WXPERL_W_VERSION_GE( 2, 7, 2 )
    EVT( EVT_RICHTEXT_STYLESHEET_CHANGING, 3, wxEVT_COMMAND_RICHTEXT_STYLESHEET_CHANGING )
    EVT( EVT_RICHTEXT_STYLESHEET_CHANGED, 3, wxEVT_COMMAND_RICHTEXT_STYLESHEET_CHANGED )
    EVT( EVT_RICHTEXT_STYLESHEET_REPLACING, 3, wxEVT_COMMAND_RICHTEXT_STYLESHEET_REPLACING )
    EVT( EVT_RICHTEXT_STYLESHEET_REPLACED, 3, wxEVT_COMMAND_RICHTEXT_STYLESHEET_REPLACED )
#endif
#if WXPERL_W_VERSION_GE( 2, 8, 11 )
    EVT( EVT_RICHTEXT_CHARACTER, 3, wxEVT_COMMAND_RICHTEXT_CHARACTER )
    EVT( EVT_RICHTEXT_DELETE, 3, wxEVT_COMMAND_RICHTEXT_DELETE )
    EVT( EVT_RICHTEXT_STYLE_CHANGED, 3, wxEVT_COMMAND_RICHTEXT_STYLE_CHANGED )
    EVT( EVT_RICHTEXT_CONTENT_INSERTED, 3, wxEVT_COMMAND_RICHTEXT_CONTENT_INSERTED )
    EVT( EVT_RICHTEXT_CONTENT_DELETED, 3, wxEVT_COMMAND_RICHTEXT_CONTENT_DELETED )
#endif
    { 0, 0, 0 }
};

#define wxPliRichTextStyleType wxRichTextStyleListBox::wxRichTextStyleType
#if WXPERL_W_VERSION_LT( 2, 8, 0 )
#undef _
#define _( s ) wxT( s )
#endif

#ifndef PERL_UNUSED_VAR
#  define PERL_UNUSED_VAR(var) if (0) var = var
#endif

#ifndef dVAR
#  define dVAR		dNOOP
#endif


/* This stuff is not part of the API! You have been warned. */
#ifndef PERL_VERSION_DECIMAL
#  define PERL_VERSION_DECIMAL(r,v,s) (r*1000000 + v*1000 + s)
#endif
#ifndef PERL_DECIMAL_VERSION
#  define PERL_DECIMAL_VERSION \
	  PERL_VERSION_DECIMAL(PERL_REVISION,PERL_VERSION,PERL_SUBVERSION)
#endif
#ifndef PERL_VERSION_GE
#  define PERL_VERSION_GE(r,v,s) \
	  (PERL_DECIMAL_VERSION >= PERL_VERSION_DECIMAL(r,v,s))
#endif
#ifndef PERL_VERSION_LE
#  define PERL_VERSION_LE(r,v,s) \
	  (PERL_DECIMAL_VERSION <= PERL_VERSION_DECIMAL(r,v,s))
#endif

/* XS_INTERNAL is the explicit static-linkage variant of the default
 * XS macro.
 *
 * XS_EXTERNAL is the same as XS_INTERNAL except it does not include
 * "STATIC", ie. it exports XSUB symbols. You probably don't want that
 * for anything but the BOOT XSUB.
 *
 * See XSUB.h in core!
 */


/* TODO: This might be compatible further back than 5.10.0. */
#if PERL_VERSION_GE(5, 10, 0) && PERL_VERSION_LE(5, 15, 1)
#  undef XS_EXTERNAL
#  undef XS_INTERNAL
#  if defined(__CYGWIN__) && defined(USE_DYNAMIC_LOADING)
#    define XS_EXTERNAL(name) __declspec(dllexport) XSPROTO(name)
#    define XS_INTERNAL(name) STATIC XSPROTO(name)
#  endif
#  if defined(__SYMBIAN32__)
#    define XS_EXTERNAL(name) EXPORT_C XSPROTO(name)
#    define XS_INTERNAL(name) EXPORT_C STATIC XSPROTO(name)
#  endif
#  ifndef XS_EXTERNAL
#    if defined(HASATTRIBUTE_UNUSED) && !defined(__cplusplus)
#      define XS_EXTERNAL(name) void name(pTHX_ CV* cv __attribute__unused__)
#      define XS_INTERNAL(name) STATIC void name(pTHX_ CV* cv __attribute__unused__)
#    else
#      ifdef __cplusplus
#        define XS_EXTERNAL(name) extern "C" XSPROTO(name)
#        define XS_INTERNAL(name) static XSPROTO(name)
#      else
#        define XS_EXTERNAL(name) XSPROTO(name)
#        define XS_INTERNAL(name) STATIC XSPROTO(name)
#      endif
#    endif
#  endif
#endif

/* perl >= 5.10.0 && perl <= 5.15.1 */


/* The XS_EXTERNAL macro is used for functions that must not be static
 * like the boot XSUB of a module. If perl didn't have an XS_EXTERNAL
 * macro defined, the best we can do is assume XS is the same.
 * Dito for XS_INTERNAL.
 */
#ifndef XS_EXTERNAL
#  define XS_EXTERNAL(name) XS(name)
#endif
#ifndef XS_INTERNAL
#  define XS_INTERNAL(name) XS(name)
#endif

/* Now, finally, after all this mess, we want an ExtUtils::ParseXS
 * internal macro that we're free to redefine for varying linkage due
 * to the EXPORT_XSUB_SYMBOLS XS keyword. This is internal, use
 * XS_EXTERNAL(name) or XS_INTERNAL(name) in your code if you need to!
 */

#undef XS_EUPXS
#if defined(PERL_EUPXS_ALWAYS_EXPORT)
#  define XS_EUPXS(name) XS_EXTERNAL(name)
#else
   /* default to internal */
#  define XS_EUPXS(name) XS_INTERNAL(name)
#endif

#ifndef PERL_ARGS_ASSERT_CROAK_XS_USAGE
#define PERL_ARGS_ASSERT_CROAK_XS_USAGE assert(cv); assert(params)

/* prototype to pass -Wmissing-prototypes */
STATIC void
S_croak_xs_usage(const CV *const cv, const char *const params);

STATIC void
S_croak_xs_usage(const CV *const cv, const char *const params)
{
    const GV *const gv = CvGV(cv);

    PERL_ARGS_ASSERT_CROAK_XS_USAGE;

    if (gv) {
        const char *const gvname = GvNAME(gv);
        const HV *const stash = GvSTASH(gv);
        const char *const hvname = stash ? HvNAME(stash) : NULL;

        if (hvname)
	    Perl_croak_nocontext("Usage: %s::%s(%s)", hvname, gvname, params);
        else
	    Perl_croak_nocontext("Usage: %s(%s)", gvname, params);
    } else {
        /* Pants. I don't think that it should be possible to get here. */
	Perl_croak_nocontext("Usage: CODE(0x%" UVxf ")(%s)", PTR2UV(cv), params);
    }
}
#undef  PERL_ARGS_ASSERT_CROAK_XS_USAGE

#define croak_xs_usage        S_croak_xs_usage

#endif

/* NOTE: the prototype of newXSproto() is different in versions of perls,
 * so we define a portable version of newXSproto()
 */
#ifdef newXS_flags
#define newXSproto_portable(name, c_impl, file, proto) newXS_flags(name, c_impl, file, proto, 0)
#else
#define newXSproto_portable(name, c_impl, file, proto) (PL_Sv=(SV*)newXS(name, c_impl, file), sv_setpv(PL_Sv, proto), (CV*)PL_Sv)
#endif /* !defined(newXS_flags) */

#if PERL_VERSION_LE(5, 21, 5)
#  define newXS_deffile(a,b) Perl_newXS(aTHX_ a,b,file)
#else
#  define newXS_deffile(a,b) Perl_newXS_deffile(aTHX_ a,b)
#endif


/* INCLUDE_COMMAND:  Including output of '/usr/bin/perl -I../.. -MExtUtils::XSpp::Cmd -e xspp -- -t typemap.xsp -t ../../typemap.xsp XS/RichTextCtrl.xsp' from 'RichText.xs' */

#include <exception>

#undef  xsp_constructor_class
#define xsp_constructor_class(c) (c)
#undef _
#define _(x) wxGetTranslation(wxT(x))
#include <wx/event.h>
#include <wx/button.h>
#include <wx/checkbox.h>
#include <wx/richtext/richtextctrl.h>
#include <wx/richtext/richtextstyles.h>
#include <wx/richtext/richtextformatdlg.h>
#include <wx/richtext/richtextstyledlg.h>
#include <wx/richtext/richtextprint.h>
#include "xspp/richtextctrl.h"
#if WXPERL_W_VERSION_LE( 2, 7, 2 )
#define XSpp_7969698b_013544
#define XSubPPtmpAAAA 1


XS_EUPXS(XS_Wx__RichTextEvent_GetIndex); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextEvent_GetIndex)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxRichTextEvent *    THIS = (wxRichTextEvent *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextEvent" )
;
	int	RETVAL;
	dXSTARG;
    try {
      RETVAL = THIS->GetIndex();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__RichTextEvent_SetIndex); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextEvent_SetIndex)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, n");
    {
	wxRichTextEvent *    THIS = (wxRichTextEvent *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextEvent" )
;
	int	n = (int)SvIV(ST(1))
;
    try {
      THIS->SetIndex( n );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}

#endif

XS_EUPXS(XS_Wx__RichTextEvent_GetFlags); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextEvent_GetFlags)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxRichTextEvent *    THIS = (wxRichTextEvent *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextEvent" )
;
	int	RETVAL;
	dXSTARG;
    try {
      RETVAL = THIS->GetFlags();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__RichTextEvent_SetFlags); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextEvent_SetFlags)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, flags");
    {
	wxRichTextEvent *    THIS = (wxRichTextEvent *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextEvent" )
;
	int	flags = (int)SvIV(ST(1))
;
    try {
      THIS->SetFlags( flags );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}

#if WXPERL_W_VERSION_GE( 2, 7, 2 )
#define XSpp_7969698b_009392
#define XSubPPtmpAAAB 1


XS_EUPXS(XS_Wx__RichTextEvent_GetOldStyleSheet); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextEvent_GetOldStyleSheet)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxRichTextEvent *    THIS = (wxRichTextEvent *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextEvent" )
;
	wxRichTextStyleSheet *	RETVAL;
    try {
      RETVAL = THIS->GetOldStyleSheet();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_object_2_sv( aTHX_ RETVALSV, RETVAL );
    wxPli_thread_sv_register( aTHX_ "Wx::RichTextStyleSheet", RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    wxPli_object_set_deleteable( aTHX_ ST(0), false );
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__RichTextEvent_SetOldStyleSheet); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextEvent_SetOldStyleSheet)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, sheet");
    {
	wxRichTextEvent *    THIS = (wxRichTextEvent *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextEvent" )
;
	wxRichTextStyleSheet*    sheet = (wxRichTextStyleSheet *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::RichTextStyleSheet" )
;
    try {
      THIS->SetOldStyleSheet( sheet );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__RichTextEvent_GetNewStyleSheet); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextEvent_GetNewStyleSheet)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxRichTextEvent *    THIS = (wxRichTextEvent *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextEvent" )
;
	wxRichTextStyleSheet *	RETVAL;
    try {
      RETVAL = THIS->GetNewStyleSheet();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_object_2_sv( aTHX_ RETVALSV, RETVAL );
    wxPli_thread_sv_register( aTHX_ "Wx::RichTextStyleSheet", RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    wxPli_object_set_deleteable( aTHX_ ST(0), false );
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__RichTextEvent_SetNewStyleSheet); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextEvent_SetNewStyleSheet)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, sheet");
    {
	wxRichTextEvent *    THIS = (wxRichTextEvent *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextEvent" )
;
	wxRichTextStyleSheet*    sheet = (wxRichTextStyleSheet *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::RichTextStyleSheet" )
;
    try {
      THIS->SetNewStyleSheet( sheet );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}

#endif
#undef  xsp_constructor_class
#define xsp_constructor_class(c) (CLASS)

XS_EUPXS(XS_Wx__RichTextCtrl_newDefault); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextCtrl_newDefault)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "CLASS");
    {
	char *	CLASS = (char *)SvPV_nolen(ST(0))
;
	wxRichTextCtrl *	RETVAL;
     RETVAL = new wxRichTextCtrl();
                wxPli_create_evthandler( aTHX_ RETVAL, CLASS );
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_evthandler_2_sv( aTHX_ RETVALSV, RETVAL );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}

#undef  xsp_constructor_class
#define xsp_constructor_class(c) (c)
#undef  xsp_constructor_class
#define xsp_constructor_class(c) (CLASS)

XS_EUPXS(XS_Wx__RichTextCtrl_newFull); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextCtrl_newFull)
{
    dVAR; dXSARGS;
    if (items < 2 || items > 7)
       croak_xs_usage(cv,  "CLASS, parent, id= wxID_ANY, string= wxEmptyString, pos= wxDefaultPosition, size= wxDefaultSize, style= wxRE_MULTILINE");
    {
	char *	CLASS = (char *)SvPV_nolen(ST(0))
;
	wxRichTextCtrl *	RETVAL;
	wxWindow*    parent = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::Window" )
;
	wxWindowID	id;
	wxString	string;
	wxPoint	pos;
	wxSize	size;
	long	style;

	if (items < 3)
	    id = wxID_ANY;
	else {
    id = wxPli_get_wxwindowid( aTHX_ ST(2) )
;
	}

	if (items < 4)
	    string = wxEmptyString;
	else {
    WXSTRING_INPUT( string, wxString, ST(3) )
;
	}

	if (items < 5)
	    pos = wxDefaultPosition;
	else {
    pos = wxPli_sv_2_wxpoint( aTHX_ ST(4) )
;
	}

	if (items < 6)
	    size = wxDefaultSize;
	else {
    size = wxPli_sv_2_wxsize( aTHX_ ST(5) )
;
	}

	if (items < 7)
	    style = wxRE_MULTILINE;
	else {
	    style = (long)SvIV(ST(6))
;
	}
     RETVAL = new wxRichTextCtrl( parent, id, string,
                                             pos, size, style );
                wxPli_create_evthandler( aTHX_ RETVAL, CLASS );
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_evthandler_2_sv( aTHX_ RETVALSV, RETVAL );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}

#undef  xsp_constructor_class
#define xsp_constructor_class(c) (c)

XS_EUPXS(XS_Wx__RichTextCtrl_Create); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextCtrl_Create)
{
    dVAR; dXSARGS;
    if (items < 2 || items > 7)
       croak_xs_usage(cv,  "THIS, parent, id= wxID_ANY, string= wxEmptyString, pos= wxDefaultPosition, size= wxDefaultSize, style= wxRE_MULTILINE");
    {
	wxRichTextCtrl *    THIS = (wxRichTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextCtrl" )
;
	bool	RETVAL;
	wxWindow*    parent = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::Window" )
;
	wxWindowID	id;
	wxString	string;
	wxPoint	pos;
	wxSize	size;
	long	style;

	if (items < 3)
	    id = wxID_ANY;
	else {
    id = wxPli_get_wxwindowid( aTHX_ ST(2) )
;
	}

	if (items < 4)
	    string = wxEmptyString;
	else {
    WXSTRING_INPUT( string, wxString, ST(3) )
;
	}

	if (items < 5)
	    pos = wxDefaultPosition;
	else {
    pos = wxPli_sv_2_wxpoint( aTHX_ ST(4) )
;
	}

	if (items < 6)
	    size = wxDefaultSize;
	else {
    size = wxPli_sv_2_wxsize( aTHX_ ST(5) )
;
	}

	if (items < 7)
	    style = wxRE_MULTILINE;
	else {
	    style = (long)SvIV(ST(6))
;
	}
    try {
      RETVAL = THIS->Create( parent, id, string, pos, size, style );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__RichTextCtrl_GetFilename); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextCtrl_GetFilename)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxRichTextCtrl *    THIS = (wxRichTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextCtrl" )
;
	wxString	RETVAL;
    try {
      RETVAL = THIS->GetFilename();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    WXSTRING_OUTPUT( RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__RichTextCtrl_SetFilename); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextCtrl_SetFilename)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, filename");
    {
	wxRichTextCtrl *    THIS = (wxRichTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextCtrl" )
;
	wxString	filename;

    WXSTRING_INPUT( filename, wxString, ST(1) )
;
    try {
      THIS->SetFilename( filename );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__RichTextCtrl_SetDelayedLayoutThreshold); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextCtrl_SetDelayedLayoutThreshold)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, threshold");
    {
	wxRichTextCtrl *    THIS = (wxRichTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextCtrl" )
;
	long	threshold = (long)SvIV(ST(1))
;
    try {
      THIS->SetDelayedLayoutThreshold( threshold );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__RichTextCtrl_GetDelayedLayoutThreshold); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextCtrl_GetDelayedLayoutThreshold)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxRichTextCtrl *    THIS = (wxRichTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextCtrl" )
;
	long	RETVAL;
	dXSTARG;
    try {
      RETVAL = THIS->GetDelayedLayoutThreshold();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__RichTextCtrl_SetStyleFromTo); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextCtrl_SetStyleFromTo)
{
    dVAR; dXSARGS;
    if (items != 4)
       croak_xs_usage(cv,  "THIS, start, end, style");
    {
	wxRichTextCtrl *    THIS = (wxRichTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextCtrl" )
;
	bool	RETVAL;
	long	start = (long)SvIV(ST(1))
;
	long	end = (long)SvIV(ST(2))
;
	wxTextAttr*    style = (wxTextAttr *) wxPli_sv_2_object( aTHX_ ST(3), "Wx::TextAttr" )
;
    try {
      RETVAL = THIS->SetStyle( start, end, *( style ) );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__RichTextCtrl_SetStyleExFromTo); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextCtrl_SetStyleExFromTo)
{
    dVAR; dXSARGS;
    if (items != 4)
       croak_xs_usage(cv,  "THIS, start, end, style");
    {
	wxRichTextCtrl *    THIS = (wxRichTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextCtrl" )
;
	bool	RETVAL;
	long	start = (long)SvIV(ST(1))
;
	long	end = (long)SvIV(ST(2))
;
	wxTextAttrEx*    style = (wxTextAttrEx *) wxPli_sv_2_object( aTHX_ ST(3), "Wx::TextAttrEx" )
;
    try {
      RETVAL = THIS->SetStyle( start, end, *( style ) );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__RichTextCtrl_SetStyleRange); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextCtrl_SetStyleRange)
{
    dVAR; dXSARGS;
    if (items != 3)
       croak_xs_usage(cv,  "THIS, range, style");
    {
	wxRichTextCtrl *    THIS = (wxRichTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextCtrl" )
;
	bool	RETVAL;
	wxRichTextRange*    range = (wxRichTextRange *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::RichTextRange" )
;
	wxRichTextAttr*    style = (wxRichTextAttr *) wxPli_sv_2_object( aTHX_ ST(2), "Wx::RichTextAttr" )
;
    try {
      RETVAL = THIS->SetStyle( *( range ), *( style ) );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}

#if WXPERL_W_VERSION_GE( 2, 7, 1 )
#define XSpp_7969698b_056866
#if WXPERL_W_VERSION_LT( 2, 9, 0 )
#define XSpp_7969698b_010884
#define XSubPPtmpAAAC 1


XS_EUPXS(XS_Wx__RichTextCtrl_SetStyleExExFromTo); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextCtrl_SetStyleExExFromTo)
{
    dVAR; dXSARGS;
    if (items < 4 || items > 5)
       croak_xs_usage(cv,  "THIS, start, end, style, flags= wxRICHTEXT_SETSTYLE_WITH_UNDO");
    {
	wxRichTextCtrl *    THIS = (wxRichTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextCtrl" )
;
	bool	RETVAL;
	long	start = (long)SvIV(ST(1))
;
	long	end = (long)SvIV(ST(2))
;
	wxTextAttrEx*    style = (wxTextAttrEx *) wxPli_sv_2_object( aTHX_ ST(3), "Wx::TextAttrEx" )
;
	int	flags;

	if (items < 5)
	    flags = wxRICHTEXT_SETSTYLE_WITH_UNDO;
	else {
	    flags = (int)SvIV(ST(4))
;
	}
    try {
      RETVAL = THIS->SetStyleEx( start, end, *( style ), flags );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}

#endif
#define XSubPPtmpAAAD 1


XS_EUPXS(XS_Wx__RichTextCtrl_SetStyleExRange); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextCtrl_SetStyleExRange)
{
    dVAR; dXSARGS;
    if (items < 3 || items > 4)
       croak_xs_usage(cv,  "THIS, range, style, flags= wxRICHTEXT_SETSTYLE_WITH_UNDO");
    {
	wxRichTextCtrl *    THIS = (wxRichTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextCtrl" )
;
	bool	RETVAL;
	wxRichTextRange*    range = (wxRichTextRange *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::RichTextRange" )
;
	wxTextAttrEx*    style = (wxTextAttrEx *) wxPli_sv_2_object( aTHX_ ST(2), "Wx::TextAttrEx" )
;
	int	flags;

	if (items < 4)
	    flags = wxRICHTEXT_SETSTYLE_WITH_UNDO;
	else {
	    flags = (int)SvIV(ST(3))
;
	}
    try {
      RETVAL = THIS->SetStyleEx( *( range ), *( style ), flags );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__RichTextCtrl_SetStyleExExRange); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextCtrl_SetStyleExExRange)
{
    dVAR; dXSARGS;
    if (items < 3 || items > 4)
       croak_xs_usage(cv,  "THIS, range, style, flags= wxRICHTEXT_SETSTYLE_WITH_UNDO");
    {
	wxRichTextCtrl *    THIS = (wxRichTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextCtrl" )
;
	bool	RETVAL;
	wxRichTextRange*    range = (wxRichTextRange *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::RichTextRange" )
;
	wxRichTextAttr*    style = (wxRichTextAttr *) wxPli_sv_2_object( aTHX_ ST(2), "Wx::RichTextAttr" )
;
	int	flags;

	if (items < 4)
	    flags = wxRICHTEXT_SETSTYLE_WITH_UNDO;
	else {
	    flags = (int)SvIV(ST(3))
;
	}
    try {
      RETVAL = THIS->SetStyleEx( *( range ), *( style ), flags );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}

#endif

XS_EUPXS(XS_Wx__RichTextCtrl_GetBasicStyle); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextCtrl_GetBasicStyle)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxRichTextCtrl *    THIS = (wxRichTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextCtrl" )
;
	wxTextAttrEx *	RETVAL;
    try {
      RETVAL = new wxTextAttrEx( THIS->GetBasicStyle() );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_non_object_2_sv( aTHX_ RETVALSV, RETVAL, "Wx::TextAttrEx" );
    wxPli_thread_sv_register( aTHX_ "Wx::TextAttrEx", RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__RichTextCtrl_GetDefaultStyleEx); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextCtrl_GetDefaultStyleEx)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxRichTextCtrl *    THIS = (wxRichTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextCtrl" )
;
	wxTextAttrEx *	RETVAL;
    try {
      RETVAL = new wxTextAttrEx( THIS->GetDefaultStyleEx() );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_non_object_2_sv( aTHX_ RETVALSV, RETVAL, "Wx::TextAttrEx" );
    wxPli_thread_sv_register( aTHX_ "Wx::TextAttrEx", RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__RichTextCtrl_Newline); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextCtrl_Newline)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxRichTextCtrl *    THIS = (wxRichTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextCtrl" )
;
	bool	RETVAL;
    try {
      RETVAL = THIS->Newline();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}

#if WXPERL_W_VERSION_GE( 2, 8, 0 )
#define XSpp_7969698b_010099
#define XSubPPtmpAAAE 1


XS_EUPXS(XS_Wx__RichTextCtrl_LineBreak); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextCtrl_LineBreak)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxRichTextCtrl *    THIS = (wxRichTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextCtrl" )
;
	bool	RETVAL;
    try {
      RETVAL = THIS->LineBreak();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}

#endif

XS_EUPXS(XS_Wx__RichTextCtrl_BeginStyle); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextCtrl_BeginStyle)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, style");
    {
	wxRichTextCtrl *    THIS = (wxRichTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextCtrl" )
;
	bool	RETVAL;
	wxTextAttrEx*    style = (wxTextAttrEx *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::TextAttrEx" )
;
    try {
      RETVAL = THIS->BeginStyle( *( style ) );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__RichTextCtrl_EndStyle); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextCtrl_EndStyle)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxRichTextCtrl *    THIS = (wxRichTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextCtrl" )
;
	bool	RETVAL;
    try {
      RETVAL = THIS->EndStyle();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__RichTextCtrl_EndAllStyles); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextCtrl_EndAllStyles)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxRichTextCtrl *    THIS = (wxRichTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextCtrl" )
;
	bool	RETVAL;
    try {
      RETVAL = THIS->EndAllStyles();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__RichTextCtrl_BeginBold); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextCtrl_BeginBold)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxRichTextCtrl *    THIS = (wxRichTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextCtrl" )
;
	bool	RETVAL;
    try {
      RETVAL = THIS->BeginBold();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__RichTextCtrl_EndBold); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextCtrl_EndBold)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxRichTextCtrl *    THIS = (wxRichTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextCtrl" )
;
	bool	RETVAL;
    try {
      RETVAL = THIS->EndBold();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__RichTextCtrl_BeginItalic); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextCtrl_BeginItalic)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxRichTextCtrl *    THIS = (wxRichTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextCtrl" )
;
	bool	RETVAL;
    try {
      RETVAL = THIS->BeginItalic();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__RichTextCtrl_EndItalic); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextCtrl_EndItalic)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxRichTextCtrl *    THIS = (wxRichTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextCtrl" )
;
	bool	RETVAL;
    try {
      RETVAL = THIS->EndItalic();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__RichTextCtrl_BeginUnderline); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextCtrl_BeginUnderline)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxRichTextCtrl *    THIS = (wxRichTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextCtrl" )
;
	bool	RETVAL;
    try {
      RETVAL = THIS->BeginUnderline();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__RichTextCtrl_EndUnderline); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextCtrl_EndUnderline)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxRichTextCtrl *    THIS = (wxRichTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextCtrl" )
;
	bool	RETVAL;
    try {
      RETVAL = THIS->EndUnderline();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__RichTextCtrl_BeginFontSize); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextCtrl_BeginFontSize)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, pointSize");
    {
	wxRichTextCtrl *    THIS = (wxRichTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextCtrl" )
;
	bool	RETVAL;
	int	pointSize = (int)SvIV(ST(1))
;
    try {
      RETVAL = THIS->BeginFontSize( pointSize );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__RichTextCtrl_EndFontSize); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextCtrl_EndFontSize)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxRichTextCtrl *    THIS = (wxRichTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextCtrl" )
;
	bool	RETVAL;
    try {
      RETVAL = THIS->EndFontSize();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__RichTextCtrl_BeginFont); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextCtrl_BeginFont)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, font");
    {
	wxRichTextCtrl *    THIS = (wxRichTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextCtrl" )
;
	bool	RETVAL;
	wxFont*    font = (wxFont *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::Font" )
;
    try {
      RETVAL = THIS->BeginFont( *( font ) );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__RichTextCtrl_EndFont); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextCtrl_EndFont)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxRichTextCtrl *    THIS = (wxRichTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextCtrl" )
;
	bool	RETVAL;
    try {
      RETVAL = THIS->EndFont();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__RichTextCtrl_BeginTextColour); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextCtrl_BeginTextColour)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, colour");
    {
	wxRichTextCtrl *    THIS = (wxRichTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextCtrl" )
;
	bool	RETVAL;
	wxColour*    colour = (wxColour *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::Colour" )
;
    try {
      RETVAL = THIS->BeginTextColour( *( colour ) );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__RichTextCtrl_EndTextColour); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextCtrl_EndTextColour)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxRichTextCtrl *    THIS = (wxRichTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextCtrl" )
;
	bool	RETVAL;
    try {
      RETVAL = THIS->EndTextColour();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__RichTextCtrl_BeginAlignment); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextCtrl_BeginAlignment)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, alignment");
    {
	wxRichTextCtrl *    THIS = (wxRichTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextCtrl" )
;
	bool	RETVAL;
	wxTextAttrAlignment	alignment = (wxTextAttrAlignment)SvIV(ST(1))
;
    try {
      RETVAL = THIS->BeginAlignment( alignment );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__RichTextCtrl_EndAlignment); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextCtrl_EndAlignment)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxRichTextCtrl *    THIS = (wxRichTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextCtrl" )
;
	bool	RETVAL;
    try {
      RETVAL = THIS->EndAlignment();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__RichTextCtrl_BeginLeftIndent); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextCtrl_BeginLeftIndent)
{
    dVAR; dXSARGS;
    if (items < 2 || items > 3)
       croak_xs_usage(cv,  "THIS, leftIndent, leftSubIndent= 0");
    {
	wxRichTextCtrl *    THIS = (wxRichTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextCtrl" )
;
	bool	RETVAL;
	int	leftIndent = (int)SvIV(ST(1))
;
	int	leftSubIndent;

	if (items < 3)
	    leftSubIndent = 0;
	else {
	    leftSubIndent = (int)SvIV(ST(2))
;
	}
    try {
      RETVAL = THIS->BeginLeftIndent( leftIndent, leftSubIndent );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__RichTextCtrl_EndLeftIndent); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextCtrl_EndLeftIndent)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxRichTextCtrl *    THIS = (wxRichTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextCtrl" )
;
	bool	RETVAL;
    try {
      RETVAL = THIS->EndLeftIndent();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__RichTextCtrl_BeginRightIndent); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextCtrl_BeginRightIndent)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, rightIndent");
    {
	wxRichTextCtrl *    THIS = (wxRichTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextCtrl" )
;
	bool	RETVAL;
	int	rightIndent = (int)SvIV(ST(1))
;
    try {
      RETVAL = THIS->BeginRightIndent( rightIndent );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__RichTextCtrl_EndRightIndent); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextCtrl_EndRightIndent)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxRichTextCtrl *    THIS = (wxRichTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextCtrl" )
;
	bool	RETVAL;
    try {
      RETVAL = THIS->EndRightIndent();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__RichTextCtrl_BeginParagraphSpacing); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextCtrl_BeginParagraphSpacing)
{
    dVAR; dXSARGS;
    if (items != 3)
       croak_xs_usage(cv,  "THIS, before, after");
    {
	wxRichTextCtrl *    THIS = (wxRichTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextCtrl" )
;
	bool	RETVAL;
	int	before = (int)SvIV(ST(1))
;
	int	after = (int)SvIV(ST(2))
;
    try {
      RETVAL = THIS->BeginParagraphSpacing( before, after );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__RichTextCtrl_EndParagraphSpacing); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextCtrl_EndParagraphSpacing)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxRichTextCtrl *    THIS = (wxRichTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextCtrl" )
;
	bool	RETVAL;
    try {
      RETVAL = THIS->EndParagraphSpacing();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__RichTextCtrl_BeginLineSpacing); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextCtrl_BeginLineSpacing)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, lineSpacing");
    {
	wxRichTextCtrl *    THIS = (wxRichTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextCtrl" )
;
	bool	RETVAL;
	int	lineSpacing = (int)SvIV(ST(1))
;
    try {
      RETVAL = THIS->BeginLineSpacing( lineSpacing );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__RichTextCtrl_EndLineSpacing); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextCtrl_EndLineSpacing)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxRichTextCtrl *    THIS = (wxRichTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextCtrl" )
;
	bool	RETVAL;
    try {
      RETVAL = THIS->EndLineSpacing();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__RichTextCtrl_BeginNumberedBullet); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextCtrl_BeginNumberedBullet)
{
    dVAR; dXSARGS;
    if (items < 4 || items > 5)
       croak_xs_usage(cv,  "THIS, bulletNumber, leftIndent, leftSubIndent, bulletStyle= wxTEXT_ATTR_DEFAULT_NUMBERED_BULLET");
    {
	wxRichTextCtrl *    THIS = (wxRichTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextCtrl" )
;
	bool	RETVAL;
	int	bulletNumber = (int)SvIV(ST(1))
;
	int	leftIndent = (int)SvIV(ST(2))
;
	int	leftSubIndent = (int)SvIV(ST(3))
;
	int	bulletStyle;

	if (items < 5)
	    bulletStyle = wxTEXT_ATTR_DEFAULT_NUMBERED_BULLET;
	else {
	    bulletStyle = (int)SvIV(ST(4))
;
	}
    try {
      RETVAL = THIS->BeginNumberedBullet( bulletNumber, leftIndent, leftSubIndent, bulletStyle );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__RichTextCtrl_EndNumberedBullet); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextCtrl_EndNumberedBullet)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxRichTextCtrl *    THIS = (wxRichTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextCtrl" )
;
	bool	RETVAL;
    try {
      RETVAL = THIS->EndNumberedBullet();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}

#if WXPERL_W_VERSION_GE( 2, 7, 2 )
#define XSpp_7969698b_082466
#define XSubPPtmpAAAF 1


XS_EUPXS(XS_Wx__RichTextCtrl_BeginSymbolBullet); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextCtrl_BeginSymbolBullet)
{
    dVAR; dXSARGS;
    if (items < 4 || items > 5)
       croak_xs_usage(cv,  "THIS, symbol, leftIndent, leftSubIndent, bulletStyle= wxTEXT_ATTR_BULLET_STYLE_SYMBOL");
    {
	wxRichTextCtrl *    THIS = (wxRichTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextCtrl" )
;
	bool	RETVAL;
	wxString	symbol;
	int	leftIndent = (int)SvIV(ST(2))
;
	int	leftSubIndent = (int)SvIV(ST(3))
;
	int	bulletStyle;

    WXSTRING_INPUT( symbol, wxString, ST(1) )
;

	if (items < 5)
	    bulletStyle = wxTEXT_ATTR_BULLET_STYLE_SYMBOL;
	else {
	    bulletStyle = (int)SvIV(ST(4))
;
	}
    try {
      RETVAL = THIS->BeginSymbolBullet( symbol, leftIndent, leftSubIndent, bulletStyle );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}

#else
#define XSpp_7969698b_010314
#define XSubPPtmpAAAG 1


XS_EUPXS(XS_Wx__RichTextCtrl_BeginSymbolBullet); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextCtrl_BeginSymbolBullet)
{
    dVAR; dXSARGS;
    if (items < 4 || items > 5)
       croak_xs_usage(cv,  "THIS, symbol, leftIndent, leftSubIndent, bulletStyle= wxTEXT_ATTR_BULLET_STYLE_SYMBOL");
    {
	wxRichTextCtrl *    THIS = (wxRichTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextCtrl" )
;
	bool	RETVAL;
	wxChar	symbol = (wxChar)SvIV(ST(1))
;
	int	leftIndent = (int)SvIV(ST(2))
;
	int	leftSubIndent = (int)SvIV(ST(3))
;
	int	bulletStyle;

	if (items < 5)
	    bulletStyle = wxTEXT_ATTR_BULLET_STYLE_SYMBOL;
	else {
	    bulletStyle = (int)SvIV(ST(4))
;
	}
    try {
      RETVAL = THIS->BeginSymbolBullet( symbol, leftIndent, leftSubIndent, bulletStyle );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}

#endif

XS_EUPXS(XS_Wx__RichTextCtrl_EndSymbolBullet); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextCtrl_EndSymbolBullet)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxRichTextCtrl *    THIS = (wxRichTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextCtrl" )
;
	bool	RETVAL;
    try {
      RETVAL = THIS->EndSymbolBullet();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}

#if WXPERL_W_VERSION_GE( 2, 7, 2 )
#define XSpp_7969698b_021019
#define XSubPPtmpAAAH 1


XS_EUPXS(XS_Wx__RichTextCtrl_BeginStandardBullet); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextCtrl_BeginStandardBullet)
{
    dVAR; dXSARGS;
    if (items < 4 || items > 5)
       croak_xs_usage(cv,  "THIS, bulletName, leftIndent, leftSubIndent, bulletStyle= wxTEXT_ATTR_BULLET_STYLE_STANDARD");
    {
	wxRichTextCtrl *    THIS = (wxRichTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextCtrl" )
;
	bool	RETVAL;
	wxString	bulletName;
	int	leftIndent = (int)SvIV(ST(2))
;
	int	leftSubIndent = (int)SvIV(ST(3))
;
	int	bulletStyle;

    WXSTRING_INPUT( bulletName, wxString, ST(1) )
;

	if (items < 5)
	    bulletStyle = wxTEXT_ATTR_BULLET_STYLE_STANDARD;
	else {
	    bulletStyle = (int)SvIV(ST(4))
;
	}
    try {
      RETVAL = THIS->BeginStandardBullet( bulletName, leftIndent, leftSubIndent, bulletStyle );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__RichTextCtrl_EndStandardBullet); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextCtrl_EndStandardBullet)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxRichTextCtrl *    THIS = (wxRichTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextCtrl" )
;
	bool	RETVAL;
    try {
      RETVAL = THIS->EndStandardBullet();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}

#endif

XS_EUPXS(XS_Wx__RichTextCtrl_BeginCharacterStyle); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextCtrl_BeginCharacterStyle)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, characterStyle");
    {
	wxRichTextCtrl *    THIS = (wxRichTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextCtrl" )
;
	bool	RETVAL;
	wxString	characterStyle;

    WXSTRING_INPUT( characterStyle, wxString, ST(1) )
;
    try {
      RETVAL = THIS->BeginCharacterStyle( characterStyle );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__RichTextCtrl_EndCharacterStyle); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextCtrl_EndCharacterStyle)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxRichTextCtrl *    THIS = (wxRichTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextCtrl" )
;
	bool	RETVAL;
    try {
      RETVAL = THIS->EndCharacterStyle();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__RichTextCtrl_BeginParagraphStyle); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextCtrl_BeginParagraphStyle)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, paragraphStyle");
    {
	wxRichTextCtrl *    THIS = (wxRichTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextCtrl" )
;
	bool	RETVAL;
	wxString	paragraphStyle;

    WXSTRING_INPUT( paragraphStyle, wxString, ST(1) )
;
    try {
      RETVAL = THIS->BeginParagraphStyle( paragraphStyle );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__RichTextCtrl_EndParagraphStyle); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextCtrl_EndParagraphStyle)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxRichTextCtrl *    THIS = (wxRichTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextCtrl" )
;
	bool	RETVAL;
    try {
      RETVAL = THIS->EndParagraphStyle();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}

#if WXPERL_W_VERSION_GE( 2, 7, 2 )
#define XSpp_7969698b_074976
#define XSubPPtmpAAAI 1


XS_EUPXS(XS_Wx__RichTextCtrl_BeginListStyle); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextCtrl_BeginListStyle)
{
    dVAR; dXSARGS;
    if (items < 2 || items > 4)
       croak_xs_usage(cv,  "THIS, listStyle, level= 1, number= 1");
    {
	wxRichTextCtrl *    THIS = (wxRichTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextCtrl" )
;
	bool	RETVAL;
	wxString	listStyle;
	int	level;
	int	number;

    WXSTRING_INPUT( listStyle, wxString, ST(1) )
;

	if (items < 3)
	    level = 1;
	else {
	    level = (int)SvIV(ST(2))
;
	}

	if (items < 4)
	    number = 1;
	else {
	    number = (int)SvIV(ST(3))
;
	}
    try {
      RETVAL = THIS->BeginListStyle( listStyle, level, number );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__RichTextCtrl_EndListStyle); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextCtrl_EndListStyle)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxRichTextCtrl *    THIS = (wxRichTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextCtrl" )
;
	bool	RETVAL;
    try {
      RETVAL = THIS->EndListStyle();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__RichTextCtrl_BeginURL); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextCtrl_BeginURL)
{
    dVAR; dXSARGS;
    if (items < 2 || items > 3)
       croak_xs_usage(cv,  "THIS, url, characterStyle= wxEmptyString");
    {
	wxRichTextCtrl *    THIS = (wxRichTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextCtrl" )
;
	bool	RETVAL;
	wxString	url;
	wxString	characterStyle;

    WXSTRING_INPUT( url, wxString, ST(1) )
;

	if (items < 3)
	    characterStyle = wxEmptyString;
	else {
    WXSTRING_INPUT( characterStyle, wxString, ST(2) )
;
	}
    try {
      RETVAL = THIS->BeginURL( url, characterStyle );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__RichTextCtrl_EndURL); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextCtrl_EndURL)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxRichTextCtrl *    THIS = (wxRichTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextCtrl" )
;
	bool	RETVAL;
    try {
      RETVAL = THIS->EndURL();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}

#endif

XS_EUPXS(XS_Wx__RichTextCtrl_SetDefaultStyleToCursorStyle); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextCtrl_SetDefaultStyleToCursorStyle)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxRichTextCtrl *    THIS = (wxRichTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextCtrl" )
;
	bool	RETVAL;
    try {
      RETVAL = THIS->SetDefaultStyleToCursorStyle();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}

#if WXPERL_W_VERSION_GE( 2, 7, 2 )
#define XSpp_7969698b_032378
#define XSubPPtmpAAAJ 1


XS_EUPXS(XS_Wx__RichTextCtrl_ClearListStyle); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextCtrl_ClearListStyle)
{
    dVAR; dXSARGS;
    if (items < 2 || items > 3)
       croak_xs_usage(cv,  "THIS, range, flags= wxRICHTEXT_SETSTYLE_WITH_UNDO");
    {
	wxRichTextCtrl *    THIS = (wxRichTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextCtrl" )
;
	bool	RETVAL;
	wxRichTextRange*    range = (wxRichTextRange *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::RichTextRange" )
;
	int	flags;

	if (items < 3)
	    flags = wxRICHTEXT_SETSTYLE_WITH_UNDO;
	else {
	    flags = (int)SvIV(ST(2))
;
	}
    try {
      RETVAL = THIS->ClearListStyle( *( range ), flags );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}

#endif

XS_EUPXS(XS_Wx__RichTextCtrl_SelectNone); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextCtrl_SelectNone)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxRichTextCtrl *    THIS = (wxRichTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextCtrl" )
;
    try {
      THIS->SelectNone();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}

#if WXPERL_W_VERSION_GE( 2, 7, 1 )
#define XSpp_7969698b_052214
#define XSubPPtmpAAAK 1


XS_EUPXS(XS_Wx__RichTextCtrl_SelectWord); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextCtrl_SelectWord)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, position");
    {
	wxRichTextCtrl *    THIS = (wxRichTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextCtrl" )
;
	bool	RETVAL;
	long	position = (long)SvIV(ST(1))
;
    try {
      RETVAL = THIS->SelectWord( position );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}

#endif

XS_EUPXS(XS_Wx__RichTextCtrl_GetSelectionRange); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextCtrl_GetSelectionRange)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxRichTextCtrl *    THIS = (wxRichTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextCtrl" )
;
	wxRichTextRange *	RETVAL;
    try {
      RETVAL = new wxRichTextRange( THIS->GetSelectionRange() );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_non_object_2_sv( aTHX_ RETVALSV, RETVAL, "Wx::RichTextRange" );
    wxPli_thread_sv_register( aTHX_ "Wx::RichTextRange", RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__RichTextCtrl_SetSelectionRange); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextCtrl_SetSelectionRange)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, range");
    {
	wxRichTextCtrl *    THIS = (wxRichTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextCtrl" )
;
	wxRichTextRange*    range = (wxRichTextRange *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::RichTextRange" )
;
    try {
      THIS->SetSelectionRange( *( range ) );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}

#if WXPERL_W_VERSION_GE( 2, 7, 1 )
#define XSpp_7969698b_030047
#define XSubPPtmpAAAL 1


XS_EUPXS(XS_Wx__RichTextCtrl_GetInternalSelectionRange); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextCtrl_GetInternalSelectionRange)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxRichTextCtrl *    THIS = (wxRichTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextCtrl" )
;
	wxRichTextRange *	RETVAL;
    try {
      RETVAL = new wxRichTextRange( THIS->GetInternalSelectionRange() );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_non_object_2_sv( aTHX_ RETVALSV, RETVAL, "Wx::RichTextRange" );
    wxPli_thread_sv_register( aTHX_ "Wx::RichTextRange", RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__RichTextCtrl_SetInternalSelectionRange); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextCtrl_SetInternalSelectionRange)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, range");
    {
	wxRichTextCtrl *    THIS = (wxRichTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextCtrl" )
;
	wxRichTextRange*    range = (wxRichTextRange *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::RichTextRange" )
;
    try {
      THIS->SetInternalSelectionRange( *( range ) );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}

#endif
#if WXPERL_W_VERSION_LE( 2, 9, 1 )
#define XSpp_7969698b_018447
#define XSubPPtmpAAAM 1


XS_EUPXS(XS_Wx__RichTextCtrl_HasSelection); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextCtrl_HasSelection)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxRichTextCtrl *    THIS = (wxRichTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextCtrl" )
;
	bool	RETVAL;
    try {
      RETVAL = THIS->HasSelection();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}

#endif

XS_EUPXS(XS_Wx__RichTextCtrl_AddParagraph); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextCtrl_AddParagraph)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, text");
    {
	wxRichTextCtrl *    THIS = (wxRichTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextCtrl" )
;
	wxRichTextRange *	RETVAL;
	wxString	text;

    WXSTRING_INPUT( text, wxString, ST(1) )
;
    try {
      RETVAL = new wxRichTextRange( THIS->AddParagraph( text ) );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_non_object_2_sv( aTHX_ RETVALSV, RETVAL, "Wx::RichTextRange" );
    wxPli_thread_sv_register( aTHX_ "Wx::RichTextRange", RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__RichTextCtrl_AddImage); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextCtrl_AddImage)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, image");
    {
	wxRichTextCtrl *    THIS = (wxRichTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextCtrl" )
;
	wxRichTextRange *	RETVAL;
	wxImage*    image = (wxImage *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::Image" )
;
    try {
      RETVAL = new wxRichTextRange( THIS->AddImage( *( image ) ) );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_non_object_2_sv( aTHX_ RETVALSV, RETVAL, "Wx::RichTextRange" );
    wxPli_thread_sv_register( aTHX_ "Wx::RichTextRange", RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__RichTextCtrl_LayoutContent); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextCtrl_LayoutContent)
{
    dVAR; dXSARGS;
    if (items < 1 || items > 2)
       croak_xs_usage(cv,  "THIS, onlyVisibleRect= false");
    {
	wxRichTextCtrl *    THIS = (wxRichTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextCtrl" )
;
	bool	RETVAL;
	bool	onlyVisibleRect;

	if (items < 2)
	    onlyVisibleRect = false;
	else {
	    onlyVisibleRect = (bool)SvTRUE(ST(1))
;
	}
    try {
      RETVAL = THIS->LayoutContent( onlyVisibleRect );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__RichTextCtrl_MoveCaret); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextCtrl_MoveCaret)
{
    dVAR; dXSARGS;
    if (items < 2 || items > 3)
       croak_xs_usage(cv,  "THIS, pos, showAtLineStart= false");
    {
	wxRichTextCtrl *    THIS = (wxRichTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextCtrl" )
;
	bool	RETVAL;
	long	pos = (long)SvIV(ST(1))
;
	bool	showAtLineStart;

	if (items < 3)
	    showAtLineStart = false;
	else {
	    showAtLineStart = (bool)SvTRUE(ST(2))
;
	}
    try {
      RETVAL = THIS->MoveCaret( pos, showAtLineStart );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__RichTextCtrl_MoveRight); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextCtrl_MoveRight)
{
    dVAR; dXSARGS;
    if (items < 1 || items > 3)
       croak_xs_usage(cv,  "THIS, noPositions= 1, flags= 0");
    {
	wxRichTextCtrl *    THIS = (wxRichTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextCtrl" )
;
	bool	RETVAL;
	int	noPositions;
	int	flags;

	if (items < 2)
	    noPositions = 1;
	else {
	    noPositions = (int)SvIV(ST(1))
;
	}

	if (items < 3)
	    flags = 0;
	else {
	    flags = (int)SvIV(ST(2))
;
	}
    try {
      RETVAL = THIS->MoveRight( noPositions, flags );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__RichTextCtrl_MoveLeft); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextCtrl_MoveLeft)
{
    dVAR; dXSARGS;
    if (items < 1 || items > 3)
       croak_xs_usage(cv,  "THIS, noPositions= 1, flags= 0");
    {
	wxRichTextCtrl *    THIS = (wxRichTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextCtrl" )
;
	bool	RETVAL;
	int	noPositions;
	int	flags;

	if (items < 2)
	    noPositions = 1;
	else {
	    noPositions = (int)SvIV(ST(1))
;
	}

	if (items < 3)
	    flags = 0;
	else {
	    flags = (int)SvIV(ST(2))
;
	}
    try {
      RETVAL = THIS->MoveLeft( noPositions, flags );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__RichTextCtrl_MoveUp); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextCtrl_MoveUp)
{
    dVAR; dXSARGS;
    if (items < 1 || items > 3)
       croak_xs_usage(cv,  "THIS, noLines= 1, flags= 0");
    {
	wxRichTextCtrl *    THIS = (wxRichTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextCtrl" )
;
	bool	RETVAL;
	int	noLines;
	int	flags;

	if (items < 2)
	    noLines = 1;
	else {
	    noLines = (int)SvIV(ST(1))
;
	}

	if (items < 3)
	    flags = 0;
	else {
	    flags = (int)SvIV(ST(2))
;
	}
    try {
      RETVAL = THIS->MoveUp( noLines, flags );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__RichTextCtrl_MoveDown); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextCtrl_MoveDown)
{
    dVAR; dXSARGS;
    if (items < 1 || items > 3)
       croak_xs_usage(cv,  "THIS, noLines= 1, flags= 0");
    {
	wxRichTextCtrl *    THIS = (wxRichTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextCtrl" )
;
	bool	RETVAL;
	int	noLines;
	int	flags;

	if (items < 2)
	    noLines = 1;
	else {
	    noLines = (int)SvIV(ST(1))
;
	}

	if (items < 3)
	    flags = 0;
	else {
	    flags = (int)SvIV(ST(2))
;
	}
    try {
      RETVAL = THIS->MoveDown( noLines, flags );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__RichTextCtrl_MoveToLineEnd); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextCtrl_MoveToLineEnd)
{
    dVAR; dXSARGS;
    if (items < 1 || items > 2)
       croak_xs_usage(cv,  "THIS, flags= 0");
    {
	wxRichTextCtrl *    THIS = (wxRichTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextCtrl" )
;
	bool	RETVAL;
	int	flags;

	if (items < 2)
	    flags = 0;
	else {
	    flags = (int)SvIV(ST(1))
;
	}
    try {
      RETVAL = THIS->MoveToLineEnd( flags );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__RichTextCtrl_MoveToLineStart); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextCtrl_MoveToLineStart)
{
    dVAR; dXSARGS;
    if (items < 1 || items > 2)
       croak_xs_usage(cv,  "THIS, flags= 0");
    {
	wxRichTextCtrl *    THIS = (wxRichTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextCtrl" )
;
	bool	RETVAL;
	int	flags;

	if (items < 2)
	    flags = 0;
	else {
	    flags = (int)SvIV(ST(1))
;
	}
    try {
      RETVAL = THIS->MoveToLineStart( flags );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__RichTextCtrl_MoveToParagraphEnd); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextCtrl_MoveToParagraphEnd)
{
    dVAR; dXSARGS;
    if (items < 1 || items > 2)
       croak_xs_usage(cv,  "THIS, flags= 0");
    {
	wxRichTextCtrl *    THIS = (wxRichTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextCtrl" )
;
	bool	RETVAL;
	int	flags;

	if (items < 2)
	    flags = 0;
	else {
	    flags = (int)SvIV(ST(1))
;
	}
    try {
      RETVAL = THIS->MoveToParagraphEnd( flags );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__RichTextCtrl_MoveToParagraphStart); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextCtrl_MoveToParagraphStart)
{
    dVAR; dXSARGS;
    if (items < 1 || items > 2)
       croak_xs_usage(cv,  "THIS, flags= 0");
    {
	wxRichTextCtrl *    THIS = (wxRichTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextCtrl" )
;
	bool	RETVAL;
	int	flags;

	if (items < 2)
	    flags = 0;
	else {
	    flags = (int)SvIV(ST(1))
;
	}
    try {
      RETVAL = THIS->MoveToParagraphStart( flags );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__RichTextCtrl_MoveHome); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextCtrl_MoveHome)
{
    dVAR; dXSARGS;
    if (items < 1 || items > 2)
       croak_xs_usage(cv,  "THIS, flags= 0");
    {
	wxRichTextCtrl *    THIS = (wxRichTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextCtrl" )
;
	bool	RETVAL;
	int	flags;

	if (items < 2)
	    flags = 0;
	else {
	    flags = (int)SvIV(ST(1))
;
	}
    try {
      RETVAL = THIS->MoveHome( flags );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__RichTextCtrl_MoveEnd); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextCtrl_MoveEnd)
{
    dVAR; dXSARGS;
    if (items < 1 || items > 2)
       croak_xs_usage(cv,  "THIS, flags= 0");
    {
	wxRichTextCtrl *    THIS = (wxRichTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextCtrl" )
;
	bool	RETVAL;
	int	flags;

	if (items < 2)
	    flags = 0;
	else {
	    flags = (int)SvIV(ST(1))
;
	}
    try {
      RETVAL = THIS->MoveEnd( flags );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__RichTextCtrl_PageUp); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextCtrl_PageUp)
{
    dVAR; dXSARGS;
    if (items < 1 || items > 3)
       croak_xs_usage(cv,  "THIS, noPages= 1, flags= 0");
    {
	wxRichTextCtrl *    THIS = (wxRichTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextCtrl" )
;
	bool	RETVAL;
	int	noPages;
	int	flags;

	if (items < 2)
	    noPages = 1;
	else {
	    noPages = (int)SvIV(ST(1))
;
	}

	if (items < 3)
	    flags = 0;
	else {
	    flags = (int)SvIV(ST(2))
;
	}
    try {
      RETVAL = THIS->PageUp( noPages, flags );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__RichTextCtrl_PageDown); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextCtrl_PageDown)
{
    dVAR; dXSARGS;
    if (items < 1 || items > 3)
       croak_xs_usage(cv,  "THIS, noPages= 1, flags= 0");
    {
	wxRichTextCtrl *    THIS = (wxRichTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextCtrl" )
;
	bool	RETVAL;
	int	noPages;
	int	flags;

	if (items < 2)
	    noPages = 1;
	else {
	    noPages = (int)SvIV(ST(1))
;
	}

	if (items < 3)
	    flags = 0;
	else {
	    flags = (int)SvIV(ST(2))
;
	}
    try {
      RETVAL = THIS->PageDown( noPages, flags );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__RichTextCtrl_WordLeft); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextCtrl_WordLeft)
{
    dVAR; dXSARGS;
    if (items < 1 || items > 3)
       croak_xs_usage(cv,  "THIS, noPages= 1, flags= 0");
    {
	wxRichTextCtrl *    THIS = (wxRichTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextCtrl" )
;
	bool	RETVAL;
	int	noPages;
	int	flags;

	if (items < 2)
	    noPages = 1;
	else {
	    noPages = (int)SvIV(ST(1))
;
	}

	if (items < 3)
	    flags = 0;
	else {
	    flags = (int)SvIV(ST(2))
;
	}
    try {
      RETVAL = THIS->WordLeft( noPages, flags );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__RichTextCtrl_WordRight); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextCtrl_WordRight)
{
    dVAR; dXSARGS;
    if (items < 1 || items > 3)
       croak_xs_usage(cv,  "THIS, noPages= 1, flags= 0");
    {
	wxRichTextCtrl *    THIS = (wxRichTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextCtrl" )
;
	bool	RETVAL;
	int	noPages;
	int	flags;

	if (items < 2)
	    noPages = 1;
	else {
	    noPages = (int)SvIV(ST(1))
;
	}

	if (items < 3)
	    flags = 0;
	else {
	    flags = (int)SvIV(ST(2))
;
	}
    try {
      RETVAL = THIS->WordRight( noPages, flags );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__RichTextCtrl_BeginBatchUndo); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextCtrl_BeginBatchUndo)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, cmdName");
    {
	wxRichTextCtrl *    THIS = (wxRichTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextCtrl" )
;
	bool	RETVAL;
	wxString	cmdName;

    WXSTRING_INPUT( cmdName, wxString, ST(1) )
;
    try {
      RETVAL = THIS->BeginBatchUndo( cmdName );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__RichTextCtrl_EndBatchUndo); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextCtrl_EndBatchUndo)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxRichTextCtrl *    THIS = (wxRichTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextCtrl" )
;
	bool	RETVAL;
    try {
      RETVAL = THIS->EndBatchUndo();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__RichTextCtrl_BatchingUndo); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextCtrl_BatchingUndo)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxRichTextCtrl *    THIS = (wxRichTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextCtrl" )
;
	bool	RETVAL;
    try {
      RETVAL = THIS->BatchingUndo();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__RichTextCtrl_BeginSuppressUndo); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextCtrl_BeginSuppressUndo)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxRichTextCtrl *    THIS = (wxRichTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextCtrl" )
;
	bool	RETVAL;
    try {
      RETVAL = THIS->BeginSuppressUndo();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__RichTextCtrl_EndSuppressUndo); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextCtrl_EndSuppressUndo)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxRichTextCtrl *    THIS = (wxRichTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextCtrl" )
;
	bool	RETVAL;
    try {
      RETVAL = THIS->EndSuppressUndo();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__RichTextCtrl_SuppressingUndo); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextCtrl_SuppressingUndo)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxRichTextCtrl *    THIS = (wxRichTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextCtrl" )
;
	bool	RETVAL;
    try {
      RETVAL = THIS->SuppressingUndo();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__RichTextCtrl_CanDeleteSelection); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextCtrl_CanDeleteSelection)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxRichTextCtrl *    THIS = (wxRichTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextCtrl" )
;
	bool	RETVAL;
    try {
      RETVAL = THIS->CanDeleteSelection();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__RichTextCtrl_DeleteSelection); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextCtrl_DeleteSelection)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxRichTextCtrl *    THIS = (wxRichTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextCtrl" )
;
    try {
      THIS->DeleteSelection();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__RichTextCtrl_HasCAEx); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextCtrl_HasCAEx)
{
    dVAR; dXSARGS;
    if (items != 3)
       croak_xs_usage(cv,  "THIS, range, style");
    {
	wxRichTextCtrl *    THIS = (wxRichTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextCtrl" )
;
	bool	RETVAL;
	wxRichTextRange*    range = (wxRichTextRange *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::RichTextRange" )
;
	wxTextAttrEx*    style = (wxTextAttrEx *) wxPli_sv_2_object( aTHX_ ST(2), "Wx::TextAttrEx" )
;
    try {
      RETVAL = THIS->HasCharacterAttributes( *( range ), *( style ) );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__RichTextCtrl_HasCARich); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextCtrl_HasCARich)
{
    dVAR; dXSARGS;
    if (items != 3)
       croak_xs_usage(cv,  "THIS, range, style");
    {
	wxRichTextCtrl *    THIS = (wxRichTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextCtrl" )
;
	bool	RETVAL;
	wxRichTextRange*    range = (wxRichTextRange *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::RichTextRange" )
;
	wxRichTextAttr*    style = (wxRichTextAttr *) wxPli_sv_2_object( aTHX_ ST(2), "Wx::RichTextAttr" )
;
    try {
      RETVAL = THIS->HasCharacterAttributes( *( range ), *( style ) );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__RichTextCtrl_HasPAEx); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextCtrl_HasPAEx)
{
    dVAR; dXSARGS;
    if (items != 3)
       croak_xs_usage(cv,  "THIS, range, style");
    {
	wxRichTextCtrl *    THIS = (wxRichTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextCtrl" )
;
	bool	RETVAL;
	wxRichTextRange*    range = (wxRichTextRange *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::RichTextRange" )
;
	wxTextAttrEx*    style = (wxTextAttrEx *) wxPli_sv_2_object( aTHX_ ST(2), "Wx::TextAttrEx" )
;
    try {
      RETVAL = THIS->HasParagraphAttributes( *( range ), *( style ) );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__RichTextCtrl_HasPARich); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextCtrl_HasPARich)
{
    dVAR; dXSARGS;
    if (items != 3)
       croak_xs_usage(cv,  "THIS, range, style");
    {
	wxRichTextCtrl *    THIS = (wxRichTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextCtrl" )
;
	bool	RETVAL;
	wxRichTextRange*    range = (wxRichTextRange *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::RichTextRange" )
;
	wxRichTextAttr*    style = (wxRichTextAttr *) wxPli_sv_2_object( aTHX_ ST(2), "Wx::RichTextAttr" )
;
    try {
      RETVAL = THIS->HasParagraphAttributes( *( range ), *( style ) );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__RichTextCtrl_IsSelectionBold); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextCtrl_IsSelectionBold)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxRichTextCtrl *    THIS = (wxRichTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextCtrl" )
;
	bool	RETVAL;
    try {
      RETVAL = THIS->IsSelectionBold();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__RichTextCtrl_IsSelectionItalics); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextCtrl_IsSelectionItalics)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxRichTextCtrl *    THIS = (wxRichTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextCtrl" )
;
	bool	RETVAL;
    try {
      RETVAL = THIS->IsSelectionItalics();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__RichTextCtrl_IsSelectionUnderlined); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextCtrl_IsSelectionUnderlined)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxRichTextCtrl *    THIS = (wxRichTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextCtrl" )
;
	bool	RETVAL;
    try {
      RETVAL = THIS->IsSelectionUnderlined();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__RichTextCtrl_IsSelectionAligned); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextCtrl_IsSelectionAligned)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, alignment");
    {
	wxRichTextCtrl *    THIS = (wxRichTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextCtrl" )
;
	bool	RETVAL;
	wxTextAttrAlignment	alignment = (wxTextAttrAlignment)SvIV(ST(1))
;
    try {
      RETVAL = THIS->IsSelectionAligned( alignment );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__RichTextCtrl_ApplyBoldToSelection); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextCtrl_ApplyBoldToSelection)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxRichTextCtrl *    THIS = (wxRichTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextCtrl" )
;
	bool	RETVAL;
    try {
      RETVAL = THIS->ApplyBoldToSelection();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__RichTextCtrl_ApplyItalicToSelection); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextCtrl_ApplyItalicToSelection)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxRichTextCtrl *    THIS = (wxRichTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextCtrl" )
;
	bool	RETVAL;
    try {
      RETVAL = THIS->ApplyItalicToSelection();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__RichTextCtrl_ApplyUnderlineToSelection); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextCtrl_ApplyUnderlineToSelection)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxRichTextCtrl *    THIS = (wxRichTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextCtrl" )
;
	bool	RETVAL;
    try {
      RETVAL = THIS->ApplyUnderlineToSelection();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__RichTextCtrl_ApplyAlignmentToSelection); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextCtrl_ApplyAlignmentToSelection)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, alignment");
    {
	wxRichTextCtrl *    THIS = (wxRichTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextCtrl" )
;
	bool	RETVAL;
	wxTextAttrAlignment	alignment = (wxTextAttrAlignment)SvIV(ST(1))
;
    try {
      RETVAL = THIS->ApplyAlignmentToSelection( alignment );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}

#if WXPERL_W_VERSION_GE( 2, 7, 1 )
#define XSpp_7969698b_053592
#define XSubPPtmpAAAN 1


XS_EUPXS(XS_Wx__RichTextCtrl_ApplyStyle); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextCtrl_ApplyStyle)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, def");
    {
	wxRichTextCtrl *    THIS = (wxRichTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextCtrl" )
;
	bool	RETVAL;
	wxRichTextStyleDefinition*    def = (wxRichTextStyleDefinition *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::RichTextStyleDefinition" )
;
    try {
      RETVAL = THIS->ApplyStyle( def );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__RichTextCtrl_SetStyleSheet); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextCtrl_SetStyleSheet)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, styleSheet");
    {
	wxRichTextCtrl *    THIS = (wxRichTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextCtrl" )
;
	wxRichTextStyleSheet*    styleSheet = (wxRichTextStyleSheet *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::RichTextStyleSheet" )
;
    try {
      THIS->SetStyleSheet( styleSheet );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__RichTextCtrl_GetStyleSheet); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextCtrl_GetStyleSheet)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxRichTextCtrl *    THIS = (wxRichTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextCtrl" )
;
	wxRichTextStyleSheet *	RETVAL;
    try {
      RETVAL = THIS->GetStyleSheet();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_object_2_sv( aTHX_ RETVALSV, RETVAL );
    wxPli_thread_sv_register( aTHX_ "Wx::RichTextStyleSheet", RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    wxPli_object_set_deleteable( aTHX_ ST(0), false );
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__RichTextCtrl_ApplyStyleSheet); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextCtrl_ApplyStyleSheet)
{
    dVAR; dXSARGS;
    if (items < 1 || items > 2)
       croak_xs_usage(cv,  "THIS, styleSheet= NULL");
    {
	wxRichTextCtrl *    THIS = (wxRichTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextCtrl" )
;
	bool	RETVAL;
	wxRichTextStyleSheet*	styleSheet;

	if (items < 2)
	    styleSheet = NULL;
	else {
    styleSheet = (wxRichTextStyleSheet *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::RichTextStyleSheet" )
;
	}
    try {
      RETVAL = THIS->ApplyStyleSheet( styleSheet );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}

#endif
#if WXPERL_W_VERSION_GE( 2, 7, 2 )
#define XSpp_7969698b_001637
#define XSubPPtmpAAAO 1


XS_EUPXS(XS_Wx__RichTextCtrl_PushStyleSheet); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextCtrl_PushStyleSheet)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, styleSheet");
    {
	wxRichTextCtrl *    THIS = (wxRichTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextCtrl" )
;
	bool	RETVAL;
	wxRichTextStyleSheet*    styleSheet = (wxRichTextStyleSheet *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::RichTextStyleSheet" )
;
    try {
      RETVAL = THIS->PushStyleSheet( styleSheet );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__RichTextCtrl_PopStyleSheet); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextCtrl_PopStyleSheet)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxRichTextCtrl *    THIS = (wxRichTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextCtrl" )
;
	wxRichTextStyleSheet *	RETVAL;
    try {
      RETVAL = THIS->PopStyleSheet();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_object_2_sv( aTHX_ RETVALSV, RETVAL );
    wxPli_thread_sv_register( aTHX_ "Wx::RichTextStyleSheet", RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    wxPli_object_set_deleteable( aTHX_ ST(0), false );
    }
    XSRETURN(1);
}

#endif

XS_EUPXS(XS_Wx__RichTextCtrl_PositionCaret); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextCtrl_PositionCaret)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxRichTextCtrl *    THIS = (wxRichTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextCtrl" )
;
    try {
      THIS->PositionCaret();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__RichTextCtrl_ExtendSelection); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextCtrl_ExtendSelection)
{
    dVAR; dXSARGS;
    if (items != 4)
       croak_xs_usage(cv,  "THIS, oldPosition, newPosition, flags");
    {
	wxRichTextCtrl *    THIS = (wxRichTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextCtrl" )
;
	bool	RETVAL;
	long	oldPosition = (long)SvIV(ST(1))
;
	long	newPosition = (long)SvIV(ST(2))
;
	int	flags = (int)SvIV(ST(3))
;
    try {
      RETVAL = THIS->ExtendSelection( oldPosition, newPosition, flags );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__RichTextCtrl_ScrollIntoView); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextCtrl_ScrollIntoView)
{
    dVAR; dXSARGS;
    if (items != 3)
       croak_xs_usage(cv,  "THIS, position, keyCode");
    {
	wxRichTextCtrl *    THIS = (wxRichTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextCtrl" )
;
	bool	RETVAL;
	long	position = (long)SvIV(ST(1))
;
	int	keyCode = (int)SvIV(ST(2))
;
    try {
      RETVAL = THIS->ScrollIntoView( position, keyCode );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__RichTextCtrl_SetCaretPosition); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextCtrl_SetCaretPosition)
{
    dVAR; dXSARGS;
    if (items < 2 || items > 3)
       croak_xs_usage(cv,  "THIS, position, showAtLineStart= false");
    {
	wxRichTextCtrl *    THIS = (wxRichTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextCtrl" )
;
	long	position = (long)SvIV(ST(1))
;
	bool	showAtLineStart;

	if (items < 3)
	    showAtLineStart = false;
	else {
	    showAtLineStart = (bool)SvTRUE(ST(2))
;
	}
    try {
      THIS->SetCaretPosition( position, showAtLineStart );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__RichTextCtrl_GetCaretPosition); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextCtrl_GetCaretPosition)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxRichTextCtrl *    THIS = (wxRichTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextCtrl" )
;
	long	RETVAL;
	dXSTARG;
    try {
      RETVAL = THIS->GetCaretPosition();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}

#if WXPERL_W_VERSION_GE( 2, 7, 1 )
#define XSpp_7969698b_036843
#define XSubPPtmpAAAP 1


XS_EUPXS(XS_Wx__RichTextCtrl_GetAdjustedCaretPosition); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextCtrl_GetAdjustedCaretPosition)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, caretPos");
    {
	wxRichTextCtrl *    THIS = (wxRichTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextCtrl" )
;
	long	RETVAL;
	dXSTARG;
	long	caretPos = (long)SvIV(ST(1))
;
    try {
      RETVAL = THIS->GetAdjustedCaretPosition( caretPos );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}

#endif

XS_EUPXS(XS_Wx__RichTextCtrl_MoveCaretForward); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextCtrl_MoveCaretForward)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, oldPosition");
    {
	wxRichTextCtrl *    THIS = (wxRichTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextCtrl" )
;
	long	oldPosition = (long)SvIV(ST(1))
;
    try {
      THIS->MoveCaretForward( oldPosition );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__RichTextCtrl_MoveCaretBack); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextCtrl_MoveCaretBack)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, oldPosition");
    {
	wxRichTextCtrl *    THIS = (wxRichTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextCtrl" )
;
	long	oldPosition = (long)SvIV(ST(1))
;
    try {
      THIS->MoveCaretBack( oldPosition );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__RichTextCtrl_GetPhysicalPoint); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextCtrl_GetPhysicalPoint)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, ptLogical");
    {
	wxRichTextCtrl *    THIS = (wxRichTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextCtrl" )
;
	wxPoint	RETVAL;
	wxPoint    ptLogical = wxPli_sv_2_wxpoint( aTHX_ ST(1) )
;
    try {
      RETVAL = THIS->GetPhysicalPoint( ptLogical );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_non_object_2_sv( aTHX_ RETVALSV, new wxPoint(RETVAL), "Wx::Point" );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__RichTextCtrl_GetLogicalPoint); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextCtrl_GetLogicalPoint)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, ptPhysical");
    {
	wxRichTextCtrl *    THIS = (wxRichTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextCtrl" )
;
	wxPoint	RETVAL;
	wxPoint    ptPhysical = wxPli_sv_2_wxpoint( aTHX_ ST(1) )
;
    try {
      RETVAL = THIS->GetLogicalPoint( ptPhysical );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_non_object_2_sv( aTHX_ RETVALSV, new wxPoint(RETVAL), "Wx::Point" );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__RichTextCtrl_FindNextWordPosition); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextCtrl_FindNextWordPosition)
{
    dVAR; dXSARGS;
    if (items < 1 || items > 2)
       croak_xs_usage(cv,  "THIS, direction= 1");
    {
	wxRichTextCtrl *    THIS = (wxRichTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextCtrl" )
;
	long	RETVAL;
	dXSTARG;
	int	direction;

	if (items < 2)
	    direction = 1;
	else {
	    direction = (int)SvIV(ST(1))
;
	}
    try {
      RETVAL = THIS->FindNextWordPosition( direction );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__RichTextCtrl_IsPositionVisible); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextCtrl_IsPositionVisible)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, pos");
    {
	wxRichTextCtrl *    THIS = (wxRichTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextCtrl" )
;
	bool	RETVAL;
	long	pos = (long)SvIV(ST(1))
;
    try {
      RETVAL = THIS->IsPositionVisible( pos );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__RichTextCtrl_GetFirstVisiblePosition); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextCtrl_GetFirstVisiblePosition)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxRichTextCtrl *    THIS = (wxRichTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextCtrl" )
;
	long	RETVAL;
	dXSTARG;
    try {
      RETVAL = THIS->GetFirstVisiblePosition();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}

#if WXPERL_W_VERSION_GE( 2, 7, 1 )
#define XSpp_7969698b_038713
#define XSubPPtmpAAAQ 1


XS_EUPXS(XS_Wx__RichTextCtrl_GetCaretPositionForDefaultStyle); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextCtrl_GetCaretPositionForDefaultStyle)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxRichTextCtrl *    THIS = (wxRichTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextCtrl" )
;
	long	RETVAL;
	dXSTARG;
    try {
      RETVAL = THIS->GetCaretPositionForDefaultStyle();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__RichTextCtrl_SetCaretPositionForDefaultStyle); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextCtrl_SetCaretPositionForDefaultStyle)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, pos");
    {
	wxRichTextCtrl *    THIS = (wxRichTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextCtrl" )
;
	long	pos = (long)SvIV(ST(1))
;
    try {
      THIS->SetCaretPositionForDefaultStyle( pos );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__RichTextCtrl_IsDefaultStyleShowing); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextCtrl_IsDefaultStyleShowing)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxRichTextCtrl *    THIS = (wxRichTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextCtrl" )
;
	bool	RETVAL;
    try {
      RETVAL = THIS->IsDefaultStyleShowing();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__RichTextCtrl_SetAndShowDefaultStyle); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextCtrl_SetAndShowDefaultStyle)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, attr");
    {
	wxRichTextCtrl *    THIS = (wxRichTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextCtrl" )
;
	wxRichTextAttr*    attr = (wxRichTextAttr *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::RichTextAttr" )
;
    try {
      THIS->SetAndShowDefaultStyle( *( attr ) );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}

#endif
#if WXPERL_W_VERSION_GE( 2, 7, 2 )
#define XSpp_7969698b_018928
#define XSubPPtmpAAAR 1


XS_EUPXS(XS_Wx__RichTextCtrl_GetFirstVisiblePoint); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextCtrl_GetFirstVisiblePoint)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxRichTextCtrl *    THIS = (wxRichTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextCtrl" )
;
	wxPoint	RETVAL;
    try {
      RETVAL = THIS->GetFirstVisiblePoint();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_non_object_2_sv( aTHX_ RETVALSV, new wxPoint(RETVAL), "Wx::Point" );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}

#endif

XS_EUPXS(XS_Wx__RichTextCtrl_WriteImageFile); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextCtrl_WriteImageFile)
{
    dVAR; dXSARGS;
    if (items != 3)
       croak_xs_usage(cv,  "THIS, filename, bitmapType");
    {
	wxRichTextCtrl *    THIS = (wxRichTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextCtrl" )
;
	bool	RETVAL;
	wxString	filename;
	wxBitmapType	bitmapType = (wxBitmapType)SvIV(ST(2))
;

    WXSTRING_INPUT( filename, wxString, ST(1) )
;
    try {
      RETVAL = THIS->WriteImage( filename, bitmapType );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__RichTextCtrl_WriteImageBitmap); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextCtrl_WriteImageBitmap)
{
    dVAR; dXSARGS;
    if (items < 2 || items > 3)
       croak_xs_usage(cv,  "THIS, bitmap, bitmapType= wxBITMAP_TYPE_PNG");
    {
	wxRichTextCtrl *    THIS = (wxRichTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextCtrl" )
;
	bool	RETVAL;
	wxBitmap*    bitmap = (wxBitmap *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::Bitmap" )
;
	wxBitmapType	bitmapType;

	if (items < 3)
	    bitmapType = wxBITMAP_TYPE_PNG;
	else {
	    bitmapType = (wxBitmapType)SvIV(ST(2))
;
	}
    try {
      RETVAL = THIS->WriteImage( *( bitmap ), bitmapType );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__RichTextCtrl_WriteImageImage); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextCtrl_WriteImageImage)
{
    dVAR; dXSARGS;
    if (items < 2 || items > 3)
       croak_xs_usage(cv,  "THIS, image, bitmapType= wxBITMAP_TYPE_PNG");
    {
	wxRichTextCtrl *    THIS = (wxRichTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextCtrl" )
;
	bool	RETVAL;
	wxImage*    image = (wxImage *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::Image" )
;
	wxBitmapType	bitmapType;

	if (items < 3)
	    bitmapType = wxBITMAP_TYPE_PNG;
	else {
	    bitmapType = (wxBitmapType)SvIV(ST(2))
;
	}
    try {
      RETVAL = THIS->WriteImage( *( image ), bitmapType );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__RichTextCtrl_SetBasicStyleRich); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextCtrl_SetBasicStyleRich)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, style");
    {
	wxRichTextCtrl *    THIS = (wxRichTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextCtrl" )
;
	wxRichTextAttr*    style = (wxRichTextAttr *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::RichTextAttr" )
;
    try {
      THIS->SetBasicStyle( *( style ) );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__RichTextCtrl_SetBasicStyleEx); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextCtrl_SetBasicStyleEx)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, style");
    {
	wxRichTextCtrl *    THIS = (wxRichTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextCtrl" )
;
	wxTextAttrEx*    style = (wxTextAttrEx *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::TextAttrEx" )
;
    try {
      THIS->SetBasicStyle( *( style ) );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__RichTextCtrl_SetDefaultStyleEx); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextCtrl_SetDefaultStyleEx)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, style");
    {
	wxRichTextCtrl *    THIS = (wxRichTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextCtrl" )
;
	bool	RETVAL;
	wxTextAttrEx*    style = (wxTextAttrEx *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::TextAttrEx" )
;
    try {
      RETVAL = THIS->SetDefaultStyle( *( style ) );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__RichTextCtrl_SetDefaultStyleDefault); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextCtrl_SetDefaultStyleDefault)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, style");
    {
	wxRichTextCtrl *    THIS = (wxRichTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextCtrl" )
;
	bool	RETVAL;
	wxTextAttr*    style = (wxTextAttr *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::TextAttr" )
;
    try {
      RETVAL = THIS->SetDefaultStyle( *( style ) );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__RichTextCtrl_SetBasicStyle); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextCtrl_SetBasicStyle)
{
    dVAR; dXSARGS;
    if (items < 1)
       croak_xs_usage(cv,  "THIS, ...");
    PERL_UNUSED_VAR(ax); /* -Wall */
    SP -= items;
    {
	wxRichTextCtrl *    THIS = (wxRichTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextCtrl" )
;
    BEGIN_OVERLOAD()
        MATCH_REDISP( wxPliOvl_wrta, SetBasicStyleRich )
        MATCH_REDISP( wxPliOvl_wtae, SetBasicStyleEx )
    END_OVERLOAD( "Wx::RichTextCtrl::SetBasicStyle" )
	PUTBACK;
	return;
    }
}


XS_EUPXS(XS_Wx__RichTextCtrl_SetDefaultStyle); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextCtrl_SetDefaultStyle)
{
    dVAR; dXSARGS;
    if (items < 1)
       croak_xs_usage(cv,  "THIS, ...");
    PERL_UNUSED_VAR(ax); /* -Wall */
    SP -= items;
    {
	wxRichTextCtrl *    THIS = (wxRichTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextCtrl" )
;
    BEGIN_OVERLOAD()
        MATCH_REDISP( wxPliOvl_wtae, SetDefaultStyleEx )
        MATCH_REDISP( wxPliOvl_wtat, SetDefaultStyleDefault )
    END_OVERLOAD( "Wx::RichTextCtrl::SetDefaultStyle" )
	PUTBACK;
	return;
    }
}


XS_EUPXS(XS_Wx__RichTextCtrl_GetBuffer); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextCtrl_GetBuffer)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxRichTextCtrl *    THIS = (wxRichTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextCtrl" )
;
	wxRichTextBuffer *	RETVAL;
     RETVAL = &THIS->GetBuffer(); 
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_object_2_sv( aTHX_ RETVALSV, RETVAL );
    wxPli_thread_sv_register( aTHX_ "Wx::RichTextBuffer", RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
     wxPli_object_set_deleteable( aTHX_ ST(0), false ); 
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__RichTextCtrl_new); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextCtrl_new)
{
    dVAR; dXSARGS;
    if (items < 1)
       croak_xs_usage(cv,  "CLASS, ...");
    PERL_UNUSED_VAR(ax); /* -Wall */
    SP -= items;
    {
	char *	CLASS = (char *)SvPV_nolen(ST(0))
;
    BEGIN_OVERLOAD()
        MATCH_VOIDM_REDISP( newDefault )
        MATCH_ANY_REDISP( newFull )
    END_OVERLOAD( "Wx::RichTextCtrl::new" )
	PUTBACK;
	return;
    }
}


XS_EUPXS(XS_Wx__RichTextCtrl_SetStyle); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextCtrl_SetStyle)
{
    dVAR; dXSARGS;
    if (items < 1)
       croak_xs_usage(cv,  "THIS, ...");
    PERL_UNUSED_VAR(ax); /* -Wall */
    SP -= items;
    {
	wxRichTextCtrl *    THIS = (wxRichTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextCtrl" )
;
    BEGIN_OVERLOAD()
        MATCH_REDISP( wxPliOvl_wrtr_wrta, SetStyleRange )
        MATCH_REDISP( wxPliOvl_n_n_wtae, SetStyleExFromTo )
        MATCH_REDISP( wxPliOvl_n_n_wtat, SetStyleFromTo )
    END_OVERLOAD( "Wx::RichTextCtrl::SetStyle" )
	PUTBACK;
	return;
    }
}

#if WXPERL_W_VERSION_GE( 2, 7, 1 )
#define XSubPPtmpAAAS 1


XS_EUPXS(XS_Wx__RichTextCtrl_SetStyleEx); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextCtrl_SetStyleEx)
{
    dVAR; dXSARGS;
    if (items < 1)
       croak_xs_usage(cv,  "THIS, ...");
    PERL_UNUSED_VAR(ax); /* -Wall */
    SP -= items;
    {
	wxRichTextCtrl *    THIS = (wxRichTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextCtrl" )
;
    BEGIN_OVERLOAD()
#if WXPERL_W_VERSION_LT( 2, 9, 0 )
        MATCH_REDISP_COUNT_ALLOWMORE( wxPliOvl_n_n_wtae, SetStyleExExFromTo, 2 )
#else
        MATCH_REDISP_COUNT_ALLOWMORE( wxPliOvl_wrtr_wrta_n, SetStyleExExRange, 2 )
        MATCH_REDISP_COUNT_ALLOWMORE( wxPliOvl_wrtr_wtae_n, SetStyleExRange, 2 )
#endif
    END_OVERLOAD( "Wx::RichTextCtrl::SetStyleEx" )
	PUTBACK;
	return;
    }
}

#endif

XS_EUPXS(XS_Wx__RichTextCtrl_HasCharacterAttributes); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextCtrl_HasCharacterAttributes)
{
    dVAR; dXSARGS;
    if (items < 1)
       croak_xs_usage(cv,  "THIS, ...");
    PERL_UNUSED_VAR(ax); /* -Wall */
    SP -= items;
    {
	wxRichTextCtrl *    THIS = (wxRichTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextCtrl" )
;
    BEGIN_OVERLOAD()
        MATCH_REDISP( wxPliOvl_wrtr_wrta, HasCARich )
        MATCH_REDISP( wxPliOvl_wrtr_wtae, HasCAEx )
    END_OVERLOAD( "Wx::RichTextCtrl::HasCharacterAttributes" )
	PUTBACK;
	return;
    }
}


XS_EUPXS(XS_Wx__RichTextCtrl_HasParagraphAttributes); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextCtrl_HasParagraphAttributes)
{
    dVAR; dXSARGS;
    if (items < 1)
       croak_xs_usage(cv,  "THIS, ...");
    PERL_UNUSED_VAR(ax); /* -Wall */
    SP -= items;
    {
	wxRichTextCtrl *    THIS = (wxRichTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextCtrl" )
;
    BEGIN_OVERLOAD()
        MATCH_REDISP( wxPliOvl_wrtr_wrta, HasPARich )
        MATCH_REDISP( wxPliOvl_wrtr_wtae, HasPAEx )
    END_OVERLOAD( "Wx::RichTextCtrl::HasParagraphAttributes" )
	PUTBACK;
	return;
    }
}


XS_EUPXS(XS_Wx__RichTextCtrl_DeleteSelectedContent); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextCtrl_DeleteSelectedContent)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    PERL_UNUSED_VAR(ax); /* -Wall */
    SP -= items;
    {
	wxRichTextCtrl *    THIS = (wxRichTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextCtrl" )
;
    long newPos;
    bool retval = THIS->DeleteSelectedContent( &newPos );
    EXTEND( SP, 2 );
    PUSHs( newSViv( retval ) );
    PUSHs( newSViv( retval ? newPos : -1 ) );
	PUTBACK;
	return;
    }
}


XS_EUPXS(XS_Wx__RichTextCtrl_GetCaretPositionForIndex); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextCtrl_GetCaretPositionForIndex)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, position");
    PERL_UNUSED_VAR(ax); /* -Wall */
    SP -= items;
    {
	long	position = (long)SvIV(ST(1))
;
	wxRichTextCtrl *    THIS = (wxRichTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextCtrl" )
;
    wxRect rect;
    bool retval = THIS->GetCaretPositionForIndex( position, rect );
    EXTEND( SP, 2 );
    PUSHs( newSViv( retval ) );
    PUSHs( retval ? wxPli_non_object_2_sv( aTHX_ sv_newmortal(),
                                           new wxRect( rect ), "Wx::Rect" ) :
                    &PL_sv_undef );
	PUTBACK;
	return;
    }
}


XS_EUPXS(XS_Wx__RichTextCtrl_GetRichTextAttrStyle); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextCtrl_GetRichTextAttrStyle)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, position");
    PERL_UNUSED_VAR(ax); /* -Wall */
    SP -= items;
    {
	long	position = (long)SvIV(ST(1))
;
	wxRichTextCtrl *    THIS = (wxRichTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextCtrl" )
;
    wxRichTextAttr attr;
    bool retval = THIS->GetStyle( position, attr );
    EXTEND( SP, 2 );
    PUSHs( newSViv( retval ) );
    PUSHs( retval ? wxPli_non_object_2_sv( aTHX_ sv_newmortal(),
                                           new wxRichTextAttr( attr ),
                                           "Wx::RichTextAttr" ) :
                    &PL_sv_undef );
	PUTBACK;
	return;
    }
}


XS_EUPXS(XS_Wx__RichTextCtrl_GetTextAttrExStyle); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextCtrl_GetTextAttrExStyle)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, position");
    PERL_UNUSED_VAR(ax); /* -Wall */
    SP -= items;
    {
	long	position = (long)SvIV(ST(1))
;
	wxRichTextCtrl *    THIS = (wxRichTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextCtrl" )
;
    wxTextAttrEx attr;
    bool retval = THIS->GetStyle( position, attr );
    EXTEND( SP, 2 );
    PUSHs( newSViv( retval ) );
    PUSHs( retval ? wxPli_non_object_2_sv( aTHX_ sv_newmortal(),
                                           new wxTextAttrEx( attr ),
                                           "Wx::TextAttrEx" ) :
                    &PL_sv_undef );
	PUTBACK;
	return;
    }
}


XS_EUPXS(XS_Wx__RichTextCtrl_GetTextAttrStyle); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextCtrl_GetTextAttrStyle)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, position");
    PERL_UNUSED_VAR(ax); /* -Wall */
    SP -= items;
    {
	long	position = (long)SvIV(ST(1))
;
	wxRichTextCtrl *    THIS = (wxRichTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextCtrl" )
;
    wxTextAttr attr;
    bool retval = THIS->GetStyle( position, attr );
    EXTEND( SP, 2 );
    PUSHs( newSViv( retval ) );
    PUSHs( retval ? wxPli_non_object_2_sv( aTHX_ sv_newmortal(),
                                           new wxTextAttr( attr ),
                                           "Wx::TextAttr" ) :
                    &PL_sv_undef );
	PUTBACK;
	return;
    }
}

#if WXPERL_W_VERSION_GE( 2, 9, 0 )
#define XSubPPtmpAAAT 1


XS_EUPXS(XS_Wx__RichTextCtrl_GetStyle); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextCtrl_GetStyle)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, position");
    PERL_UNUSED_VAR(ax); /* -Wall */
    SP -= items;
    {
	long	position = (long)SvIV(ST(1))
;
	wxRichTextCtrl *    THIS = (wxRichTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextCtrl" )
;
    wxTextAttr attr;
    bool retval = THIS->GetStyle( position, attr );
    EXTEND( SP, 2 );
    PUSHs( newSViv( retval ) );
    PUSHs( retval ? wxPli_non_object_2_sv( aTHX_ sv_newmortal(),
                                           new wxTextAttr( attr ),
                                           "Wx::TextAttr" ) :
                    &PL_sv_undef );
	PUTBACK;
	return;
    }
}

#endif
#if WXPERL_W_VERSION_GE( 2, 7, 1 )
#define XSubPPtmpAAAU 1


XS_EUPXS(XS_Wx__RichTextCtrl_GetRichTextAttrUncombinedStyle); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextCtrl_GetRichTextAttrUncombinedStyle)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, position");
    PERL_UNUSED_VAR(ax); /* -Wall */
    SP -= items;
    {
	long	position = (long)SvIV(ST(1))
;
	wxRichTextCtrl *    THIS = (wxRichTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextCtrl" )
;
    wxRichTextAttr attr;
    bool retval = THIS->GetUncombinedStyle( position, attr );
    EXTEND( SP, 2 );
    PUSHs( newSViv( retval ) );
    PUSHs( retval ? wxPli_non_object_2_sv( aTHX_ sv_newmortal(),
                                           new wxRichTextAttr( attr ),
                                           "Wx::RichTextAttr" ) :
                    &PL_sv_undef );
	PUTBACK;
	return;
    }
}

#endif
#if WXPERL_W_VERSION_GE( 2, 7, 1 ) && WXPERL_W_VERSION_LT( 2, 9, 2 )
#define XSubPPtmpAAAV 1


XS_EUPXS(XS_Wx__RichTextCtrl_GetTextAttrExUncombinedStyle); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextCtrl_GetTextAttrExUncombinedStyle)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, position");
    PERL_UNUSED_VAR(ax); /* -Wall */
    SP -= items;
    {
	long	position = (long)SvIV(ST(1))
;
	wxRichTextCtrl *    THIS = (wxRichTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextCtrl" )
;
    wxTextAttrEx attr;
    bool retval = THIS->GetUncombinedStyle( position, attr );
    EXTEND( SP, 2 );
    PUSHs( newSViv( retval ) );
    PUSHs( retval ? wxPli_non_object_2_sv( aTHX_ sv_newmortal(),
                                           new wxTextAttrEx( attr ),
                                           "Wx::TextAttrEx" ) :
                    &PL_sv_undef );
	PUTBACK;
	return;
    }
}


XS_EUPXS(XS_Wx__RichTextCtrl_GetTextAttrUncombinedStyle); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextCtrl_GetTextAttrUncombinedStyle)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, position");
    PERL_UNUSED_VAR(ax); /* -Wall */
    SP -= items;
    {
	long	position = (long)SvIV(ST(1))
;
	wxRichTextCtrl *    THIS = (wxRichTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextCtrl" )
;
    wxTextAttr attr;
    bool retval = THIS->GetUncombinedStyle( position, attr );
    EXTEND( SP, 2 );
    PUSHs( newSViv( retval ) );
    PUSHs( retval ? wxPli_non_object_2_sv( aTHX_ sv_newmortal(),
                                           new wxTextAttr( attr ),
                                           "Wx::TextAttr" ) :
                    &PL_sv_undef );
	PUTBACK;
	return;
    }
}

#endif
#if WXPERL_W_VERSION_GE( 2, 9, 0 ) && WXPERL_W_VERSION_LT( 2, 9, 2 )
#define XSubPPtmpAAAW 1


XS_EUPXS(XS_Wx__RichTextCtrl_GetUncombinedStyle); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextCtrl_GetUncombinedStyle)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, position");
    PERL_UNUSED_VAR(ax); /* -Wall */
    SP -= items;
    {
	long	position = (long)SvIV(ST(1))
;
	wxRichTextCtrl *    THIS = (wxRichTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextCtrl" )
;
    wxTextAttr attr;
    bool retval = THIS->GetUncombinedStyle( position, attr );
    EXTEND( SP, 2 );
    PUSHs( newSViv( retval ) );
    PUSHs( retval ? wxPli_non_object_2_sv( aTHX_ sv_newmortal(),
                                           new wxTextAttr( attr ),
                                           "Wx::TextAttr" ) :
                    &PL_sv_undef );
	PUTBACK;
	return;
    }
}

#endif
#if WXPERL_W_VERSION_GE( 2, 8, 0 )
#define XSubPPtmpAAAX 1


XS_EUPXS(XS_Wx__RichTextCtrl_GetRichTextAttrStyleForRange); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextCtrl_GetRichTextAttrStyleForRange)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, range");
    PERL_UNUSED_VAR(ax); /* -Wall */
    SP -= items;
    {
	wxRichTextRange*    range = (wxRichTextRange *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::RichTextRange" )
;
	wxRichTextCtrl *    THIS = (wxRichTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextCtrl" )
;
    wxRichTextAttr attr;
    bool retval = THIS->GetStyleForRange( *range, attr );
    EXTEND( SP, 2 );
    PUSHs( newSViv( retval ) );
    PUSHs( retval ? wxPli_non_object_2_sv( aTHX_ sv_newmortal(),
                                           new wxRichTextAttr( attr ),
                                           "Wx::RichTextAttr" ) :
                    &PL_sv_undef );
	PUTBACK;
	return;
    }
}


XS_EUPXS(XS_Wx__RichTextCtrl_GetTextAttrExStyleForRange); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextCtrl_GetTextAttrExStyleForRange)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, range");
    PERL_UNUSED_VAR(ax); /* -Wall */
    SP -= items;
    {
	wxRichTextRange*    range = (wxRichTextRange *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::RichTextRange" )
;
	wxRichTextCtrl *    THIS = (wxRichTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextCtrl" )
;
    wxTextAttrEx attr;
    bool retval = THIS->GetStyleForRange( *range, attr );
    EXTEND( SP, 2 );
    PUSHs( newSViv( retval ) );
    PUSHs( retval ? wxPli_non_object_2_sv( aTHX_ sv_newmortal(),
                                           new wxTextAttrEx( attr ),
                                           "Wx::TextAttrEx" ) :
                    &PL_sv_undef );
	PUTBACK;
	return;
    }
}

#endif
#if WXPERL_W_VERSION_GE( 2, 9, 0 )
#define XSubPPtmpAAAY 1


XS_EUPXS(XS_Wx__RichTextCtrl_GetStyleForRange); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextCtrl_GetStyleForRange)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, range");
    PERL_UNUSED_VAR(ax); /* -Wall */
    SP -= items;
    {
	wxRichTextRange*    range = (wxRichTextRange *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::RichTextRange" )
;
	wxRichTextCtrl *    THIS = (wxRichTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextCtrl" )
;
    wxTextAttr attr;
    bool retval = THIS->GetStyleForRange( *range, attr );
    EXTEND( SP, 2 );
    PUSHs( newSViv( retval ) );
    PUSHs( retval ? wxPli_non_object_2_sv( aTHX_ sv_newmortal(),
                                           new wxTextAttrEx( attr ),
                                           "Wx::TextAttrEx" ) :
                    &PL_sv_undef );
	PUTBACK;
	return;
    }
}

#endif

XS_EUPXS(XS_Wx__RichTextCtrl_WriteImage); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextCtrl_WriteImage)
{
    dVAR; dXSARGS;
    PERL_UNUSED_VAR(cv); /* -W */
    PERL_UNUSED_VAR(items); /* -W */
    PERL_UNUSED_VAR(ax); /* -Wall */
    SP -= items;
    {
    BEGIN_OVERLOAD()
        MATCH_REDISP_COUNT_ALLOWMORE( wxPliOvl_wimg_n, WriteImageImage, 1 )
        MATCH_REDISP_COUNT_ALLOWMORE( wxPliOvl_wbmp_n, WriteImageBitmap, 1 )
        MATCH_REDISP( wxPliOvl_s_n, WriteImageFile )
    END_OVERLOAD( "Wx::RichTextCtrl::WriteImage" )
	PUTBACK;
	return;
    }
}

#if WXPERL_W_VERSION_GE( 2, 9, 2 )
#define XSpp_7969698b_094979
#define WXPERL_IN_RICHTEXTCTRL
#define XSubPPtmpAAAZ 1


/* INCLUDE_COMMAND:  Including output of '/usr/bin/perl -MExtUtils::XSpp::Cmd -e xspp -- -t typemap.xsp -t ../../typemap.xsp ../../XS/TextCtrlIface.xsp' from '/usr/bin/perl -I../.. -MExtUtils::XSpp::Cmd -e xspp -- -t typemap.xsp -t ../../typemap.xsp XS/RichTextCtrl.xsp' */

#include <exception>

#undef  xsp_constructor_class
#define xsp_constructor_class(c) (c)

/* INCLUDE: Returning to '/usr/bin/perl -I../.. -MExtUtils::XSpp::Cmd -e xspp -- -t typemap.xsp -t ../../typemap.xsp XS/RichTextCtrl.xsp' from '/usr/bin/perl -MExtUtils::XSpp::Cmd -e xspp -- -t typemap.xsp -t ../../typemap.xsp ../../XS/TextCtrlIface.xsp' */


/* INCLUDE_COMMAND:  Including output of '/usr/bin/perl -pe "s/TextCtrlIface/RichTextCtrl/g" xspp/TextCtrlIface.h' from '/usr/bin/perl -I../.. -MExtUtils::XSpp::Cmd -e xspp -- -t typemap.xsp -t ../../typemap.xsp XS/RichTextCtrl.xsp' */

#include <exception>

#undef  xsp_constructor_class
#define xsp_constructor_class(c) (c)
#if WXPERL_W_VERSION_GE( 2, 9, 2 )
#define XSpp_84f64d48_024732
#define XSubPPtmpAABA 1


XS_EUPXS(XS_Wx__RichTextCtrl_GetValue); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextCtrl_GetValue)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxRichTextCtrl *    THIS = (wxRichTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextCtrl" )
;
	wxString	RETVAL;
    try {
      RETVAL = THIS->GetValue();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    WXSTRING_OUTPUT( RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__RichTextCtrl_SetValue); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextCtrl_SetValue)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, value");
    {
	wxRichTextCtrl *    THIS = (wxRichTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextCtrl" )
;
	wxString	value;

    WXSTRING_INPUT( value, wxString, ST(1) )
;
    try {
      THIS->SetValue( value );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__RichTextCtrl_ChangeValue); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextCtrl_ChangeValue)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, value");
    {
	wxRichTextCtrl *    THIS = (wxRichTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextCtrl" )
;
	wxString	value;

    WXSTRING_INPUT( value, wxString, ST(1) )
;
    try {
      THIS->ChangeValue( value );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__RichTextCtrl_GetRange); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextCtrl_GetRange)
{
    dVAR; dXSARGS;
    if (items != 3)
       croak_xs_usage(cv,  "THIS, from, to");
    {
	wxRichTextCtrl *    THIS = (wxRichTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextCtrl" )
;
	wxString	RETVAL;
	long	from = (long)SvIV(ST(1))
;
	long	to = (long)SvIV(ST(2))
;
    try {
      RETVAL = THIS->GetRange( from, to );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    WXSTRING_OUTPUT( RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__RichTextCtrl_WriteText); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextCtrl_WriteText)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, text");
    {
	wxRichTextCtrl *    THIS = (wxRichTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextCtrl" )
;
	wxString	text;

    WXSTRING_INPUT( text, wxString, ST(1) )
;
    try {
      THIS->WriteText( text );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__RichTextCtrl_AppendText); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextCtrl_AppendText)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, text");
    {
	wxRichTextCtrl *    THIS = (wxRichTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextCtrl" )
;
	wxString	text;

    WXSTRING_INPUT( text, wxString, ST(1) )
;
    try {
      THIS->AppendText( text );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__RichTextCtrl_IsEmpty); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextCtrl_IsEmpty)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxRichTextCtrl *    THIS = (wxRichTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextCtrl" )
;
	bool	RETVAL;
    try {
      RETVAL = THIS->IsEmpty();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__RichTextCtrl_Clear); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextCtrl_Clear)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxRichTextCtrl *    THIS = (wxRichTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextCtrl" )
;
    try {
      THIS->Clear();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__RichTextCtrl_Replace); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextCtrl_Replace)
{
    dVAR; dXSARGS;
    if (items != 4)
       croak_xs_usage(cv,  "THIS, from, to, value");
    {
	wxRichTextCtrl *    THIS = (wxRichTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextCtrl" )
;
	long	from = (long)SvIV(ST(1))
;
	long	to = (long)SvIV(ST(2))
;
	wxString	value;

    WXSTRING_INPUT( value, wxString, ST(3) )
;
    try {
      THIS->Replace( from, to, value );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__RichTextCtrl_Remove); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextCtrl_Remove)
{
    dVAR; dXSARGS;
    if (items != 3)
       croak_xs_usage(cv,  "THIS, from, to");
    {
	wxRichTextCtrl *    THIS = (wxRichTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextCtrl" )
;
	long	from = (long)SvIV(ST(1))
;
	long	to = (long)SvIV(ST(2))
;
    try {
      THIS->Remove( from, to );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__RichTextCtrl_RemoveSelection); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextCtrl_RemoveSelection)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxRichTextCtrl *    THIS = (wxRichTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextCtrl" )
;
    try {
      THIS->RemoveSelection();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__RichTextCtrl_Copy); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextCtrl_Copy)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxRichTextCtrl *    THIS = (wxRichTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextCtrl" )
;
    try {
      THIS->Copy();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__RichTextCtrl_Cut); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextCtrl_Cut)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxRichTextCtrl *    THIS = (wxRichTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextCtrl" )
;
    try {
      THIS->Cut();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__RichTextCtrl_Paste); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextCtrl_Paste)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxRichTextCtrl *    THIS = (wxRichTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextCtrl" )
;
    try {
      THIS->Paste();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__RichTextCtrl_CanCopy); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextCtrl_CanCopy)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxRichTextCtrl *    THIS = (wxRichTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextCtrl" )
;
	bool	RETVAL;
    try {
      RETVAL = THIS->CanCopy();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__RichTextCtrl_CanCut); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextCtrl_CanCut)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxRichTextCtrl *    THIS = (wxRichTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextCtrl" )
;
	bool	RETVAL;
    try {
      RETVAL = THIS->CanCut();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__RichTextCtrl_CanPaste); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextCtrl_CanPaste)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxRichTextCtrl *    THIS = (wxRichTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextCtrl" )
;
	bool	RETVAL;
    try {
      RETVAL = THIS->CanPaste();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__RichTextCtrl_Undo); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextCtrl_Undo)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxRichTextCtrl *    THIS = (wxRichTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextCtrl" )
;
    try {
      THIS->Undo();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__RichTextCtrl_Redo); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextCtrl_Redo)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxRichTextCtrl *    THIS = (wxRichTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextCtrl" )
;
    try {
      THIS->Redo();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__RichTextCtrl_CanUndo); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextCtrl_CanUndo)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxRichTextCtrl *    THIS = (wxRichTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextCtrl" )
;
	bool	RETVAL;
    try {
      RETVAL = THIS->CanUndo();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__RichTextCtrl_CanRedo); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextCtrl_CanRedo)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxRichTextCtrl *    THIS = (wxRichTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextCtrl" )
;
	bool	RETVAL;
    try {
      RETVAL = THIS->CanRedo();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__RichTextCtrl_SetInsertionPoint); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextCtrl_SetInsertionPoint)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, pos");
    {
	wxRichTextCtrl *    THIS = (wxRichTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextCtrl" )
;
	long	pos = (long)SvIV(ST(1))
;
    try {
      THIS->SetInsertionPoint( pos );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__RichTextCtrl_SetInsertionPointEnd); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextCtrl_SetInsertionPointEnd)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxRichTextCtrl *    THIS = (wxRichTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextCtrl" )
;
    try {
      THIS->SetInsertionPointEnd();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__RichTextCtrl_GetInsertionPoint); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextCtrl_GetInsertionPoint)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxRichTextCtrl *    THIS = (wxRichTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextCtrl" )
;
	long	RETVAL;
	dXSTARG;
    try {
      RETVAL = THIS->GetInsertionPoint();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__RichTextCtrl_GetLastPosition); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextCtrl_GetLastPosition)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxRichTextCtrl *    THIS = (wxRichTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextCtrl" )
;
	long	RETVAL;
	dXSTARG;
    try {
      RETVAL = THIS->GetLastPosition();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__RichTextCtrl_SetSelection); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextCtrl_SetSelection)
{
    dVAR; dXSARGS;
    if (items != 3)
       croak_xs_usage(cv,  "THIS, from, to");
    {
	wxRichTextCtrl *    THIS = (wxRichTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextCtrl" )
;
	long	from = (long)SvIV(ST(1))
;
	long	to = (long)SvIV(ST(2))
;
    try {
      THIS->SetSelection( from, to );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__RichTextCtrl_SelectAll); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextCtrl_SelectAll)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxRichTextCtrl *    THIS = (wxRichTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextCtrl" )
;
    try {
      THIS->SelectAll();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__RichTextCtrl_HasSelection); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextCtrl_HasSelection)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxRichTextCtrl *    THIS = (wxRichTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextCtrl" )
;
	bool	RETVAL;
    try {
      RETVAL = THIS->HasSelection();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__RichTextCtrl_GetStringSelection); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextCtrl_GetStringSelection)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxRichTextCtrl *    THIS = (wxRichTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextCtrl" )
;
	wxString	RETVAL;
    try {
      RETVAL = THIS->GetStringSelection();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    WXSTRING_OUTPUT( RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__RichTextCtrl_AutoCompleteFileNames); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextCtrl_AutoCompleteFileNames)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxRichTextCtrl *    THIS = (wxRichTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextCtrl" )
;
	bool	RETVAL;
    try {
      RETVAL = THIS->AutoCompleteFileNames();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__RichTextCtrl_AutoComplete); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextCtrl_AutoComplete)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, choices");
    {
	wxRichTextCtrl *    THIS = (wxRichTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextCtrl" )
;
	bool	RETVAL;
	wxArrayString	choices;

    wxPli_av_2_arraystring( aTHX_ ST(1), & choices )
;
    try {
      RETVAL = THIS->AutoComplete( choices );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__RichTextCtrl_IsEditable); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextCtrl_IsEditable)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxRichTextCtrl *    THIS = (wxRichTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextCtrl" )
;
	bool	RETVAL;
    try {
      RETVAL = THIS->IsEditable();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__RichTextCtrl_SetEditable); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextCtrl_SetEditable)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, editable");
    {
	wxRichTextCtrl *    THIS = (wxRichTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextCtrl" )
;
	bool	editable = (bool)SvTRUE(ST(1))
;
    try {
      THIS->SetEditable( editable );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__RichTextCtrl_SetMaxLength); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextCtrl_SetMaxLength)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, len");
    {
	wxRichTextCtrl *    THIS = (wxRichTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextCtrl" )
;
	unsigned long    len = (unsigned long)SvUV( ST(1) )
;
    try {
      THIS->SetMaxLength( len );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__RichTextCtrl_SetHint); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextCtrl_SetHint)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, hint");
    {
	wxRichTextCtrl *    THIS = (wxRichTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextCtrl" )
;
	bool	RETVAL;
	wxString	hint;

    WXSTRING_INPUT( hint, wxString, ST(1) )
;
    try {
      RETVAL = THIS->SetHint( hint );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__RichTextCtrl_GetHint); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextCtrl_GetHint)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxRichTextCtrl *    THIS = (wxRichTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextCtrl" )
;
	wxString	RETVAL;
    try {
      RETVAL = THIS->GetHint();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    WXSTRING_OUTPUT( RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__RichTextCtrl_SetMargins); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextCtrl_SetMargins)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, pt");
    {
	wxRichTextCtrl *    THIS = (wxRichTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextCtrl" )
;
	bool	RETVAL;
	wxPoint    pt = wxPli_sv_2_wxpoint( aTHX_ ST(1) )
;
    try {
      RETVAL = THIS->SetMargins( pt );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__RichTextCtrl_GetMargins); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextCtrl_GetMargins)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxRichTextCtrl *    THIS = (wxRichTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextCtrl" )
;
	wxPoint	RETVAL;
    try {
      RETVAL = THIS->GetMargins();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_non_object_2_sv( aTHX_ RETVALSV, new wxPoint(RETVAL), "Wx::Point" );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__RichTextCtrl_GetLineLength); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextCtrl_GetLineLength)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, lineNo");
    {
	wxRichTextCtrl *    THIS = (wxRichTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextCtrl" )
;
	int	RETVAL;
	dXSTARG;
	long	lineNo = (long)SvIV(ST(1))
;
    try {
      RETVAL = THIS->GetLineLength( lineNo );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__RichTextCtrl_GetLineText); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextCtrl_GetLineText)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, lineNo");
    {
	wxRichTextCtrl *    THIS = (wxRichTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextCtrl" )
;
	wxString	RETVAL;
	long	lineNo = (long)SvIV(ST(1))
;
    try {
      RETVAL = THIS->GetLineText( lineNo );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    WXSTRING_OUTPUT( RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__RichTextCtrl_GetNumberOfLines); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextCtrl_GetNumberOfLines)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxRichTextCtrl *    THIS = (wxRichTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextCtrl" )
;
	int	RETVAL;
	dXSTARG;
    try {
      RETVAL = THIS->GetNumberOfLines();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}

#if defined(WXPERL_IN_RICHTEXTCTRL)
#define XSpp_84f64d48_006789
#define XSubPPtmpAABB 1


XS_EUPXS(XS_Wx__RichTextCtrl_LoadFile); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextCtrl_LoadFile)
{
    dVAR; dXSARGS;
    if (items < 2 || items > 3)
       croak_xs_usage(cv,  "THIS, file, fileType= wxTEXT_TYPE_ANY");
    {
	wxRichTextCtrl *    THIS = (wxRichTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextCtrl" )
;
	bool	RETVAL;
	wxString	file;
	int	fileType;

    WXSTRING_INPUT( file, wxString, ST(1) )
;

	if (items < 3)
	    fileType = wxTEXT_TYPE_ANY;
	else {
	    fileType = (int)SvIV(ST(2))
;
	}
    try {
      RETVAL = THIS->LoadFile( file, fileType );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__RichTextCtrl_SaveFile); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextCtrl_SaveFile)
{
    dVAR; dXSARGS;
    if (items < 1 || items > 3)
       croak_xs_usage(cv,  "THIS, file= wxEmptyString, fileType= wxTEXT_TYPE_ANY");
    {
	wxRichTextCtrl *    THIS = (wxRichTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextCtrl" )
;
	bool	RETVAL;
	wxString	file;
	int	fileType;

	if (items < 2)
	    file = wxEmptyString;
	else {
    WXSTRING_INPUT( file, wxString, ST(1) )
;
	}

	if (items < 3)
	    fileType = wxTEXT_TYPE_ANY;
	else {
	    fileType = (int)SvIV(ST(2))
;
	}
    try {
      RETVAL = THIS->SaveFile( file, fileType );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}

#endif

XS_EUPXS(XS_Wx__RichTextCtrl_IsModified); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextCtrl_IsModified)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxRichTextCtrl *    THIS = (wxRichTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextCtrl" )
;
	bool	RETVAL;
    try {
      RETVAL = THIS->IsModified();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__RichTextCtrl_MarkDirty); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextCtrl_MarkDirty)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxRichTextCtrl *    THIS = (wxRichTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextCtrl" )
;
    try {
      THIS->MarkDirty();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__RichTextCtrl_DiscardEdits); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextCtrl_DiscardEdits)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxRichTextCtrl *    THIS = (wxRichTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextCtrl" )
;
    try {
      THIS->DiscardEdits();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__RichTextCtrl_SetModified); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextCtrl_SetModified)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, modified");
    {
	wxRichTextCtrl *    THIS = (wxRichTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextCtrl" )
;
	bool	modified = (bool)SvTRUE(ST(1))
;
    try {
      THIS->SetModified( modified );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}

#if defined(WXPERL_IN_SEARCHCTRL)
#define XSpp_84f64d48_009161
#define XSubPPtmpAABC 1


XS_EUPXS(XS_Wx__RichTextCtrl_SetStyle); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextCtrl_SetStyle)
{
    dVAR; dXSARGS;
    if (items != 4)
       croak_xs_usage(cv,  "THIS, start, end, style");
    {
	wxRichTextCtrl *    THIS = (wxRichTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextCtrl" )
;
	bool	RETVAL;
	long	start = (long)SvIV(ST(1))
;
	long	end = (long)SvIV(ST(2))
;
	wxTextAttr*    style = (wxTextAttr *) wxPli_sv_2_object( aTHX_ ST(3), "Wx::TextAttr" )
;
    try {
      RETVAL = THIS->SetStyle( start, end, *( style ) );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}

#endif
#if !defined(WXPERL_IN_RICHTEXTCTRL)
#define XSpp_84f64d48_056595
#define XSubPPtmpAABD 1


XS_EUPXS(XS_Wx__RichTextCtrl_SetDefaultStyle); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextCtrl_SetDefaultStyle)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, style");
    {
	wxRichTextCtrl *    THIS = (wxRichTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextCtrl" )
;
	bool	RETVAL;
	wxTextAttr*    style = (wxTextAttr *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::TextAttr" )
;
    try {
      RETVAL = THIS->SetDefaultStyle( *( style ) );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}

#endif

XS_EUPXS(XS_Wx__RichTextCtrl_GetDefaultStyle); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextCtrl_GetDefaultStyle)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxRichTextCtrl *    THIS = (wxRichTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextCtrl" )
;
	wxTextAttr *	RETVAL;
    try {
      RETVAL = new wxTextAttr( THIS->GetDefaultStyle() );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_non_object_2_sv( aTHX_ RETVALSV, RETVAL, "Wx::TextAttr" );
    wxPli_thread_sv_register( aTHX_ "Wx::TextAttr", RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__RichTextCtrl_XYToPosition); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextCtrl_XYToPosition)
{
    dVAR; dXSARGS;
    if (items != 3)
       croak_xs_usage(cv,  "THIS, x, y");
    {
	wxRichTextCtrl *    THIS = (wxRichTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextCtrl" )
;
	long	RETVAL;
	dXSTARG;
	long	x = (long)SvIV(ST(1))
;
	long	y = (long)SvIV(ST(2))
;
    try {
      RETVAL = THIS->XYToPosition( x, y );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__RichTextCtrl_ShowPosition); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextCtrl_ShowPosition)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, pos");
    {
	wxRichTextCtrl *    THIS = (wxRichTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextCtrl" )
;
	long	pos = (long)SvIV(ST(1))
;
    try {
      THIS->ShowPosition( pos );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__RichTextCtrl_GetSelection); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextCtrl_GetSelection)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    PERL_UNUSED_VAR(ax); /* -Wall */
    SP -= items;
    {
    long from;
    long to;
	wxRichTextCtrl *    THIS = (wxRichTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextCtrl" )
;
    THIS->GetSelection( &from, &to );
    EXTEND( SP, 2 );
    PUSHs( sv_2mortal( newSViv( from ) ) );
    PUSHs( sv_2mortal( newSViv( to ) ) );
	PUTBACK;
	return;
    }
}

#if defined(WXPERL_IN_SEARCHCTRL)
#define XSpp_84f64d48_013502
#define XSubPPtmpAABE 1


XS_EUPXS(XS_Wx__RichTextCtrl_GetStyle); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextCtrl_GetStyle)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, position");
    PERL_UNUSED_VAR(ax); /* -Wall */
    SP -= items;
    {
	long	position = (long)SvIV(ST(1))
;
	wxRichTextCtrl *    THIS = (wxRichTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextCtrl" )
;
    wxTextAttr attr;
    bool retval = THIS->GetStyle( position, attr );
    EXTEND( SP, 2 );
    PUSHs( newSViv( retval ) );
    PUSHs( retval ? wxPli_non_object_2_sv( aTHX_ sv_newmortal(),
                                           new wxTextAttr( attr ),
                                           "Wx::TextAttr" ) :
                    &PL_sv_undef );
	PUTBACK;
	return;
    }
}

#endif

XS_EUPXS(XS_Wx__RichTextCtrl_PositionToXY); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextCtrl_PositionToXY)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, pos");
    PERL_UNUSED_VAR(ax); /* -Wall */
    SP -= items;
    {
	long	pos = (long)SvIV(ST(1))
;
    long x;
    long y;
	wxRichTextCtrl *    THIS = (wxRichTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextCtrl" )
;
    THIS->PositionToXY( pos, &x, &y );
    EXTEND( SP, 2 );
    PUSHs( sv_2mortal( newSViv( x ) ) );
    PUSHs( sv_2mortal( newSViv( y ) ) );
	PUTBACK;
	return;
    }
}


XS_EUPXS(XS_Wx__RichTextCtrl_HitTest); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextCtrl_HitTest)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, pt");
    PERL_UNUSED_VAR(ax); /* -Wall */
    SP -= items;
    {
	wxPoint    pt = wxPli_sv_2_wxpoint( aTHX_ ST(1) )
;
	wxRichTextCtrl *    THIS = (wxRichTextCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextCtrl" )
;
    long col, row;
    wxTextCtrlHitTestResult res = THIS->HitTest( pt, &col, &row );

    EXTEND( SP, 3 );
    PUSHs( sv_2mortal( newSViv( res ) ) );
    PUSHs( sv_2mortal( newSViv( col ) ) );
    PUSHs( sv_2mortal( newSViv( row ) ) );
	PUTBACK;
	return;
    }
}

#endif

/* INCLUDE: Returning to '/usr/bin/perl -I../.. -MExtUtils::XSpp::Cmd -e xspp -- -t typemap.xsp -t ../../typemap.xsp XS/RichTextCtrl.xsp' from '/usr/bin/perl -pe "s/TextCtrlIface/RichTextCtrl/g" xspp/TextCtrlIface.h' */

#undef WXPERL_IN_RICHTEXTCTRL
#endif

/* INCLUDE: Returning to 'RichText.xs' from '/usr/bin/perl -I../.. -MExtUtils::XSpp::Cmd -e xspp -- -t typemap.xsp -t ../../typemap.xsp XS/RichTextCtrl.xsp' */


/* INCLUDE_COMMAND:  Including output of '/usr/bin/perl -MExtUtils::XSpp::Cmd -e xspp -- -t typemap.xsp -t ../../typemap.xsp XS/RichTextAttr.xsp' from 'RichText.xs' */

#include <exception>

#undef  xsp_constructor_class
#define xsp_constructor_class(c) (c)
#include <wx/event.h>
#include <wx/richtext/richtextbuffer.h>
#undef  xsp_constructor_class
#define xsp_constructor_class(c) (CLASS)

XS_EUPXS(XS_Wx__RichTextRange_newDefault); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextRange_newDefault)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "CLASS");
    {
	char *	CLASS = (char *)SvPV_nolen(ST(0))
;
	wxRichTextRange *	RETVAL;
    try {
      RETVAL = new wxRichTextRange();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_non_object_2_sv( aTHX_ RETVALSV, RETVAL, "Wx::RichTextRange" );
    wxPli_thread_sv_register( aTHX_ "Wx::RichTextRange", RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}

#undef  xsp_constructor_class
#define xsp_constructor_class(c) (c)
#undef  xsp_constructor_class
#define xsp_constructor_class(c) (CLASS)

XS_EUPXS(XS_Wx__RichTextRange_newFromTo); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextRange_newFromTo)
{
    dVAR; dXSARGS;
    if (items != 3)
       croak_xs_usage(cv,  "CLASS, start, end");
    {
	char *	CLASS = (char *)SvPV_nolen(ST(0))
;
	wxRichTextRange *	RETVAL;
	long	start = (long)SvIV(ST(1))
;
	long	end = (long)SvIV(ST(2))
;
    try {
      RETVAL = new wxRichTextRange( start, end );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_non_object_2_sv( aTHX_ RETVALSV, RETVAL, "Wx::RichTextRange" );
    wxPli_thread_sv_register( aTHX_ "Wx::RichTextRange", RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}

#undef  xsp_constructor_class
#define xsp_constructor_class(c) (c)
#undef  xsp_constructor_class
#define xsp_constructor_class(c) (CLASS)

XS_EUPXS(XS_Wx__RichTextRange_newCopy); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextRange_newCopy)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "CLASS, range");
    {
	char *	CLASS = (char *)SvPV_nolen(ST(0))
;
	wxRichTextRange *	RETVAL;
	wxRichTextRange*    range = (wxRichTextRange *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::RichTextRange" )
;
    try {
      RETVAL = new wxRichTextRange( *( range ) );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_non_object_2_sv( aTHX_ RETVALSV, RETVAL, "Wx::RichTextRange" );
    wxPli_thread_sv_register( aTHX_ "Wx::RichTextRange", RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}

#undef  xsp_constructor_class
#define xsp_constructor_class(c) (c)

XS_EUPXS(XS_Wx__RichTextRange_CLONE); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextRange_CLONE)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "CLASS");
    {
	char *	CLASS = (char *)SvPV_nolen(ST(0))
;
    wxPli_thread_sv_clone( aTHX_ CLASS, (wxPliCloneSV)wxPli_detach_object );
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__RichTextRange_DESTROY); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextRange_DESTROY)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxRichTextRange *    THIS = (wxRichTextRange *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextRange" )
;
     wxPli_thread_sv_unregister( aTHX_ "Wx::RichTextRange", THIS, ST(0) );
                delete THIS;
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__RichTextRange_SetRange); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextRange_SetRange)
{
    dVAR; dXSARGS;
    if (items != 3)
       croak_xs_usage(cv,  "THIS, start, end");
    {
	wxRichTextRange *    THIS = (wxRichTextRange *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextRange" )
;
	long	start = (long)SvIV(ST(1))
;
	long	end = (long)SvIV(ST(2))
;
    try {
      THIS->SetRange( start, end );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__RichTextRange_SetStart); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextRange_SetStart)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, start");
    {
	wxRichTextRange *    THIS = (wxRichTextRange *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextRange" )
;
	long	start = (long)SvIV(ST(1))
;
    try {
      THIS->SetStart( start );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__RichTextRange_GetStart); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextRange_GetStart)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxRichTextRange *    THIS = (wxRichTextRange *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextRange" )
;
	long	RETVAL;
	dXSTARG;
    try {
      RETVAL = THIS->GetStart();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__RichTextRange_SetEnd); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextRange_SetEnd)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, end");
    {
	wxRichTextRange *    THIS = (wxRichTextRange *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextRange" )
;
	long	end = (long)SvIV(ST(1))
;
    try {
      THIS->SetEnd( end );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__RichTextRange_GetEnd); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextRange_GetEnd)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxRichTextRange *    THIS = (wxRichTextRange *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextRange" )
;
	long	RETVAL;
	dXSTARG;
    try {
      RETVAL = THIS->GetEnd();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__RichTextRange_IsOutside); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextRange_IsOutside)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, range");
    {
	wxRichTextRange *    THIS = (wxRichTextRange *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextRange" )
;
	bool	RETVAL;
	wxRichTextRange*    range = (wxRichTextRange *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::RichTextRange" )
;
    try {
      RETVAL = THIS->IsOutside( *( range ) );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__RichTextRange_IsWithin); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextRange_IsWithin)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, range");
    {
	wxRichTextRange *    THIS = (wxRichTextRange *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextRange" )
;
	bool	RETVAL;
	wxRichTextRange*    range = (wxRichTextRange *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::RichTextRange" )
;
    try {
      RETVAL = THIS->IsWithin( *( range ) );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__RichTextRange_Contains); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextRange_Contains)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, pos");
    {
	wxRichTextRange *    THIS = (wxRichTextRange *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextRange" )
;
	bool	RETVAL;
	long	pos = (long)SvIV(ST(1))
;
    try {
      RETVAL = THIS->Contains( pos );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__RichTextRange_LimitTo); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextRange_LimitTo)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, range");
    {
	wxRichTextRange *    THIS = (wxRichTextRange *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextRange" )
;
	bool	RETVAL;
	wxRichTextRange*    range = (wxRichTextRange *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::RichTextRange" )
;
    try {
      RETVAL = THIS->LimitTo( *( range ) );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__RichTextRange_GetLength); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextRange_GetLength)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxRichTextRange *    THIS = (wxRichTextRange *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextRange" )
;
	long	RETVAL;
	dXSTARG;
    try {
      RETVAL = THIS->GetLength();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__RichTextRange_new); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextRange_new)
{
    dVAR; dXSARGS;
    if (items < 1)
       croak_xs_usage(cv,  "CLASS, ...");
    PERL_UNUSED_VAR(ax); /* -Wall */
    SP -= items;
    {
	char *	CLASS = (char *)SvPV_nolen(ST(0))
;
    BEGIN_OVERLOAD()
        MATCH_VOIDM_REDISP( newDefault )
        MATCH_REDISP( wxPliOvl_n_n, newFromTo )
        MATCH_REDISP( wxPliOvl_wrtr, newCopy )
    END_OVERLOAD( Wx::RichTextRange::new )
	PUTBACK;
	return;
    }
}

#undef  xsp_constructor_class
#define xsp_constructor_class(c) (CLASS)

XS_EUPXS(XS_Wx__TextAttrEx_newDefault); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__TextAttrEx_newDefault)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "CLASS");
    {
	char *	CLASS = (char *)SvPV_nolen(ST(0))
;
	wxTextAttrEx *	RETVAL;
    try {
      RETVAL = new wxTextAttrEx();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_non_object_2_sv( aTHX_ RETVALSV, RETVAL, "Wx::TextAttrEx" );
    wxPli_thread_sv_register( aTHX_ "Wx::TextAttrEx", RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}

#undef  xsp_constructor_class
#define xsp_constructor_class(c) (c)
#undef  xsp_constructor_class
#define xsp_constructor_class(c) (CLASS)

XS_EUPXS(XS_Wx__TextAttrEx_newCopy); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__TextAttrEx_newCopy)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "CLASS, attr");
    {
	char *	CLASS = (char *)SvPV_nolen(ST(0))
;
	wxTextAttrEx *	RETVAL;
	wxTextAttrEx*    attr = (wxTextAttrEx *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::TextAttrEx" )
;
    try {
      RETVAL = new wxTextAttrEx( *( attr ) );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_non_object_2_sv( aTHX_ RETVALSV, RETVAL, "Wx::TextAttrEx" );
    wxPli_thread_sv_register( aTHX_ "Wx::TextAttrEx", RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}

#undef  xsp_constructor_class
#define xsp_constructor_class(c) (c)
#undef  xsp_constructor_class
#define xsp_constructor_class(c) (CLASS)

XS_EUPXS(XS_Wx__TextAttrEx_newAttr); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__TextAttrEx_newAttr)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "CLASS, attr");
    {
	char *	CLASS = (char *)SvPV_nolen(ST(0))
;
	wxTextAttrEx *	RETVAL;
	wxTextAttr*    attr = (wxTextAttr *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::TextAttr" )
;
    try {
      RETVAL = new wxTextAttrEx( *( attr ) );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_non_object_2_sv( aTHX_ RETVALSV, RETVAL, "Wx::TextAttrEx" );
    wxPli_thread_sv_register( aTHX_ "Wx::TextAttrEx", RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}

#undef  xsp_constructor_class
#define xsp_constructor_class(c) (c)

XS_EUPXS(XS_Wx__TextAttrEx_CLONE); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__TextAttrEx_CLONE)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "CLASS");
    {
	char *	CLASS = (char *)SvPV_nolen(ST(0))
;
    wxPli_thread_sv_clone( aTHX_ CLASS, (wxPliCloneSV)wxPli_detach_object );
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__TextAttrEx_DESTROY); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__TextAttrEx_DESTROY)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxTextAttrEx *    THIS = (wxTextAttrEx *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::TextAttrEx" )
;
     wxPli_thread_sv_unregister( aTHX_ "Wx::TextAttrEx", THIS, ST(0) );
                delete THIS;
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__TextAttrEx_SetCharacterStyleName); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__TextAttrEx_SetCharacterStyleName)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, name");
    {
	wxTextAttrEx *    THIS = (wxTextAttrEx *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::TextAttrEx" )
;
	wxString	name;

    WXSTRING_INPUT( name, wxString, ST(1) )
;
    try {
      THIS->SetCharacterStyleName( name );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__TextAttrEx_SetParagraphStyleName); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__TextAttrEx_SetParagraphStyleName)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, name");
    {
	wxTextAttrEx *    THIS = (wxTextAttrEx *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::TextAttrEx" )
;
	wxString	name;

    WXSTRING_INPUT( name, wxString, ST(1) )
;
    try {
      THIS->SetParagraphStyleName( name );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}

#if WXPERL_W_VERSION_GE( 2, 7, 2 )
#define XSpp_b93c44bc_002681
#define XSubPPtmpAABF 1


XS_EUPXS(XS_Wx__TextAttrEx_SetListStyleName); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__TextAttrEx_SetListStyleName)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, name");
    {
	wxTextAttrEx *    THIS = (wxTextAttrEx *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::TextAttrEx" )
;
	wxString	name;

    WXSTRING_INPUT( name, wxString, ST(1) )
;
    try {
      THIS->SetListStyleName( name );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}

#endif

XS_EUPXS(XS_Wx__TextAttrEx_SetParagraphSpacingAfter); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__TextAttrEx_SetParagraphSpacingAfter)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, spacing");
    {
	wxTextAttrEx *    THIS = (wxTextAttrEx *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::TextAttrEx" )
;
	int	spacing = (int)SvIV(ST(1))
;
    try {
      THIS->SetParagraphSpacingAfter( spacing );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__TextAttrEx_SetParagraphSpacingBefore); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__TextAttrEx_SetParagraphSpacingBefore)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, spacing");
    {
	wxTextAttrEx *    THIS = (wxTextAttrEx *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::TextAttrEx" )
;
	int	spacing = (int)SvIV(ST(1))
;
    try {
      THIS->SetParagraphSpacingBefore( spacing );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__TextAttrEx_SetLineSpacing); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__TextAttrEx_SetLineSpacing)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, spacing");
    {
	wxTextAttrEx *    THIS = (wxTextAttrEx *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::TextAttrEx" )
;
	int	spacing = (int)SvIV(ST(1))
;
    try {
      THIS->SetLineSpacing( spacing );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__TextAttrEx_SetBulletStyle); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__TextAttrEx_SetBulletStyle)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, style");
    {
	wxTextAttrEx *    THIS = (wxTextAttrEx *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::TextAttrEx" )
;
	int	style = (int)SvIV(ST(1))
;
    try {
      THIS->SetBulletStyle( style );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__TextAttrEx_SetBulletNumber); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__TextAttrEx_SetBulletNumber)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, n");
    {
	wxTextAttrEx *    THIS = (wxTextAttrEx *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::TextAttrEx" )
;
	int	n = (int)SvIV(ST(1))
;
    try {
      THIS->SetBulletNumber( n );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}

#if WXPERL_W_VERSION_GE( 2, 7, 2 )
#define XSpp_b93c44bc_073413
#define XSubPPtmpAABG 1


XS_EUPXS(XS_Wx__TextAttrEx_SetBulletText); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__TextAttrEx_SetBulletText)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, text");
    {
	wxTextAttrEx *    THIS = (wxTextAttrEx *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::TextAttrEx" )
;
	wxString	text;

    WXSTRING_INPUT( text, wxString, ST(1) )
;
    try {
      THIS->SetBulletText( text );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__TextAttrEx_SetBulletName); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__TextAttrEx_SetBulletName)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, name");
    {
	wxTextAttrEx *    THIS = (wxTextAttrEx *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::TextAttrEx" )
;
	wxString	name;

    WXSTRING_INPUT( name, wxString, ST(1) )
;
    try {
      THIS->SetBulletName( name );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__TextAttrEx_SetBulletFont); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__TextAttrEx_SetBulletFont)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, bulletFont");
    {
	wxTextAttrEx *    THIS = (wxTextAttrEx *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::TextAttrEx" )
;
	wxString	bulletFont;

    WXSTRING_INPUT( bulletFont, wxString, ST(1) )
;
    try {
      THIS->SetBulletFont( bulletFont );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__TextAttrEx_SetURL); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__TextAttrEx_SetURL)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, url");
    {
	wxTextAttrEx *    THIS = (wxTextAttrEx *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::TextAttrEx" )
;
	wxString	url;

    WXSTRING_INPUT( url, wxString, ST(1) )
;
    try {
      THIS->SetURL( url );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__TextAttrEx_SetPageBreak); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__TextAttrEx_SetPageBreak)
{
    dVAR; dXSARGS;
    if (items < 1 || items > 2)
       croak_xs_usage(cv,  "THIS, pageBreak= true");
    {
	wxTextAttrEx *    THIS = (wxTextAttrEx *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::TextAttrEx" )
;
	bool	pageBreak;

	if (items < 2)
	    pageBreak = true;
	else {
	    pageBreak = (bool)SvTRUE(ST(1))
;
	}
    try {
      THIS->SetPageBreak( pageBreak );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}

#endif

XS_EUPXS(XS_Wx__TextAttrEx_GetCharacterStyleName); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__TextAttrEx_GetCharacterStyleName)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxTextAttrEx *    THIS = (wxTextAttrEx *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::TextAttrEx" )
;
	wxString	RETVAL;
    try {
      RETVAL = THIS->GetCharacterStyleName();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    WXSTRING_OUTPUT( RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__TextAttrEx_GetParagraphStyleName); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__TextAttrEx_GetParagraphStyleName)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxTextAttrEx *    THIS = (wxTextAttrEx *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::TextAttrEx" )
;
	wxString	RETVAL;
    try {
      RETVAL = THIS->GetParagraphStyleName();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    WXSTRING_OUTPUT( RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}

#if WXPERL_W_VERSION_GE( 2, 7, 2 )
#define XSpp_b93c44bc_054149
#define XSubPPtmpAABH 1


XS_EUPXS(XS_Wx__TextAttrEx_GetListStyleName); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__TextAttrEx_GetListStyleName)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxTextAttrEx *    THIS = (wxTextAttrEx *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::TextAttrEx" )
;
	wxString	RETVAL;
    try {
      RETVAL = THIS->GetListStyleName();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    WXSTRING_OUTPUT( RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}

#endif

XS_EUPXS(XS_Wx__TextAttrEx_GetParagraphSpacingAfter); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__TextAttrEx_GetParagraphSpacingAfter)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxTextAttrEx *    THIS = (wxTextAttrEx *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::TextAttrEx" )
;
	int	RETVAL;
	dXSTARG;
    try {
      RETVAL = THIS->GetParagraphSpacingAfter();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__TextAttrEx_GetParagraphSpacingBefore); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__TextAttrEx_GetParagraphSpacingBefore)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxTextAttrEx *    THIS = (wxTextAttrEx *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::TextAttrEx" )
;
	int	RETVAL;
	dXSTARG;
    try {
      RETVAL = THIS->GetParagraphSpacingBefore();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__TextAttrEx_GetLineSpacing); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__TextAttrEx_GetLineSpacing)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxTextAttrEx *    THIS = (wxTextAttrEx *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::TextAttrEx" )
;
	int	RETVAL;
	dXSTARG;
    try {
      RETVAL = THIS->GetLineSpacing();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__TextAttrEx_GetBulletStyle); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__TextAttrEx_GetBulletStyle)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxTextAttrEx *    THIS = (wxTextAttrEx *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::TextAttrEx" )
;
	int	RETVAL;
	dXSTARG;
    try {
      RETVAL = THIS->GetBulletStyle();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__TextAttrEx_GetBulletNumber); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__TextAttrEx_GetBulletNumber)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxTextAttrEx *    THIS = (wxTextAttrEx *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::TextAttrEx" )
;
	int	RETVAL;
	dXSTARG;
    try {
      RETVAL = THIS->GetBulletNumber();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}

#if WXPERL_W_VERSION_GE( 2, 7, 2 )
#define XSpp_b93c44bc_085292
#define XSubPPtmpAABI 1


XS_EUPXS(XS_Wx__TextAttrEx_GetBulletText); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__TextAttrEx_GetBulletText)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxTextAttrEx *    THIS = (wxTextAttrEx *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::TextAttrEx" )
;
	wxString	RETVAL;
    try {
      RETVAL = THIS->GetBulletText();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    WXSTRING_OUTPUT( RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__TextAttrEx_GetBulletName); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__TextAttrEx_GetBulletName)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxTextAttrEx *    THIS = (wxTextAttrEx *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::TextAttrEx" )
;
	wxString	RETVAL;
    try {
      RETVAL = THIS->GetBulletName();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    WXSTRING_OUTPUT( RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__TextAttrEx_GetBulletFont); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__TextAttrEx_GetBulletFont)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxTextAttrEx *    THIS = (wxTextAttrEx *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::TextAttrEx" )
;
	wxString	RETVAL;
    try {
      RETVAL = THIS->GetBulletFont();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    WXSTRING_OUTPUT( RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__TextAttrEx_GetURL); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__TextAttrEx_GetURL)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxTextAttrEx *    THIS = (wxTextAttrEx *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::TextAttrEx" )
;
	wxString	RETVAL;
    try {
      RETVAL = THIS->GetURL();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    WXSTRING_OUTPUT( RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}

#endif
#if WXPERL_W_VERSION_LT( 2, 8, 0 )
#define XSpp_b93c44bc_085630
#define XSubPPtmpAABJ 1


XS_EUPXS(XS_Wx__TextAttrEx_HasWeight); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__TextAttrEx_HasWeight)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxTextAttrEx *    THIS = (wxTextAttrEx *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::TextAttrEx" )
;
	bool	RETVAL;
    try {
      RETVAL = THIS->HasWeight();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__TextAttrEx_HasSize); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__TextAttrEx_HasSize)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxTextAttrEx *    THIS = (wxTextAttrEx *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::TextAttrEx" )
;
	bool	RETVAL;
    try {
      RETVAL = THIS->HasSize();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__TextAttrEx_HasItalic); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__TextAttrEx_HasItalic)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxTextAttrEx *    THIS = (wxTextAttrEx *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::TextAttrEx" )
;
	bool	RETVAL;
    try {
      RETVAL = THIS->HasItalic();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__TextAttrEx_HasUnderlined); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__TextAttrEx_HasUnderlined)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxTextAttrEx *    THIS = (wxTextAttrEx *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::TextAttrEx" )
;
	bool	RETVAL;
    try {
      RETVAL = THIS->HasUnderlined();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__TextAttrEx_HasFaceName); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__TextAttrEx_HasFaceName)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxTextAttrEx *    THIS = (wxTextAttrEx *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::TextAttrEx" )
;
	bool	RETVAL;
    try {
      RETVAL = THIS->HasFaceName();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}

#endif

XS_EUPXS(XS_Wx__TextAttrEx_HasParagraphSpacingAfter); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__TextAttrEx_HasParagraphSpacingAfter)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxTextAttrEx *    THIS = (wxTextAttrEx *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::TextAttrEx" )
;
	bool	RETVAL;
    try {
      RETVAL = THIS->HasParagraphSpacingAfter();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__TextAttrEx_HasParagraphSpacingBefore); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__TextAttrEx_HasParagraphSpacingBefore)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxTextAttrEx *    THIS = (wxTextAttrEx *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::TextAttrEx" )
;
	bool	RETVAL;
    try {
      RETVAL = THIS->HasParagraphSpacingBefore();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__TextAttrEx_HasLineSpacing); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__TextAttrEx_HasLineSpacing)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxTextAttrEx *    THIS = (wxTextAttrEx *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::TextAttrEx" )
;
	bool	RETVAL;
    try {
      RETVAL = THIS->HasLineSpacing();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__TextAttrEx_HasCharacterStyleName); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__TextAttrEx_HasCharacterStyleName)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxTextAttrEx *    THIS = (wxTextAttrEx *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::TextAttrEx" )
;
	bool	RETVAL;
    try {
      RETVAL = THIS->HasCharacterStyleName();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__TextAttrEx_HasParagraphStyleName); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__TextAttrEx_HasParagraphStyleName)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxTextAttrEx *    THIS = (wxTextAttrEx *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::TextAttrEx" )
;
	bool	RETVAL;
    try {
      RETVAL = THIS->HasParagraphStyleName();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}

#if WXPERL_W_VERSION_GE( 2, 7, 2 )
#define XSpp_b93c44bc_005272
#define XSubPPtmpAABK 1


XS_EUPXS(XS_Wx__TextAttrEx_HasListStyleName); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__TextAttrEx_HasListStyleName)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxTextAttrEx *    THIS = (wxTextAttrEx *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::TextAttrEx" )
;
	bool	RETVAL;
    try {
      RETVAL = THIS->HasListStyleName();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}

#endif

XS_EUPXS(XS_Wx__TextAttrEx_HasBulletStyle); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__TextAttrEx_HasBulletStyle)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxTextAttrEx *    THIS = (wxTextAttrEx *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::TextAttrEx" )
;
	bool	RETVAL;
    try {
      RETVAL = THIS->HasBulletStyle();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__TextAttrEx_HasBulletNumber); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__TextAttrEx_HasBulletNumber)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxTextAttrEx *    THIS = (wxTextAttrEx *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::TextAttrEx" )
;
	bool	RETVAL;
    try {
      RETVAL = THIS->HasBulletNumber();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}

#if WXPERL_W_VERSION_GE( 2, 7, 2 )
#define XSpp_b93c44bc_012218
#define XSubPPtmpAABL 1


XS_EUPXS(XS_Wx__TextAttrEx_HasBulletText); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__TextAttrEx_HasBulletText)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxTextAttrEx *    THIS = (wxTextAttrEx *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::TextAttrEx" )
;
	bool	RETVAL;
    try {
      RETVAL = THIS->HasBulletText();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__TextAttrEx_HasBulletName); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__TextAttrEx_HasBulletName)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxTextAttrEx *    THIS = (wxTextAttrEx *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::TextAttrEx" )
;
	bool	RETVAL;
    try {
      RETVAL = THIS->HasBulletName();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__TextAttrEx_HasURL); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__TextAttrEx_HasURL)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxTextAttrEx *    THIS = (wxTextAttrEx *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::TextAttrEx" )
;
	bool	RETVAL;
    try {
      RETVAL = THIS->HasURL();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__TextAttrEx_HasPageBreak); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__TextAttrEx_HasPageBreak)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxTextAttrEx *    THIS = (wxTextAttrEx *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::TextAttrEx" )
;
	bool	RETVAL;
    try {
      RETVAL = THIS->HasPageBreak();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}

#endif

XS_EUPXS(XS_Wx__TextAttrEx_IsCharacterStyle); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__TextAttrEx_IsCharacterStyle)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxTextAttrEx *    THIS = (wxTextAttrEx *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::TextAttrEx" )
;
	bool	RETVAL;
    try {
      RETVAL = THIS->IsCharacterStyle();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__TextAttrEx_IsParagraphStyle); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__TextAttrEx_IsParagraphStyle)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxTextAttrEx *    THIS = (wxTextAttrEx *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::TextAttrEx" )
;
	bool	RETVAL;
    try {
      RETVAL = THIS->IsParagraphStyle();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__TextAttrEx_IsDefault); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__TextAttrEx_IsDefault)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxTextAttrEx *    THIS = (wxTextAttrEx *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::TextAttrEx" )
;
	bool	RETVAL;
    try {
      RETVAL = THIS->IsDefault();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}

#if WXPERL_W_VERSION_LT( 2, 9, 0 ) && WXPERL_W_VERSION_GE( 2, 8, 0 )
#define XSpp_b93c44bc_055736
#define XSubPPtmpAABM 1


XS_EUPXS(XS_Wx__TextAttrEx_GetOutlineLevel); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__TextAttrEx_GetOutlineLevel)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxTextAttrEx *    THIS = (wxTextAttrEx *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::TextAttrEx" )
;
	int	RETVAL;
	dXSTARG;
    try {
      RETVAL = THIS->GetOutlineLevel();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__TextAttrEx_HasOutlineLevel); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__TextAttrEx_HasOutlineLevel)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxTextAttrEx *    THIS = (wxTextAttrEx *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::TextAttrEx" )
;
	bool	RETVAL;
    try {
      RETVAL = THIS->HasOutlineLevel();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__TextAttrEx_SetOutlineLevel); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__TextAttrEx_SetOutlineLevel)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, level");
    {
	wxTextAttrEx *    THIS = (wxTextAttrEx *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::TextAttrEx" )
;
	int	level = (int)SvIV(ST(1))
;
    try {
      THIS->SetOutlineLevel( level );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__TextAttrEx_GetTextEffects); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__TextAttrEx_GetTextEffects)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxTextAttrEx *    THIS = (wxTextAttrEx *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::TextAttrEx" )
;
	int	RETVAL;
	dXSTARG;
    try {
      RETVAL = THIS->GetTextEffects();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__TextAttrEx_HasTextEffects); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__TextAttrEx_HasTextEffects)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxTextAttrEx *    THIS = (wxTextAttrEx *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::TextAttrEx" )
;
	bool	RETVAL;
    try {
      RETVAL = THIS->HasTextEffects();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__TextAttrEx_SetTextEffects); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__TextAttrEx_SetTextEffects)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, effects");
    {
	wxTextAttrEx *    THIS = (wxTextAttrEx *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::TextAttrEx" )
;
	int	effects = (int)SvIV(ST(1))
;
    try {
      THIS->SetTextEffects( effects );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__TextAttrEx_GetTextEffectFlags); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__TextAttrEx_GetTextEffectFlags)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxTextAttrEx *    THIS = (wxTextAttrEx *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::TextAttrEx" )
;
	int	RETVAL;
	dXSTARG;
    try {
      RETVAL = THIS->GetTextEffectFlags();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__TextAttrEx_HasTextEffect); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__TextAttrEx_HasTextEffect)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, effect");
    {
	wxTextAttrEx *    THIS = (wxTextAttrEx *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::TextAttrEx" )
;
	bool	RETVAL;
	int	effect = (int)SvIV(ST(1))
;
    try {
      RETVAL = THIS->HasTextEffect( effect );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__TextAttrEx_SetTextEffectFlags); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__TextAttrEx_SetTextEffectFlags)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, effects");
    {
	wxTextAttrEx *    THIS = (wxTextAttrEx *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::TextAttrEx" )
;
	int	effects = (int)SvIV(ST(1))
;
    try {
      THIS->SetTextEffectFlags( effects );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}

#endif

XS_EUPXS(XS_Wx__TextAttrEx_new); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__TextAttrEx_new)
{
    dVAR; dXSARGS;
    if (items < 1)
       croak_xs_usage(cv,  "CLASS, ...");
    PERL_UNUSED_VAR(ax); /* -Wall */
    SP -= items;
    {
	char *	CLASS = (char *)SvPV_nolen(ST(0))
;
    BEGIN_OVERLOAD()
        MATCH_VOIDM_REDISP( newDefault )
        MATCH_REDISP( wxPliOvl_wtae, newCopy )
        MATCH_REDISP( wxPliOvl_wtat, newAttr )
    END_OVERLOAD( Wx::TextAttrEx::new )
	PUTBACK;
	return;
    }
}

#undef  xsp_constructor_class
#define xsp_constructor_class(c) (CLASS)

XS_EUPXS(XS_Wx__RichTextAttr_newDefault); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextAttr_newDefault)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "CLASS");
    {
	char *	CLASS = (char *)SvPV_nolen(ST(0))
;
	wxRichTextAttr *	RETVAL;
    try {
      RETVAL = new wxRichTextAttr();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_non_object_2_sv( aTHX_ RETVALSV, RETVAL, "Wx::RichTextAttr" );
    wxPli_thread_sv_register( aTHX_ "Wx::RichTextAttr", RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}

#undef  xsp_constructor_class
#define xsp_constructor_class(c) (c)
#undef  xsp_constructor_class
#define xsp_constructor_class(c) (CLASS)

XS_EUPXS(XS_Wx__RichTextAttr_newCopy); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextAttr_newCopy)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "CLASS, attr");
    {
	char *	CLASS = (char *)SvPV_nolen(ST(0))
;
	wxRichTextAttr *	RETVAL;
	wxRichTextAttr*    attr = (wxRichTextAttr *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::RichTextAttr" )
;
    try {
      RETVAL = new wxRichTextAttr( *( attr ) );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_non_object_2_sv( aTHX_ RETVALSV, RETVAL, "Wx::RichTextAttr" );
    wxPli_thread_sv_register( aTHX_ "Wx::RichTextAttr", RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}

#undef  xsp_constructor_class
#define xsp_constructor_class(c) (c)
#undef  xsp_constructor_class
#define xsp_constructor_class(c) (CLASS)

XS_EUPXS(XS_Wx__RichTextAttr_newAttrEx); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextAttr_newAttrEx)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "CLASS, attr");
    {
	char *	CLASS = (char *)SvPV_nolen(ST(0))
;
	wxRichTextAttr *	RETVAL;
	wxTextAttrEx*    attr = (wxTextAttrEx *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::TextAttrEx" )
;
    try {
      RETVAL = new wxRichTextAttr( *( attr ) );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_non_object_2_sv( aTHX_ RETVALSV, RETVAL, "Wx::RichTextAttr" );
    wxPli_thread_sv_register( aTHX_ "Wx::RichTextAttr", RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}

#undef  xsp_constructor_class
#define xsp_constructor_class(c) (c)
#undef  xsp_constructor_class
#define xsp_constructor_class(c) (CLASS)

XS_EUPXS(XS_Wx__RichTextAttr_newAttr); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextAttr_newAttr)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "CLASS, attr");
    {
	char *	CLASS = (char *)SvPV_nolen(ST(0))
;
	wxRichTextAttr *	RETVAL;
	wxTextAttr*    attr = (wxTextAttr *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::TextAttr" )
;
    try {
      RETVAL = new wxRichTextAttr( *( attr ) );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_non_object_2_sv( aTHX_ RETVALSV, RETVAL, "Wx::RichTextAttr" );
    wxPli_thread_sv_register( aTHX_ "Wx::RichTextAttr", RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}

#undef  xsp_constructor_class
#define xsp_constructor_class(c) (c)
#if WXPERL_W_VERSION_GE( 2, 9, 0 ) && WXPERL_W_VERSION_LT( 2, 9, 2 )
#define XSpp_b93c44bc_009305
#undef  xsp_constructor_class
#define xsp_constructor_class(c) (CLASS)
#define XSubPPtmpAABN 1


XS_EUPXS(XS_Wx__RichTextAttr_newFull); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextAttr_newFull)
{
    dVAR; dXSARGS;
    if (items < 2 || items > 5)
       croak_xs_usage(cv,  "CLASS, colText, colBack= wxNullColourPtr, font= wxNullFontPtr, alignment= wxTEXT_ALIGNMENT_DEFAULT");
    {
	char *	CLASS = (char *)SvPV_nolen(ST(0))
;
	wxRichTextAttr *	RETVAL;
	wxColour*    colText = (wxColour *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::Colour" )
;
	wxColour*	colBack;
	wxFont*	font;
	wxTextAttrAlignment	alignment;

	if (items < 3)
	    colBack = wxNullColourPtr;
	else {
    colBack = (wxColour *) wxPli_sv_2_object( aTHX_ ST(2), "Wx::Colour" )
;
	}

	if (items < 4)
	    font = wxNullFontPtr;
	else {
    font = (wxFont *) wxPli_sv_2_object( aTHX_ ST(3), "Wx::Font" )
;
	}

	if (items < 5)
	    alignment = wxTEXT_ALIGNMENT_DEFAULT;
	else {
	    alignment = (wxTextAttrAlignment)SvIV(ST(4))
;
	}
    try {
      RETVAL = new wxRichTextAttr( *( colText ), *( colBack ), *( font ), alignment );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_non_object_2_sv( aTHX_ RETVALSV, RETVAL, "Wx::RichTextAttr" );
    wxPli_thread_sv_register( aTHX_ "Wx::RichTextAttr", RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}

#undef  xsp_constructor_class
#define xsp_constructor_class(c) (c)
#else
#define XSpp_b93c44bc_032261
#if WXPERL_W_VERSION_LT( 2, 9, 0 )
#define XSpp_b93c44bc_026303
#undef  xsp_constructor_class
#define xsp_constructor_class(c) (CLASS)
#define XSubPPtmpAABO 1


XS_EUPXS(XS_Wx__RichTextAttr_newFull); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextAttr_newFull)
{
    dVAR; dXSARGS;
    if (items < 2 || items > 4)
       croak_xs_usage(cv,  "CLASS, colText, colBack= wxNullColourPtr, alignment= wxTEXT_ALIGNMENT_DEFAULT");
    {
	char *	CLASS = (char *)SvPV_nolen(ST(0))
;
	wxRichTextAttr *	RETVAL;
	wxColour*    colText = (wxColour *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::Colour" )
;
	wxColour*	colBack;
	wxTextAttrAlignment	alignment;

	if (items < 3)
	    colBack = wxNullColourPtr;
	else {
    colBack = (wxColour *) wxPli_sv_2_object( aTHX_ ST(2), "Wx::Colour" )
;
	}

	if (items < 4)
	    alignment = wxTEXT_ALIGNMENT_DEFAULT;
	else {
	    alignment = (wxTextAttrAlignment)SvIV(ST(3))
;
	}
    try {
      RETVAL = new wxRichTextAttr( *( colText ), *( colBack ), alignment );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_non_object_2_sv( aTHX_ RETVALSV, RETVAL, "Wx::RichTextAttr" );
    wxPli_thread_sv_register( aTHX_ "Wx::RichTextAttr", RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}

#undef  xsp_constructor_class
#define xsp_constructor_class(c) (c)
#endif
#endif

XS_EUPXS(XS_Wx__RichTextAttr_CLONE); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextAttr_CLONE)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "CLASS");
    {
	char *	CLASS = (char *)SvPV_nolen(ST(0))
;
    wxPli_thread_sv_clone( aTHX_ CLASS, (wxPliCloneSV)wxPli_detach_object );
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__RichTextAttr_DESTROY); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextAttr_DESTROY)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxRichTextAttr *    THIS = (wxRichTextAttr *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextAttr" )
;
     wxPli_thread_sv_unregister( aTHX_ "Wx::RichTextAttr", THIS, ST(0) );
                delete THIS;
    }
    XSRETURN_EMPTY;
}

#if WXPERL_W_VERSION_LT( 2, 9, 0 )
#define XSpp_b93c44bc_036112
#define XSubPPtmpAABP 1


XS_EUPXS(XS_Wx__RichTextAttr_CreateFont); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextAttr_CreateFont)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxRichTextAttr *    THIS = (wxRichTextAttr *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextAttr" )
;
	wxFont *	RETVAL;
    try {
      RETVAL = new wxFont( THIS->CreateFont() );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_object_2_sv( aTHX_ RETVALSV, RETVAL );
    wxPli_thread_sv_register( aTHX_ "Wx::Font", RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}

#endif

XS_EUPXS(XS_Wx__RichTextAttr_GetFontAttributes); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextAttr_GetFontAttributes)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, font");
    {
	wxRichTextAttr *    THIS = (wxRichTextAttr *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextAttr" )
;
	bool	RETVAL;
	wxFont*    font = (wxFont *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::Font" )
;
    try {
      RETVAL = THIS->GetFontAttributes( *( font ) );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__RichTextAttr_SetTextColour); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextAttr_SetTextColour)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, colText");
    {
	wxRichTextAttr *    THIS = (wxRichTextAttr *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextAttr" )
;
	wxColour*    colText = (wxColour *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::Colour" )
;
    try {
      THIS->SetTextColour( *( colText ) );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__RichTextAttr_SetBackgroundColour); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextAttr_SetBackgroundColour)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, colBack");
    {
	wxRichTextAttr *    THIS = (wxRichTextAttr *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextAttr" )
;
	wxColour*    colBack = (wxColour *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::Colour" )
;
    try {
      THIS->SetBackgroundColour( *( colBack ) );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__RichTextAttr_SetAlignment); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextAttr_SetAlignment)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, alignment");
    {
	wxRichTextAttr *    THIS = (wxRichTextAttr *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextAttr" )
;
	wxTextAttrAlignment	alignment = (wxTextAttrAlignment)SvIV(ST(1))
;
    try {
      THIS->SetAlignment( alignment );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__RichTextAttr_SetTabs); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextAttr_SetTabs)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, tabs");
    {
	wxRichTextAttr *    THIS = (wxRichTextAttr *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextAttr" )
;
	wxArrayInt	tabs;

    wxPli_av_2_arrayint( aTHX_ ST(1), & tabs )
;
    try {
      THIS->SetTabs( tabs );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__RichTextAttr_SetLeftIndent); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextAttr_SetLeftIndent)
{
    dVAR; dXSARGS;
    if (items < 2 || items > 3)
       croak_xs_usage(cv,  "THIS, indent, subIndent= 0");
    {
	wxRichTextAttr *    THIS = (wxRichTextAttr *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextAttr" )
;
	int	indent = (int)SvIV(ST(1))
;
	int	subIndent;

	if (items < 3)
	    subIndent = 0;
	else {
	    subIndent = (int)SvIV(ST(2))
;
	}
    try {
      THIS->SetLeftIndent( indent, subIndent );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__RichTextAttr_SetRightIndent); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextAttr_SetRightIndent)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, indent");
    {
	wxRichTextAttr *    THIS = (wxRichTextAttr *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextAttr" )
;
	int	indent = (int)SvIV(ST(1))
;
    try {
      THIS->SetRightIndent( indent );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__RichTextAttr_SetFontSize); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextAttr_SetFontSize)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, pointSize");
    {
	wxRichTextAttr *    THIS = (wxRichTextAttr *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextAttr" )
;
	int	pointSize = (int)SvIV(ST(1))
;
    try {
      THIS->SetFontSize( pointSize );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__RichTextAttr_SetFontStyle); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextAttr_SetFontStyle)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, fontStyle");
    {
	wxRichTextAttr *    THIS = (wxRichTextAttr *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextAttr" )
;
	wxFontStyle	fontStyle = (wxFontStyle)SvIV(ST(1))
;
    try {
      THIS->SetFontStyle( fontStyle );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__RichTextAttr_SetFontWeight); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextAttr_SetFontWeight)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, fontWeight");
    {
	wxRichTextAttr *    THIS = (wxRichTextAttr *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextAttr" )
;
	wxFontWeight	fontWeight = (wxFontWeight)SvIV(ST(1))
;
    try {
      THIS->SetFontWeight( fontWeight );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__RichTextAttr_SetFontFaceName); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextAttr_SetFontFaceName)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, faceName");
    {
	wxRichTextAttr *    THIS = (wxRichTextAttr *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextAttr" )
;
	wxString	faceName;

    WXSTRING_INPUT( faceName, wxString, ST(1) )
;
    try {
      THIS->SetFontFaceName( faceName );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__RichTextAttr_SetFontUnderlined); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextAttr_SetFontUnderlined)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, underlined");
    {
	wxRichTextAttr *    THIS = (wxRichTextAttr *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextAttr" )
;
	bool	underlined = (bool)SvTRUE(ST(1))
;
    try {
      THIS->SetFontUnderlined( underlined );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__RichTextAttr_SetFlags); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextAttr_SetFlags)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, flags");
    {
	wxRichTextAttr *    THIS = (wxRichTextAttr *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextAttr" )
;
	long	flags = (long)SvIV(ST(1))
;
    try {
      THIS->SetFlags( flags );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__RichTextAttr_SetCharacterStyleName); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextAttr_SetCharacterStyleName)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, name");
    {
	wxRichTextAttr *    THIS = (wxRichTextAttr *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextAttr" )
;
	wxString	name;

    WXSTRING_INPUT( name, wxString, ST(1) )
;
    try {
      THIS->SetCharacterStyleName( name );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__RichTextAttr_SetParagraphStyleName); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextAttr_SetParagraphStyleName)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, name");
    {
	wxRichTextAttr *    THIS = (wxRichTextAttr *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextAttr" )
;
	wxString	name;

    WXSTRING_INPUT( name, wxString, ST(1) )
;
    try {
      THIS->SetParagraphStyleName( name );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}

#if WXPERL_W_VERSION_GE( 2, 7, 2 )
#define XSpp_b93c44bc_082210
#define XSubPPtmpAABQ 1


XS_EUPXS(XS_Wx__RichTextAttr_SetListStyleName); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextAttr_SetListStyleName)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, name");
    {
	wxRichTextAttr *    THIS = (wxRichTextAttr *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextAttr" )
;
	wxString	name;

    WXSTRING_INPUT( name, wxString, ST(1) )
;
    try {
      THIS->SetListStyleName( name );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}

#endif

XS_EUPXS(XS_Wx__RichTextAttr_SetParagraphSpacingAfter); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextAttr_SetParagraphSpacingAfter)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, spacing");
    {
	wxRichTextAttr *    THIS = (wxRichTextAttr *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextAttr" )
;
	int	spacing = (int)SvIV(ST(1))
;
    try {
      THIS->SetParagraphSpacingAfter( spacing );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__RichTextAttr_SetParagraphSpacingBefore); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextAttr_SetParagraphSpacingBefore)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, spacing");
    {
	wxRichTextAttr *    THIS = (wxRichTextAttr *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextAttr" )
;
	int	spacing = (int)SvIV(ST(1))
;
    try {
      THIS->SetParagraphSpacingBefore( spacing );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__RichTextAttr_SetLineSpacing); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextAttr_SetLineSpacing)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, spacing");
    {
	wxRichTextAttr *    THIS = (wxRichTextAttr *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextAttr" )
;
	int	spacing = (int)SvIV(ST(1))
;
    try {
      THIS->SetLineSpacing( spacing );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__RichTextAttr_SetBulletStyle); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextAttr_SetBulletStyle)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, style");
    {
	wxRichTextAttr *    THIS = (wxRichTextAttr *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextAttr" )
;
	int	style = (int)SvIV(ST(1))
;
    try {
      THIS->SetBulletStyle( style );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__RichTextAttr_SetBulletNumber); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextAttr_SetBulletNumber)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, n");
    {
	wxRichTextAttr *    THIS = (wxRichTextAttr *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextAttr" )
;
	int	n = (int)SvIV(ST(1))
;
    try {
      THIS->SetBulletNumber( n );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}

#if WXPERL_W_VERSION_GE( 2, 7, 2 )
#define XSpp_b93c44bc_014055
#define XSubPPtmpAABR 1


XS_EUPXS(XS_Wx__RichTextAttr_SetBulletText); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextAttr_SetBulletText)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, text");
    {
	wxRichTextAttr *    THIS = (wxRichTextAttr *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextAttr" )
;
	wxString	text;

    WXSTRING_INPUT( text, wxString, ST(1) )
;
    try {
      THIS->SetBulletText( text );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__RichTextAttr_SetBulletFont); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextAttr_SetBulletFont)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, bulletFont");
    {
	wxRichTextAttr *    THIS = (wxRichTextAttr *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextAttr" )
;
	wxString	bulletFont;

    WXSTRING_INPUT( bulletFont, wxString, ST(1) )
;
    try {
      THIS->SetBulletFont( bulletFont );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__RichTextAttr_SetBulletName); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextAttr_SetBulletName)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, name");
    {
	wxRichTextAttr *    THIS = (wxRichTextAttr *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextAttr" )
;
	wxString	name;

    WXSTRING_INPUT( name, wxString, ST(1) )
;
    try {
      THIS->SetBulletName( name );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__RichTextAttr_SetURL); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextAttr_SetURL)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, url");
    {
	wxRichTextAttr *    THIS = (wxRichTextAttr *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextAttr" )
;
	wxString	url;

    WXSTRING_INPUT( url, wxString, ST(1) )
;
    try {
      THIS->SetURL( url );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__RichTextAttr_SetPageBreak); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextAttr_SetPageBreak)
{
    dVAR; dXSARGS;
    if (items < 1 || items > 2)
       croak_xs_usage(cv,  "THIS, pageBreak= true");
    {
	wxRichTextAttr *    THIS = (wxRichTextAttr *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextAttr" )
;
	bool	pageBreak;

	if (items < 2)
	    pageBreak = true;
	else {
	    pageBreak = (bool)SvTRUE(ST(1))
;
	}
    try {
      THIS->SetPageBreak( pageBreak );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}

#endif

XS_EUPXS(XS_Wx__RichTextAttr_GetTextColour); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextAttr_GetTextColour)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxRichTextAttr *    THIS = (wxRichTextAttr *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextAttr" )
;
	wxColour *	RETVAL;
    try {
      RETVAL = new wxColour( THIS->GetTextColour() );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_non_object_2_sv( aTHX_ RETVALSV, RETVAL, "Wx::Colour" );
    wxPli_thread_sv_register( aTHX_ "Wx::Colour", RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__RichTextAttr_GetBackgroundColour); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextAttr_GetBackgroundColour)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxRichTextAttr *    THIS = (wxRichTextAttr *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextAttr" )
;
	wxColour *	RETVAL;
    try {
      RETVAL = new wxColour( THIS->GetBackgroundColour() );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_non_object_2_sv( aTHX_ RETVALSV, RETVAL, "Wx::Colour" );
    wxPli_thread_sv_register( aTHX_ "Wx::Colour", RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__RichTextAttr_GetAlignment); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextAttr_GetAlignment)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxRichTextAttr *    THIS = (wxRichTextAttr *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextAttr" )
;
	wxTextAttrAlignment	RETVAL;
	dXSTARG;
    try {
      RETVAL = THIS->GetAlignment();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__RichTextAttr_GetLeftIndent); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextAttr_GetLeftIndent)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxRichTextAttr *    THIS = (wxRichTextAttr *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextAttr" )
;
	long	RETVAL;
	dXSTARG;
    try {
      RETVAL = THIS->GetLeftIndent();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__RichTextAttr_GetLeftSubIndent); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextAttr_GetLeftSubIndent)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxRichTextAttr *    THIS = (wxRichTextAttr *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextAttr" )
;
	long	RETVAL;
	dXSTARG;
    try {
      RETVAL = THIS->GetLeftSubIndent();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__RichTextAttr_GetRightIndent); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextAttr_GetRightIndent)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxRichTextAttr *    THIS = (wxRichTextAttr *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextAttr" )
;
	long	RETVAL;
	dXSTARG;
    try {
      RETVAL = THIS->GetRightIndent();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__RichTextAttr_GetFlags); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextAttr_GetFlags)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxRichTextAttr *    THIS = (wxRichTextAttr *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextAttr" )
;
	long	RETVAL;
	dXSTARG;
    try {
      RETVAL = THIS->GetFlags();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__RichTextAttr_GetFontSize); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextAttr_GetFontSize)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxRichTextAttr *    THIS = (wxRichTextAttr *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextAttr" )
;
	int	RETVAL;
	dXSTARG;
    try {
      RETVAL = THIS->GetFontSize();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}

#if WXPERL_W_VERSION_GE( 2, 9, 0 )
#define XSpp_b93c44bc_005234
#define XSubPPtmpAABS 1


XS_EUPXS(XS_Wx__RichTextAttr_GetFontStyle); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextAttr_GetFontStyle)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxRichTextAttr *    THIS = (wxRichTextAttr *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextAttr" )
;
	wxFontStyle	RETVAL;
	dXSTARG;
    try {
      RETVAL = THIS->GetFontStyle();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__RichTextAttr_GetFontWeight); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextAttr_GetFontWeight)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxRichTextAttr *    THIS = (wxRichTextAttr *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextAttr" )
;
	wxFontWeight	RETVAL;
	dXSTARG;
    try {
      RETVAL = THIS->GetFontWeight();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}

#else
#define XSpp_b93c44bc_009589
#define XSubPPtmpAABT 1


XS_EUPXS(XS_Wx__RichTextAttr_GetFontStyle); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextAttr_GetFontStyle)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxRichTextAttr *    THIS = (wxRichTextAttr *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextAttr" )
;
	int	RETVAL;
	dXSTARG;
    try {
      RETVAL = THIS->GetFontStyle();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__RichTextAttr_GetFontWeight); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextAttr_GetFontWeight)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxRichTextAttr *    THIS = (wxRichTextAttr *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextAttr" )
;
	int	RETVAL;
	dXSTARG;
    try {
      RETVAL = THIS->GetFontWeight();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}

#endif

XS_EUPXS(XS_Wx__RichTextAttr_GetFontUnderlined); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextAttr_GetFontUnderlined)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxRichTextAttr *    THIS = (wxRichTextAttr *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextAttr" )
;
	bool	RETVAL;
    try {
      RETVAL = THIS->GetFontUnderlined();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__RichTextAttr_GetFontFaceName); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextAttr_GetFontFaceName)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxRichTextAttr *    THIS = (wxRichTextAttr *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextAttr" )
;
	wxString	RETVAL;
    try {
      RETVAL = THIS->GetFontFaceName();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    WXSTRING_OUTPUT( RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__RichTextAttr_GetCharacterStyleName); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextAttr_GetCharacterStyleName)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxRichTextAttr *    THIS = (wxRichTextAttr *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextAttr" )
;
	wxString	RETVAL;
    try {
      RETVAL = THIS->GetCharacterStyleName();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    WXSTRING_OUTPUT( RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__RichTextAttr_GetParagraphStyleName); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextAttr_GetParagraphStyleName)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxRichTextAttr *    THIS = (wxRichTextAttr *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextAttr" )
;
	wxString	RETVAL;
    try {
      RETVAL = THIS->GetParagraphStyleName();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    WXSTRING_OUTPUT( RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}

#if WXPERL_W_VERSION_GE( 2, 7, 2 )
#define XSpp_b93c44bc_013246
#define XSubPPtmpAABU 1


XS_EUPXS(XS_Wx__RichTextAttr_GetListStyleName); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextAttr_GetListStyleName)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxRichTextAttr *    THIS = (wxRichTextAttr *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextAttr" )
;
	wxString	RETVAL;
    try {
      RETVAL = THIS->GetListStyleName();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    WXSTRING_OUTPUT( RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}

#endif

XS_EUPXS(XS_Wx__RichTextAttr_GetParagraphSpacingAfter); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextAttr_GetParagraphSpacingAfter)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxRichTextAttr *    THIS = (wxRichTextAttr *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextAttr" )
;
	int	RETVAL;
	dXSTARG;
    try {
      RETVAL = THIS->GetParagraphSpacingAfter();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__RichTextAttr_GetParagraphSpacingBefore); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextAttr_GetParagraphSpacingBefore)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxRichTextAttr *    THIS = (wxRichTextAttr *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextAttr" )
;
	int	RETVAL;
	dXSTARG;
    try {
      RETVAL = THIS->GetParagraphSpacingBefore();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__RichTextAttr_GetLineSpacing); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextAttr_GetLineSpacing)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxRichTextAttr *    THIS = (wxRichTextAttr *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextAttr" )
;
	int	RETVAL;
	dXSTARG;
    try {
      RETVAL = THIS->GetLineSpacing();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__RichTextAttr_GetBulletStyle); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextAttr_GetBulletStyle)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxRichTextAttr *    THIS = (wxRichTextAttr *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextAttr" )
;
	int	RETVAL;
	dXSTARG;
    try {
      RETVAL = THIS->GetBulletStyle();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__RichTextAttr_GetBulletNumber); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextAttr_GetBulletNumber)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxRichTextAttr *    THIS = (wxRichTextAttr *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextAttr" )
;
	int	RETVAL;
	dXSTARG;
    try {
      RETVAL = THIS->GetBulletNumber();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}

#if WXPERL_W_VERSION_GE( 2, 7, 2 )
#define XSpp_b93c44bc_060970
#define XSubPPtmpAABV 1


XS_EUPXS(XS_Wx__RichTextAttr_GetBulletText); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextAttr_GetBulletText)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxRichTextAttr *    THIS = (wxRichTextAttr *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextAttr" )
;
	wxString	RETVAL;
    try {
      RETVAL = THIS->GetBulletText();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    WXSTRING_OUTPUT( RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__RichTextAttr_GetBulletFont); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextAttr_GetBulletFont)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxRichTextAttr *    THIS = (wxRichTextAttr *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextAttr" )
;
	wxString	RETVAL;
    try {
      RETVAL = THIS->GetBulletFont();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    WXSTRING_OUTPUT( RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__RichTextAttr_GetBulletName); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextAttr_GetBulletName)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxRichTextAttr *    THIS = (wxRichTextAttr *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextAttr" )
;
	wxString	RETVAL;
    try {
      RETVAL = THIS->GetBulletName();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    WXSTRING_OUTPUT( RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__RichTextAttr_GetURL); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextAttr_GetURL)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxRichTextAttr *    THIS = (wxRichTextAttr *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextAttr" )
;
	wxString	RETVAL;
    try {
      RETVAL = THIS->GetURL();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    WXSTRING_OUTPUT( RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}

#endif

XS_EUPXS(XS_Wx__RichTextAttr_HasTextColour); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextAttr_HasTextColour)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxRichTextAttr *    THIS = (wxRichTextAttr *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextAttr" )
;
	bool	RETVAL;
    try {
      RETVAL = THIS->HasTextColour();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__RichTextAttr_HasBackgroundColour); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextAttr_HasBackgroundColour)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxRichTextAttr *    THIS = (wxRichTextAttr *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextAttr" )
;
	bool	RETVAL;
    try {
      RETVAL = THIS->HasBackgroundColour();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__RichTextAttr_HasAlignment); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextAttr_HasAlignment)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxRichTextAttr *    THIS = (wxRichTextAttr *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextAttr" )
;
	bool	RETVAL;
    try {
      RETVAL = THIS->HasAlignment();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__RichTextAttr_HasTabs); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextAttr_HasTabs)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxRichTextAttr *    THIS = (wxRichTextAttr *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextAttr" )
;
	bool	RETVAL;
    try {
      RETVAL = THIS->HasTabs();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__RichTextAttr_HasLeftIndent); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextAttr_HasLeftIndent)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxRichTextAttr *    THIS = (wxRichTextAttr *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextAttr" )
;
	bool	RETVAL;
    try {
      RETVAL = THIS->HasLeftIndent();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__RichTextAttr_HasRightIndent); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextAttr_HasRightIndent)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxRichTextAttr *    THIS = (wxRichTextAttr *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextAttr" )
;
	bool	RETVAL;
    try {
      RETVAL = THIS->HasRightIndent();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}

#if WXPERL_W_VERSION_LT( 2, 8, 0 )
#define XSpp_b93c44bc_002274
#define XSubPPtmpAABW 1


XS_EUPXS(XS_Wx__RichTextAttr_HasWeight); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextAttr_HasWeight)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxRichTextAttr *    THIS = (wxRichTextAttr *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextAttr" )
;
	bool	RETVAL;
    try {
      RETVAL = THIS->HasWeight();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__RichTextAttr_HasSize); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextAttr_HasSize)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxRichTextAttr *    THIS = (wxRichTextAttr *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextAttr" )
;
	bool	RETVAL;
    try {
      RETVAL = THIS->HasSize();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__RichTextAttr_HasItalic); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextAttr_HasItalic)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxRichTextAttr *    THIS = (wxRichTextAttr *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextAttr" )
;
	bool	RETVAL;
    try {
      RETVAL = THIS->HasItalic();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__RichTextAttr_HasUnderlined); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextAttr_HasUnderlined)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxRichTextAttr *    THIS = (wxRichTextAttr *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextAttr" )
;
	bool	RETVAL;
    try {
      RETVAL = THIS->HasUnderlined();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__RichTextAttr_HasFaceName); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextAttr_HasFaceName)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxRichTextAttr *    THIS = (wxRichTextAttr *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextAttr" )
;
	bool	RETVAL;
    try {
      RETVAL = THIS->HasFaceName();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}

#endif

XS_EUPXS(XS_Wx__RichTextAttr_HasFont); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextAttr_HasFont)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxRichTextAttr *    THIS = (wxRichTextAttr *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextAttr" )
;
	bool	RETVAL;
    try {
      RETVAL = THIS->HasFont();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__RichTextAttr_HasParagraphSpacingAfter); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextAttr_HasParagraphSpacingAfter)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxRichTextAttr *    THIS = (wxRichTextAttr *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextAttr" )
;
	bool	RETVAL;
    try {
      RETVAL = THIS->HasParagraphSpacingAfter();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__RichTextAttr_HasParagraphSpacingBefore); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextAttr_HasParagraphSpacingBefore)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxRichTextAttr *    THIS = (wxRichTextAttr *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextAttr" )
;
	bool	RETVAL;
    try {
      RETVAL = THIS->HasParagraphSpacingBefore();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__RichTextAttr_HasLineSpacing); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextAttr_HasLineSpacing)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxRichTextAttr *    THIS = (wxRichTextAttr *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextAttr" )
;
	bool	RETVAL;
    try {
      RETVAL = THIS->HasLineSpacing();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__RichTextAttr_HasCharacterStyleName); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextAttr_HasCharacterStyleName)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxRichTextAttr *    THIS = (wxRichTextAttr *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextAttr" )
;
	bool	RETVAL;
    try {
      RETVAL = THIS->HasCharacterStyleName();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__RichTextAttr_HasParagraphStyleName); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextAttr_HasParagraphStyleName)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxRichTextAttr *    THIS = (wxRichTextAttr *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextAttr" )
;
	bool	RETVAL;
    try {
      RETVAL = THIS->HasParagraphStyleName();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}

#if WXPERL_W_VERSION_GE( 2, 7, 2 )
#define XSpp_b93c44bc_028078
#define XSubPPtmpAABX 1


XS_EUPXS(XS_Wx__RichTextAttr_HasListStyleName); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextAttr_HasListStyleName)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxRichTextAttr *    THIS = (wxRichTextAttr *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextAttr" )
;
	bool	RETVAL;
    try {
      RETVAL = THIS->HasListStyleName();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}

#endif

XS_EUPXS(XS_Wx__RichTextAttr_HasBulletStyle); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextAttr_HasBulletStyle)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxRichTextAttr *    THIS = (wxRichTextAttr *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextAttr" )
;
	bool	RETVAL;
    try {
      RETVAL = THIS->HasBulletStyle();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__RichTextAttr_HasBulletNumber); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextAttr_HasBulletNumber)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxRichTextAttr *    THIS = (wxRichTextAttr *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextAttr" )
;
	bool	RETVAL;
    try {
      RETVAL = THIS->HasBulletNumber();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}

#if WXPERL_W_VERSION_GE( 2, 7, 2 )
#define XSpp_b93c44bc_074483
#define XSubPPtmpAABY 1


XS_EUPXS(XS_Wx__RichTextAttr_HasBulletText); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextAttr_HasBulletText)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxRichTextAttr *    THIS = (wxRichTextAttr *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextAttr" )
;
	bool	RETVAL;
    try {
      RETVAL = THIS->HasBulletText();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__RichTextAttr_HasBulletName); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextAttr_HasBulletName)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxRichTextAttr *    THIS = (wxRichTextAttr *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextAttr" )
;
	bool	RETVAL;
    try {
      RETVAL = THIS->HasBulletName();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__RichTextAttr_HasURL); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextAttr_HasURL)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxRichTextAttr *    THIS = (wxRichTextAttr *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextAttr" )
;
	bool	RETVAL;
    try {
      RETVAL = THIS->HasURL();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__RichTextAttr_HasPageBreak); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextAttr_HasPageBreak)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxRichTextAttr *    THIS = (wxRichTextAttr *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextAttr" )
;
	bool	RETVAL;
    try {
      RETVAL = THIS->HasPageBreak();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}

#endif

XS_EUPXS(XS_Wx__RichTextAttr_IsCharacterStyle); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextAttr_IsCharacterStyle)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxRichTextAttr *    THIS = (wxRichTextAttr *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextAttr" )
;
	bool	RETVAL;
    try {
      RETVAL = THIS->IsCharacterStyle();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__RichTextAttr_IsParagraphStyle); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextAttr_IsParagraphStyle)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxRichTextAttr *    THIS = (wxRichTextAttr *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextAttr" )
;
	bool	RETVAL;
    try {
      RETVAL = THIS->IsParagraphStyle();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__RichTextAttr_IsDefault); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextAttr_IsDefault)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxRichTextAttr *    THIS = (wxRichTextAttr *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextAttr" )
;
	bool	RETVAL;
    try {
      RETVAL = THIS->IsDefault();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__RichTextAttr_new); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextAttr_new)
{
    dVAR; dXSARGS;
    if (items < 1)
       croak_xs_usage(cv,  "CLASS, ...");
    PERL_UNUSED_VAR(ax); /* -Wall */
    SP -= items;
    {
	char *	CLASS = (char *)SvPV_nolen(ST(0))
;
    BEGIN_OVERLOAD()
        MATCH_VOIDM_REDISP( newDefault )
        MATCH_REDISP( wxPliOvl_wrta, newCopy )
        MATCH_REDISP( wxPliOvl_wtae, newAttrEx )
        MATCH_REDISP( wxPliOvl_wtat, newAttr )
#if WXPERL_W_VERSION_LT( 2, 9, 2 )
        MATCH_REDISP_COUNT_ALLOWMORE( wxPliOvl_wcol_wcol_n, newFull, 2 )
#endif
    END_OVERLOAD( Wx::RichTextAttr::new )
	PUTBACK;
	return;
    }
}


XS_EUPXS(XS_Wx__RichTextAttr_GetTabs); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextAttr_GetTabs)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    PERL_UNUSED_VAR(ax); /* -Wall */
    SP -= items;
    {
	wxRichTextAttr *    THIS = (wxRichTextAttr *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextAttr" )
;
    const wxArrayInt& tabs = THIS->GetTabs();
    PUTBACK;
    wxPli_intarray_push( aTHX_ tabs );
    SPAGAIN;
	PUTBACK;
	return;
    }
}


/* INCLUDE: Returning to 'RichText.xs' from '/usr/bin/perl -MExtUtils::XSpp::Cmd -e xspp -- -t typemap.xsp -t ../../typemap.xsp XS/RichTextAttr.xsp' */


/* INCLUDE_COMMAND:  Including output of '/usr/bin/perl -MExtUtils::XSpp::Cmd -e xspp -- -t typemap.xsp -t ../../typemap.xsp XS/RichTextStyle.xsp' from 'RichText.xs' */

#include <exception>

#undef  xsp_constructor_class
#define xsp_constructor_class(c) (c)
#include <wx/richtext/richtextstyles.h>

XS_EUPXS(XS_Wx__RichTextStyleDefinition_CLONE); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextStyleDefinition_CLONE)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "CLASS");
    {
	char *	CLASS = (char *)SvPV_nolen(ST(0))
;
    wxPli_thread_sv_clone( aTHX_ CLASS, (wxPliCloneSV)wxPli_detach_object );
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__RichTextStyleDefinition_DESTROY); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextStyleDefinition_DESTROY)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxRichTextStyleDefinition *    THIS = (wxRichTextStyleDefinition *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextStyleDefinition" )
;
      wxPli_thread_sv_unregister( aTHX_ wxPli_get_class( aTHX_ ST(0) ), THIS, ST(0) );
                 if( wxPli_object_is_deleteable( aTHX_ ST(0) ) )
                     delete THIS;
    }
    XSRETURN_EMPTY;
}

#if WXPERL_W_VERSION_GE( 2, 7, 1 )
#define XSpp_17b3d0c4_080024
#define XSubPPtmpAABZ 1


XS_EUPXS(XS_Wx__RichTextStyleDefinition_Copy); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextStyleDefinition_Copy)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, def");
    {
	wxRichTextStyleDefinition *    THIS = (wxRichTextStyleDefinition *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextStyleDefinition" )
;
	wxRichTextStyleDefinition*    def = (wxRichTextStyleDefinition *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::RichTextStyleDefinition" )
;
    try {
      THIS->Copy( *( def ) );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__RichTextStyleDefinition_Eq); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextStyleDefinition_Eq)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, def");
    {
	wxRichTextStyleDefinition *    THIS = (wxRichTextStyleDefinition *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextStyleDefinition" )
;
	bool	RETVAL;
	wxRichTextStyleDefinition*    def = (wxRichTextStyleDefinition *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::RichTextStyleDefinition" )
;
    try {
      RETVAL = THIS->Eq( *( def ) );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}

#endif

XS_EUPXS(XS_Wx__RichTextStyleDefinition_SetName); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextStyleDefinition_SetName)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, name");
    {
	wxRichTextStyleDefinition *    THIS = (wxRichTextStyleDefinition *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextStyleDefinition" )
;
	wxString	name;

    WXSTRING_INPUT( name, wxString, ST(1) )
;
    try {
      THIS->SetName( name );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__RichTextStyleDefinition_GetName); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextStyleDefinition_GetName)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxRichTextStyleDefinition *    THIS = (wxRichTextStyleDefinition *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextStyleDefinition" )
;
	wxString	RETVAL;
    try {
      RETVAL = THIS->GetName();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    WXSTRING_OUTPUT( RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}

#if WXPERL_W_VERSION_GE( 2, 8, 0 )
#define XSpp_17b3d0c4_096604
#define XSubPPtmpAACA 1


XS_EUPXS(XS_Wx__RichTextStyleDefinition_SetDescription); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextStyleDefinition_SetDescription)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, descr");
    {
	wxRichTextStyleDefinition *    THIS = (wxRichTextStyleDefinition *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextStyleDefinition" )
;
	wxString	descr;

    WXSTRING_INPUT( descr, wxString, ST(1) )
;
    try {
      THIS->SetDescription( descr );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__RichTextStyleDefinition_GetDescription); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextStyleDefinition_GetDescription)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxRichTextStyleDefinition *    THIS = (wxRichTextStyleDefinition *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextStyleDefinition" )
;
	wxString	RETVAL;
    try {
      RETVAL = THIS->GetDescription();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    WXSTRING_OUTPUT( RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}

#endif

XS_EUPXS(XS_Wx__RichTextStyleDefinition_SetBaseStyle); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextStyleDefinition_SetBaseStyle)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, name");
    {
	wxRichTextStyleDefinition *    THIS = (wxRichTextStyleDefinition *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextStyleDefinition" )
;
	wxString	name;

    WXSTRING_INPUT( name, wxString, ST(1) )
;
    try {
      THIS->SetBaseStyle( name );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__RichTextStyleDefinition_GetBaseStyle); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextStyleDefinition_GetBaseStyle)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxRichTextStyleDefinition *    THIS = (wxRichTextStyleDefinition *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextStyleDefinition" )
;
	wxString	RETVAL;
    try {
      RETVAL = THIS->GetBaseStyle();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    WXSTRING_OUTPUT( RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__RichTextStyleDefinition_SetStyle); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextStyleDefinition_SetStyle)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, style");
    {
	wxRichTextStyleDefinition *    THIS = (wxRichTextStyleDefinition *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextStyleDefinition" )
;
	wxRichTextAttr*    style = (wxRichTextAttr *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::RichTextAttr" )
;
    try {
      THIS->SetStyle( *( style ) );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__RichTextStyleDefinition_GetStyle); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextStyleDefinition_GetStyle)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxRichTextStyleDefinition *    THIS = (wxRichTextStyleDefinition *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextStyleDefinition" )
;
	wxRichTextAttr *	RETVAL;
    try {
      RETVAL = new wxRichTextAttr( THIS->GetStyle() );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_non_object_2_sv( aTHX_ RETVALSV, RETVAL, "Wx::RichTextAttr" );
    wxPli_thread_sv_register( aTHX_ "Wx::RichTextAttr", RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}

#if WXPERL_W_VERSION_GE( 2, 8, 0 )
#define XSpp_17b3d0c4_016226
#define XSubPPtmpAACB 1


XS_EUPXS(XS_Wx__RichTextStyleDefinition_GetStyleMergedWithBase); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextStyleDefinition_GetStyleMergedWithBase)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, sheet");
    {
	wxRichTextStyleDefinition *    THIS = (wxRichTextStyleDefinition *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextStyleDefinition" )
;
	wxTextAttr *	RETVAL;
	wxRichTextStyleSheet*    sheet = (wxRichTextStyleSheet *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::RichTextStyleSheet" )
;
    try {
      RETVAL = new wxTextAttr( THIS->GetStyleMergedWithBase( sheet ) );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_non_object_2_sv( aTHX_ RETVALSV, RETVAL, "Wx::TextAttr" );
    wxPli_thread_sv_register( aTHX_ "Wx::TextAttr", RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}

#endif
#undef  xsp_constructor_class
#define xsp_constructor_class(c) (CLASS)

XS_EUPXS(XS_Wx__RichTextCharacterStyleDefinition_new); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextCharacterStyleDefinition_new)
{
    dVAR; dXSARGS;
    if (items < 1 || items > 2)
       croak_xs_usage(cv,  "CLASS, name= wxEmptyString");
    {
	char *	CLASS = (char *)SvPV_nolen(ST(0))
;
	wxRichTextCharacterStyleDefinition *	RETVAL;
	wxString	name;

	if (items < 2)
	    name = wxEmptyString;
	else {
    WXSTRING_INPUT( name, wxString, ST(1) )
;
	}
    try {
      RETVAL = new wxRichTextCharacterStyleDefinition( name );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_object_2_sv( aTHX_ RETVALSV, RETVAL );
    wxPli_thread_sv_register( aTHX_ "Wx::RichTextCharacterStyleDefinition", RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}

#undef  xsp_constructor_class
#define xsp_constructor_class(c) (c)
#undef  xsp_constructor_class
#define xsp_constructor_class(c) (CLASS)

XS_EUPXS(XS_Wx__RichTextParagraphStyleDefinition_new); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextParagraphStyleDefinition_new)
{
    dVAR; dXSARGS;
    if (items < 1 || items > 2)
       croak_xs_usage(cv,  "CLASS, name= wxEmptyString");
    {
	char *	CLASS = (char *)SvPV_nolen(ST(0))
;
	wxRichTextParagraphStyleDefinition *	RETVAL;
	wxString	name;

	if (items < 2)
	    name = wxEmptyString;
	else {
    WXSTRING_INPUT( name, wxString, ST(1) )
;
	}
    try {
      RETVAL = new wxRichTextParagraphStyleDefinition( name );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_object_2_sv( aTHX_ RETVALSV, RETVAL );
    wxPli_thread_sv_register( aTHX_ "Wx::RichTextParagraphStyleDefinition", RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}

#undef  xsp_constructor_class
#define xsp_constructor_class(c) (c)
#if WXPERL_W_VERSION_GE( 2, 7, 1 )
#define XSpp_17b3d0c4_099506
#define XSubPPtmpAACC 1


XS_EUPXS(XS_Wx__RichTextParagraphStyleDefinition_Copy); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextParagraphStyleDefinition_Copy)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, def");
    {
	wxRichTextParagraphStyleDefinition *    THIS = (wxRichTextParagraphStyleDefinition *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextParagraphStyleDefinition" )
;
	wxRichTextParagraphStyleDefinition*    def = (wxRichTextParagraphStyleDefinition *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::RichTextParagraphStyleDefinition" )
;
    try {
      THIS->Copy( *( def ) );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}

#endif

XS_EUPXS(XS_Wx__RichTextParagraphStyleDefinition_SetNextStyle); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextParagraphStyleDefinition_SetNextStyle)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, name");
    {
	wxRichTextParagraphStyleDefinition *    THIS = (wxRichTextParagraphStyleDefinition *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextParagraphStyleDefinition" )
;
	wxString	name;

    WXSTRING_INPUT( name, wxString, ST(1) )
;
    try {
      THIS->SetNextStyle( name );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__RichTextParagraphStyleDefinition_GetNextStyle); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextParagraphStyleDefinition_GetNextStyle)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxRichTextParagraphStyleDefinition *    THIS = (wxRichTextParagraphStyleDefinition *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextParagraphStyleDefinition" )
;
	wxString	RETVAL;
    try {
      RETVAL = THIS->GetNextStyle();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    WXSTRING_OUTPUT( RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}

#if WXPERL_W_VERSION_GE( 2, 7, 2 )
#define XSpp_17b3d0c4_006168
#undef  xsp_constructor_class
#define xsp_constructor_class(c) (CLASS)
#define XSubPPtmpAACD 1


XS_EUPXS(XS_Wx__RichTextListStyleDefinition_new); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextListStyleDefinition_new)
{
    dVAR; dXSARGS;
    if (items < 1 || items > 2)
       croak_xs_usage(cv,  "CLASS, name= wxEmptyString");
    {
	char *	CLASS = (char *)SvPV_nolen(ST(0))
;
	wxRichTextListStyleDefinition *	RETVAL;
	wxString	name;

	if (items < 2)
	    name = wxEmptyString;
	else {
    WXSTRING_INPUT( name, wxString, ST(1) )
;
	}
    try {
      RETVAL = new wxRichTextListStyleDefinition( name );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_object_2_sv( aTHX_ RETVALSV, RETVAL );
    wxPli_thread_sv_register( aTHX_ "Wx::RichTextListStyleDefinition", RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}

#undef  xsp_constructor_class
#define xsp_constructor_class(c) (c)

XS_EUPXS(XS_Wx__RichTextListStyleDefinition_Copy); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextListStyleDefinition_Copy)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, def");
    {
	wxRichTextListStyleDefinition *    THIS = (wxRichTextListStyleDefinition *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextListStyleDefinition" )
;
	wxRichTextListStyleDefinition*    def = (wxRichTextListStyleDefinition *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::RichTextListStyleDefinition" )
;
    try {
      THIS->Copy( *( def ) );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__RichTextListStyleDefinition_SetLevelAttributes); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextListStyleDefinition_SetLevelAttributes)
{
    dVAR; dXSARGS;
    if (items != 3)
       croak_xs_usage(cv,  "THIS, i, attr");
    {
	wxRichTextListStyleDefinition *    THIS = (wxRichTextListStyleDefinition *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextListStyleDefinition" )
;
	int	i = (int)SvIV(ST(1))
;
	wxRichTextAttr*    attr = (wxRichTextAttr *) wxPli_sv_2_object( aTHX_ ST(2), "Wx::RichTextAttr" )
;
    try {
      THIS->SetLevelAttributes( i, *( attr ) );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__RichTextListStyleDefinition_GetLevelAttributes); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextListStyleDefinition_GetLevelAttributes)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, i");
    {
	wxRichTextListStyleDefinition *    THIS = (wxRichTextListStyleDefinition *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextListStyleDefinition" )
;
	wxRichTextAttr *	RETVAL;
	int	i = (int)SvIV(ST(1))
;
    try {
      RETVAL = THIS->GetLevelAttributes( i );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_non_object_2_sv( aTHX_ RETVALSV, RETVAL, "Wx::RichTextAttr" );
    wxPli_thread_sv_register( aTHX_ "Wx::RichTextAttr", RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    wxPli_object_set_deleteable( aTHX_ ST(0), false );
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__RichTextListStyleDefinition_SetAttributes); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextListStyleDefinition_SetAttributes)
{
    dVAR; dXSARGS;
    if (items < 5 || items > 6)
       croak_xs_usage(cv,  "THIS, i, leftIndent, leftSubIndent, bulletStyle, bulletSymbol= wxEmptyString");
    {
	wxRichTextListStyleDefinition *    THIS = (wxRichTextListStyleDefinition *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextListStyleDefinition" )
;
	int	i = (int)SvIV(ST(1))
;
	int	leftIndent = (int)SvIV(ST(2))
;
	int	leftSubIndent = (int)SvIV(ST(3))
;
	int	bulletStyle = (int)SvIV(ST(4))
;
	wxString	bulletSymbol;

	if (items < 6)
	    bulletSymbol = wxEmptyString;
	else {
    WXSTRING_INPUT( bulletSymbol, wxString, ST(5) )
;
	}
    try {
      THIS->SetAttributes( i, leftIndent, leftSubIndent, bulletStyle, bulletSymbol );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__RichTextListStyleDefinition_FindLevelForIndent); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextListStyleDefinition_FindLevelForIndent)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, indent");
    {
	wxRichTextListStyleDefinition *    THIS = (wxRichTextListStyleDefinition *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextListStyleDefinition" )
;
	int	RETVAL;
	dXSTARG;
	int	indent = (int)SvIV(ST(1))
;
    try {
      RETVAL = THIS->FindLevelForIndent( indent );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__RichTextListStyleDefinition_CombineWithParagraphStyle); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextListStyleDefinition_CombineWithParagraphStyle)
{
    dVAR; dXSARGS;
    if (items != 3)
       croak_xs_usage(cv,  "THIS, indent, paraStyle");
    {
	wxRichTextListStyleDefinition *    THIS = (wxRichTextListStyleDefinition *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextListStyleDefinition" )
;
	wxRichTextAttr *	RETVAL;
	int	indent = (int)SvIV(ST(1))
;
	wxRichTextAttr*    paraStyle = (wxRichTextAttr *) wxPli_sv_2_object( aTHX_ ST(2), "Wx::RichTextAttr" )
;
    try {
      RETVAL = new wxRichTextAttr( THIS->CombineWithParagraphStyle( indent, *( paraStyle ) ) );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_non_object_2_sv( aTHX_ RETVALSV, RETVAL, "Wx::RichTextAttr" );
    wxPli_thread_sv_register( aTHX_ "Wx::RichTextAttr", RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__RichTextListStyleDefinition_GetCombinedStyle); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextListStyleDefinition_GetCombinedStyle)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, indent");
    {
	wxRichTextListStyleDefinition *    THIS = (wxRichTextListStyleDefinition *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextListStyleDefinition" )
;
	wxRichTextAttr *	RETVAL;
	int	indent = (int)SvIV(ST(1))
;
    try {
      RETVAL = new wxRichTextAttr( THIS->GetCombinedStyle( indent ) );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_non_object_2_sv( aTHX_ RETVALSV, RETVAL, "Wx::RichTextAttr" );
    wxPli_thread_sv_register( aTHX_ "Wx::RichTextAttr", RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__RichTextListStyleDefinition_GetCombinedStyleForLevel); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextListStyleDefinition_GetCombinedStyleForLevel)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, level");
    {
	wxRichTextListStyleDefinition *    THIS = (wxRichTextListStyleDefinition *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextListStyleDefinition" )
;
	wxRichTextAttr *	RETVAL;
	int	level = (int)SvIV(ST(1))
;
    try {
      RETVAL = new wxRichTextAttr( THIS->GetCombinedStyleForLevel( level ) );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_non_object_2_sv( aTHX_ RETVALSV, RETVAL, "Wx::RichTextAttr" );
    wxPli_thread_sv_register( aTHX_ "Wx::RichTextAttr", RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__RichTextListStyleDefinition_GetLevelCount); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextListStyleDefinition_GetLevelCount)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxRichTextListStyleDefinition *    THIS = (wxRichTextListStyleDefinition *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextListStyleDefinition" )
;
	int	RETVAL;
	dXSTARG;
    try {
      RETVAL = THIS->GetLevelCount();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__RichTextListStyleDefinition_IsNumbered); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextListStyleDefinition_IsNumbered)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, i");
    {
	wxRichTextListStyleDefinition *    THIS = (wxRichTextListStyleDefinition *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextListStyleDefinition" )
;
	bool	RETVAL;
	int	i = (int)SvIV(ST(1))
;
    try {
      RETVAL = THIS->IsNumbered( i );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}

#endif
#undef  xsp_constructor_class
#define xsp_constructor_class(c) (CLASS)

XS_EUPXS(XS_Wx__RichTextStyleSheet_new); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextStyleSheet_new)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "CLASS");
    {
	char *	CLASS = (char *)SvPV_nolen(ST(0))
;
	wxRichTextStyleSheet *	RETVAL;
    try {
      RETVAL = new wxRichTextStyleSheet();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_object_2_sv( aTHX_ RETVALSV, RETVAL );
    wxPli_thread_sv_register( aTHX_ "Wx::RichTextStyleSheet", RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}

#undef  xsp_constructor_class
#define xsp_constructor_class(c) (c)

XS_EUPXS(XS_Wx__RichTextStyleSheet_CLONE); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextStyleSheet_CLONE)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "CLASS");
    {
	char *	CLASS = (char *)SvPV_nolen(ST(0))
;
    wxPli_thread_sv_clone( aTHX_ CLASS, (wxPliCloneSV)wxPli_detach_object );
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__RichTextStyleSheet_DESTROY); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextStyleSheet_DESTROY)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxRichTextStyleSheet *    THIS = (wxRichTextStyleSheet *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextStyleSheet" )
;
      wxPli_thread_sv_unregister( aTHX_ "Wx::RichTextStyleSheet", THIS, ST(0) );
                 if( wxPli_object_is_deleteable( aTHX_ ST(0) ) )
                     delete THIS;
    }
    XSRETURN_EMPTY;
}

#if WXPERL_W_VERSION_GE( 2, 8, 0 )
#define XSpp_17b3d0c4_082185
#define XSubPPtmpAACE 1


XS_EUPXS(XS_Wx__RichTextStyleSheet_AddStyle); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextStyleSheet_AddStyle)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, def");
    {
	wxRichTextStyleSheet *    THIS = (wxRichTextStyleSheet *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextStyleSheet" )
;
	bool	RETVAL;
	wxRichTextStyleDefinition*    def = (wxRichTextStyleDefinition *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::RichTextStyleDefinition" )
;
    try {
      wxPli_object_set_deleteable( aTHX_ ST(1), false );
      RETVAL = THIS->AddStyle( def );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__RichTextStyleSheet_FindStyle); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextStyleSheet_FindStyle)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, name");
    {
	wxRichTextStyleSheet *    THIS = (wxRichTextStyleSheet *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextStyleSheet" )
;
	wxRichTextStyleDefinition *	RETVAL;
	wxString	name;

    WXSTRING_INPUT( name, wxString, ST(1) )
;
    try {
      RETVAL = THIS->FindStyle( name );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_object_2_sv( aTHX_ RETVALSV, RETVAL );
    wxPli_thread_sv_register( aTHX_ "Wx::RichTextStyleDefinition", RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    wxPli_object_set_deleteable( aTHX_ ST(0), false );
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__RichTextStyleSheet_RemoveStyle); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextStyleSheet_RemoveStyle)
{
    dVAR; dXSARGS;
    if (items < 2 || items > 3)
       croak_xs_usage(cv,  "THIS, def, deleteStyle= false");
    {
	wxRichTextStyleSheet *    THIS = (wxRichTextStyleSheet *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextStyleSheet" )
;
	bool	RETVAL;
	wxRichTextStyleDefinition*    def = (wxRichTextStyleDefinition *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::RichTextStyleDefinition" )
;
	bool	deleteStyle;

	if (items < 3)
	    deleteStyle = false;
	else {
	    deleteStyle = (bool)SvTRUE(ST(2))
;
	}
    try {
      RETVAL = THIS->RemoveStyle( def, deleteStyle );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}

#endif
#if WXPERL_W_VERSION_GE( 2, 7, 1 )
#define XSpp_17b3d0c4_053856
#define XSubPPtmpAACF 1


XS_EUPXS(XS_Wx__RichTextStyleSheet_Copy); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextStyleSheet_Copy)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, sheet");
    {
	wxRichTextStyleSheet *    THIS = (wxRichTextStyleSheet *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextStyleSheet" )
;
	wxRichTextStyleSheet*    sheet = (wxRichTextStyleSheet *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::RichTextStyleSheet" )
;
    try {
      THIS->Copy( *( sheet ) );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}

#endif

XS_EUPXS(XS_Wx__RichTextStyleSheet_AddCharacterStyle); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextStyleSheet_AddCharacterStyle)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, def");
    {
	wxRichTextStyleSheet *    THIS = (wxRichTextStyleSheet *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextStyleSheet" )
;
	bool	RETVAL;
	wxRichTextCharacterStyleDefinition*    def = (wxRichTextCharacterStyleDefinition *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::RichTextCharacterStyleDefinition" )
;
    try {
      wxPli_object_set_deleteable( aTHX_ ST(1), false );
      RETVAL = THIS->AddCharacterStyle( def );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__RichTextStyleSheet_AddParagraphStyle); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextStyleSheet_AddParagraphStyle)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, def");
    {
	wxRichTextStyleSheet *    THIS = (wxRichTextStyleSheet *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextStyleSheet" )
;
	bool	RETVAL;
	wxRichTextParagraphStyleDefinition*    def = (wxRichTextParagraphStyleDefinition *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::RichTextParagraphStyleDefinition" )
;
    try {
      wxPli_object_set_deleteable( aTHX_ ST(1), false );
      RETVAL = THIS->AddParagraphStyle( def );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}

#if WXPERL_W_VERSION_GE( 2, 7, 2 )
#define XSpp_17b3d0c4_008000
#define XSubPPtmpAACG 1


XS_EUPXS(XS_Wx__RichTextStyleSheet_AddListStyle); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextStyleSheet_AddListStyle)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, def");
    {
	wxRichTextStyleSheet *    THIS = (wxRichTextStyleSheet *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextStyleSheet" )
;
	bool	RETVAL;
	wxRichTextListStyleDefinition*    def = (wxRichTextListStyleDefinition *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::RichTextListStyleDefinition" )
;
    try {
      wxPli_object_set_deleteable( aTHX_ ST(1), false );
      RETVAL = THIS->AddListStyle( def );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}

#endif

XS_EUPXS(XS_Wx__RichTextStyleSheet_RemoveCharacterStyle); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextStyleSheet_RemoveCharacterStyle)
{
    dVAR; dXSARGS;
    if (items < 2 || items > 3)
       croak_xs_usage(cv,  "THIS, def, deleteStyle= false");
    {
	wxRichTextStyleSheet *    THIS = (wxRichTextStyleSheet *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextStyleSheet" )
;
	bool	RETVAL;
	wxRichTextStyleDefinition*    def = (wxRichTextStyleDefinition *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::RichTextStyleDefinition" )
;
	bool	deleteStyle;

	if (items < 3)
	    deleteStyle = false;
	else {
	    deleteStyle = (bool)SvTRUE(ST(2))
;
	}
    try {
      RETVAL = THIS->RemoveCharacterStyle( def, deleteStyle );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__RichTextStyleSheet_RemoveParagraphStyle); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextStyleSheet_RemoveParagraphStyle)
{
    dVAR; dXSARGS;
    if (items < 2 || items > 3)
       croak_xs_usage(cv,  "THIS, def, deleteStyle= false");
    {
	wxRichTextStyleSheet *    THIS = (wxRichTextStyleSheet *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextStyleSheet" )
;
	bool	RETVAL;
	wxRichTextStyleDefinition*    def = (wxRichTextStyleDefinition *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::RichTextStyleDefinition" )
;
	bool	deleteStyle;

	if (items < 3)
	    deleteStyle = false;
	else {
	    deleteStyle = (bool)SvTRUE(ST(2))
;
	}
    try {
      RETVAL = THIS->RemoveParagraphStyle( def, deleteStyle );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}

#if WXPERL_W_VERSION_GE( 2, 7, 2 )
#define XSpp_17b3d0c4_066448
#define XSubPPtmpAACH 1


XS_EUPXS(XS_Wx__RichTextStyleSheet_RemoveListStyle); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextStyleSheet_RemoveListStyle)
{
    dVAR; dXSARGS;
    if (items < 2 || items > 3)
       croak_xs_usage(cv,  "THIS, def, deleteStyle= false");
    {
	wxRichTextStyleSheet *    THIS = (wxRichTextStyleSheet *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextStyleSheet" )
;
	bool	RETVAL;
	wxRichTextStyleDefinition*    def = (wxRichTextStyleDefinition *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::RichTextStyleDefinition" )
;
	bool	deleteStyle;

	if (items < 3)
	    deleteStyle = false;
	else {
	    deleteStyle = (bool)SvTRUE(ST(2))
;
	}
    try {
      RETVAL = THIS->RemoveListStyle( def, deleteStyle );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}

#endif
#if WXPERL_W_VERSION_GE( 2, 7, 2 )
#define XSpp_17b3d0c4_046945
#define XSubPPtmpAACI 1


XS_EUPXS(XS_Wx__RichTextStyleSheet_FindCharacterStyle); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextStyleSheet_FindCharacterStyle)
{
    dVAR; dXSARGS;
    if (items < 2 || items > 3)
       croak_xs_usage(cv,  "THIS, name, recurse= true");
    {
	wxRichTextStyleSheet *    THIS = (wxRichTextStyleSheet *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextStyleSheet" )
;
	wxRichTextCharacterStyleDefinition *	RETVAL;
	wxString	name;
	bool	recurse;

    WXSTRING_INPUT( name, wxString, ST(1) )
;

	if (items < 3)
	    recurse = true;
	else {
	    recurse = (bool)SvTRUE(ST(2))
;
	}
    try {
      RETVAL = THIS->FindCharacterStyle( name, recurse );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_object_2_sv( aTHX_ RETVALSV, RETVAL );
    wxPli_thread_sv_register( aTHX_ "Wx::RichTextCharacterStyleDefinition", RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    wxPli_object_set_deleteable( aTHX_ ST(0), false );
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__RichTextStyleSheet_FindParagraphStyle); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextStyleSheet_FindParagraphStyle)
{
    dVAR; dXSARGS;
    if (items < 2 || items > 3)
       croak_xs_usage(cv,  "THIS, name, recurse= true");
    {
	wxRichTextStyleSheet *    THIS = (wxRichTextStyleSheet *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextStyleSheet" )
;
	wxRichTextParagraphStyleDefinition *	RETVAL;
	wxString	name;
	bool	recurse;

    WXSTRING_INPUT( name, wxString, ST(1) )
;

	if (items < 3)
	    recurse = true;
	else {
	    recurse = (bool)SvTRUE(ST(2))
;
	}
    try {
      RETVAL = THIS->FindParagraphStyle( name, recurse );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_object_2_sv( aTHX_ RETVALSV, RETVAL );
    wxPli_thread_sv_register( aTHX_ "Wx::RichTextParagraphStyleDefinition", RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    wxPli_object_set_deleteable( aTHX_ ST(0), false );
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__RichTextStyleSheet_FindListStyle); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextStyleSheet_FindListStyle)
{
    dVAR; dXSARGS;
    if (items < 2 || items > 3)
       croak_xs_usage(cv,  "THIS, name, recurse= true");
    {
	wxRichTextStyleSheet *    THIS = (wxRichTextStyleSheet *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextStyleSheet" )
;
	wxRichTextListStyleDefinition *	RETVAL;
	wxString	name;
	bool	recurse;

    WXSTRING_INPUT( name, wxString, ST(1) )
;

	if (items < 3)
	    recurse = true;
	else {
	    recurse = (bool)SvTRUE(ST(2))
;
	}
    try {
      RETVAL = THIS->FindListStyle( name, recurse );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_object_2_sv( aTHX_ RETVALSV, RETVAL );
    wxPli_thread_sv_register( aTHX_ "Wx::RichTextListStyleDefinition", RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    wxPli_object_set_deleteable( aTHX_ ST(0), false );
    }
    XSRETURN(1);
}

#endif

XS_EUPXS(XS_Wx__RichTextStyleSheet_GetCharacterStyleCount); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextStyleSheet_GetCharacterStyleCount)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxRichTextStyleSheet *    THIS = (wxRichTextStyleSheet *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextStyleSheet" )
;
	size_t	RETVAL;
	dXSTARG;
    try {
      RETVAL = THIS->GetCharacterStyleCount();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	XSprePUSH;
	PUSHu((UV)RETVAL );
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__RichTextStyleSheet_GetParagraphStyleCount); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextStyleSheet_GetParagraphStyleCount)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxRichTextStyleSheet *    THIS = (wxRichTextStyleSheet *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextStyleSheet" )
;
	size_t	RETVAL;
	dXSTARG;
    try {
      RETVAL = THIS->GetParagraphStyleCount();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	XSprePUSH;
	PUSHu((UV)RETVAL );
    }
    XSRETURN(1);
}

#if WXPERL_W_VERSION_GE( 2, 7, 2 )
#define XSpp_17b3d0c4_023978
#define XSubPPtmpAACJ 1


XS_EUPXS(XS_Wx__RichTextStyleSheet_GetListStyleCount); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextStyleSheet_GetListStyleCount)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxRichTextStyleSheet *    THIS = (wxRichTextStyleSheet *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextStyleSheet" )
;
	size_t	RETVAL;
	dXSTARG;
    try {
      RETVAL = THIS->GetListStyleCount();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	XSprePUSH;
	PUSHu((UV)RETVAL );
    }
    XSRETURN(1);
}

#endif

XS_EUPXS(XS_Wx__RichTextStyleSheet_GetCharacterStyle); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextStyleSheet_GetCharacterStyle)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, n");
    {
	wxRichTextStyleSheet *    THIS = (wxRichTextStyleSheet *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextStyleSheet" )
;
	wxRichTextCharacterStyleDefinition *	RETVAL;
	size_t    n = (size_t)SvUV( ST(1) )
;
    try {
      RETVAL = THIS->GetCharacterStyle( n );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_object_2_sv( aTHX_ RETVALSV, RETVAL );
    wxPli_thread_sv_register( aTHX_ "Wx::RichTextCharacterStyleDefinition", RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    wxPli_object_set_deleteable( aTHX_ ST(0), false );
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__RichTextStyleSheet_GetParagraphStyle); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextStyleSheet_GetParagraphStyle)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, n");
    {
	wxRichTextStyleSheet *    THIS = (wxRichTextStyleSheet *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextStyleSheet" )
;
	wxRichTextParagraphStyleDefinition *	RETVAL;
	size_t    n = (size_t)SvUV( ST(1) )
;
    try {
      RETVAL = THIS->GetParagraphStyle( n );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_object_2_sv( aTHX_ RETVALSV, RETVAL );
    wxPli_thread_sv_register( aTHX_ "Wx::RichTextParagraphStyleDefinition", RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    wxPli_object_set_deleteable( aTHX_ ST(0), false );
    }
    XSRETURN(1);
}

#if WXPERL_W_VERSION_GE( 2, 7, 2 )
#define XSpp_17b3d0c4_002774
#define XSubPPtmpAACK 1


XS_EUPXS(XS_Wx__RichTextStyleSheet_GetListStyle); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextStyleSheet_GetListStyle)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, n");
    {
	wxRichTextStyleSheet *    THIS = (wxRichTextStyleSheet *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextStyleSheet" )
;
	wxRichTextListStyleDefinition *	RETVAL;
	size_t    n = (size_t)SvUV( ST(1) )
;
    try {
      RETVAL = THIS->GetListStyle( n );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_object_2_sv( aTHX_ RETVALSV, RETVAL );
    wxPli_thread_sv_register( aTHX_ "Wx::RichTextListStyleDefinition", RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    wxPli_object_set_deleteable( aTHX_ ST(0), false );
    }
    XSRETURN(1);
}

#endif

XS_EUPXS(XS_Wx__RichTextStyleSheet_DeleteStyles); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextStyleSheet_DeleteStyles)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxRichTextStyleSheet *    THIS = (wxRichTextStyleSheet *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextStyleSheet" )
;
    try {
      THIS->DeleteStyles();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}

#if WXPERL_W_VERSION_GE( 2, 7, 2 )
#define XSpp_17b3d0c4_024434
#define XSubPPtmpAACL 1


XS_EUPXS(XS_Wx__RichTextStyleSheet_InsertSheet); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextStyleSheet_InsertSheet)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, before");
    {
	wxRichTextStyleSheet *    THIS = (wxRichTextStyleSheet *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextStyleSheet" )
;
	bool	RETVAL;
	wxRichTextStyleSheet*    before = (wxRichTextStyleSheet *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::RichTextStyleSheet" )
;
    try {
      RETVAL = THIS->InsertSheet( before );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__RichTextStyleSheet_AppendSheet); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextStyleSheet_AppendSheet)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, after");
    {
	wxRichTextStyleSheet *    THIS = (wxRichTextStyleSheet *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextStyleSheet" )
;
	bool	RETVAL;
	wxRichTextStyleSheet*    after = (wxRichTextStyleSheet *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::RichTextStyleSheet" )
;
    try {
      RETVAL = THIS->AppendSheet( after );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__RichTextStyleSheet_Unlink); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextStyleSheet_Unlink)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxRichTextStyleSheet *    THIS = (wxRichTextStyleSheet *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextStyleSheet" )
;
    try {
      THIS->Unlink();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__RichTextStyleSheet_GetNextSheet); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextStyleSheet_GetNextSheet)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxRichTextStyleSheet *    THIS = (wxRichTextStyleSheet *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextStyleSheet" )
;
	wxRichTextStyleSheet *	RETVAL;
    try {
      RETVAL = THIS->GetNextSheet();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_object_2_sv( aTHX_ RETVALSV, RETVAL );
    wxPli_thread_sv_register( aTHX_ "Wx::RichTextStyleSheet", RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    wxPli_object_set_deleteable( aTHX_ ST(0), false );
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__RichTextStyleSheet_SetNextSheet); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextStyleSheet_SetNextSheet)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, sheet");
    {
	wxRichTextStyleSheet *    THIS = (wxRichTextStyleSheet *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextStyleSheet" )
;
	wxRichTextStyleSheet*    sheet = (wxRichTextStyleSheet *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::RichTextStyleSheet" )
;
    try {
      THIS->SetNextSheet( sheet );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__RichTextStyleSheet_GetPreviousSheet); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextStyleSheet_GetPreviousSheet)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxRichTextStyleSheet *    THIS = (wxRichTextStyleSheet *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextStyleSheet" )
;
	wxRichTextStyleSheet *	RETVAL;
    try {
      RETVAL = THIS->GetPreviousSheet();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_object_2_sv( aTHX_ RETVALSV, RETVAL );
    wxPli_thread_sv_register( aTHX_ "Wx::RichTextStyleSheet", RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    wxPli_object_set_deleteable( aTHX_ ST(0), false );
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__RichTextStyleSheet_SetPreviousSheet); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextStyleSheet_SetPreviousSheet)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, sheet");
    {
	wxRichTextStyleSheet *    THIS = (wxRichTextStyleSheet *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextStyleSheet" )
;
	wxRichTextStyleSheet*    sheet = (wxRichTextStyleSheet *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::RichTextStyleSheet" )
;
    try {
      THIS->SetPreviousSheet( sheet );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}

#endif
#if WXPERL_W_VERSION_GE( 2, 8, 0 )
#define XSpp_17b3d0c4_024609
#define XSubPPtmpAACM 1


XS_EUPXS(XS_Wx__RichTextStyleSheet_SetName); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextStyleSheet_SetName)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, name");
    {
	wxRichTextStyleSheet *    THIS = (wxRichTextStyleSheet *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextStyleSheet" )
;
	wxString	name;

    WXSTRING_INPUT( name, wxString, ST(1) )
;
    try {
      THIS->SetName( name );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__RichTextStyleSheet_GetName); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextStyleSheet_GetName)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxRichTextStyleSheet *    THIS = (wxRichTextStyleSheet *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextStyleSheet" )
;
	wxString	RETVAL;
    try {
      RETVAL = THIS->GetName();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    WXSTRING_OUTPUT( RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__RichTextStyleSheet_SetDescription); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextStyleSheet_SetDescription)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, descr");
    {
	wxRichTextStyleSheet *    THIS = (wxRichTextStyleSheet *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextStyleSheet" )
;
	wxString	descr;

    WXSTRING_INPUT( descr, wxString, ST(1) )
;
    try {
      THIS->SetDescription( descr );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__RichTextStyleSheet_GetDescription); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextStyleSheet_GetDescription)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxRichTextStyleSheet *    THIS = (wxRichTextStyleSheet *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextStyleSheet" )
;
	wxString	RETVAL;
    try {
      RETVAL = THIS->GetDescription();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    WXSTRING_OUTPUT( RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}

#endif

/* INCLUDE: Returning to 'RichText.xs' from '/usr/bin/perl -MExtUtils::XSpp::Cmd -e xspp -- -t typemap.xsp -t ../../typemap.xsp XS/RichTextStyle.xsp' */


/* INCLUDE_COMMAND:  Including output of '/usr/bin/perl -MExtUtils::XSpp::Cmd -e xspp -- -t typemap.xsp -t ../../typemap.xsp XS/RichTextStyleCtrl.xsp' from 'RichText.xs' */

#include <exception>

#undef  xsp_constructor_class
#define xsp_constructor_class(c) (c)
#include <wx/checkbox.h>
#include <wx/richtext/richtextstyles.h>
#if WXPERL_W_VERSION_GE( 2, 7, 1 )
#define XSpp_96487896_062093
#undef  xsp_constructor_class
#define xsp_constructor_class(c) (CLASS)
#define XSubPPtmpAACN 1


XS_EUPXS(XS_Wx__RichTextStyleListBox_newDefault); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextStyleListBox_newDefault)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "CLASS");
    {
	char *	CLASS = (char *)SvPV_nolen(ST(0))
;
	wxRichTextStyleListBox *	RETVAL;
    try {
      RETVAL = new wxRichTextStyleListBox();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_evthandler_2_sv( aTHX_ RETVALSV, RETVAL );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}

#undef  xsp_constructor_class
#define xsp_constructor_class(c) (c)
#endif
#undef  xsp_constructor_class
#define xsp_constructor_class(c) (CLASS)

XS_EUPXS(XS_Wx__RichTextStyleListBox_newFull); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextStyleListBox_newFull)
{
    dVAR; dXSARGS;
    if (items < 2 || items > 6)
       croak_xs_usage(cv,  "CLASS, parent, id= wxID_ANY, pos= wxDefaultPosition, size= wxDefaultSize, style= 0");
    {
	char *	CLASS = (char *)SvPV_nolen(ST(0))
;
	wxRichTextStyleListBox *	RETVAL;
	wxWindow*    parent = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::Window" )
;
	wxWindowID	id;
	wxPoint	pos;
	wxSize	size;
	long	style;

	if (items < 3)
	    id = wxID_ANY;
	else {
    id = wxPli_get_wxwindowid( aTHX_ ST(2) )
;
	}

	if (items < 4)
	    pos = wxDefaultPosition;
	else {
    pos = wxPli_sv_2_wxpoint( aTHX_ ST(3) )
;
	}

	if (items < 5)
	    size = wxDefaultSize;
	else {
    size = wxPli_sv_2_wxsize( aTHX_ ST(4) )
;
	}

	if (items < 6)
	    style = 0;
	else {
	    style = (long)SvIV(ST(5))
;
	}
    try {
      RETVAL = new wxRichTextStyleListBox( parent, id, pos, size, style );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_evthandler_2_sv( aTHX_ RETVALSV, RETVAL );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}

#undef  xsp_constructor_class
#define xsp_constructor_class(c) (c)

XS_EUPXS(XS_Wx__RichTextStyleListBox_new); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextStyleListBox_new)
{
    dVAR; dXSARGS;
    if (items < 1)
       croak_xs_usage(cv,  "CLASS, ...");
    PERL_UNUSED_VAR(ax); /* -Wall */
    SP -= items;
    {
	char *	CLASS = (char *)SvPV_nolen(ST(0))
;
    BEGIN_OVERLOAD()
        MATCH_VOIDM_REDISP( newDefault )
        MATCH_ANY_REDISP( newFull )
    END_OVERLOAD( "Wx::RichTextStyleListBox::new" )
	PUTBACK;
	return;
    }
}


XS_EUPXS(XS_Wx__RichTextStyleListBox_Create); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextStyleListBox_Create)
{
    dVAR; dXSARGS;
    if (items < 2 || items > 6)
       croak_xs_usage(cv,  "THIS, parent, id= wxID_ANY, pos= wxDefaultPosition, size= wxDefaultSize, style= 0");
    {
	wxRichTextStyleListBox *    THIS = (wxRichTextStyleListBox *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextStyleListBox" )
;
	bool	RETVAL;
	wxWindow*    parent = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::Window" )
;
	wxWindowID	id;
	wxPoint	pos;
	wxSize	size;
	long	style;

	if (items < 3)
	    id = wxID_ANY;
	else {
    id = wxPli_get_wxwindowid( aTHX_ ST(2) )
;
	}

	if (items < 4)
	    pos = wxDefaultPosition;
	else {
    pos = wxPli_sv_2_wxpoint( aTHX_ ST(3) )
;
	}

	if (items < 5)
	    size = wxDefaultSize;
	else {
    size = wxPli_sv_2_wxsize( aTHX_ ST(4) )
;
	}

	if (items < 6)
	    style = 0;
	else {
	    style = (long)SvIV(ST(5))
;
	}
    try {
      RETVAL = THIS->Create( parent, id, pos, size, style );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__RichTextStyleListBox_SetStyleSheet); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextStyleListBox_SetStyleSheet)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, styleSheet");
    {
	wxRichTextStyleListBox *    THIS = (wxRichTextStyleListBox *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextStyleListBox" )
;
	wxRichTextStyleSheet*    styleSheet = (wxRichTextStyleSheet *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::RichTextStyleSheet" )
;
    try {
      THIS->SetStyleSheet( styleSheet );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__RichTextStyleListBox_GetStyleSheet); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextStyleListBox_GetStyleSheet)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxRichTextStyleListBox *    THIS = (wxRichTextStyleListBox *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextStyleListBox" )
;
	wxRichTextStyleSheet *	RETVAL;
    try {
      RETVAL = THIS->GetStyleSheet();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_object_2_sv( aTHX_ RETVALSV, RETVAL );
    wxPli_thread_sv_register( aTHX_ "Wx::RichTextStyleSheet", RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    wxPli_object_set_deleteable( aTHX_ ST(0), false );
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__RichTextStyleListBox_SetRichTextCtrl); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextStyleListBox_SetRichTextCtrl)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, ctrl");
    {
	wxRichTextStyleListBox *    THIS = (wxRichTextStyleListBox *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextStyleListBox" )
;
	wxRichTextCtrl*    ctrl = (wxRichTextCtrl *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::RichTextCtrl" )
;
    try {
      THIS->SetRichTextCtrl( ctrl );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__RichTextStyleListBox_GetRichTextCtrl); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextStyleListBox_GetRichTextCtrl)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxRichTextStyleListBox *    THIS = (wxRichTextStyleListBox *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextStyleListBox" )
;
	wxRichTextCtrl *	RETVAL;
    try {
      RETVAL = THIS->GetRichTextCtrl();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_evthandler_2_sv( aTHX_ RETVALSV, RETVAL );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__RichTextStyleListBox_GetStyle); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextStyleListBox_GetStyle)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, i");
    {
	wxRichTextStyleListBox *    THIS = (wxRichTextStyleListBox *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextStyleListBox" )
;
	wxRichTextStyleDefinition *	RETVAL;
	size_t    i = (size_t)SvUV( ST(1) )
;
    try {
      RETVAL = THIS->GetStyle( i );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_object_2_sv( aTHX_ RETVALSV, RETVAL );
    wxPli_thread_sv_register( aTHX_ "Wx::RichTextStyleDefinition", RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    wxPli_object_set_deleteable( aTHX_ ST(0), false );
    }
    XSRETURN(1);
}

#if WXPERL_W_VERSION_GE( 2, 7, 1 )
#define XSpp_96487896_090837
#define XSubPPtmpAACO 1


XS_EUPXS(XS_Wx__RichTextStyleListBox_GetIndexForStyle); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextStyleListBox_GetIndexForStyle)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, name");
    {
	wxRichTextStyleListBox *    THIS = (wxRichTextStyleListBox *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextStyleListBox" )
;
	int	RETVAL;
	dXSTARG;
	wxString	name;

    WXSTRING_INPUT( name, wxString, ST(1) )
;
    try {
      RETVAL = THIS->GetIndexForStyle( name );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__RichTextStyleListBox_SetStyleSelection); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextStyleListBox_SetStyleSelection)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, name");
    {
	wxRichTextStyleListBox *    THIS = (wxRichTextStyleListBox *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextStyleListBox" )
;
	int	RETVAL;
	dXSTARG;
	wxString	name;

    WXSTRING_INPUT( name, wxString, ST(1) )
;
    try {
      RETVAL = THIS->SetStyleSelection( name );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}

#endif

XS_EUPXS(XS_Wx__RichTextStyleListBox_UpdateStyles); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextStyleListBox_UpdateStyles)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxRichTextStyleListBox *    THIS = (wxRichTextStyleListBox *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextStyleListBox" )
;
    try {
      THIS->UpdateStyles();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}

#if WXPERL_W_VERSION_GE( 2, 7, 1 )
#define XSpp_96487896_099148
#define XSubPPtmpAACP 1


XS_EUPXS(XS_Wx__RichTextStyleListBox_ApplyStyle); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextStyleListBox_ApplyStyle)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, i");
    {
	wxRichTextStyleListBox *    THIS = (wxRichTextStyleListBox *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextStyleListBox" )
;
	int	i = (int)SvIV(ST(1))
;
    try {
      THIS->ApplyStyle( i );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__RichTextStyleListBox_SetApplyOnSelection); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextStyleListBox_SetApplyOnSelection)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, applyOnSel");
    {
	wxRichTextStyleListBox *    THIS = (wxRichTextStyleListBox *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextStyleListBox" )
;
	bool	applyOnSel = (bool)SvTRUE(ST(1))
;
    try {
      THIS->SetApplyOnSelection( applyOnSel );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__RichTextStyleListBox_GetApplyOnSelection); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextStyleListBox_GetApplyOnSelection)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxRichTextStyleListBox *    THIS = (wxRichTextStyleListBox *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextStyleListBox" )
;
	bool	RETVAL;
    try {
      RETVAL = THIS->GetApplyOnSelection();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}

#endif
#if WXPERL_W_VERSION_GE( 2, 7, 2 )
#define XSpp_96487896_035295
#define XSubPPtmpAACQ 1


XS_EUPXS(XS_Wx__RichTextStyleListBox_SetStyleType); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextStyleListBox_SetStyleType)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, styleType");
    {
	wxRichTextStyleListBox *    THIS = (wxRichTextStyleListBox *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextStyleListBox" )
;
	wxPliRichTextStyleType	styleType = (wxPliRichTextStyleType)SvIV(ST(1))
;
    try {
      THIS->SetStyleType( styleType );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__RichTextStyleListBox_GetStyleType); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextStyleListBox_GetStyleType)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxRichTextStyleListBox *    THIS = (wxRichTextStyleListBox *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextStyleListBox" )
;
	wxPliRichTextStyleType	RETVAL;
	dXSTARG;
    try {
      RETVAL = THIS->GetStyleType();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}

#endif

XS_EUPXS(XS_Wx__RichTextStyleListBox_ConvertTenthsMMToPixels); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextStyleListBox_ConvertTenthsMMToPixels)
{
    dVAR; dXSARGS;
    if (items != 3)
       croak_xs_usage(cv,  "THIS, dc, units");
    {
	wxRichTextStyleListBox *    THIS = (wxRichTextStyleListBox *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextStyleListBox" )
;
	int	RETVAL;
	dXSTARG;
	wxDC*    dc = (wxDC *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::DC" )
;
	int	units = (int)SvIV(ST(2))
;
    try {
      RETVAL = THIS->ConvertTenthsMMToPixels( *( dc ), units );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__RichTextStyleListBox_CreateHTML); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextStyleListBox_CreateHTML)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, def");
    {
	wxRichTextStyleListBox *    THIS = (wxRichTextStyleListBox *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextStyleListBox" )
;
	wxString	RETVAL;
	wxRichTextStyleDefinition*    def = (wxRichTextStyleDefinition *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::RichTextStyleDefinition" )
;
    try {
      RETVAL = THIS->CreateHTML( def );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    WXSTRING_OUTPUT( RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}

#if WXPERL_W_VERSION_GE( 2, 7, 2 )
#define XSpp_96487896_028495
#undef  xsp_constructor_class
#define xsp_constructor_class(c) (CLASS)
#define XSubPPtmpAACR 1


XS_EUPXS(XS_Wx__RichTextStyleListCtrl_newDefault); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextStyleListCtrl_newDefault)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "CLASS");
    {
	char *	CLASS = (char *)SvPV_nolen(ST(0))
;
	wxRichTextStyleListCtrl *	RETVAL;
    try {
      RETVAL = new wxRichTextStyleListCtrl();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_evthandler_2_sv( aTHX_ RETVALSV, RETVAL );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}

#undef  xsp_constructor_class
#define xsp_constructor_class(c) (c)
#undef  xsp_constructor_class
#define xsp_constructor_class(c) (CLASS)

XS_EUPXS(XS_Wx__RichTextStyleListCtrl_newFull); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextStyleListCtrl_newFull)
{
    dVAR; dXSARGS;
    if (items < 2 || items > 6)
       croak_xs_usage(cv,  "CLASS, parent, id= wxID_ANY, pos= wxDefaultPosition, size= wxDefaultSize, style= 0");
    {
	char *	CLASS = (char *)SvPV_nolen(ST(0))
;
	wxRichTextStyleListCtrl *	RETVAL;
	wxWindow*    parent = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::Window" )
;
	wxWindowID	id;
	wxPoint	pos;
	wxSize	size;
	long	style;

	if (items < 3)
	    id = wxID_ANY;
	else {
    id = wxPli_get_wxwindowid( aTHX_ ST(2) )
;
	}

	if (items < 4)
	    pos = wxDefaultPosition;
	else {
    pos = wxPli_sv_2_wxpoint( aTHX_ ST(3) )
;
	}

	if (items < 5)
	    size = wxDefaultSize;
	else {
    size = wxPli_sv_2_wxsize( aTHX_ ST(4) )
;
	}

	if (items < 6)
	    style = 0;
	else {
	    style = (long)SvIV(ST(5))
;
	}
    try {
      RETVAL = new wxRichTextStyleListCtrl( parent, id, pos, size, style );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_evthandler_2_sv( aTHX_ RETVALSV, RETVAL );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}

#undef  xsp_constructor_class
#define xsp_constructor_class(c) (c)

XS_EUPXS(XS_Wx__RichTextStyleListCtrl_new); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextStyleListCtrl_new)
{
    dVAR; dXSARGS;
    if (items < 1)
       croak_xs_usage(cv,  "CLASS, ...");
    PERL_UNUSED_VAR(ax); /* -Wall */
    SP -= items;
    {
	char *	CLASS = (char *)SvPV_nolen(ST(0))
;
    BEGIN_OVERLOAD()
        MATCH_VOIDM_REDISP( newDefault )
        MATCH_ANY_REDISP( newFull )
    END_OVERLOAD( "Wx::RichTextStyleListCtrl::new" )
	PUTBACK;
	return;
    }
}


XS_EUPXS(XS_Wx__RichTextStyleListCtrl_Create); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextStyleListCtrl_Create)
{
    dVAR; dXSARGS;
    if (items < 2 || items > 6)
       croak_xs_usage(cv,  "THIS, parent, id= wxID_ANY, pos= wxDefaultPosition, size= wxDefaultSize, style= 0");
    {
	wxRichTextStyleListCtrl *    THIS = (wxRichTextStyleListCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextStyleListCtrl" )
;
	bool	RETVAL;
	wxWindow*    parent = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::Window" )
;
	wxWindowID	id;
	wxPoint	pos;
	wxSize	size;
	long	style;

	if (items < 3)
	    id = wxID_ANY;
	else {
    id = wxPli_get_wxwindowid( aTHX_ ST(2) )
;
	}

	if (items < 4)
	    pos = wxDefaultPosition;
	else {
    pos = wxPli_sv_2_wxpoint( aTHX_ ST(3) )
;
	}

	if (items < 5)
	    size = wxDefaultSize;
	else {
    size = wxPli_sv_2_wxsize( aTHX_ ST(4) )
;
	}

	if (items < 6)
	    style = 0;
	else {
	    style = (long)SvIV(ST(5))
;
	}
    try {
      RETVAL = THIS->Create( parent, id, pos, size, style );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__RichTextStyleListCtrl_SetStyleSheet); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextStyleListCtrl_SetStyleSheet)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, styleSheet");
    {
	wxRichTextStyleListCtrl *    THIS = (wxRichTextStyleListCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextStyleListCtrl" )
;
	wxRichTextStyleSheet*    styleSheet = (wxRichTextStyleSheet *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::RichTextStyleSheet" )
;
    try {
      THIS->SetStyleSheet( styleSheet );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__RichTextStyleListCtrl_GetStyleSheet); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextStyleListCtrl_GetStyleSheet)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxRichTextStyleListCtrl *    THIS = (wxRichTextStyleListCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextStyleListCtrl" )
;
	wxRichTextStyleSheet *	RETVAL;
    try {
      RETVAL = THIS->GetStyleSheet();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_object_2_sv( aTHX_ RETVALSV, RETVAL );
    wxPli_thread_sv_register( aTHX_ "Wx::RichTextStyleSheet", RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    wxPli_object_set_deleteable( aTHX_ ST(0), false );
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__RichTextStyleListCtrl_SetRichTextCtrl); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextStyleListCtrl_SetRichTextCtrl)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, ctrl");
    {
	wxRichTextStyleListCtrl *    THIS = (wxRichTextStyleListCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextStyleListCtrl" )
;
	wxRichTextCtrl*    ctrl = (wxRichTextCtrl *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::RichTextCtrl" )
;
    try {
      THIS->SetRichTextCtrl( ctrl );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__RichTextStyleListCtrl_GetRichTextCtrl); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextStyleListCtrl_GetRichTextCtrl)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxRichTextStyleListCtrl *    THIS = (wxRichTextStyleListCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextStyleListCtrl" )
;
	wxRichTextCtrl *	RETVAL;
    try {
      RETVAL = THIS->GetRichTextCtrl();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_evthandler_2_sv( aTHX_ RETVALSV, RETVAL );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__RichTextStyleListCtrl_UpdateStyles); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextStyleListCtrl_UpdateStyles)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxRichTextStyleListCtrl *    THIS = (wxRichTextStyleListCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextStyleListCtrl" )
;
    try {
      THIS->UpdateStyles();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__RichTextStyleListCtrl_SetStyleType); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextStyleListCtrl_SetStyleType)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, styleType");
    {
	wxRichTextStyleListCtrl *    THIS = (wxRichTextStyleListCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextStyleListCtrl" )
;
	wxPliRichTextStyleType	styleType = (wxPliRichTextStyleType)SvIV(ST(1))
;
    try {
      THIS->SetStyleType( styleType );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__RichTextStyleListCtrl_GetStyleType); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextStyleListCtrl_GetStyleType)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxRichTextStyleListCtrl *    THIS = (wxRichTextStyleListCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextStyleListCtrl" )
;
	wxPliRichTextStyleType	RETVAL;
	dXSTARG;
    try {
      RETVAL = THIS->GetStyleType();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__RichTextStyleListCtrl_StyleTypeToIndex); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextStyleListCtrl_StyleTypeToIndex)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, styleType");
    {
	wxRichTextStyleListCtrl *    THIS = (wxRichTextStyleListCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextStyleListCtrl" )
;
	int	RETVAL;
	dXSTARG;
	wxPliRichTextStyleType	styleType = (wxPliRichTextStyleType)SvIV(ST(1))
;
    try {
      RETVAL = THIS->StyleTypeToIndex( styleType );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__RichTextStyleListCtrl_StyleIndexToType); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextStyleListCtrl_StyleIndexToType)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, i");
    {
	wxRichTextStyleListCtrl *    THIS = (wxRichTextStyleListCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextStyleListCtrl" )
;
	wxPliRichTextStyleType	RETVAL;
	dXSTARG;
	int	i = (int)SvIV(ST(1))
;
    try {
      RETVAL = THIS->StyleIndexToType( i );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__RichTextStyleListCtrl_GetStyleListBox); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextStyleListCtrl_GetStyleListBox)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxRichTextStyleListCtrl *    THIS = (wxRichTextStyleListCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextStyleListCtrl" )
;
	wxRichTextStyleListBox *	RETVAL;
    try {
      RETVAL = THIS->GetStyleListBox();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_evthandler_2_sv( aTHX_ RETVALSV, RETVAL );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__RichTextStyleListCtrl_GetStyleChoice); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextStyleListCtrl_GetStyleChoice)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxRichTextStyleListCtrl *    THIS = (wxRichTextStyleListCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextStyleListCtrl" )
;
	wxChoice *	RETVAL;
    try {
      RETVAL = THIS->GetStyleChoice();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_evthandler_2_sv( aTHX_ RETVALSV, RETVAL );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}

#endif
#if WXPERL_W_VERSION_GE( 2, 7, 1 )
#define XSpp_96487896_071968
#undef  xsp_constructor_class
#define xsp_constructor_class(c) (CLASS)
#define XSubPPtmpAACS 1


XS_EUPXS(XS_Wx__RichTextStyleComboCtrl_newDefault); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextStyleComboCtrl_newDefault)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "CLASS");
    {
	char *	CLASS = (char *)SvPV_nolen(ST(0))
;
	wxRichTextStyleComboCtrl *	RETVAL;
    try {
      RETVAL = new wxRichTextStyleComboCtrl();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_evthandler_2_sv( aTHX_ RETVALSV, RETVAL );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}

#undef  xsp_constructor_class
#define xsp_constructor_class(c) (c)
#undef  xsp_constructor_class
#define xsp_constructor_class(c) (CLASS)

XS_EUPXS(XS_Wx__RichTextStyleComboCtrl_newFull); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextStyleComboCtrl_newFull)
{
    dVAR; dXSARGS;
    if (items < 2 || items > 6)
       croak_xs_usage(cv,  "CLASS, parent, id= wxID_ANY, pos= wxDefaultPosition, size= wxDefaultSize, style= 0");
    {
	char *	CLASS = (char *)SvPV_nolen(ST(0))
;
	wxRichTextStyleComboCtrl *	RETVAL;
	wxWindow*    parent = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::Window" )
;
	wxWindowID	id;
	wxPoint	pos;
	wxSize	size;
	long	style;

	if (items < 3)
	    id = wxID_ANY;
	else {
    id = wxPli_get_wxwindowid( aTHX_ ST(2) )
;
	}

	if (items < 4)
	    pos = wxDefaultPosition;
	else {
    pos = wxPli_sv_2_wxpoint( aTHX_ ST(3) )
;
	}

	if (items < 5)
	    size = wxDefaultSize;
	else {
    size = wxPli_sv_2_wxsize( aTHX_ ST(4) )
;
	}

	if (items < 6)
	    style = 0;
	else {
	    style = (long)SvIV(ST(5))
;
	}
    try {
      RETVAL = new wxRichTextStyleComboCtrl( parent, id, pos, size, style );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_evthandler_2_sv( aTHX_ RETVALSV, RETVAL );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}

#undef  xsp_constructor_class
#define xsp_constructor_class(c) (c)

XS_EUPXS(XS_Wx__RichTextStyleComboCtrl_new); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextStyleComboCtrl_new)
{
    dVAR; dXSARGS;
    if (items < 1)
       croak_xs_usage(cv,  "CLASS, ...");
    PERL_UNUSED_VAR(ax); /* -Wall */
    SP -= items;
    {
	char *	CLASS = (char *)SvPV_nolen(ST(0))
;
    BEGIN_OVERLOAD()
        MATCH_VOIDM_REDISP( newDefault )
        MATCH_ANY_REDISP( newFull )
    END_OVERLOAD( "Wx::RichTextStyleComboCtrl::new" )
	PUTBACK;
	return;
    }
}


XS_EUPXS(XS_Wx__RichTextStyleComboCtrl_Create); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextStyleComboCtrl_Create)
{
    dVAR; dXSARGS;
    if (items < 2 || items > 6)
       croak_xs_usage(cv,  "THIS, parent, id= wxID_ANY, pos= wxDefaultPosition, size= wxDefaultSize, style= 0");
    {
	wxRichTextStyleComboCtrl *    THIS = (wxRichTextStyleComboCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextStyleComboCtrl" )
;
	bool	RETVAL;
	wxWindow*    parent = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::Window" )
;
	wxWindowID	id;
	wxPoint	pos;
	wxSize	size;
	long	style;

	if (items < 3)
	    id = wxID_ANY;
	else {
    id = wxPli_get_wxwindowid( aTHX_ ST(2) )
;
	}

	if (items < 4)
	    pos = wxDefaultPosition;
	else {
    pos = wxPli_sv_2_wxpoint( aTHX_ ST(3) )
;
	}

	if (items < 5)
	    size = wxDefaultSize;
	else {
    size = wxPli_sv_2_wxsize( aTHX_ ST(4) )
;
	}

	if (items < 6)
	    style = 0;
	else {
	    style = (long)SvIV(ST(5))
;
	}
    try {
      RETVAL = THIS->Create( parent, id, pos, size, style );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__RichTextStyleComboCtrl_UpdateStyles); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextStyleComboCtrl_UpdateStyles)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxRichTextStyleComboCtrl *    THIS = (wxRichTextStyleComboCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextStyleComboCtrl" )
;
    try {
      THIS->UpdateStyles();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__RichTextStyleComboCtrl_SetStyleSheet); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextStyleComboCtrl_SetStyleSheet)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, styleSheet");
    {
	wxRichTextStyleComboCtrl *    THIS = (wxRichTextStyleComboCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextStyleComboCtrl" )
;
	wxRichTextStyleSheet*    styleSheet = (wxRichTextStyleSheet *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::RichTextStyleSheet" )
;
    try {
      THIS->SetStyleSheet( styleSheet );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__RichTextStyleComboCtrl_GetStyleSheet); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextStyleComboCtrl_GetStyleSheet)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxRichTextStyleComboCtrl *    THIS = (wxRichTextStyleComboCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextStyleComboCtrl" )
;
	wxRichTextStyleSheet *	RETVAL;
    try {
      RETVAL = THIS->GetStyleSheet();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_object_2_sv( aTHX_ RETVALSV, RETVAL );
    wxPli_thread_sv_register( aTHX_ "Wx::RichTextStyleSheet", RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    wxPli_object_set_deleteable( aTHX_ ST(0), false );
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__RichTextStyleComboCtrl_SetRichTextCtrl); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextStyleComboCtrl_SetRichTextCtrl)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, ctrl");
    {
	wxRichTextStyleComboCtrl *    THIS = (wxRichTextStyleComboCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextStyleComboCtrl" )
;
	wxRichTextCtrl*    ctrl = (wxRichTextCtrl *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::RichTextCtrl" )
;
    try {
      THIS->SetRichTextCtrl( ctrl );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__RichTextStyleComboCtrl_GetRichTextCtrl); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextStyleComboCtrl_GetRichTextCtrl)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxRichTextStyleComboCtrl *    THIS = (wxRichTextStyleComboCtrl *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextStyleComboCtrl" )
;
	wxRichTextCtrl *	RETVAL;
    try {
      RETVAL = THIS->GetRichTextCtrl();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_evthandler_2_sv( aTHX_ RETVALSV, RETVAL );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}

#endif

/* INCLUDE: Returning to 'RichText.xs' from '/usr/bin/perl -MExtUtils::XSpp::Cmd -e xspp -- -t typemap.xsp -t ../../typemap.xsp XS/RichTextStyleCtrl.xsp' */


/* INCLUDE_COMMAND:  Including output of '/usr/bin/perl -MExtUtils::XSpp::Cmd -e xspp -- -t typemap.xsp -t ../../typemap.xsp XS/RichTextFormattingDialog.xsp' from 'RichText.xs' */

#include <exception>

#undef  xsp_constructor_class
#define xsp_constructor_class(c) (c)
#include <wx/richtext/richtextformatdlg.h>
#include <wx/imaglist.h>
#define wxRICHTEXT_FM_DEFAULT_APPLY_STYLE wxRICHTEXT_SETSTYLE_WITH_UNDO|wxRICHTEXT_SETSTYLE_OPTIMIZE
#undef  xsp_constructor_class
#define xsp_constructor_class(c) (CLASS)

XS_EUPXS(XS_Wx__RichTextFormattingDialog_newDefault); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextFormattingDialog_newDefault)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "CLASS");
    {
	char *	CLASS = (char *)SvPV_nolen(ST(0))
;
	wxRichTextFormattingDialog *	RETVAL;
    try {
      RETVAL = new wxRichTextFormattingDialog();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_object_2_sv( aTHX_ RETVALSV, RETVAL );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}

#undef  xsp_constructor_class
#define xsp_constructor_class(c) (c)
#undef  xsp_constructor_class
#define xsp_constructor_class(c) (CLASS)

XS_EUPXS(XS_Wx__RichTextFormattingDialog_newFull); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextFormattingDialog_newFull)
{
    dVAR; dXSARGS;
    if (items < 3 || items > 8)
       croak_xs_usage(cv,  "CLASS, flags, parent, title= wxT(\"Formatting\"), id= wxID_ANY, pos= wxDefaultPosition, sz= wxDefaultSize, style= wxDEFAULT_DIALOG_STYLE");
    {
	char *	CLASS = (char *)SvPV_nolen(ST(0))
;
	wxRichTextFormattingDialog *	RETVAL;
	long	flags = (long)SvIV(ST(1))
;
	wxWindow*    parent = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(2), "Wx::Window" )
;
	wxString	title;
	wxWindowID	id;
	wxPoint	pos;
	wxSize	sz;
	long	style;

	if (items < 4)
	    title = wxT("Formatting");
	else {
    WXSTRING_INPUT( title, wxString, ST(3) )
;
	}

	if (items < 5)
	    id = wxID_ANY;
	else {
    id = wxPli_get_wxwindowid( aTHX_ ST(4) )
;
	}

	if (items < 6)
	    pos = wxDefaultPosition;
	else {
    pos = wxPli_sv_2_wxpoint( aTHX_ ST(5) )
;
	}

	if (items < 7)
	    sz = wxDefaultSize;
	else {
    sz = wxPli_sv_2_wxsize( aTHX_ ST(6) )
;
	}

	if (items < 8)
	    style = wxDEFAULT_DIALOG_STYLE;
	else {
	    style = (long)SvIV(ST(7))
;
	}
    try {
      RETVAL = new wxRichTextFormattingDialog( flags, parent, title, id, pos, sz, style );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_object_2_sv( aTHX_ RETVALSV, RETVAL );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}

#undef  xsp_constructor_class
#define xsp_constructor_class(c) (c)

XS_EUPXS(XS_Wx__RichTextFormattingDialog_new); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextFormattingDialog_new)
{
    dVAR; dXSARGS;
    if (items < 1)
       croak_xs_usage(cv,  "CLASS, ...");
    PERL_UNUSED_VAR(ax); /* -Wall */
    SP -= items;
    {
	char *	CLASS = (char *)SvPV_nolen(ST(0))
;
    BEGIN_OVERLOAD()
        MATCH_VOIDM_REDISP( newDefault )
        MATCH_ANY_REDISP( newFull )
    END_OVERLOAD( "Wx::RichTextFormattingDialog::new" )
	PUTBACK;
	return;
    }
}


XS_EUPXS(XS_Wx__RichTextFormattingDialog_Create); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextFormattingDialog_Create)
{
    dVAR; dXSARGS;
    if (items < 3 || items > 8)
       croak_xs_usage(cv,  "THIS, flags, parent, title= wxT(\"Formatting\"), id= wxID_ANY, pos= wxDefaultPosition, sz= wxDefaultSize, style= wxDEFAULT_DIALOG_STYLE");
    {
	wxRichTextFormattingDialog *    THIS = (wxRichTextFormattingDialog *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextFormattingDialog" )
;
	bool	RETVAL;
	long	flags = (long)SvIV(ST(1))
;
	wxWindow*    parent = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(2), "Wx::Window" )
;
	wxString	title;
	wxWindowID	id;
	wxPoint	pos;
	wxSize	sz;
	long	style;

	if (items < 4)
	    title = wxT("Formatting");
	else {
    WXSTRING_INPUT( title, wxString, ST(3) )
;
	}

	if (items < 5)
	    id = wxID_ANY;
	else {
    id = wxPli_get_wxwindowid( aTHX_ ST(4) )
;
	}

	if (items < 6)
	    pos = wxDefaultPosition;
	else {
    pos = wxPli_sv_2_wxpoint( aTHX_ ST(5) )
;
	}

	if (items < 7)
	    sz = wxDefaultSize;
	else {
    sz = wxPli_sv_2_wxsize( aTHX_ ST(6) )
;
	}

	if (items < 8)
	    style = wxDEFAULT_DIALOG_STYLE;
	else {
	    style = (long)SvIV(ST(7))
;
	}
    try {
      RETVAL = THIS->Create( flags, parent, title, id, pos, sz, style );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__RichTextFormattingDialog_GetStyle); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextFormattingDialog_GetStyle)
{
    dVAR; dXSARGS;
    if (items != 3)
       croak_xs_usage(cv,  "THIS, ctrl, range");
    {
	wxRichTextFormattingDialog *    THIS = (wxRichTextFormattingDialog *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextFormattingDialog" )
;
	bool	RETVAL;
	wxRichTextCtrl*    ctrl = (wxRichTextCtrl *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::RichTextCtrl" )
;
	wxRichTextRange*    range = (wxRichTextRange *) wxPli_sv_2_object( aTHX_ ST(2), "Wx::RichTextRange" )
;
    try {
      RETVAL = THIS->GetStyle( ctrl, *( range ) );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__RichTextFormattingDialog_SetStyle); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextFormattingDialog_SetStyle)
{
    dVAR; dXSARGS;
    if (items < 2 || items > 3)
       croak_xs_usage(cv,  "THIS, style, update= true");
    {
	wxRichTextFormattingDialog *    THIS = (wxRichTextFormattingDialog *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextFormattingDialog" )
;
	bool	RETVAL;
	wxTextAttrEx*    style = (wxTextAttrEx *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::TextAttrEx" )
;
	bool	update;

	if (items < 3)
	    update = true;
	else {
	    update = (bool)SvTRUE(ST(2))
;
	}
    try {
      RETVAL = THIS->SetStyle( *( style ), update );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__RichTextFormattingDialog_SetStyleDefinition); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextFormattingDialog_SetStyleDefinition)
{
    dVAR; dXSARGS;
    if (items < 3 || items > 4)
       croak_xs_usage(cv,  "THIS, styleDef, sheet, update= true");
    {
	wxRichTextFormattingDialog *    THIS = (wxRichTextFormattingDialog *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextFormattingDialog" )
;
	bool	RETVAL;
	wxRichTextStyleDefinition*    styleDef = (wxRichTextStyleDefinition *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::RichTextStyleDefinition" )
;
	wxRichTextStyleSheet*    sheet = (wxRichTextStyleSheet *) wxPli_sv_2_object( aTHX_ ST(2), "Wx::RichTextStyleSheet" )
;
	bool	update;

	if (items < 4)
	    update = true;
	else {
	    update = (bool)SvTRUE(ST(3))
;
	}
    try {
      RETVAL = THIS->SetStyleDefinition( *( styleDef ), sheet, update );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__RichTextFormattingDialog_GetStyleDefinition); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextFormattingDialog_GetStyleDefinition)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxRichTextFormattingDialog *    THIS = (wxRichTextFormattingDialog *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextFormattingDialog" )
;
	wxRichTextStyleDefinition *	RETVAL;
    try {
      RETVAL = THIS->GetStyleDefinition();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_object_2_sv( aTHX_ RETVALSV, RETVAL );
    wxPli_thread_sv_register( aTHX_ "Wx::RichTextStyleDefinition", RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    wxPli_object_set_deleteable( aTHX_ ST(0), false );
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__RichTextFormattingDialog_GetDialogStyleDefinition); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextFormattingDialog_GetDialogStyleDefinition)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, win");
    {
	wxRichTextFormattingDialog *    THIS = (wxRichTextFormattingDialog *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextFormattingDialog" )
;
	wxRichTextStyleDefinition *	RETVAL;
	wxWindow*    win = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::Window" )
;
    try {
      RETVAL = THIS->GetDialogStyleDefinition( win );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_object_2_sv( aTHX_ RETVALSV, RETVAL );
    wxPli_thread_sv_register( aTHX_ "Wx::RichTextStyleDefinition", RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    wxPli_object_set_deleteable( aTHX_ ST(0), false );
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__RichTextFormattingDialog_GetStyleSheet); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextFormattingDialog_GetStyleSheet)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxRichTextFormattingDialog *    THIS = (wxRichTextFormattingDialog *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextFormattingDialog" )
;
	wxRichTextStyleSheet *	RETVAL;
    try {
      RETVAL = THIS->GetStyleSheet();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_object_2_sv( aTHX_ RETVALSV, RETVAL );
    wxPli_thread_sv_register( aTHX_ "Wx::RichTextStyleSheet", RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    wxPli_object_set_deleteable( aTHX_ ST(0), false );
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__RichTextFormattingDialog_UpdateDisplay); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextFormattingDialog_UpdateDisplay)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxRichTextFormattingDialog *    THIS = (wxRichTextFormattingDialog *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextFormattingDialog" )
;
	bool	RETVAL;
    try {
      RETVAL = THIS->UpdateDisplay();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__RichTextFormattingDialog_ApplyStyle); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextFormattingDialog_ApplyStyle)
{
    dVAR; dXSARGS;
    if (items < 3 || items > 4)
       croak_xs_usage(cv,  "THIS, ctrl, range, flags= wxRICHTEXT_FM_DEFAULT_APPLY_STYLE");
    {
	wxRichTextFormattingDialog *    THIS = (wxRichTextFormattingDialog *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextFormattingDialog" )
;
	bool	RETVAL;
	wxRichTextCtrl*    ctrl = (wxRichTextCtrl *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::RichTextCtrl" )
;
	wxRichTextRange*    range = (wxRichTextRange *) wxPli_sv_2_object( aTHX_ ST(2), "Wx::RichTextRange" )
;
	int	flags;

	if (items < 4)
	    flags = wxRICHTEXT_FM_DEFAULT_APPLY_STYLE;
	else {
	    flags = (int)SvIV(ST(3))
;
	}
    try {
      RETVAL = THIS->ApplyStyle( ctrl, *( range ), flags );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__RichTextFormattingDialog_GetAttributes); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextFormattingDialog_GetAttributes)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxRichTextFormattingDialog *    THIS = (wxRichTextFormattingDialog *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextFormattingDialog" )
;
	wxTextAttrEx *	RETVAL;
    try {
      RETVAL = new wxTextAttrEx( THIS->GetAttributes() );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_non_object_2_sv( aTHX_ RETVALSV, RETVAL, "Wx::TextAttrEx" );
    wxPli_thread_sv_register( aTHX_ "Wx::TextAttrEx", RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__RichTextFormattingDialog_SetAttributes); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextFormattingDialog_SetAttributes)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, attr");
    {
	wxRichTextFormattingDialog *    THIS = (wxRichTextFormattingDialog *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextFormattingDialog" )
;
	wxTextAttrEx*    attr = (wxTextAttrEx *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::TextAttrEx" )
;
    try {
      THIS->SetAttributes( *( attr ) );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__RichTextFormattingDialog_SetImageList); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextFormattingDialog_SetImageList)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, imageList");
    {
	wxRichTextFormattingDialog *    THIS = (wxRichTextFormattingDialog *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextFormattingDialog" )
;
	wxImageList*    imageList = (wxImageList *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::ImageList" )
;
    try {
      THIS->SetImageList( imageList );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__RichTextFormattingDialog_GetImageList); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextFormattingDialog_GetImageList)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxRichTextFormattingDialog *    THIS = (wxRichTextFormattingDialog *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextFormattingDialog" )
;
	wxImageList *	RETVAL;
    try {
      RETVAL = THIS->GetImageList();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_object_2_sv( aTHX_ RETVALSV, RETVAL );
    wxPli_thread_sv_register( aTHX_ "Wx::ImageList", RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__RichTextFormattingDialog_ShowToolTips); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextFormattingDialog_ShowToolTips)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	bool	RETVAL;
    RETVAL = wxRichTextFormattingDialog::ShowToolTips();
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__RichTextFormattingDialog_SetShowToolTips); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextFormattingDialog_SetShowToolTips)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "show");
    {
	bool	show = (bool)SvTRUE(ST(0))
;
    wxRichTextFormattingDialog::SetShowToolTips( show );
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__RichTextFormattingDialog_AddPageId); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextFormattingDialog_AddPageId)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, id");
    {
	wxRichTextFormattingDialog *    THIS = (wxRichTextFormattingDialog *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextFormattingDialog" )
;
	int	id = (int)SvIV(ST(1))
;
    try {
      THIS->AddPageId( id );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


/* INCLUDE: Returning to 'RichText.xs' from '/usr/bin/perl -MExtUtils::XSpp::Cmd -e xspp -- -t typemap.xsp -t ../../typemap.xsp XS/RichTextFormattingDialog.xsp' */


/* INCLUDE_COMMAND:  Including output of '/usr/bin/perl -MExtUtils::XSpp::Cmd -e xspp -- -t typemap.xsp -t ../../typemap.xsp XS/RichTextFileHandler.xsp' from 'RichText.xs' */

#include <exception>

#undef  xsp_constructor_class
#define xsp_constructor_class(c) (c)
#include <wx/event.h>
#include <wx/richtext/richtextbuffer.h>
#include "xspp/filehandler.h"

XS_EUPXS(XS_Wx__RichTextFileHandler_CanHandle); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextFileHandler_CanHandle)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, filename");
    {
	wxRichTextFileHandler *    THIS = (wxRichTextFileHandler *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextFileHandler" )
;
	bool	RETVAL;
	wxString	filename;

    WXSTRING_INPUT( filename, wxString, ST(1) )
;
    try {
      RETVAL = THIS->CanHandle( filename );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__RichTextFileHandler_CanLoad); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextFileHandler_CanLoad)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxRichTextFileHandler *    THIS = (wxRichTextFileHandler *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextFileHandler" )
;
	bool	RETVAL;
    try {
      RETVAL = THIS->CanLoad();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__RichTextFileHandler_CanSave); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextFileHandler_CanSave)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxRichTextFileHandler *    THIS = (wxRichTextFileHandler *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextFileHandler" )
;
	bool	RETVAL;
    try {
      RETVAL = THIS->CanSave();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__RichTextFileHandler_LoadFile); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextFileHandler_LoadFile)
{
    dVAR; dXSARGS;
    if (items != 3)
       croak_xs_usage(cv,  "THIS, buffer, fh");
    {
	wxRichTextFileHandler *    THIS = (wxRichTextFileHandler *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextFileHandler" )
;
	bool	RETVAL;
	wxRichTextBuffer*    buffer = (wxRichTextBuffer *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::RichTextBuffer" )
;
	SV*	fh = ST(2)
;
     wxInputStream* stream = wxPliInputStream_ctor( fh );
                RETVAL = THIS->LoadFile( buffer, *stream );
                delete stream;
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__RichTextFileHandler_SaveFile); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextFileHandler_SaveFile)
{
    dVAR; dXSARGS;
    if (items != 3)
       croak_xs_usage(cv,  "THIS, buffer, fh");
    {
	wxRichTextFileHandler *    THIS = (wxRichTextFileHandler *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextFileHandler" )
;
	bool	RETVAL;
	wxRichTextBuffer*    buffer = (wxRichTextBuffer *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::RichTextBuffer" )
;
	SV*	fh = ST(2)
;
     wxOutputStream* stream = wxPliOutputStream_ctor( fh );
                RETVAL = THIS->SaveFile( buffer, *stream );
                delete stream;
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__RichTextFileHandler_SetName); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextFileHandler_SetName)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, name");
    {
	wxRichTextFileHandler *    THIS = (wxRichTextFileHandler *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextFileHandler" )
;
	wxString	name;

    WXSTRING_INPUT( name, wxString, ST(1) )
;
    try {
      THIS->SetName( name );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__RichTextFileHandler_GetName); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextFileHandler_GetName)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxRichTextFileHandler *    THIS = (wxRichTextFileHandler *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextFileHandler" )
;
	wxString	RETVAL;
    try {
      RETVAL = THIS->GetName();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    WXSTRING_OUTPUT( RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__RichTextFileHandler_SetExtension); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextFileHandler_SetExtension)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, ext");
    {
	wxRichTextFileHandler *    THIS = (wxRichTextFileHandler *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextFileHandler" )
;
	wxString	ext;

    WXSTRING_INPUT( ext, wxString, ST(1) )
;
    try {
      THIS->SetExtension( ext );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__RichTextFileHandler_GetExtension); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextFileHandler_GetExtension)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxRichTextFileHandler *    THIS = (wxRichTextFileHandler *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextFileHandler" )
;
	wxString	RETVAL;
    try {
      RETVAL = THIS->GetExtension();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    WXSTRING_OUTPUT( RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__RichTextFileHandler_SetType); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextFileHandler_SetType)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, type");
    {
	wxRichTextFileHandler *    THIS = (wxRichTextFileHandler *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextFileHandler" )
;
	int	type = (int)SvIV(ST(1))
;
    try {
      THIS->SetType( type );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__RichTextFileHandler_GetType); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextFileHandler_GetType)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxRichTextFileHandler *    THIS = (wxRichTextFileHandler *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextFileHandler" )
;
	int	RETVAL;
	dXSTARG;
    try {
      RETVAL = THIS->GetType();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__RichTextFileHandler_SetEncoding); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextFileHandler_SetEncoding)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, encoding");
    {
	wxRichTextFileHandler *    THIS = (wxRichTextFileHandler *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextFileHandler" )
;
	wxString	encoding;

    WXSTRING_INPUT( encoding, wxString, ST(1) )
;
    try {
      THIS->SetEncoding( encoding );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__RichTextFileHandler_GetEncoding); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextFileHandler_GetEncoding)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxRichTextFileHandler *    THIS = (wxRichTextFileHandler *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextFileHandler" )
;
	wxString	RETVAL;
    try {
      RETVAL = THIS->GetEncoding();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    WXSTRING_OUTPUT( RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__RichTextFileHandler_IsVisible); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextFileHandler_IsVisible)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxRichTextFileHandler *    THIS = (wxRichTextFileHandler *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextFileHandler" )
;
	bool	RETVAL;
    try {
      RETVAL = THIS->IsVisible();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__RichTextFileHandler_SetVisible); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextFileHandler_SetVisible)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, visible");
    {
	wxRichTextFileHandler *    THIS = (wxRichTextFileHandler *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextFileHandler" )
;
	bool	visible = (bool)SvTRUE(ST(1))
;
    try {
      THIS->SetVisible( visible );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}

#undef  xsp_constructor_class
#define xsp_constructor_class(c) (CLASS)

XS_EUPXS(XS_Wx__PlRichTextFileHandler_new); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__PlRichTextFileHandler_new)
{
    dVAR; dXSARGS;
    if (items < 1 || items > 4)
       croak_xs_usage(cv,  "CLASS, name= wxEmptyString, ext= wxEmptyString, type= 0");
    {
	char *	CLASS = (char *)SvPV_nolen(ST(0))
;
	wxPlRichTextFileHandler *	RETVAL;
	wxString	name;
	wxString	ext;
	int	type;

	if (items < 2)
	    name = wxEmptyString;
	else {
    WXSTRING_INPUT( name, wxString, ST(1) )
;
	}

	if (items < 3)
	    ext = wxEmptyString;
	else {
    WXSTRING_INPUT( ext, wxString, ST(2) )
;
	}

	if (items < 4)
	    type = 0;
	else {
	    type = (int)SvIV(ST(3))
;
	}
     RETVAL = new wxPlRichTextFileHandler( CLASS, name, ext, type );
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_object_2_sv( aTHX_ RETVALSV, RETVAL );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}

#undef  xsp_constructor_class
#define xsp_constructor_class(c) (c)

XS_EUPXS(XS_Wx__PlRichTextFileHandler_CanHandle); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__PlRichTextFileHandler_CanHandle)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, filename");
    {
	wxPlRichTextFileHandler *    THIS = (wxPlRichTextFileHandler *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::PlRichTextFileHandler" )
;
	bool	RETVAL;
	wxString	filename;

    WXSTRING_INPUT( filename, wxString, ST(1) )
;
    try {
      RETVAL = THIS->base_CanHandle( filename );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__PlRichTextFileHandler_CanLoad); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__PlRichTextFileHandler_CanLoad)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxPlRichTextFileHandler *    THIS = (wxPlRichTextFileHandler *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::PlRichTextFileHandler" )
;
	bool	RETVAL;
    try {
      RETVAL = THIS->base_CanLoad();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__PlRichTextFileHandler_CanSave); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__PlRichTextFileHandler_CanSave)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxPlRichTextFileHandler *    THIS = (wxPlRichTextFileHandler *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::PlRichTextFileHandler" )
;
	bool	RETVAL;
    try {
      RETVAL = THIS->base_CanSave();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}

#include <wx/richtext/richtextxml.h>
#undef  xsp_constructor_class
#define xsp_constructor_class(c) (CLASS)

XS_EUPXS(XS_Wx__RichTextXMLHandler_new); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextXMLHandler_new)
{
    dVAR; dXSARGS;
    if (items < 1 || items > 4)
       croak_xs_usage(cv,  "CLASS, name= wxT(\"XML\"), ext= wxT(\"xml\"), type= wxRICHTEXT_TYPE_XML");
    {
	char *	CLASS = (char *)SvPV_nolen(ST(0))
;
	wxRichTextXMLHandler *	RETVAL;
	wxString	name;
	wxString	ext;
	int	type;

	if (items < 2)
	    name = wxT("XML");
	else {
    WXSTRING_INPUT( name, wxString, ST(1) )
;
	}

	if (items < 3)
	    ext = wxT("xml");
	else {
    WXSTRING_INPUT( ext, wxString, ST(2) )
;
	}

	if (items < 4)
	    type = wxRICHTEXT_TYPE_XML;
	else {
	    type = (int)SvIV(ST(3))
;
	}
    try {
      RETVAL = new wxRichTextXMLHandler( name, ext, type );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_object_2_sv( aTHX_ RETVALSV, RETVAL );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}

#undef  xsp_constructor_class
#define xsp_constructor_class(c) (c)
#if WXPERL_W_VERSION_GE( 2, 8, 3 )
#define XSpp_1b37851a_067478
#include <wx/richtext/richtexthtml.h>
#undef  xsp_constructor_class
#define xsp_constructor_class(c) (CLASS)
#define XSubPPtmpAACT 1


XS_EUPXS(XS_Wx__RichTextHTMLHandler_new); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextHTMLHandler_new)
{
    dVAR; dXSARGS;
    if (items < 1 || items > 4)
       croak_xs_usage(cv,  "CLASS, name= wxT(\"HTML\"), ext= wxT(\"html\"), type= wxRICHTEXT_TYPE_HTML");
    {
	char *	CLASS = (char *)SvPV_nolen(ST(0))
;
	wxRichTextHTMLHandler *	RETVAL;
	wxString	name;
	wxString	ext;
	int	type;

	if (items < 2)
	    name = wxT("HTML");
	else {
    WXSTRING_INPUT( name, wxString, ST(1) )
;
	}

	if (items < 3)
	    ext = wxT("html");
	else {
    WXSTRING_INPUT( ext, wxString, ST(2) )
;
	}

	if (items < 4)
	    type = wxRICHTEXT_TYPE_HTML;
	else {
	    type = (int)SvIV(ST(3))
;
	}
    try {
      RETVAL = new wxRichTextHTMLHandler( name, ext, type );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_object_2_sv( aTHX_ RETVALSV, RETVAL );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}

#undef  xsp_constructor_class
#define xsp_constructor_class(c) (c)

XS_EUPXS(XS_Wx__RichTextHTMLHandler_ClearTemporaryImageLocations); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextHTMLHandler_ClearTemporaryImageLocations)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxRichTextHTMLHandler *    THIS = (wxRichTextHTMLHandler *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextHTMLHandler" )
;
    try {
      THIS->ClearTemporaryImageLocations();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__RichTextHTMLHandler_DeleteTemporaryImages); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextHTMLHandler_DeleteTemporaryImages)
{
    dVAR; dXSARGS;
    if (items < 1)
       croak_xs_usage(cv,  "THIS, ...");
    if (items == 2)
    {
	wxRichTextHTMLHandler *    THIS = (wxRichTextHTMLHandler *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextHTMLHandler" )
;
	bool	RETVAL;
      int flags = SvIV( ST(1) );
      wxArrayString imageLocations;
      wxPli_av_2_arraystring( aTHX_ ST(2), &imageLocations );
      RETVAL = THIS->DeleteTemporaryImages( flags, imageLocations );
	ST(0) = boolSV(RETVAL);
    }
    else
    {
	wxRichTextHTMLHandler *    THIS = (wxRichTextHTMLHandler *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextHTMLHandler" )
;
	bool	RETVAL;
      RETVAL = THIS->DeleteTemporaryImages();
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__RichTextHTMLHandler_GetFontSizeMapping); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextHTMLHandler_GetFontSizeMapping)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    PERL_UNUSED_VAR(ax); /* -Wall */
    SP -= items;
    {
	wxRichTextHTMLHandler *    THIS = (wxRichTextHTMLHandler *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextHTMLHandler" )
;
    PUTBACK;
    wxPli_intarray_push( aTHX_ THIS->GetFontSizeMapping() );
    SPAGAIN;
	PUTBACK;
	return;
    }
}


XS_EUPXS(XS_Wx__RichTextHTMLHandler_GetTemporaryImageLocations); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextHTMLHandler_GetTemporaryImageLocations)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    PERL_UNUSED_VAR(ax); /* -Wall */
    SP -= items;
    {
	wxRichTextHTMLHandler *    THIS = (wxRichTextHTMLHandler *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextHTMLHandler" )
;
    PUTBACK;
    wxPli_stringarray_push( aTHX_ THIS->GetTemporaryImageLocations() );
    SPAGAIN;
	PUTBACK;
	return;
    }
}


XS_EUPXS(XS_Wx__RichTextHTMLHandler_GetTempDir); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextHTMLHandler_GetTempDir)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxRichTextHTMLHandler *    THIS = (wxRichTextHTMLHandler *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextHTMLHandler" )
;
	wxString	RETVAL;
    try {
      RETVAL = THIS->GetTempDir();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    WXSTRING_OUTPUT( RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__RichTextHTMLHandler_SetFileCounter); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextHTMLHandler_SetFileCounter)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, counter");
    {
	wxRichTextHTMLHandler *    THIS = (wxRichTextHTMLHandler *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextHTMLHandler" )
;
	int	counter = (int)SvIV(ST(1))
;
    try {
      THIS->SetFileCounter( counter );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__RichTextHTMLHandler_SetFontSizeMapping); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextHTMLHandler_SetFontSizeMapping)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, fontSizeMapping");
    {
	wxRichTextHTMLHandler *    THIS = (wxRichTextHTMLHandler *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextHTMLHandler" )
;
	wxArrayInt	fontSizeMapping;

    wxPli_av_2_arrayint( aTHX_ ST(1), & fontSizeMapping )
;
    try {
      THIS->SetFontSizeMapping( fontSizeMapping );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__RichTextHTMLHandler_SetTempDir); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextHTMLHandler_SetTempDir)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, tempDir");
    {
	wxRichTextHTMLHandler *    THIS = (wxRichTextHTMLHandler *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextHTMLHandler" )
;
	wxString	tempDir;

    WXSTRING_INPUT( tempDir, wxString, ST(1) )
;
    try {
      THIS->SetTempDir( tempDir );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__RichTextHTMLHandler_SetTemporaryImageLocations); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextHTMLHandler_SetTemporaryImageLocations)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, locations");
    {
	wxRichTextHTMLHandler *    THIS = (wxRichTextHTMLHandler *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextHTMLHandler" )
;
	wxArrayString	locations;

    wxPli_av_2_arraystring( aTHX_ ST(1), & locations )
;
    try {
      THIS->SetTemporaryImageLocations( locations );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}

#endif

/* INCLUDE: Returning to 'RichText.xs' from '/usr/bin/perl -MExtUtils::XSpp::Cmd -e xspp -- -t typemap.xsp -t ../../typemap.xsp XS/RichTextFileHandler.xsp' */


/* INCLUDE_COMMAND:  Including output of '/usr/bin/perl -I../.. -MExtUtils::XSpp::Cmd -e xspp -- -t typemap.xsp -t ../../typemap.xsp XS/RichTextBuffer.xsp' from 'RichText.xs' */

#include <exception>

#undef  xsp_constructor_class
#define xsp_constructor_class(c) (c)
#include <wx/event.h>
#include <wx/richtext/richtextbuffer.h>

XS_EUPXS(XS_Wx__RichTextBuffer_CLONE); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextBuffer_CLONE)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "CLASS");
    {
	char *	CLASS = (char *)SvPV_nolen(ST(0))
;
    wxPli_thread_sv_clone( aTHX_ CLASS, (wxPliCloneSV)wxPli_detach_object );
    }
    XSRETURN_EMPTY;
}

#undef  xsp_constructor_class
#define xsp_constructor_class(c) (CLASS)

XS_EUPXS(XS_Wx__RichTextBuffer_new); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextBuffer_new)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "CLASS, obj");
    {
	char *	CLASS = (char *)SvPV_nolen(ST(0))
;
	wxRichTextBuffer *	RETVAL;
	wxRichTextBuffer*    obj = (wxRichTextBuffer *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::RichTextBuffer" )
;
    try {
      RETVAL = new wxRichTextBuffer( *( obj ) );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_object_2_sv( aTHX_ RETVALSV, RETVAL );
    wxPli_thread_sv_register( aTHX_ "Wx::RichTextBuffer", RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}

#undef  xsp_constructor_class
#define xsp_constructor_class(c) (c)

XS_EUPXS(XS_Wx__RichTextBuffer_Destroy); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextBuffer_Destroy)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxRichTextBuffer *    THIS = (wxRichTextBuffer *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextBuffer" )
;
      wxPli_thread_sv_unregister( aTHX_ "Wx::RichTextBuffer", THIS, ST(0) );
             if( wxPli_object_is_deleteable( aTHX_ ST(0) ) )
                 delete THIS;
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__RichTextBuffer_ResetAndClearCommands); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextBuffer_ResetAndClearCommands)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxRichTextBuffer *    THIS = (wxRichTextBuffer *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextBuffer" )
;
    try {
      THIS->ResetAndClearCommands();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__RichTextBuffer_AddEventHandler); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextBuffer_AddEventHandler)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, handler");
    {
	wxRichTextBuffer *    THIS = (wxRichTextBuffer *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextBuffer" )
;
	bool	RETVAL;
	wxEvtHandler*    handler = (wxEvtHandler *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::EvtHandler" )
;
    try {
      RETVAL = THIS->AddEventHandler( handler );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__RichTextBuffer_AddHandler); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextBuffer_AddHandler)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, handler");
    {
	wxRichTextBuffer *    THIS = (wxRichTextBuffer *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextBuffer" )
;
	wxRichTextFileHandler*    handler = (wxRichTextFileHandler *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::RichTextFileHandler" )
;
    try {
      THIS->AddHandler( handler );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}

#if WXPERL_W_VERSION_GE( 2, 7, 1 )
#define XSpp_36f656d1_050843
#define XSubPPtmpAACU 1


XS_EUPXS(XS_Wx__RichTextBuffer_SetStyleEx); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextBuffer_SetStyleEx)
{
    dVAR; dXSARGS;
    if (items < 3 || items > 4)
       croak_xs_usage(cv,  "THIS, range, style, flags= wxRICHTEXT_SETSTYLE_WITH_UNDO");
    {
	wxRichTextBuffer *    THIS = (wxRichTextBuffer *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextBuffer" )
;
	bool	RETVAL;
	wxRichTextRange*    range = (wxRichTextRange *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::RichTextRange" )
;
	wxTextAttrEx*    style = (wxTextAttrEx *) wxPli_sv_2_object( aTHX_ ST(2), "Wx::TextAttrEx" )
;
	int	flags;

	if (items < 4)
	    flags = wxRICHTEXT_SETSTYLE_WITH_UNDO;
	else {
	    flags = (int)SvIV(ST(3))
;
	}
    try {
      RETVAL = THIS->SetStyle( *( range ), *( style ), flags );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__RichTextBuffer_SetStyleRich); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextBuffer_SetStyleRich)
{
    dVAR; dXSARGS;
    if (items < 3 || items > 4)
       croak_xs_usage(cv,  "THIS, range, style, flags= wxRICHTEXT_SETSTYLE_WITH_UNDO");
    {
	wxRichTextBuffer *    THIS = (wxRichTextBuffer *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextBuffer" )
;
	bool	RETVAL;
	wxRichTextRange*    range = (wxRichTextRange *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::RichTextRange" )
;
	wxRichTextAttr*    style = (wxRichTextAttr *) wxPli_sv_2_object( aTHX_ ST(2), "Wx::RichTextAttr" )
;
	int	flags;

	if (items < 4)
	    flags = wxRICHTEXT_SETSTYLE_WITH_UNDO;
	else {
	    flags = (int)SvIV(ST(3))
;
	}
    try {
      RETVAL = THIS->SetStyle( *( range ), *( style ), flags );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__RichTextBuffer_SetStyle); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextBuffer_SetStyle)
{
    dVAR; dXSARGS;
    if (items < 1)
       croak_xs_usage(cv,  "THIS, ...");
    PERL_UNUSED_VAR(ax); /* -Wall */
    SP -= items;
    {
	wxRichTextBuffer *    THIS = (wxRichTextBuffer *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextBuffer" )
;
    BEGIN_OVERLOAD()
        MATCH_REDISP_COUNT_ALLOWMORE( wxPliOvl_wrtr_wrta_n, SetStyleRich, 2 )
        MATCH_REDISP_COUNT_ALLOWMORE( wxPliOvl_wrtr_wtae_n, SetStyleEx, 2 )
    END_OVERLOAD( "Wx::RichTextBuffer::SetStyle" )
	PUTBACK;
	return;
    }
}

#endif

XS_EUPXS(XS_Wx__RichTextBuffer_InsertTextWithUndo); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextBuffer_InsertTextWithUndo)
{
    dVAR; dXSARGS;
    if (items < 4 || items > 5)
       croak_xs_usage(cv,  "THIS, pos, text, ctrl, flags= 0");
    {
	wxRichTextBuffer *    THIS = (wxRichTextBuffer *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextBuffer" )
;
	bool	RETVAL;
	long	pos = (long)SvIV(ST(1))
;
	wxString	text;
	wxRichTextCtrl*    ctrl = (wxRichTextCtrl *) wxPli_sv_2_object( aTHX_ ST(3), "Wx::RichTextCtrl" )
;
	int	flags;

    WXSTRING_INPUT( text, wxString, ST(2) )
;

	if (items < 5)
	    flags = 0;
	else {
	    flags = (int)SvIV(ST(4))
;
	}
    try {
      RETVAL = THIS->InsertTextWithUndo( pos, text, ctrl, flags );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__RichTextBuffer_InsertNewlineWithUndo); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextBuffer_InsertNewlineWithUndo)
{
    dVAR; dXSARGS;
    if (items < 3 || items > 4)
       croak_xs_usage(cv,  "THIS, pos, ctrl, flags= 0");
    {
	wxRichTextBuffer *    THIS = (wxRichTextBuffer *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextBuffer" )
;
	bool	RETVAL;
	long	pos = (long)SvIV(ST(1))
;
	wxRichTextCtrl*    ctrl = (wxRichTextCtrl *) wxPli_sv_2_object( aTHX_ ST(2), "Wx::RichTextCtrl" )
;
	int	flags;

	if (items < 4)
	    flags = 0;
	else {
	    flags = (int)SvIV(ST(3))
;
	}
    try {
      RETVAL = THIS->InsertNewlineWithUndo( pos, ctrl, flags );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__RichTextBuffer_GetBasicStyle); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextBuffer_GetBasicStyle)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxRichTextBuffer *    THIS = (wxRichTextBuffer *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextBuffer" )
;
	wxTextAttrEx *	RETVAL;
    try {
      RETVAL = new wxTextAttrEx( THIS->GetBasicStyle() );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_non_object_2_sv( aTHX_ RETVALSV, RETVAL, "Wx::TextAttrEx" );
    wxPli_thread_sv_register( aTHX_ "Wx::TextAttrEx", RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__RichTextBuffer_GetDefaultStyle); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextBuffer_GetDefaultStyle)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxRichTextBuffer *    THIS = (wxRichTextBuffer *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextBuffer" )
;
	wxTextAttrEx *	RETVAL;
    try {
      RETVAL = new wxTextAttrEx( THIS->GetDefaultStyle() );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_non_object_2_sv( aTHX_ RETVALSV, RETVAL, "Wx::TextAttrEx" );
    wxPli_thread_sv_register( aTHX_ "Wx::TextAttrEx", RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__RichTextBuffer_BeginStyle); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextBuffer_BeginStyle)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, style");
    {
	wxRichTextBuffer *    THIS = (wxRichTextBuffer *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextBuffer" )
;
	bool	RETVAL;
	wxTextAttrEx*    style = (wxTextAttrEx *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::TextAttrEx" )
;
    try {
      RETVAL = THIS->BeginStyle( *( style ) );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__RichTextBuffer_EndStyle); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextBuffer_EndStyle)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxRichTextBuffer *    THIS = (wxRichTextBuffer *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextBuffer" )
;
	bool	RETVAL;
    try {
      RETVAL = THIS->EndStyle();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__RichTextBuffer_EndAllStyles); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextBuffer_EndAllStyles)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxRichTextBuffer *    THIS = (wxRichTextBuffer *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextBuffer" )
;
	bool	RETVAL;
    try {
      RETVAL = THIS->EndAllStyles();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__RichTextBuffer_BeginBold); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextBuffer_BeginBold)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxRichTextBuffer *    THIS = (wxRichTextBuffer *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextBuffer" )
;
	bool	RETVAL;
    try {
      RETVAL = THIS->BeginBold();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__RichTextBuffer_EndBold); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextBuffer_EndBold)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxRichTextBuffer *    THIS = (wxRichTextBuffer *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextBuffer" )
;
	bool	RETVAL;
    try {
      RETVAL = THIS->EndBold();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__RichTextBuffer_BeginItalic); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextBuffer_BeginItalic)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxRichTextBuffer *    THIS = (wxRichTextBuffer *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextBuffer" )
;
	bool	RETVAL;
    try {
      RETVAL = THIS->BeginItalic();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__RichTextBuffer_EndItalic); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextBuffer_EndItalic)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxRichTextBuffer *    THIS = (wxRichTextBuffer *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextBuffer" )
;
	bool	RETVAL;
    try {
      RETVAL = THIS->EndItalic();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__RichTextBuffer_BeginUnderline); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextBuffer_BeginUnderline)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxRichTextBuffer *    THIS = (wxRichTextBuffer *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextBuffer" )
;
	bool	RETVAL;
    try {
      RETVAL = THIS->BeginUnderline();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__RichTextBuffer_EndUnderline); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextBuffer_EndUnderline)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxRichTextBuffer *    THIS = (wxRichTextBuffer *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextBuffer" )
;
	bool	RETVAL;
    try {
      RETVAL = THIS->EndUnderline();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__RichTextBuffer_BeginFontSize); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextBuffer_BeginFontSize)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, pointSize");
    {
	wxRichTextBuffer *    THIS = (wxRichTextBuffer *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextBuffer" )
;
	bool	RETVAL;
	int	pointSize = (int)SvIV(ST(1))
;
    try {
      RETVAL = THIS->BeginFontSize( pointSize );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__RichTextBuffer_EndFontSize); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextBuffer_EndFontSize)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxRichTextBuffer *    THIS = (wxRichTextBuffer *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextBuffer" )
;
	bool	RETVAL;
    try {
      RETVAL = THIS->EndFontSize();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__RichTextBuffer_BeginFont); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextBuffer_BeginFont)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, font");
    {
	wxRichTextBuffer *    THIS = (wxRichTextBuffer *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextBuffer" )
;
	bool	RETVAL;
	wxFont*    font = (wxFont *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::Font" )
;
    try {
      RETVAL = THIS->BeginFont( *( font ) );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__RichTextBuffer_EndFont); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextBuffer_EndFont)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxRichTextBuffer *    THIS = (wxRichTextBuffer *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextBuffer" )
;
	bool	RETVAL;
    try {
      RETVAL = THIS->EndFont();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__RichTextBuffer_BeginTextColour); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextBuffer_BeginTextColour)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, colour");
    {
	wxRichTextBuffer *    THIS = (wxRichTextBuffer *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextBuffer" )
;
	bool	RETVAL;
	wxColour*    colour = (wxColour *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::Colour" )
;
    try {
      RETVAL = THIS->BeginTextColour( *( colour ) );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__RichTextBuffer_EndTextColour); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextBuffer_EndTextColour)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxRichTextBuffer *    THIS = (wxRichTextBuffer *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextBuffer" )
;
	bool	RETVAL;
    try {
      RETVAL = THIS->EndTextColour();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__RichTextBuffer_BeginAlignment); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextBuffer_BeginAlignment)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, alignment");
    {
	wxRichTextBuffer *    THIS = (wxRichTextBuffer *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextBuffer" )
;
	bool	RETVAL;
	wxTextAttrAlignment	alignment = (wxTextAttrAlignment)SvIV(ST(1))
;
    try {
      RETVAL = THIS->BeginAlignment( alignment );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__RichTextBuffer_EndAlignment); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextBuffer_EndAlignment)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxRichTextBuffer *    THIS = (wxRichTextBuffer *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextBuffer" )
;
	bool	RETVAL;
    try {
      RETVAL = THIS->EndAlignment();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__RichTextBuffer_BeginLeftIndent); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextBuffer_BeginLeftIndent)
{
    dVAR; dXSARGS;
    if (items < 2 || items > 3)
       croak_xs_usage(cv,  "THIS, leftIndent, leftSubIndent= 0");
    {
	wxRichTextBuffer *    THIS = (wxRichTextBuffer *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextBuffer" )
;
	bool	RETVAL;
	int	leftIndent = (int)SvIV(ST(1))
;
	int	leftSubIndent;

	if (items < 3)
	    leftSubIndent = 0;
	else {
	    leftSubIndent = (int)SvIV(ST(2))
;
	}
    try {
      RETVAL = THIS->BeginLeftIndent( leftIndent, leftSubIndent );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__RichTextBuffer_EndLeftIndent); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextBuffer_EndLeftIndent)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxRichTextBuffer *    THIS = (wxRichTextBuffer *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextBuffer" )
;
	bool	RETVAL;
    try {
      RETVAL = THIS->EndLeftIndent();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__RichTextBuffer_BeginRightIndent); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextBuffer_BeginRightIndent)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, rightIndent");
    {
	wxRichTextBuffer *    THIS = (wxRichTextBuffer *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextBuffer" )
;
	bool	RETVAL;
	int	rightIndent = (int)SvIV(ST(1))
;
    try {
      RETVAL = THIS->BeginRightIndent( rightIndent );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__RichTextBuffer_EndRightIndent); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextBuffer_EndRightIndent)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxRichTextBuffer *    THIS = (wxRichTextBuffer *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextBuffer" )
;
	bool	RETVAL;
    try {
      RETVAL = THIS->EndRightIndent();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__RichTextBuffer_BeginParagraphSpacing); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextBuffer_BeginParagraphSpacing)
{
    dVAR; dXSARGS;
    if (items != 3)
       croak_xs_usage(cv,  "THIS, before, after");
    {
	wxRichTextBuffer *    THIS = (wxRichTextBuffer *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextBuffer" )
;
	bool	RETVAL;
	int	before = (int)SvIV(ST(1))
;
	int	after = (int)SvIV(ST(2))
;
    try {
      RETVAL = THIS->BeginParagraphSpacing( before, after );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__RichTextBuffer_EndParagraphSpacing); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextBuffer_EndParagraphSpacing)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxRichTextBuffer *    THIS = (wxRichTextBuffer *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextBuffer" )
;
	bool	RETVAL;
    try {
      RETVAL = THIS->EndParagraphSpacing();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__RichTextBuffer_BeginLineSpacing); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextBuffer_BeginLineSpacing)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, lineSpacing");
    {
	wxRichTextBuffer *    THIS = (wxRichTextBuffer *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextBuffer" )
;
	bool	RETVAL;
	int	lineSpacing = (int)SvIV(ST(1))
;
    try {
      RETVAL = THIS->BeginLineSpacing( lineSpacing );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__RichTextBuffer_EndLineSpacing); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextBuffer_EndLineSpacing)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxRichTextBuffer *    THIS = (wxRichTextBuffer *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextBuffer" )
;
	bool	RETVAL;
    try {
      RETVAL = THIS->EndLineSpacing();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__RichTextBuffer_BeginNumberedBullet); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextBuffer_BeginNumberedBullet)
{
    dVAR; dXSARGS;
    if (items < 4 || items > 5)
       croak_xs_usage(cv,  "THIS, bulletNumber, leftIndent, leftSubIndent, bulletStyle= wxTEXT_ATTR_DEFAULT_NUMBERED_BULLET");
    {
	wxRichTextBuffer *    THIS = (wxRichTextBuffer *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextBuffer" )
;
	bool	RETVAL;
	int	bulletNumber = (int)SvIV(ST(1))
;
	int	leftIndent = (int)SvIV(ST(2))
;
	int	leftSubIndent = (int)SvIV(ST(3))
;
	int	bulletStyle;

	if (items < 5)
	    bulletStyle = wxTEXT_ATTR_DEFAULT_NUMBERED_BULLET;
	else {
	    bulletStyle = (int)SvIV(ST(4))
;
	}
    try {
      RETVAL = THIS->BeginNumberedBullet( bulletNumber, leftIndent, leftSubIndent, bulletStyle );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__RichTextBuffer_EndNumberedBullet); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextBuffer_EndNumberedBullet)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxRichTextBuffer *    THIS = (wxRichTextBuffer *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextBuffer" )
;
	bool	RETVAL;
    try {
      RETVAL = THIS->EndNumberedBullet();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}

#if WXPERL_W_VERSION_GE( 2, 7, 2 )
#define XSpp_36f656d1_014087
#define XSubPPtmpAACV 1


XS_EUPXS(XS_Wx__RichTextBuffer_BeginSymbolBullet0); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextBuffer_BeginSymbolBullet0)
{
    dVAR; dXSARGS;
    if (items < 4 || items > 5)
       croak_xs_usage(cv,  "THIS, symbol, leftIndent, leftSubIndent, bulletStyle= wxTEXT_ATTR_BULLET_STYLE_SYMBOL");
    {
	wxRichTextBuffer *    THIS = (wxRichTextBuffer *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextBuffer" )
;
	bool	RETVAL;
	wxString	symbol;
	int	leftIndent = (int)SvIV(ST(2))
;
	int	leftSubIndent = (int)SvIV(ST(3))
;
	int	bulletStyle;

    WXSTRING_INPUT( symbol, wxString, ST(1) )
;

	if (items < 5)
	    bulletStyle = wxTEXT_ATTR_BULLET_STYLE_SYMBOL;
	else {
	    bulletStyle = (int)SvIV(ST(4))
;
	}
    try {
      RETVAL = THIS->BeginSymbolBullet( symbol, leftIndent, leftSubIndent, bulletStyle );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}

#else
#define XSpp_36f656d1_003127
#define XSubPPtmpAACW 1


XS_EUPXS(XS_Wx__RichTextBuffer_BeginSymbolBullet1); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextBuffer_BeginSymbolBullet1)
{
    dVAR; dXSARGS;
    if (items < 4 || items > 5)
       croak_xs_usage(cv,  "THIS, symbol, leftIndent, leftSubIndent, bulletStyle= wxTEXT_ATTR_BULLET_STYLE_SYMBOL");
    {
	wxRichTextBuffer *    THIS = (wxRichTextBuffer *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextBuffer" )
;
	bool	RETVAL;
	wxChar	symbol = (wxChar)SvIV(ST(1))
;
	int	leftIndent = (int)SvIV(ST(2))
;
	int	leftSubIndent = (int)SvIV(ST(3))
;
	int	bulletStyle;

	if (items < 5)
	    bulletStyle = wxTEXT_ATTR_BULLET_STYLE_SYMBOL;
	else {
	    bulletStyle = (int)SvIV(ST(4))
;
	}
    try {
      RETVAL = THIS->BeginSymbolBullet( symbol, leftIndent, leftSubIndent, bulletStyle );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}

#endif

XS_EUPXS(XS_Wx__RichTextBuffer_EndSymbolBullet); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextBuffer_EndSymbolBullet)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxRichTextBuffer *    THIS = (wxRichTextBuffer *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextBuffer" )
;
	bool	RETVAL;
    try {
      RETVAL = THIS->EndSymbolBullet();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}

#if WXPERL_W_VERSION_GE( 2, 7, 2 )
#define XSpp_36f656d1_030037
#define XSubPPtmpAACX 1


XS_EUPXS(XS_Wx__RichTextBuffer_BeginStandardBullet); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextBuffer_BeginStandardBullet)
{
    dVAR; dXSARGS;
    if (items < 4 || items > 5)
       croak_xs_usage(cv,  "THIS, bulletName, leftIndent, leftSubIndent, bulletStyle= wxTEXT_ATTR_BULLET_STYLE_STANDARD");
    {
	wxRichTextBuffer *    THIS = (wxRichTextBuffer *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextBuffer" )
;
	bool	RETVAL;
	wxString	bulletName;
	int	leftIndent = (int)SvIV(ST(2))
;
	int	leftSubIndent = (int)SvIV(ST(3))
;
	int	bulletStyle;

    WXSTRING_INPUT( bulletName, wxString, ST(1) )
;

	if (items < 5)
	    bulletStyle = wxTEXT_ATTR_BULLET_STYLE_STANDARD;
	else {
	    bulletStyle = (int)SvIV(ST(4))
;
	}
    try {
      RETVAL = THIS->BeginStandardBullet( bulletName, leftIndent, leftSubIndent, bulletStyle );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__RichTextBuffer_EndStandardBullet); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextBuffer_EndStandardBullet)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxRichTextBuffer *    THIS = (wxRichTextBuffer *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextBuffer" )
;
	bool	RETVAL;
    try {
      RETVAL = THIS->EndStandardBullet();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}

#endif

XS_EUPXS(XS_Wx__RichTextBuffer_BeginCharacterStyle); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextBuffer_BeginCharacterStyle)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, characterStyle");
    {
	wxRichTextBuffer *    THIS = (wxRichTextBuffer *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextBuffer" )
;
	bool	RETVAL;
	wxString	characterStyle;

    WXSTRING_INPUT( characterStyle, wxString, ST(1) )
;
    try {
      RETVAL = THIS->BeginCharacterStyle( characterStyle );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__RichTextBuffer_EndCharacterStyle); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextBuffer_EndCharacterStyle)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxRichTextBuffer *    THIS = (wxRichTextBuffer *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextBuffer" )
;
	bool	RETVAL;
    try {
      RETVAL = THIS->EndCharacterStyle();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__RichTextBuffer_BeginParagraphStyle); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextBuffer_BeginParagraphStyle)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, paragraphStyle");
    {
	wxRichTextBuffer *    THIS = (wxRichTextBuffer *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextBuffer" )
;
	bool	RETVAL;
	wxString	paragraphStyle;

    WXSTRING_INPUT( paragraphStyle, wxString, ST(1) )
;
    try {
      RETVAL = THIS->BeginParagraphStyle( paragraphStyle );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__RichTextBuffer_EndParagraphStyle); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextBuffer_EndParagraphStyle)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxRichTextBuffer *    THIS = (wxRichTextBuffer *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextBuffer" )
;
	bool	RETVAL;
    try {
      RETVAL = THIS->EndParagraphStyle();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}

#if WXPERL_W_VERSION_GE( 2, 7, 2 )
#define XSpp_36f656d1_068760
#define XSubPPtmpAACY 1


XS_EUPXS(XS_Wx__RichTextBuffer_BeginListStyle); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextBuffer_BeginListStyle)
{
    dVAR; dXSARGS;
    if (items < 2 || items > 4)
       croak_xs_usage(cv,  "THIS, listStyle, level= 1, number= 1");
    {
	wxRichTextBuffer *    THIS = (wxRichTextBuffer *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextBuffer" )
;
	bool	RETVAL;
	wxString	listStyle;
	int	level;
	int	number;

    WXSTRING_INPUT( listStyle, wxString, ST(1) )
;

	if (items < 3)
	    level = 1;
	else {
	    level = (int)SvIV(ST(2))
;
	}

	if (items < 4)
	    number = 1;
	else {
	    number = (int)SvIV(ST(3))
;
	}
    try {
      RETVAL = THIS->BeginListStyle( listStyle, level, number );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__RichTextBuffer_EndListStyle); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextBuffer_EndListStyle)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxRichTextBuffer *    THIS = (wxRichTextBuffer *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextBuffer" )
;
	bool	RETVAL;
    try {
      RETVAL = THIS->EndListStyle();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__RichTextBuffer_BeginURL); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextBuffer_BeginURL)
{
    dVAR; dXSARGS;
    if (items < 2 || items > 3)
       croak_xs_usage(cv,  "THIS, url, characterStyle= wxEmptyString");
    {
	wxRichTextBuffer *    THIS = (wxRichTextBuffer *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextBuffer" )
;
	bool	RETVAL;
	wxString	url;
	wxString	characterStyle;

    WXSTRING_INPUT( url, wxString, ST(1) )
;

	if (items < 3)
	    characterStyle = wxEmptyString;
	else {
    WXSTRING_INPUT( characterStyle, wxString, ST(2) )
;
	}
    try {
      RETVAL = THIS->BeginURL( url, characterStyle );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__RichTextBuffer_EndURL); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextBuffer_EndURL)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxRichTextBuffer *    THIS = (wxRichTextBuffer *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextBuffer" )
;
	bool	RETVAL;
    try {
      RETVAL = THIS->EndURL();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}

#endif
#if WXPERL_W_VERSION_GE( 2, 7, 2 )
#define XSpp_36f656d1_015479
#define XSubPPtmpAACZ 1


XS_EUPXS(XS_Wx__RichTextBuffer_ClearListStyle); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextBuffer_ClearListStyle)
{
    dVAR; dXSARGS;
    if (items < 2 || items > 3)
       croak_xs_usage(cv,  "THIS, range, flags= wxRICHTEXT_SETSTYLE_WITH_UNDO");
    {
	wxRichTextBuffer *    THIS = (wxRichTextBuffer *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextBuffer" )
;
	bool	RETVAL;
	wxRichTextRange*    range = (wxRichTextRange *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::RichTextRange" )
;
	int	flags;

	if (items < 3)
	    flags = wxRICHTEXT_SETSTYLE_WITH_UNDO;
	else {
	    flags = (int)SvIV(ST(2))
;
	}
    try {
      RETVAL = THIS->ClearListStyle( *( range ), flags );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}

#endif

XS_EUPXS(XS_Wx__RichTextBuffer_AddParagraph); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextBuffer_AddParagraph)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, text");
    {
	wxRichTextBuffer *    THIS = (wxRichTextBuffer *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextBuffer" )
;
	wxRichTextRange *	RETVAL;
	wxString	text;

    WXSTRING_INPUT( text, wxString, ST(1) )
;
    try {
      RETVAL = new wxRichTextRange( THIS->AddParagraph( text ) );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_non_object_2_sv( aTHX_ RETVALSV, RETVAL, "Wx::RichTextRange" );
    wxPli_thread_sv_register( aTHX_ "Wx::RichTextRange", RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__RichTextBuffer_AddImage); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextBuffer_AddImage)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, image");
    {
	wxRichTextBuffer *    THIS = (wxRichTextBuffer *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextBuffer" )
;
	wxRichTextRange *	RETVAL;
	wxImage*    image = (wxImage *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::Image" )
;
    try {
      RETVAL = new wxRichTextRange( THIS->AddImage( *( image ) ) );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_non_object_2_sv( aTHX_ RETVALSV, RETVAL, "Wx::RichTextRange" );
    wxPli_thread_sv_register( aTHX_ "Wx::RichTextRange", RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__RichTextBuffer_BeginBatchUndo); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextBuffer_BeginBatchUndo)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, cmdName");
    {
	wxRichTextBuffer *    THIS = (wxRichTextBuffer *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextBuffer" )
;
	bool	RETVAL;
	wxString	cmdName;

    WXSTRING_INPUT( cmdName, wxString, ST(1) )
;
    try {
      RETVAL = THIS->BeginBatchUndo( cmdName );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__RichTextBuffer_EndBatchUndo); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextBuffer_EndBatchUndo)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxRichTextBuffer *    THIS = (wxRichTextBuffer *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextBuffer" )
;
	bool	RETVAL;
    try {
      RETVAL = THIS->EndBatchUndo();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__RichTextBuffer_BatchingUndo); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextBuffer_BatchingUndo)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxRichTextBuffer *    THIS = (wxRichTextBuffer *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextBuffer" )
;
	bool	RETVAL;
    try {
      RETVAL = THIS->BatchingUndo();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__RichTextBuffer_BeginSuppressUndo); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextBuffer_BeginSuppressUndo)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxRichTextBuffer *    THIS = (wxRichTextBuffer *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextBuffer" )
;
	bool	RETVAL;
    try {
      RETVAL = THIS->BeginSuppressUndo();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__RichTextBuffer_EndSuppressUndo); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextBuffer_EndSuppressUndo)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxRichTextBuffer *    THIS = (wxRichTextBuffer *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextBuffer" )
;
	bool	RETVAL;
    try {
      RETVAL = THIS->EndSuppressUndo();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__RichTextBuffer_SuppressingUndo); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextBuffer_SuppressingUndo)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxRichTextBuffer *    THIS = (wxRichTextBuffer *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextBuffer" )
;
	bool	RETVAL;
    try {
      RETVAL = THIS->SuppressingUndo();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__RichTextBuffer_SetStyleSheet); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextBuffer_SetStyleSheet)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, styleSheet");
    {
	wxRichTextBuffer *    THIS = (wxRichTextBuffer *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextBuffer" )
;
	wxRichTextStyleSheet*    styleSheet = (wxRichTextStyleSheet *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::RichTextStyleSheet" )
;
    try {
      THIS->SetStyleSheet( styleSheet );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__RichTextBuffer_GetStyleSheet); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextBuffer_GetStyleSheet)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxRichTextBuffer *    THIS = (wxRichTextBuffer *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextBuffer" )
;
	wxRichTextStyleSheet *	RETVAL;
    try {
      RETVAL = THIS->GetStyleSheet();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_object_2_sv( aTHX_ RETVALSV, RETVAL );
    wxPli_thread_sv_register( aTHX_ "Wx::RichTextStyleSheet", RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    wxPli_object_set_deleteable( aTHX_ ST(0), false );
    }
    XSRETURN(1);
}

#if WXPERL_W_VERSION_GE( 2, 7, 2 )
#define XSpp_36f656d1_095832
#define XSubPPtmpAADA 1


XS_EUPXS(XS_Wx__RichTextBuffer_PushStyleSheet); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextBuffer_PushStyleSheet)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, styleSheet");
    {
	wxRichTextBuffer *    THIS = (wxRichTextBuffer *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextBuffer" )
;
	bool	RETVAL;
	wxRichTextStyleSheet*    styleSheet = (wxRichTextStyleSheet *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::RichTextStyleSheet" )
;
    try {
      RETVAL = THIS->PushStyleSheet( styleSheet );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__RichTextBuffer_PopStyleSheet); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextBuffer_PopStyleSheet)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxRichTextBuffer *    THIS = (wxRichTextBuffer *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextBuffer" )
;
	wxRichTextStyleSheet *	RETVAL;
    try {
      RETVAL = THIS->PopStyleSheet();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_object_2_sv( aTHX_ RETVALSV, RETVAL );
    wxPli_thread_sv_register( aTHX_ "Wx::RichTextStyleSheet", RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    wxPli_object_set_deleteable( aTHX_ ST(0), false );
    }
    XSRETURN(1);
}

#endif

XS_EUPXS(XS_Wx__RichTextBuffer_SetBasicStyleRich); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextBuffer_SetBasicStyleRich)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, style");
    {
	wxRichTextBuffer *    THIS = (wxRichTextBuffer *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextBuffer" )
;
	wxRichTextAttr*    style = (wxRichTextAttr *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::RichTextAttr" )
;
    try {
      THIS->SetBasicStyle( *( style ) );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__RichTextBuffer_SetBasicStyleEx); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextBuffer_SetBasicStyleEx)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, style");
    {
	wxRichTextBuffer *    THIS = (wxRichTextBuffer *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextBuffer" )
;
	wxTextAttrEx*    style = (wxTextAttrEx *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::TextAttrEx" )
;
    try {
      THIS->SetBasicStyle( *( style ) );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__RichTextBuffer_SetBasicStyle); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextBuffer_SetBasicStyle)
{
    dVAR; dXSARGS;
    if (items < 1)
       croak_xs_usage(cv,  "THIS, ...");
    PERL_UNUSED_VAR(ax); /* -Wall */
    SP -= items;
    {
	wxRichTextBuffer *    THIS = (wxRichTextBuffer *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextBuffer" )
;
    BEGIN_OVERLOAD()
        MATCH_REDISP( wxPliOvl_wrta, SetBasicStyleRich )
        MATCH_REDISP( wxPliOvl_wtae, SetBasicStyleEx )
    END_OVERLOAD( "Wx::RichTextBuffer::SetBasicStyle" )
	PUTBACK;
	return;
    }
}

#include "cpp/overload.h"
#if 1
#define XSubPPtmpAADB 1


XS_EUPXS(XS_Wx__RichTextBuffer_BeginSymbolBullet); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextBuffer_BeginSymbolBullet)
{
    dVAR; dXSARGS;
    if (items < 1)
       croak_xs_usage(cv,  "THIS, ...");
    PERL_UNUSED_VAR(ax); /* -Wall */
    SP -= items;
    {
	wxRichTextBuffer *    THIS = (wxRichTextBuffer *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextBuffer" )
;
#if defined( XSpp_36f656d1_014087 )
    static const char *BeginSymbolBullet0_types[] = { wxPliOvlstr, wxPliOvlnum, wxPliOvlnum, wxPliOvlnum };
    static wxPliPrototype BeginSymbolBullet0_proto( BeginSymbolBullet0_types, sizeof( BeginSymbolBullet0_types ) / sizeof( BeginSymbolBullet0_types[0] ) );
#endif // defined( XSpp_36f656d1_014087 )
#if defined( XSpp_36f656d1_003127 )
    static const char *BeginSymbolBullet1_types[] = { "Wx::Char", wxPliOvlnum, wxPliOvlnum, wxPliOvlnum };
    static wxPliPrototype BeginSymbolBullet1_proto( BeginSymbolBullet1_types, sizeof( BeginSymbolBullet1_types ) / sizeof( BeginSymbolBullet1_types[0] ) );
#endif // defined( XSpp_36f656d1_003127 )
    static wxPliPrototype *wxPliOvl_all_prototypes[] = {
#if defined( XSpp_36f656d1_014087 )
        &BeginSymbolBullet0_proto,
#endif // defined( XSpp_36f656d1_014087 )
#if defined( XSpp_36f656d1_003127 )
        &BeginSymbolBullet1_proto,
#endif // defined( XSpp_36f656d1_003127 )
        NULL };
    BEGIN_OVERLOAD()
#if defined( XSpp_36f656d1_014087 )
        MATCH_REDISP_COUNT_ALLOWMORE( BeginSymbolBullet0_proto, BeginSymbolBullet0, 3 )
#endif // defined( XSpp_36f656d1_014087 )
#if defined( XSpp_36f656d1_003127 )
        MATCH_REDISP_COUNT_ALLOWMORE( BeginSymbolBullet1_proto, BeginSymbolBullet1, 3 )
#endif // defined( XSpp_36f656d1_003127 )
    END_OVERLOAD_MESSAGE( Wx::RichTextBuffer::BeginSymbolBullet, wxPliOvl_all_prototypes )
	PUTBACK;
	return;
    }
}

#endif // 1

XS_EUPXS(XS_Wx__RichTextBuffer_GetRichTextAttrStyle); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextBuffer_GetRichTextAttrStyle)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, position");
    PERL_UNUSED_VAR(ax); /* -Wall */
    SP -= items;
    {
	long	position = (long)SvIV(ST(1))
;
	wxRichTextBuffer *    THIS = (wxRichTextBuffer *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextBuffer" )
;
    wxRichTextAttr attr;
    bool retval = THIS->GetStyle( position, attr );
    EXTEND( SP, 2 );
    PUSHs( newSViv( retval ) );
    PUSHs( retval ? wxPli_non_object_2_sv( aTHX_ sv_newmortal(),
                                           new wxRichTextAttr( attr ),
                                           "Wx::RichTextAttr" ) :
                    &PL_sv_undef );
	PUTBACK;
	return;
    }
}

#if WXPERL_W_VERSION_LT( 2, 9, 2 )
#define XSubPPtmpAADC 1


XS_EUPXS(XS_Wx__RichTextBuffer_GetTextAttrExStyle); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextBuffer_GetTextAttrExStyle)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, position");
    PERL_UNUSED_VAR(ax); /* -Wall */
    SP -= items;
    {
	long	position = (long)SvIV(ST(1))
;
	wxRichTextBuffer *    THIS = (wxRichTextBuffer *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextBuffer" )
;
    wxTextAttrEx attr;
    bool retval = THIS->GetStyle( position, attr );
    EXTEND( SP, 2 );
    PUSHs( newSViv( retval ) );
    PUSHs( retval ? wxPli_non_object_2_sv( aTHX_ sv_newmortal(),
                                           new wxTextAttrEx( attr ),
                                           "Wx::TextAttrEx" ) :
                    &PL_sv_undef );
	PUTBACK;
	return;
    }
}

#endif
#if WXPERL_W_VERSION_GE( 2, 7, 1 )
#define XSubPPtmpAADD 1


XS_EUPXS(XS_Wx__RichTextBuffer_GetRichTextAttrUncombinedStyle); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextBuffer_GetRichTextAttrUncombinedStyle)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, position");
    PERL_UNUSED_VAR(ax); /* -Wall */
    SP -= items;
    {
	long	position = (long)SvIV(ST(1))
;
	wxRichTextBuffer *    THIS = (wxRichTextBuffer *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextBuffer" )
;
    wxRichTextAttr attr;
    bool retval = THIS->GetUncombinedStyle( position, attr );
    EXTEND( SP, 2 );
    PUSHs( newSViv( retval ) );
    PUSHs( retval ? wxPli_non_object_2_sv( aTHX_ sv_newmortal(),
                                           new wxRichTextAttr( attr ),
                                           "Wx::RichTextAttr" ) :
                    &PL_sv_undef );
	PUTBACK;
	return;
    }
}

#if WXPERL_W_VERSION_LT( 2, 9, 2 )
#define XSubPPtmpAADE 1


XS_EUPXS(XS_Wx__RichTextBuffer_GetTextAttrExUncombinedStyle); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextBuffer_GetTextAttrExUncombinedStyle)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, position");
    PERL_UNUSED_VAR(ax); /* -Wall */
    SP -= items;
    {
	long	position = (long)SvIV(ST(1))
;
	wxRichTextBuffer *    THIS = (wxRichTextBuffer *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextBuffer" )
;
    wxTextAttrEx attr;
    bool retval = THIS->GetUncombinedStyle( position, attr );
    EXTEND( SP, 2 );
    PUSHs( newSViv( retval ) );
    PUSHs( retval ? wxPli_non_object_2_sv( aTHX_ sv_newmortal(),
                                           new wxTextAttrEx( attr ),
                                           "Wx::TextAttrEx" ) :
                    &PL_sv_undef );
	PUTBACK;
	return;
    }
}

#endif
#endif
#if WXPERL_W_VERSION_GE( 2, 8, 0 ) && WXPERL_W_VERSION_LT( 2, 9, 2 )
#define XSubPPtmpAADF 1


XS_EUPXS(XS_Wx__RichTextBuffer_GetTextAttrExStyleForRange); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextBuffer_GetTextAttrExStyleForRange)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, range");
    PERL_UNUSED_VAR(ax); /* -Wall */
    SP -= items;
    {
	wxRichTextRange*    range = (wxRichTextRange *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::RichTextRange" )
;
	wxRichTextBuffer *    THIS = (wxRichTextBuffer *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextBuffer" )
;
    wxTextAttrEx attr;
    bool retval = THIS->GetStyleForRange( *range, attr );
    EXTEND( SP, 2 );
    PUSHs( newSViv( retval ) );
    PUSHs( retval ? wxPli_non_object_2_sv( aTHX_ sv_newmortal(),
                                           new wxTextAttrEx( attr ),
                                           "Wx::TextAttrEx" ) :
                    &PL_sv_undef );
	PUTBACK;
	return;
    }
}

#endif
#if WXPERL_W_VERSION_GE( 2, 9, 2 )
#define XSubPPtmpAADG 1


XS_EUPXS(XS_Wx__RichTextBuffer_GetRichTextAttrStyleForRange); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextBuffer_GetRichTextAttrStyleForRange)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, range");
    PERL_UNUSED_VAR(ax); /* -Wall */
    SP -= items;
    {
	wxRichTextRange*    range = (wxRichTextRange *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::RichTextRange" )
;
	wxRichTextBuffer *    THIS = (wxRichTextBuffer *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextBuffer" )
;
    wxRichTextAttr attr;
    bool retval = THIS->GetStyleForRange( *range, attr );
    EXTEND( SP, 2 );
    PUSHs( newSViv( retval ) );
    PUSHs( retval ? wxPli_non_object_2_sv( aTHX_ sv_newmortal(),
                                           new wxRichTextAttr( attr ),
                                           "Wx::RichTextAttr" ) :
                    &PL_sv_undef );
	PUTBACK;
	return;
    }
}

#endif

/* INCLUDE: Returning to 'RichText.xs' from '/usr/bin/perl -I../.. -MExtUtils::XSpp::Cmd -e xspp -- -t typemap.xsp -t ../../typemap.xsp XS/RichTextBuffer.xsp' */


/* INCLUDE_COMMAND:  Including output of '/usr/bin/perl -MExtUtils::XSpp::Cmd -e xspp -- -t typemap.xsp -t ../../typemap.xsp XS/SymbolPickerDialog.xsp' from 'RichText.xs' */

#include <exception>

#undef  xsp_constructor_class
#define xsp_constructor_class(c) (c)
#undef _
#define _(x) wxGetTranslation(wxT(x))
#include <wx/richtext/richtextsymboldlg.h>

XS_EUPXS(XS_Wx__SymbolPickerDialog_new); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__SymbolPickerDialog_new)
{
    dVAR; dXSARGS;
    if (items < 1)
       croak_xs_usage(cv,  "CLASS, ...");
    PERL_UNUSED_VAR(ax); /* -Wall */
    SP -= items;
    {
	char *	CLASS = (char *)SvPV_nolen(ST(0))
;
    BEGIN_OVERLOAD()
        MATCH_VOIDM_REDISP( newDefault )
        MATCH_ANY_REDISP( newFull )
    END_OVERLOAD( "Wx::SymbolPickerDialog::new" )
	PUTBACK;
	return;
    }
}

#undef  xsp_constructor_class
#define xsp_constructor_class(c) (CLASS)

XS_EUPXS(XS_Wx__SymbolPickerDialog_newDefault); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__SymbolPickerDialog_newDefault)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "CLASS");
    {
	char *	CLASS = (char *)SvPV_nolen(ST(0))
;
	wxSymbolPickerDialog *	RETVAL;
     RETVAL = new wxSymbolPickerDialog();
                wxPli_create_evthandler( aTHX_ RETVAL, CLASS );
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_object_2_sv( aTHX_ RETVALSV, RETVAL );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}

#undef  xsp_constructor_class
#define xsp_constructor_class(c) (c)
#undef  xsp_constructor_class
#define xsp_constructor_class(c) (CLASS)

XS_EUPXS(XS_Wx__SymbolPickerDialog_newFull); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__SymbolPickerDialog_newFull)
{
    dVAR; dXSARGS;
    if (items < 5 || items > 10)
       croak_xs_usage(cv,  "CLASS, symbol, fontName, normalTextFont, parent, id= wxID_ANY, caption= SYMBOL_WXSYMBOLPICKERDIALOG_TITLE, pos= wxDefaultPosition, size= wxDefaultSize, style= SYMBOL_WXSYMBOLPICKERDIALOG_STYLE");
    {
	char *	CLASS = (char *)SvPV_nolen(ST(0))
;
	wxSymbolPickerDialog *	RETVAL;
	wxString	symbol;
	wxString	fontName;
	wxString	normalTextFont;
	wxWindow*    parent = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(4), "Wx::Window" )
;
	wxWindowID	id;
	wxString	caption;
	wxPoint	pos;
	wxSize	size;
	long	style;

    WXSTRING_INPUT( symbol, wxString, ST(1) )
;

    WXSTRING_INPUT( fontName, wxString, ST(2) )
;

    WXSTRING_INPUT( normalTextFont, wxString, ST(3) )
;

	if (items < 6)
	    id = wxID_ANY;
	else {
    id = wxPli_get_wxwindowid( aTHX_ ST(5) )
;
	}

	if (items < 7)
	    caption = SYMBOL_WXSYMBOLPICKERDIALOG_TITLE;
	else {
    WXSTRING_INPUT( caption, wxString, ST(6) )
;
	}

	if (items < 8)
	    pos = wxDefaultPosition;
	else {
    pos = wxPli_sv_2_wxpoint( aTHX_ ST(7) )
;
	}

	if (items < 9)
	    size = wxDefaultSize;
	else {
    size = wxPli_sv_2_wxsize( aTHX_ ST(8) )
;
	}

	if (items < 10)
	    style = SYMBOL_WXSYMBOLPICKERDIALOG_STYLE;
	else {
	    style = (long)SvIV(ST(9))
;
	}
     RETVAL = new wxSymbolPickerDialog( symbol, fontName,
                                                   normalTextFont, parent, id,
                                                   caption, pos, size, style );
                wxPli_create_evthandler( aTHX_ RETVAL, CLASS );
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_object_2_sv( aTHX_ RETVALSV, RETVAL );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}

#undef  xsp_constructor_class
#define xsp_constructor_class(c) (c)

XS_EUPXS(XS_Wx__SymbolPickerDialog_Create); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__SymbolPickerDialog_Create)
{
    dVAR; dXSARGS;
    if (items < 5 || items > 10)
       croak_xs_usage(cv,  "THIS, symbol, fontName, normalTextFont, parent, id= wxID_ANY, caption= SYMBOL_WXSYMBOLPICKERDIALOG_TITLE, pos= SYMBOL_WXSYMBOLPICKERDIALOG_POSITION, size= SYMBOL_WXSYMBOLPICKERDIALOG_SIZE, style= SYMBOL_WXSYMBOLPICKERDIALOG_STYLE");
    {
	wxSymbolPickerDialog *    THIS = (wxSymbolPickerDialog *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::SymbolPickerDialog" )
;
	bool	RETVAL;
	wxString	symbol;
	wxString	fontName;
	wxString	normalTextFont;
	wxWindow*    parent = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(4), "Wx::Window" )
;
	wxWindowID	id;
	wxString	caption;
	wxPoint	pos;
	wxSize	size;
	long	style;

    WXSTRING_INPUT( symbol, wxString, ST(1) )
;

    WXSTRING_INPUT( fontName, wxString, ST(2) )
;

    WXSTRING_INPUT( normalTextFont, wxString, ST(3) )
;

	if (items < 6)
	    id = wxID_ANY;
	else {
    id = wxPli_get_wxwindowid( aTHX_ ST(5) )
;
	}

	if (items < 7)
	    caption = SYMBOL_WXSYMBOLPICKERDIALOG_TITLE;
	else {
    WXSTRING_INPUT( caption, wxString, ST(6) )
;
	}

	if (items < 8)
	    pos = SYMBOL_WXSYMBOLPICKERDIALOG_POSITION;
	else {
    pos = wxPli_sv_2_wxpoint( aTHX_ ST(7) )
;
	}

	if (items < 9)
	    size = SYMBOL_WXSYMBOLPICKERDIALOG_SIZE;
	else {
    size = wxPli_sv_2_wxsize( aTHX_ ST(8) )
;
	}

	if (items < 10)
	    style = SYMBOL_WXSYMBOLPICKERDIALOG_STYLE;
	else {
	    style = (long)SvIV(ST(9))
;
	}
    try {
      RETVAL = THIS->Create( symbol, fontName, normalTextFont, parent, id, caption, pos, size, style );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__SymbolPickerDialog_SetUnicodeMode); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__SymbolPickerDialog_SetUnicodeMode)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, unicodeMode");
    {
	wxSymbolPickerDialog *    THIS = (wxSymbolPickerDialog *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::SymbolPickerDialog" )
;
	bool	unicodeMode = (bool)SvTRUE(ST(1))
;
    try {
      THIS->SetUnicodeMode( unicodeMode );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__SymbolPickerDialog_GetSymbolChar); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__SymbolPickerDialog_GetSymbolChar)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxSymbolPickerDialog *    THIS = (wxSymbolPickerDialog *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::SymbolPickerDialog" )
;
	int	RETVAL;
	dXSTARG;
    try {
      RETVAL = THIS->GetSymbolChar();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__SymbolPickerDialog_HasSelection); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__SymbolPickerDialog_HasSelection)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxSymbolPickerDialog *    THIS = (wxSymbolPickerDialog *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::SymbolPickerDialog" )
;
	bool	RETVAL;
    try {
      RETVAL = THIS->HasSelection();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__SymbolPickerDialog_UseNormalFont); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__SymbolPickerDialog_UseNormalFont)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxSymbolPickerDialog *    THIS = (wxSymbolPickerDialog *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::SymbolPickerDialog" )
;
	bool	RETVAL;
    try {
      RETVAL = THIS->UseNormalFont();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__SymbolPickerDialog_GetFontName); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__SymbolPickerDialog_GetFontName)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxSymbolPickerDialog *    THIS = (wxSymbolPickerDialog *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::SymbolPickerDialog" )
;
	wxString	RETVAL;
    try {
      RETVAL = THIS->GetFontName();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    WXSTRING_OUTPUT( RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__SymbolPickerDialog_SetFontName); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__SymbolPickerDialog_SetFontName)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, value");
    {
	wxSymbolPickerDialog *    THIS = (wxSymbolPickerDialog *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::SymbolPickerDialog" )
;
	wxString	value;

    WXSTRING_INPUT( value, wxString, ST(1) )
;
    try {
      THIS->SetFontName( value );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__SymbolPickerDialog_GetSymbol); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__SymbolPickerDialog_GetSymbol)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxSymbolPickerDialog *    THIS = (wxSymbolPickerDialog *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::SymbolPickerDialog" )
;
	wxString	RETVAL;
    try {
      RETVAL = THIS->GetSymbol();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    WXSTRING_OUTPUT( RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__SymbolPickerDialog_SetSymbol); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__SymbolPickerDialog_SetSymbol)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, value");
    {
	wxSymbolPickerDialog *    THIS = (wxSymbolPickerDialog *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::SymbolPickerDialog" )
;
	wxString	value;

    WXSTRING_INPUT( value, wxString, ST(1) )
;
    try {
      THIS->SetSymbol( value );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__SymbolPickerDialog_GetFromUnicode); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__SymbolPickerDialog_GetFromUnicode)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxSymbolPickerDialog *    THIS = (wxSymbolPickerDialog *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::SymbolPickerDialog" )
;
	bool	RETVAL;
    try {
      RETVAL = THIS->GetFromUnicode();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__SymbolPickerDialog_SetFromUnicode); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__SymbolPickerDialog_SetFromUnicode)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, value");
    {
	wxSymbolPickerDialog *    THIS = (wxSymbolPickerDialog *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::SymbolPickerDialog" )
;
	bool	value = (bool)SvTRUE(ST(1))
;
    try {
      THIS->SetFromUnicode( value );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__SymbolPickerDialog_GetNormalTextFontName); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__SymbolPickerDialog_GetNormalTextFontName)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxSymbolPickerDialog *    THIS = (wxSymbolPickerDialog *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::SymbolPickerDialog" )
;
	wxString	RETVAL;
    try {
      RETVAL = THIS->GetNormalTextFontName();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    WXSTRING_OUTPUT( RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__SymbolPickerDialog_SetNormalTextFontName); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__SymbolPickerDialog_SetNormalTextFontName)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, value");
    {
	wxSymbolPickerDialog *    THIS = (wxSymbolPickerDialog *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::SymbolPickerDialog" )
;
	wxString	value;

    WXSTRING_INPUT( value, wxString, ST(1) )
;
    try {
      THIS->SetNormalTextFontName( value );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


/* INCLUDE: Returning to 'RichText.xs' from '/usr/bin/perl -MExtUtils::XSpp::Cmd -e xspp -- -t typemap.xsp -t ../../typemap.xsp XS/SymbolPickerDialog.xsp' */


/* INCLUDE_COMMAND:  Including output of '/usr/bin/perl -MExtUtils::XSpp::Cmd -e xspp -- -t typemap.xsp -t ../../typemap.xsp XS/RichTextStyleOrganiserDialog.xsp' from 'RichText.xs' */

#include <exception>

#undef  xsp_constructor_class
#define xsp_constructor_class(c) (c)
#undef _
#define _(x) wxGetTranslation(wxT(x))
#include <wx/button.h>
#include <wx/checkbox.h>
#include <wx/richtext/richtextstyledlg.h>

XS_EUPXS(XS_Wx__RichTextStyleOrganiserDialog_new); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextStyleOrganiserDialog_new)
{
    dVAR; dXSARGS;
    if (items < 1)
       croak_xs_usage(cv,  "CLASS, ...");
    PERL_UNUSED_VAR(ax); /* -Wall */
    SP -= items;
    {
	char *	CLASS = (char *)SvPV_nolen(ST(0))
;
    BEGIN_OVERLOAD()
        MATCH_VOIDM_REDISP( newDefault )
        MATCH_ANY_REDISP( newFull )
    END_OVERLOAD( "Wx::RichTextStyleOrganiserDialog::new" )
	PUTBACK;
	return;
    }
}

#undef  xsp_constructor_class
#define xsp_constructor_class(c) (CLASS)

XS_EUPXS(XS_Wx__RichTextStyleOrganiserDialog_newDefault); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextStyleOrganiserDialog_newDefault)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "CLASS");
    {
	char *	CLASS = (char *)SvPV_nolen(ST(0))
;
	wxRichTextStyleOrganiserDialog *	RETVAL;
     RETVAL = new wxRichTextStyleOrganiserDialog();
                wxPli_create_evthandler( aTHX_ RETVAL, CLASS );
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_object_2_sv( aTHX_ RETVALSV, RETVAL );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}

#undef  xsp_constructor_class
#define xsp_constructor_class(c) (c)
#undef  xsp_constructor_class
#define xsp_constructor_class(c) (CLASS)

XS_EUPXS(XS_Wx__RichTextStyleOrganiserDialog_newFull); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextStyleOrganiserDialog_newFull)
{
    dVAR; dXSARGS;
    if (items < 5 || items > 10)
       croak_xs_usage(cv,  "CLASS, flags, sheet, ctrl, parent, id= wxID_ANY, caption= SYMBOL_WXRICHTEXTSTYLEORGANISERDIALOG_TITLE, pos= SYMBOL_WXRICHTEXTSTYLEORGANISERDIALOG_POSITION, size= SYMBOL_WXRICHTEXTSTYLEORGANISERDIALOG_SIZE, style= SYMBOL_WXRICHTEXTSTYLEORGANISERDIALOG_STYLE");
    {
	char *	CLASS = (char *)SvPV_nolen(ST(0))
;
	wxRichTextStyleOrganiserDialog *	RETVAL;
	int	flags = (int)SvIV(ST(1))
;
	wxRichTextStyleSheet*    sheet = (wxRichTextStyleSheet *) wxPli_sv_2_object( aTHX_ ST(2), "Wx::RichTextStyleSheet" )
;
	wxRichTextCtrl*    ctrl = (wxRichTextCtrl *) wxPli_sv_2_object( aTHX_ ST(3), "Wx::RichTextCtrl" )
;
	wxWindow*    parent = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(4), "Wx::Window" )
;
	wxWindowID	id;
	wxString	caption;
	wxPoint	pos;
	wxSize	size;
	long	style;

	if (items < 6)
	    id = wxID_ANY;
	else {
    id = wxPli_get_wxwindowid( aTHX_ ST(5) )
;
	}

	if (items < 7)
	    caption = SYMBOL_WXRICHTEXTSTYLEORGANISERDIALOG_TITLE;
	else {
    WXSTRING_INPUT( caption, wxString, ST(6) )
;
	}

	if (items < 8)
	    pos = SYMBOL_WXRICHTEXTSTYLEORGANISERDIALOG_POSITION;
	else {
    pos = wxPli_sv_2_wxpoint( aTHX_ ST(7) )
;
	}

	if (items < 9)
	    size = SYMBOL_WXRICHTEXTSTYLEORGANISERDIALOG_SIZE;
	else {
    size = wxPli_sv_2_wxsize( aTHX_ ST(8) )
;
	}

	if (items < 10)
	    style = SYMBOL_WXRICHTEXTSTYLEORGANISERDIALOG_STYLE;
	else {
	    style = (long)SvIV(ST(9))
;
	}
     RETVAL = new wxRichTextStyleOrganiserDialog
                                 ( flags, sheet, ctrl, parent, id,
                                   caption, pos, size, style );
                wxPli_create_evthandler( aTHX_ RETVAL, CLASS );
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_object_2_sv( aTHX_ RETVALSV, RETVAL );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}

#undef  xsp_constructor_class
#define xsp_constructor_class(c) (c)

XS_EUPXS(XS_Wx__RichTextStyleOrganiserDialog_Create); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextStyleOrganiserDialog_Create)
{
    dVAR; dXSARGS;
    if (items < 5 || items > 10)
       croak_xs_usage(cv,  "THIS, flags, sheet, ctrl, parent, id= wxID_ANY, caption= SYMBOL_WXRICHTEXTSTYLEORGANISERDIALOG_TITLE, pos= SYMBOL_WXRICHTEXTSTYLEORGANISERDIALOG_POSITION, size= SYMBOL_WXRICHTEXTSTYLEORGANISERDIALOG_SIZE, style= SYMBOL_WXRICHTEXTSTYLEORGANISERDIALOG_STYLE");
    {
	wxRichTextStyleOrganiserDialog *    THIS = (wxRichTextStyleOrganiserDialog *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextStyleOrganiserDialog" )
;
	bool	RETVAL;
	int	flags = (int)SvIV(ST(1))
;
	wxRichTextStyleSheet*    sheet = (wxRichTextStyleSheet *) wxPli_sv_2_object( aTHX_ ST(2), "Wx::RichTextStyleSheet" )
;
	wxRichTextCtrl*    ctrl = (wxRichTextCtrl *) wxPli_sv_2_object( aTHX_ ST(3), "Wx::RichTextCtrl" )
;
	wxWindow*    parent = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(4), "Wx::Window" )
;
	wxWindowID	id;
	wxString	caption;
	wxPoint	pos;
	wxSize	size;
	long	style;

	if (items < 6)
	    id = wxID_ANY;
	else {
    id = wxPli_get_wxwindowid( aTHX_ ST(5) )
;
	}

	if (items < 7)
	    caption = SYMBOL_WXRICHTEXTSTYLEORGANISERDIALOG_TITLE;
	else {
    WXSTRING_INPUT( caption, wxString, ST(6) )
;
	}

	if (items < 8)
	    pos = SYMBOL_WXRICHTEXTSTYLEORGANISERDIALOG_POSITION;
	else {
    pos = wxPli_sv_2_wxpoint( aTHX_ ST(7) )
;
	}

	if (items < 9)
	    size = SYMBOL_WXRICHTEXTSTYLEORGANISERDIALOG_SIZE;
	else {
    size = wxPli_sv_2_wxsize( aTHX_ ST(8) )
;
	}

	if (items < 10)
	    style = SYMBOL_WXRICHTEXTSTYLEORGANISERDIALOG_STYLE;
	else {
	    style = (long)SvIV(ST(9))
;
	}
    try {
      RETVAL = THIS->Create( flags, sheet, ctrl, parent, id, caption, pos, size, style );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__RichTextStyleOrganiserDialog_SetStyleSheet); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextStyleOrganiserDialog_SetStyleSheet)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, sheet");
    {
	wxRichTextStyleOrganiserDialog *    THIS = (wxRichTextStyleOrganiserDialog *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextStyleOrganiserDialog" )
;
	wxRichTextStyleSheet*    sheet = (wxRichTextStyleSheet *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::RichTextStyleSheet" )
;
    try {
      THIS->SetStyleSheet( sheet );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__RichTextStyleOrganiserDialog_GetStyleSheet); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextStyleOrganiserDialog_GetStyleSheet)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxRichTextStyleOrganiserDialog *    THIS = (wxRichTextStyleOrganiserDialog *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextStyleOrganiserDialog" )
;
	wxRichTextStyleSheet *	RETVAL;
    try {
      RETVAL = THIS->GetStyleSheet();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_object_2_sv( aTHX_ RETVALSV, RETVAL );
    wxPli_thread_sv_register( aTHX_ "Wx::RichTextStyleSheet", RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__RichTextStyleOrganiserDialog_SetRichTextCtrl); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextStyleOrganiserDialog_SetRichTextCtrl)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, ctrl");
    {
	wxRichTextStyleOrganiserDialog *    THIS = (wxRichTextStyleOrganiserDialog *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextStyleOrganiserDialog" )
;
	wxRichTextCtrl*    ctrl = (wxRichTextCtrl *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::RichTextCtrl" )
;
    try {
      THIS->SetRichTextCtrl( ctrl );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__RichTextStyleOrganiserDialog_GetRichTextCtrl); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextStyleOrganiserDialog_GetRichTextCtrl)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxRichTextStyleOrganiserDialog *    THIS = (wxRichTextStyleOrganiserDialog *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextStyleOrganiserDialog" )
;
	wxRichTextCtrl *	RETVAL;
    try {
      RETVAL = THIS->GetRichTextCtrl();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_evthandler_2_sv( aTHX_ RETVALSV, RETVAL );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__RichTextStyleOrganiserDialog_SetFlags); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextStyleOrganiserDialog_SetFlags)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, flags");
    {
	wxRichTextStyleOrganiserDialog *    THIS = (wxRichTextStyleOrganiserDialog *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextStyleOrganiserDialog" )
;
	int	flags = (int)SvIV(ST(1))
;
    try {
      THIS->SetFlags( flags );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__RichTextStyleOrganiserDialog_GetFlags); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextStyleOrganiserDialog_GetFlags)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxRichTextStyleOrganiserDialog *    THIS = (wxRichTextStyleOrganiserDialog *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextStyleOrganiserDialog" )
;
	int	RETVAL;
	dXSTARG;
    try {
      RETVAL = THIS->GetFlags();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__RichTextStyleOrganiserDialog_GetRestartNumbering); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextStyleOrganiserDialog_GetRestartNumbering)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxRichTextStyleOrganiserDialog *    THIS = (wxRichTextStyleOrganiserDialog *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextStyleOrganiserDialog" )
;
	bool	RETVAL;
    try {
      RETVAL = THIS->GetRestartNumbering();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__RichTextStyleOrganiserDialog_SetRestartNumbering); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextStyleOrganiserDialog_SetRestartNumbering)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, restartNumbering");
    {
	wxRichTextStyleOrganiserDialog *    THIS = (wxRichTextStyleOrganiserDialog *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextStyleOrganiserDialog" )
;
	bool	restartNumbering = (bool)SvTRUE(ST(1))
;
    try {
      THIS->SetRestartNumbering( restartNumbering );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__RichTextStyleOrganiserDialog_GetSelectedStyle); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextStyleOrganiserDialog_GetSelectedStyle)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxRichTextStyleOrganiserDialog *    THIS = (wxRichTextStyleOrganiserDialog *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextStyleOrganiserDialog" )
;
	wxString	RETVAL;
    try {
      RETVAL = THIS->GetSelectedStyle();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    WXSTRING_OUTPUT( RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__RichTextStyleOrganiserDialog_GetSelectedStyleDefinition); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextStyleOrganiserDialog_GetSelectedStyleDefinition)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxRichTextStyleOrganiserDialog *    THIS = (wxRichTextStyleOrganiserDialog *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextStyleOrganiserDialog" )
;
	wxRichTextStyleDefinition *	RETVAL;
    try {
      RETVAL = THIS->GetSelectedStyleDefinition();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_object_2_sv( aTHX_ RETVALSV, RETVAL );
    wxPli_thread_sv_register( aTHX_ "Wx::RichTextStyleDefinition", RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__RichTextStyleOrganiserDialog_ApplyStyle); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextStyleOrganiserDialog_ApplyStyle)
{
    dVAR; dXSARGS;
    if (items < 1 || items > 2)
       croak_xs_usage(cv,  "THIS, ctrl= NULL");
    {
	wxRichTextStyleOrganiserDialog *    THIS = (wxRichTextStyleOrganiserDialog *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextStyleOrganiserDialog" )
;
	bool	RETVAL;
	wxRichTextCtrl*	ctrl;

	if (items < 2)
	    ctrl = NULL;
	else {
    ctrl = (wxRichTextCtrl *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::RichTextCtrl" )
;
	}
    try {
      RETVAL = THIS->ApplyStyle( ctrl );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__RichTextStyleOrganiserDialog_ShowToolTips); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextStyleOrganiserDialog_ShowToolTips)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	bool	RETVAL;
    try {
      RETVAL = wxRichTextStyleOrganiserDialog::ShowToolTips();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__RichTextStyleOrganiserDialog_SetShowToolTips); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextStyleOrganiserDialog_SetShowToolTips)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "show");
    {
	bool	show = (bool)SvTRUE(ST(0))
;
    try {
      wxRichTextStyleOrganiserDialog::SetShowToolTips( show );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


/* INCLUDE: Returning to 'RichText.xs' from '/usr/bin/perl -MExtUtils::XSpp::Cmd -e xspp -- -t typemap.xsp -t ../../typemap.xsp XS/RichTextStyleOrganiserDialog.xsp' */


/* INCLUDE_COMMAND:  Including output of '/usr/bin/perl -MExtUtils::XSpp::Cmd -e xspp -- -t typemap.xsp -t ../../typemap.xsp XS/RichTextPrinting.xsp' from 'RichText.xs' */

#include <exception>

#undef  xsp_constructor_class
#define xsp_constructor_class(c) (c)
#if WXPERL_W_VERSION_GE( 2, 8, 0 )
#define XSpp_f0ca9466_064695
#include <wx/richtext/richtextprint.h>
#undef  xsp_constructor_class
#define xsp_constructor_class(c) (CLASS)
#define XSubPPtmpAADH 1


XS_EUPXS(XS_Wx__RichTextPrintout_new); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextPrintout_new)
{
    dVAR; dXSARGS;
    if (items < 1 || items > 2)
       croak_xs_usage(cv,  "CLASS, title= wxT(\"Printout\")");
    {
	char *	CLASS = (char *)SvPV_nolen(ST(0))
;
	wxRichTextPrintout *	RETVAL;
	wxString	title;

	if (items < 2)
	    title = wxT("Printout");
	else {
    WXSTRING_INPUT( title, wxString, ST(1) )
;
	}
    try {
      RETVAL = new wxRichTextPrintout( title );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_non_object_2_sv( aTHX_ RETVALSV, RETVAL, "Wx::RichTextPrintout" );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}

#undef  xsp_constructor_class
#define xsp_constructor_class(c) (c)

XS_EUPXS(XS_Wx__RichTextPrintout_Destroy); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextPrintout_Destroy)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxRichTextPrintout *    THIS = (wxRichTextPrintout *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextPrintout" )
;
     delete THIS; 
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__RichTextPrintout_SetRichTextBuffer); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextPrintout_SetRichTextBuffer)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, buffer");
    {
	wxRichTextPrintout *    THIS = (wxRichTextPrintout *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextPrintout" )
;
	wxRichTextBuffer*    buffer = (wxRichTextBuffer *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::RichTextBuffer" )
;
    try {
      THIS->SetRichTextBuffer( buffer );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__RichTextPrintout_GetRichTextBuffer); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextPrintout_GetRichTextBuffer)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxRichTextPrintout *    THIS = (wxRichTextPrintout *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextPrintout" )
;
	wxRichTextBuffer *	RETVAL;
    try {
      RETVAL = THIS->GetRichTextBuffer();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_object_2_sv( aTHX_ RETVALSV, RETVAL );
    wxPli_thread_sv_register( aTHX_ "Wx::RichTextBuffer", RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__RichTextPrintout_SetHeaderFooterData); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextPrintout_SetHeaderFooterData)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, data");
    {
	wxRichTextPrintout *    THIS = (wxRichTextPrintout *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextPrintout" )
;
	wxRichTextHeaderFooterData*    data = (wxRichTextHeaderFooterData *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::RichTextHeaderFooterData" )
;
    try {
      THIS->SetHeaderFooterData( *( data ) );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__RichTextPrintout_GetHeaderFooterData); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextPrintout_GetHeaderFooterData)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxRichTextPrintout *    THIS = (wxRichTextPrintout *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextPrintout" )
;
	wxRichTextHeaderFooterData *	RETVAL;
    try {
      RETVAL = new wxRichTextHeaderFooterData( THIS->GetHeaderFooterData() );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_object_2_sv( aTHX_ RETVALSV, RETVAL );
    wxPli_thread_sv_register( aTHX_ "Wx::RichTextHeaderFooterData", RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__RichTextPrintout_SetMargins); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextPrintout_SetMargins)
{
    dVAR; dXSARGS;
    if (items < 1 || items > 5)
       croak_xs_usage(cv,  "THIS, top= 254, bottom= 254, left= 254, right= 254");
    {
	wxRichTextPrintout *    THIS = (wxRichTextPrintout *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextPrintout" )
;
	int	top;
	int	bottom;
	int	left;
	int	right;

	if (items < 2)
	    top = 254;
	else {
	    top = (int)SvIV(ST(1))
;
	}

	if (items < 3)
	    bottom = 254;
	else {
	    bottom = (int)SvIV(ST(2))
;
	}

	if (items < 4)
	    left = 254;
	else {
	    left = (int)SvIV(ST(3))
;
	}

	if (items < 5)
	    right = 254;
	else {
	    right = (int)SvIV(ST(4))
;
	}
    try {
      THIS->SetMargins( top, bottom, left, right );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__RichTextPrintout_CalculateScaling); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextPrintout_CalculateScaling)
{
    dVAR; dXSARGS;
    if (items != 5)
       croak_xs_usage(cv,  "THIS, dc, textRect, headerRect, footerRect");
    {
	wxRichTextPrintout *    THIS = (wxRichTextPrintout *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextPrintout" )
;
	wxDC*    dc = (wxDC *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::DC" )
;
	wxRect*    textRect = (wxRect *) wxPli_sv_2_object( aTHX_ ST(2), "Wx::Rect" )
;
	wxRect*    headerRect = (wxRect *) wxPli_sv_2_object( aTHX_ ST(3), "Wx::Rect" )
;
	wxRect*    footerRect = (wxRect *) wxPli_sv_2_object( aTHX_ ST(4), "Wx::Rect" )
;
    try {
      THIS->CalculateScaling( dc, *( textRect ), *( headerRect ), *( footerRect ) );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__RichTextPrintout_OnPrintPage); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextPrintout_OnPrintPage)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, page");
    {
	wxRichTextPrintout *    THIS = (wxRichTextPrintout *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextPrintout" )
;
	bool	RETVAL;
	int	page = (int)SvIV(ST(1))
;
    try {
      RETVAL = THIS->OnPrintPage( page );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__RichTextPrintout_HasPage); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextPrintout_HasPage)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, page");
    {
	wxRichTextPrintout *    THIS = (wxRichTextPrintout *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextPrintout" )
;
	bool	RETVAL;
	int	page = (int)SvIV(ST(1))
;
    try {
      RETVAL = THIS->HasPage( page );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__RichTextPrintout_OnBeginDocument); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextPrintout_OnBeginDocument)
{
    dVAR; dXSARGS;
    if (items != 3)
       croak_xs_usage(cv,  "THIS, startPage, endPage");
    {
	wxRichTextPrintout *    THIS = (wxRichTextPrintout *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextPrintout" )
;
	bool	RETVAL;
	int	startPage = (int)SvIV(ST(1))
;
	int	endPage = (int)SvIV(ST(2))
;
    try {
      RETVAL = THIS->OnBeginDocument( startPage, endPage );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__RichTextPrintout_OnPreparePrinting); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextPrintout_OnPreparePrinting)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxRichTextPrintout *    THIS = (wxRichTextPrintout *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextPrintout" )
;
    try {
      THIS->OnPreparePrinting();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__RichTextPrintout_GetPageInfo); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextPrintout_GetPageInfo)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    PERL_UNUSED_VAR(ax); /* -Wall */
    SP -= items;
    {
    int minPage, maxPage, pageFrom, pageTo;
	wxRichTextPrintout *    THIS = (wxRichTextPrintout *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextPrintout" )
;
    THIS->wxRichTextPrintout::GetPageInfo( &minPage, &maxPage, &pageFrom, &pageTo );
    EXTEND( SP, 4 );
    PUSHs( sv_2mortal( newSViv( minPage ) ) );
    PUSHs( sv_2mortal( newSViv( maxPage ) ) );
    PUSHs( sv_2mortal( newSViv( pageFrom ) ) );
    PUSHs( sv_2mortal( newSViv( pageTo ) ) );
	PUTBACK;
	return;
    }
}

#undef  xsp_constructor_class
#define xsp_constructor_class(c) (CLASS)

XS_EUPXS(XS_Wx__RichTextPrinting_new); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextPrinting_new)
{
    dVAR; dXSARGS;
    if (items < 1 || items > 3)
       croak_xs_usage(cv,  "CLASS, name= wxT(\"Printing\"), parentWindow= NULL");
    {
	char *	CLASS = (char *)SvPV_nolen(ST(0))
;
	wxRichTextPrinting *	RETVAL;
	wxString	name;
	wxWindow*	parentWindow;

	if (items < 2)
	    name = wxT("Printing");
	else {
    WXSTRING_INPUT( name, wxString, ST(1) )
;
	}

	if (items < 3)
	    parentWindow = NULL;
	else {
    parentWindow = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(2), "Wx::Window" )
;
	}
    try {
      RETVAL = new wxRichTextPrinting( name, parentWindow );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_non_object_2_sv( aTHX_ RETVALSV, RETVAL, "Wx::RichTextPrinting" );
    wxPli_thread_sv_register( aTHX_ "Wx::RichTextPrinting", RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}

#undef  xsp_constructor_class
#define xsp_constructor_class(c) (c)

XS_EUPXS(XS_Wx__RichTextPrinting_DESTROY); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextPrinting_DESTROY)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxRichTextPrinting *    THIS = (wxRichTextPrinting *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextPrinting" )
;
      wxPli_thread_sv_unregister( aTHX_ "Wx::RichTextPrinting", THIS, ST(0) );
                 delete THIS; 
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__RichTextPrinting_CLONE); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextPrinting_CLONE)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "CLASS");
    {
	char *	CLASS = (char *)SvPV_nolen(ST(0))
;
    wxPli_thread_sv_clone( aTHX_ CLASS, (wxPliCloneSV)wxPli_detach_object );
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__RichTextPrinting_PreviewFile); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextPrinting_PreviewFile)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, richTextFile");
    {
	wxRichTextPrinting *    THIS = (wxRichTextPrinting *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextPrinting" )
;
	bool	RETVAL;
	wxString	richTextFile;

    WXSTRING_INPUT( richTextFile, wxString, ST(1) )
;
    try {
      RETVAL = THIS->PreviewFile( richTextFile );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__RichTextPrinting_PreviewBuffer); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextPrinting_PreviewBuffer)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, buffer");
    {
	wxRichTextPrinting *    THIS = (wxRichTextPrinting *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextPrinting" )
;
	bool	RETVAL;
	wxRichTextBuffer*    buffer = (wxRichTextBuffer *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::RichTextBuffer" )
;
    try {
      RETVAL = THIS->PreviewBuffer( *( buffer ) );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}

#if WXPERL_W_VERSION_GE( 2, 9, 4 )
#define XSpp_f0ca9466_076564
#define XSubPPtmpAADI 1


XS_EUPXS(XS_Wx__RichTextPrinting_PrintFile); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextPrinting_PrintFile)
{
    dVAR; dXSARGS;
    if (items < 2 || items > 3)
       croak_xs_usage(cv,  "THIS, richTextFile, showPrintDialog= true");
    {
	wxRichTextPrinting *    THIS = (wxRichTextPrinting *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextPrinting" )
;
	bool	RETVAL;
	wxString	richTextFile;
	bool	showPrintDialog;

    WXSTRING_INPUT( richTextFile, wxString, ST(1) )
;

	if (items < 3)
	    showPrintDialog = true;
	else {
	    showPrintDialog = (bool)SvTRUE(ST(2))
;
	}
    try {
      RETVAL = THIS->PrintFile( richTextFile, showPrintDialog );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__RichTextPrinting_PrintBuffer); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextPrinting_PrintBuffer)
{
    dVAR; dXSARGS;
    if (items < 2 || items > 3)
       croak_xs_usage(cv,  "THIS, buffer, showPrintDialog= true");
    {
	wxRichTextPrinting *    THIS = (wxRichTextPrinting *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextPrinting" )
;
	bool	RETVAL;
	wxRichTextBuffer*    buffer = (wxRichTextBuffer *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::RichTextBuffer" )
;
	bool	showPrintDialog;

	if (items < 3)
	    showPrintDialog = true;
	else {
	    showPrintDialog = (bool)SvTRUE(ST(2))
;
	}
    try {
      RETVAL = THIS->PrintBuffer( *( buffer ), showPrintDialog );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}

#else
#define XSpp_f0ca9466_060417
#define XSubPPtmpAADJ 1


XS_EUPXS(XS_Wx__RichTextPrinting_PrintFile); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextPrinting_PrintFile)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, richTextFile");
    {
	wxRichTextPrinting *    THIS = (wxRichTextPrinting *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextPrinting" )
;
	bool	RETVAL;
	wxString	richTextFile;

    WXSTRING_INPUT( richTextFile, wxString, ST(1) )
;
    try {
      RETVAL = THIS->PrintFile( richTextFile );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__RichTextPrinting_PrintBuffer); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextPrinting_PrintBuffer)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, buffer");
    {
	wxRichTextPrinting *    THIS = (wxRichTextPrinting *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextPrinting" )
;
	bool	RETVAL;
	wxRichTextBuffer*    buffer = (wxRichTextBuffer *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::RichTextBuffer" )
;
    try {
      RETVAL = THIS->PrintBuffer( *( buffer ) );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}

#endif

XS_EUPXS(XS_Wx__RichTextPrinting_PageSetup); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextPrinting_PageSetup)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxRichTextPrinting *    THIS = (wxRichTextPrinting *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextPrinting" )
;
    try {
      THIS->PageSetup();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__RichTextPrinting_SetHeaderFooterData); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextPrinting_SetHeaderFooterData)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, data");
    {
	wxRichTextPrinting *    THIS = (wxRichTextPrinting *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextPrinting" )
;
	wxRichTextHeaderFooterData*    data = (wxRichTextHeaderFooterData *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::RichTextHeaderFooterData" )
;
    try {
      THIS->SetHeaderFooterData( *( data ) );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__RichTextPrinting_GetHeaderFooterData); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextPrinting_GetHeaderFooterData)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxRichTextPrinting *    THIS = (wxRichTextPrinting *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextPrinting" )
;
	wxRichTextHeaderFooterData *	RETVAL;
    try {
      RETVAL = new wxRichTextHeaderFooterData( THIS->GetHeaderFooterData() );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_object_2_sv( aTHX_ RETVALSV, RETVAL );
    wxPli_thread_sv_register( aTHX_ "Wx::RichTextHeaderFooterData", RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__RichTextPrinting_SetHeaderText); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextPrinting_SetHeaderText)
{
    dVAR; dXSARGS;
    if (items < 2 || items > 4)
       croak_xs_usage(cv,  "THIS, text, page= wxRICHTEXT_PAGE_ALL, location= wxRICHTEXT_PAGE_CENTRE");
    {
	wxRichTextPrinting *    THIS = (wxRichTextPrinting *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextPrinting" )
;
	wxString	text;
	wxRichTextOddEvenPage	page;
	wxRichTextPageLocation	location;

    WXSTRING_INPUT( text, wxString, ST(1) )
;

	if (items < 3)
	    page = wxRICHTEXT_PAGE_ALL;
	else {
	    page = (wxRichTextOddEvenPage)SvIV(ST(2))
;
	}

	if (items < 4)
	    location = wxRICHTEXT_PAGE_CENTRE;
	else {
	    location = (wxRichTextPageLocation)SvIV(ST(3))
;
	}
    try {
      THIS->SetHeaderText( text, page, location );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__RichTextPrinting_GetHeaderText); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextPrinting_GetHeaderText)
{
    dVAR; dXSARGS;
    if (items < 1 || items > 3)
       croak_xs_usage(cv,  "THIS, page= wxRICHTEXT_PAGE_EVEN, location= wxRICHTEXT_PAGE_CENTRE");
    {
	wxRichTextPrinting *    THIS = (wxRichTextPrinting *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextPrinting" )
;
	wxString	RETVAL;
	wxRichTextOddEvenPage	page;
	wxRichTextPageLocation	location;

	if (items < 2)
	    page = wxRICHTEXT_PAGE_EVEN;
	else {
	    page = (wxRichTextOddEvenPage)SvIV(ST(1))
;
	}

	if (items < 3)
	    location = wxRICHTEXT_PAGE_CENTRE;
	else {
	    location = (wxRichTextPageLocation)SvIV(ST(2))
;
	}
    try {
      RETVAL = THIS->GetHeaderText( page, location );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    WXSTRING_OUTPUT( RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__RichTextPrinting_SetFooterText); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextPrinting_SetFooterText)
{
    dVAR; dXSARGS;
    if (items < 2 || items > 4)
       croak_xs_usage(cv,  "THIS, text, page= wxRICHTEXT_PAGE_ALL, location= wxRICHTEXT_PAGE_CENTRE");
    {
	wxRichTextPrinting *    THIS = (wxRichTextPrinting *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextPrinting" )
;
	wxString	text;
	wxRichTextOddEvenPage	page;
	wxRichTextPageLocation	location;

    WXSTRING_INPUT( text, wxString, ST(1) )
;

	if (items < 3)
	    page = wxRICHTEXT_PAGE_ALL;
	else {
	    page = (wxRichTextOddEvenPage)SvIV(ST(2))
;
	}

	if (items < 4)
	    location = wxRICHTEXT_PAGE_CENTRE;
	else {
	    location = (wxRichTextPageLocation)SvIV(ST(3))
;
	}
    try {
      THIS->SetFooterText( text, page, location );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__RichTextPrinting_GetFooterText); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextPrinting_GetFooterText)
{
    dVAR; dXSARGS;
    if (items < 1 || items > 3)
       croak_xs_usage(cv,  "THIS, page= wxRICHTEXT_PAGE_EVEN, location= wxRICHTEXT_PAGE_CENTRE");
    {
	wxRichTextPrinting *    THIS = (wxRichTextPrinting *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextPrinting" )
;
	wxString	RETVAL;
	wxRichTextOddEvenPage	page;
	wxRichTextPageLocation	location;

	if (items < 2)
	    page = wxRICHTEXT_PAGE_EVEN;
	else {
	    page = (wxRichTextOddEvenPage)SvIV(ST(1))
;
	}

	if (items < 3)
	    location = wxRICHTEXT_PAGE_CENTRE;
	else {
	    location = (wxRichTextPageLocation)SvIV(ST(2))
;
	}
    try {
      RETVAL = THIS->GetFooterText( page, location );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    WXSTRING_OUTPUT( RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__RichTextPrinting_SetShowOnFirstPage); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextPrinting_SetShowOnFirstPage)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, show");
    {
	wxRichTextPrinting *    THIS = (wxRichTextPrinting *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextPrinting" )
;
	bool	show = (bool)SvTRUE(ST(1))
;
    try {
      THIS->SetShowOnFirstPage( show );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__RichTextPrinting_SetHeaderFooterFont); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextPrinting_SetHeaderFooterFont)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, font");
    {
	wxRichTextPrinting *    THIS = (wxRichTextPrinting *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextPrinting" )
;
	wxFont*    font = (wxFont *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::Font" )
;
    try {
      THIS->SetHeaderFooterFont( *( font ) );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__RichTextPrinting_SetHeaderFooterTextColour); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextPrinting_SetHeaderFooterTextColour)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, font");
    {
	wxRichTextPrinting *    THIS = (wxRichTextPrinting *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextPrinting" )
;
	wxColour*    font = (wxColour *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::Colour" )
;
    try {
      THIS->SetHeaderFooterTextColour( *( font ) );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__RichTextPrinting_GetPrintData); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextPrinting_GetPrintData)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxRichTextPrinting *    THIS = (wxRichTextPrinting *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextPrinting" )
;
	wxPrintData *	RETVAL;
    try {
      RETVAL = THIS->GetPrintData();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_object_2_sv( aTHX_ RETVALSV, RETVAL );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__RichTextPrinting_SetPrintData); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextPrinting_SetPrintData)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, printData");
    {
	wxRichTextPrinting *    THIS = (wxRichTextPrinting *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextPrinting" )
;
	wxPrintData*    printData = (wxPrintData *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::PrintData" )
;
    try {
      THIS->SetPrintData( *( printData ) );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__RichTextPrinting_GetPageSetupData); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextPrinting_GetPageSetupData)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxRichTextPrinting *    THIS = (wxRichTextPrinting *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextPrinting" )
;
	wxPageSetupDialogData *	RETVAL;
    try {
      RETVAL = THIS->GetPageSetupData();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_object_2_sv( aTHX_ RETVALSV, RETVAL );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__RichTextPrinting_SetPageSetupData); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextPrinting_SetPageSetupData)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, pageSetupData");
    {
	wxRichTextPrinting *    THIS = (wxRichTextPrinting *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextPrinting" )
;
	wxPageSetupDialogData*    pageSetupData = (wxPageSetupDialogData *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::PageSetupDialogData" )
;
    try {
      THIS->SetPageSetupData( *( pageSetupData ) );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__RichTextPrinting_SetRichTextBufferPreview); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextPrinting_SetRichTextBufferPreview)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, buffer");
    {
	wxRichTextPrinting *    THIS = (wxRichTextPrinting *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextPrinting" )
;
	wxRichTextBuffer*    buffer = (wxRichTextBuffer *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::RichTextBuffer" )
;
     THIS->SetRichTextBufferPreview(buffer); 
     wxPli_object_set_deleteable( aTHX_ ST(0), false ); 
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__RichTextPrinting_GetRichTextBufferPreview); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextPrinting_GetRichTextBufferPreview)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxRichTextPrinting *    THIS = (wxRichTextPrinting *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextPrinting" )
;
	wxRichTextBuffer *	RETVAL;
     RETVAL = THIS->GetRichTextBufferPreview(); 
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_object_2_sv( aTHX_ RETVALSV, RETVAL );
    wxPli_thread_sv_register( aTHX_ "Wx::RichTextBuffer", RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
     wxPli_object_set_deleteable( aTHX_ ST(0), false ); 
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__RichTextPrinting_SetRichTextBufferPrinting); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextPrinting_SetRichTextBufferPrinting)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, buffer");
    {
	wxRichTextPrinting *    THIS = (wxRichTextPrinting *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextPrinting" )
;
	wxRichTextBuffer*    buffer = (wxRichTextBuffer *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::RichTextBuffer" )
;
     THIS->SetRichTextBufferPrinting(buffer); 
     wxPli_object_set_deleteable( aTHX_ ST(0), false ); 
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__RichTextPrinting_GetRichTextBufferPrinting); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextPrinting_GetRichTextBufferPrinting)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxRichTextPrinting *    THIS = (wxRichTextPrinting *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextPrinting" )
;
	wxRichTextBuffer *	RETVAL;
     RETVAL = THIS->GetRichTextBufferPrinting(); 
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_object_2_sv( aTHX_ RETVALSV, RETVAL );
    wxPli_thread_sv_register( aTHX_ "Wx::RichTextBuffer", RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
     wxPli_object_set_deleteable( aTHX_ ST(0), false ); 
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__RichTextPrinting_SetParentWindow); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextPrinting_SetParentWindow)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, parent");
    {
	wxRichTextPrinting *    THIS = (wxRichTextPrinting *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextPrinting" )
;
	wxWindow*    parent = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::Window" )
;
    try {
      THIS->SetParentWindow( parent );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__RichTextPrinting_GetParentWindow); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextPrinting_GetParentWindow)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxRichTextPrinting *    THIS = (wxRichTextPrinting *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextPrinting" )
;
	wxWindow *	RETVAL;
    try {
      RETVAL = THIS->GetParentWindow();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_object_2_sv( aTHX_ RETVALSV, RETVAL );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__RichTextPrinting_SetTitle); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextPrinting_SetTitle)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, title");
    {
	wxRichTextPrinting *    THIS = (wxRichTextPrinting *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextPrinting" )
;
	wxString	title;

    WXSTRING_INPUT( title, wxString, ST(1) )
;
    try {
      THIS->SetTitle( title );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__RichTextPrinting_GetTitle); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextPrinting_GetTitle)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxRichTextPrinting *    THIS = (wxRichTextPrinting *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextPrinting" )
;
	wxString	RETVAL;
    try {
      RETVAL = THIS->GetTitle();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    WXSTRING_OUTPUT( RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__RichTextPrinting_SetPreviewRect); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextPrinting_SetPreviewRect)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, rect");
    {
	wxRichTextPrinting *    THIS = (wxRichTextPrinting *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextPrinting" )
;
	wxRect*    rect = (wxRect *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::Rect" )
;
    try {
      THIS->SetPreviewRect( *( rect ) );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__RichTextPrinting_GetPreviewRect); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextPrinting_GetPreviewRect)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxRichTextPrinting *    THIS = (wxRichTextPrinting *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextPrinting" )
;
	wxRect *	RETVAL;
    try {
      RETVAL = new wxRect( THIS->GetPreviewRect() );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_non_object_2_sv( aTHX_ RETVALSV, RETVAL, "Wx::Rect" );
    wxPli_thread_sv_register( aTHX_ "Wx::Rect", RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}

#undef  xsp_constructor_class
#define xsp_constructor_class(c) (CLASS)

XS_EUPXS(XS_Wx__RichTextHeaderFooterData_newDefault); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextHeaderFooterData_newDefault)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "CLASS");
    {
	char *	CLASS = (char *)SvPV_nolen(ST(0))
;
	wxRichTextHeaderFooterData *	RETVAL;
    try {
      RETVAL = new wxRichTextHeaderFooterData();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_object_2_sv( aTHX_ RETVALSV, RETVAL );
    wxPli_thread_sv_register( aTHX_ "Wx::RichTextHeaderFooterData", RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}

#undef  xsp_constructor_class
#define xsp_constructor_class(c) (c)
#undef  xsp_constructor_class
#define xsp_constructor_class(c) (CLASS)

XS_EUPXS(XS_Wx__RichTextHeaderFooterData_newCopy); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextHeaderFooterData_newCopy)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "CLASS, data");
    {
	char *	CLASS = (char *)SvPV_nolen(ST(0))
;
	wxRichTextHeaderFooterData *	RETVAL;
	wxRichTextHeaderFooterData*    data = (wxRichTextHeaderFooterData *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::RichTextHeaderFooterData" )
;
    try {
      RETVAL = new wxRichTextHeaderFooterData( *( data ) );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_object_2_sv( aTHX_ RETVALSV, RETVAL );
    wxPli_thread_sv_register( aTHX_ "Wx::RichTextHeaderFooterData", RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}

#undef  xsp_constructor_class
#define xsp_constructor_class(c) (c)

XS_EUPXS(XS_Wx__RichTextHeaderFooterData_DESTROY); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextHeaderFooterData_DESTROY)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxRichTextHeaderFooterData *    THIS = (wxRichTextHeaderFooterData *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextHeaderFooterData" )
;
      wxPli_thread_sv_unregister( aTHX_ "Wx::RichTextHeaderFooterData", THIS, ST(0) );
                 delete THIS; 
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__RichTextHeaderFooterData_CLONE); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextHeaderFooterData_CLONE)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "CLASS");
    {
	char *	CLASS = (char *)SvPV_nolen(ST(0))
;
    wxPli_thread_sv_clone( aTHX_ CLASS, (wxPliCloneSV)wxPli_detach_object );
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__RichTextHeaderFooterData_SetHeaderText); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextHeaderFooterData_SetHeaderText)
{
    dVAR; dXSARGS;
    if (items < 2 || items > 4)
       croak_xs_usage(cv,  "THIS, text, page= wxRICHTEXT_PAGE_ALL, location= wxRICHTEXT_PAGE_CENTRE");
    {
	wxRichTextHeaderFooterData *    THIS = (wxRichTextHeaderFooterData *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextHeaderFooterData" )
;
	wxString	text;
	wxRichTextOddEvenPage	page;
	wxRichTextPageLocation	location;

    WXSTRING_INPUT( text, wxString, ST(1) )
;

	if (items < 3)
	    page = wxRICHTEXT_PAGE_ALL;
	else {
	    page = (wxRichTextOddEvenPage)SvIV(ST(2))
;
	}

	if (items < 4)
	    location = wxRICHTEXT_PAGE_CENTRE;
	else {
	    location = (wxRichTextPageLocation)SvIV(ST(3))
;
	}
    try {
      THIS->SetHeaderText( text, page, location );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__RichTextHeaderFooterData_GetHeaderText); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextHeaderFooterData_GetHeaderText)
{
    dVAR; dXSARGS;
    if (items < 1 || items > 3)
       croak_xs_usage(cv,  "THIS, page= wxRICHTEXT_PAGE_EVEN, location= wxRICHTEXT_PAGE_CENTRE");
    {
	wxRichTextHeaderFooterData *    THIS = (wxRichTextHeaderFooterData *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextHeaderFooterData" )
;
	wxString	RETVAL;
	wxRichTextOddEvenPage	page;
	wxRichTextPageLocation	location;

	if (items < 2)
	    page = wxRICHTEXT_PAGE_EVEN;
	else {
	    page = (wxRichTextOddEvenPage)SvIV(ST(1))
;
	}

	if (items < 3)
	    location = wxRICHTEXT_PAGE_CENTRE;
	else {
	    location = (wxRichTextPageLocation)SvIV(ST(2))
;
	}
    try {
      RETVAL = THIS->GetHeaderText( page, location );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    WXSTRING_OUTPUT( RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__RichTextHeaderFooterData_SetFooterText); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextHeaderFooterData_SetFooterText)
{
    dVAR; dXSARGS;
    if (items < 2 || items > 4)
       croak_xs_usage(cv,  "THIS, text, page= wxRICHTEXT_PAGE_ALL, location= wxRICHTEXT_PAGE_CENTRE");
    {
	wxRichTextHeaderFooterData *    THIS = (wxRichTextHeaderFooterData *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextHeaderFooterData" )
;
	wxString	text;
	wxRichTextOddEvenPage	page;
	wxRichTextPageLocation	location;

    WXSTRING_INPUT( text, wxString, ST(1) )
;

	if (items < 3)
	    page = wxRICHTEXT_PAGE_ALL;
	else {
	    page = (wxRichTextOddEvenPage)SvIV(ST(2))
;
	}

	if (items < 4)
	    location = wxRICHTEXT_PAGE_CENTRE;
	else {
	    location = (wxRichTextPageLocation)SvIV(ST(3))
;
	}
    try {
      THIS->SetFooterText( text, page, location );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__RichTextHeaderFooterData_GetFooterText); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextHeaderFooterData_GetFooterText)
{
    dVAR; dXSARGS;
    if (items < 1 || items > 3)
       croak_xs_usage(cv,  "THIS, page= wxRICHTEXT_PAGE_EVEN, location= wxRICHTEXT_PAGE_CENTRE");
    {
	wxRichTextHeaderFooterData *    THIS = (wxRichTextHeaderFooterData *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextHeaderFooterData" )
;
	wxString	RETVAL;
	wxRichTextOddEvenPage	page;
	wxRichTextPageLocation	location;

	if (items < 2)
	    page = wxRICHTEXT_PAGE_EVEN;
	else {
	    page = (wxRichTextOddEvenPage)SvIV(ST(1))
;
	}

	if (items < 3)
	    location = wxRICHTEXT_PAGE_CENTRE;
	else {
	    location = (wxRichTextPageLocation)SvIV(ST(2))
;
	}
    try {
      RETVAL = THIS->GetFooterText( page, location );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    WXSTRING_OUTPUT( RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__RichTextHeaderFooterData_SetText); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextHeaderFooterData_SetText)
{
    dVAR; dXSARGS;
    if (items != 5)
       croak_xs_usage(cv,  "THIS, text, headerFooter, page, location");
    {
	wxRichTextHeaderFooterData *    THIS = (wxRichTextHeaderFooterData *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextHeaderFooterData" )
;
	wxString	text;
	int	headerFooter = (int)SvIV(ST(2))
;
	wxRichTextOddEvenPage	page = (wxRichTextOddEvenPage)SvIV(ST(3))
;
	wxRichTextPageLocation	location = (wxRichTextPageLocation)SvIV(ST(4))
;

    WXSTRING_INPUT( text, wxString, ST(1) )
;
    try {
      THIS->SetText( text, headerFooter, page, location );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__RichTextHeaderFooterData_GetText); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextHeaderFooterData_GetText)
{
    dVAR; dXSARGS;
    if (items != 4)
       croak_xs_usage(cv,  "THIS, headerFooter, page, location");
    {
	wxRichTextHeaderFooterData *    THIS = (wxRichTextHeaderFooterData *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextHeaderFooterData" )
;
	wxString	RETVAL;
	int	headerFooter = (int)SvIV(ST(1))
;
	wxRichTextOddEvenPage	page = (wxRichTextOddEvenPage)SvIV(ST(2))
;
	wxRichTextPageLocation	location = (wxRichTextPageLocation)SvIV(ST(3))
;
    try {
      RETVAL = THIS->GetText( headerFooter, page, location );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    WXSTRING_OUTPUT( RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__RichTextHeaderFooterData_SetMargins); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextHeaderFooterData_SetMargins)
{
    dVAR; dXSARGS;
    if (items != 3)
       croak_xs_usage(cv,  "THIS, headerMargin, footerMargin");
    {
	wxRichTextHeaderFooterData *    THIS = (wxRichTextHeaderFooterData *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextHeaderFooterData" )
;
	int	headerMargin = (int)SvIV(ST(1))
;
	int	footerMargin = (int)SvIV(ST(2))
;
    try {
      THIS->SetMargins( headerMargin, footerMargin );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__RichTextHeaderFooterData_GetHeaderMargin); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextHeaderFooterData_GetHeaderMargin)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxRichTextHeaderFooterData *    THIS = (wxRichTextHeaderFooterData *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextHeaderFooterData" )
;
	int	RETVAL;
	dXSTARG;
    try {
      RETVAL = THIS->GetHeaderMargin();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__RichTextHeaderFooterData_GetFooterMargin); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextHeaderFooterData_GetFooterMargin)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxRichTextHeaderFooterData *    THIS = (wxRichTextHeaderFooterData *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextHeaderFooterData" )
;
	int	RETVAL;
	dXSTARG;
    try {
      RETVAL = THIS->GetFooterMargin();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__RichTextHeaderFooterData_SetShowOnFirstPage); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextHeaderFooterData_SetShowOnFirstPage)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, showOnFirstPage");
    {
	wxRichTextHeaderFooterData *    THIS = (wxRichTextHeaderFooterData *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextHeaderFooterData" )
;
	bool	showOnFirstPage = (bool)SvTRUE(ST(1))
;
    try {
      THIS->SetShowOnFirstPage( showOnFirstPage );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__RichTextHeaderFooterData_GetShowOnFirstPage); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextHeaderFooterData_GetShowOnFirstPage)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxRichTextHeaderFooterData *    THIS = (wxRichTextHeaderFooterData *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextHeaderFooterData" )
;
	bool	RETVAL;
    try {
      RETVAL = THIS->GetShowOnFirstPage();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__RichTextHeaderFooterData_Clear); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextHeaderFooterData_Clear)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxRichTextHeaderFooterData *    THIS = (wxRichTextHeaderFooterData *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextHeaderFooterData" )
;
    try {
      THIS->Clear();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__RichTextHeaderFooterData_SetFont); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextHeaderFooterData_SetFont)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, font");
    {
	wxRichTextHeaderFooterData *    THIS = (wxRichTextHeaderFooterData *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextHeaderFooterData" )
;
	wxFont*    font = (wxFont *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::Font" )
;
    try {
      THIS->SetFont( *( font ) );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__RichTextHeaderFooterData_GetFont); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextHeaderFooterData_GetFont)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxRichTextHeaderFooterData *    THIS = (wxRichTextHeaderFooterData *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextHeaderFooterData" )
;
	wxFont *	RETVAL;
    try {
      RETVAL = new wxFont( THIS->GetFont() );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_object_2_sv( aTHX_ RETVALSV, RETVAL );
    wxPli_thread_sv_register( aTHX_ "Wx::Font", RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__RichTextHeaderFooterData_SetTextColour); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextHeaderFooterData_SetTextColour)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, col");
    {
	wxRichTextHeaderFooterData *    THIS = (wxRichTextHeaderFooterData *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextHeaderFooterData" )
;
	wxColour*    col = (wxColour *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::Colour" )
;
    try {
      THIS->SetTextColour( *( col ) );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__RichTextHeaderFooterData_GetTextColour); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextHeaderFooterData_GetTextColour)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxRichTextHeaderFooterData *    THIS = (wxRichTextHeaderFooterData *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::RichTextHeaderFooterData" )
;
	wxColour *	RETVAL;
    try {
      RETVAL = new wxColour( THIS->GetTextColour() );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_non_object_2_sv( aTHX_ RETVALSV, RETVAL, "Wx::Colour" );
    wxPli_thread_sv_register( aTHX_ "Wx::Colour", RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__RichTextHeaderFooterData_new); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichTextHeaderFooterData_new)
{
    dVAR; dXSARGS;
    if (items < 1)
       croak_xs_usage(cv,  "CLASS, ...");
    PERL_UNUSED_VAR(ax); /* -Wall */
    SP -= items;
    {
	char *	CLASS = (char *)SvPV_nolen(ST(0))
;
    BEGIN_OVERLOAD()
        MATCH_VOIDM_REDISP( newDefault )
        MATCH_REDISP( wxPliOvl_wrth, newCopy )
    END_OVERLOAD( Wx::RichTextHeaderFooterData::new )
	PUTBACK;
	return;
    }
}

#endif

/* INCLUDE: Returning to 'RichText.xs' from '/usr/bin/perl -MExtUtils::XSpp::Cmd -e xspp -- -t typemap.xsp -t ../../typemap.xsp XS/RichTextPrinting.xsp' */


XS_EUPXS(XS_Wx__RichText_SetEvents); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__RichText_SetEvents)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
    wxPli_set_events( evts );
    }
    XSRETURN_EMPTY;
}

#include "cpp/ovl_const.cpp"
#if defined(__WXMSW__)
#undef XS
#define XS( name ) WXXS( name )
#endif
#ifdef __cplusplus
extern "C"
#endif
XS_EXTERNAL(boot_Wx__RichText); /* prototype to pass -Wmissing-prototypes */
XS_EXTERNAL(boot_Wx__RichText)
{
#if PERL_VERSION_LE(5, 21, 5)
    dVAR; dXSARGS;
#else
    dVAR; dXSBOOTARGSXSAPIVERCHK;
#endif
#if PERL_VERSION_LE(5, 8, 999) /* PERL_VERSION_LT is 5.33+ */
    char* file = __FILE__;
#else
    const char* file = __FILE__;
#endif

    PERL_UNUSED_VAR(file);

    PERL_UNUSED_VAR(cv); /* -W */
    PERL_UNUSED_VAR(items); /* -W */
#if PERL_VERSION_LE(5, 21, 5)
    XS_VERSION_BOOTCHECK;
#  ifdef XS_APIVERSION_BOOTCHECK
    XS_APIVERSION_BOOTCHECK;
#  endif
#endif

#if XSubPPtmpAAAA
        newXS_deffile("Wx::RichTextEvent::GetIndex", XS_Wx__RichTextEvent_GetIndex);
        newXS_deffile("Wx::RichTextEvent::SetIndex", XS_Wx__RichTextEvent_SetIndex);
#endif
        newXS_deffile("Wx::RichTextEvent::GetFlags", XS_Wx__RichTextEvent_GetFlags);
        newXS_deffile("Wx::RichTextEvent::SetFlags", XS_Wx__RichTextEvent_SetFlags);
#if XSubPPtmpAAAB
        newXS_deffile("Wx::RichTextEvent::GetOldStyleSheet", XS_Wx__RichTextEvent_GetOldStyleSheet);
        newXS_deffile("Wx::RichTextEvent::SetOldStyleSheet", XS_Wx__RichTextEvent_SetOldStyleSheet);
        newXS_deffile("Wx::RichTextEvent::GetNewStyleSheet", XS_Wx__RichTextEvent_GetNewStyleSheet);
        newXS_deffile("Wx::RichTextEvent::SetNewStyleSheet", XS_Wx__RichTextEvent_SetNewStyleSheet);
#endif
        newXS_deffile("Wx::RichTextCtrl::newDefault", XS_Wx__RichTextCtrl_newDefault);
        newXS_deffile("Wx::RichTextCtrl::newFull", XS_Wx__RichTextCtrl_newFull);
        newXS_deffile("Wx::RichTextCtrl::Create", XS_Wx__RichTextCtrl_Create);
        newXS_deffile("Wx::RichTextCtrl::GetFilename", XS_Wx__RichTextCtrl_GetFilename);
        newXS_deffile("Wx::RichTextCtrl::SetFilename", XS_Wx__RichTextCtrl_SetFilename);
        newXS_deffile("Wx::RichTextCtrl::SetDelayedLayoutThreshold", XS_Wx__RichTextCtrl_SetDelayedLayoutThreshold);
        newXS_deffile("Wx::RichTextCtrl::GetDelayedLayoutThreshold", XS_Wx__RichTextCtrl_GetDelayedLayoutThreshold);
        newXS_deffile("Wx::RichTextCtrl::SetStyleFromTo", XS_Wx__RichTextCtrl_SetStyleFromTo);
        newXS_deffile("Wx::RichTextCtrl::SetStyleExFromTo", XS_Wx__RichTextCtrl_SetStyleExFromTo);
        newXS_deffile("Wx::RichTextCtrl::SetStyleRange", XS_Wx__RichTextCtrl_SetStyleRange);
#if XSubPPtmpAAAC
        newXS_deffile("Wx::RichTextCtrl::SetStyleExExFromTo", XS_Wx__RichTextCtrl_SetStyleExExFromTo);
#endif
#if XSubPPtmpAAAD
        newXS_deffile("Wx::RichTextCtrl::SetStyleExRange", XS_Wx__RichTextCtrl_SetStyleExRange);
        newXS_deffile("Wx::RichTextCtrl::SetStyleExExRange", XS_Wx__RichTextCtrl_SetStyleExExRange);
#endif
        newXS_deffile("Wx::RichTextCtrl::GetBasicStyle", XS_Wx__RichTextCtrl_GetBasicStyle);
        newXS_deffile("Wx::RichTextCtrl::GetDefaultStyleEx", XS_Wx__RichTextCtrl_GetDefaultStyleEx);
        newXS_deffile("Wx::RichTextCtrl::Newline", XS_Wx__RichTextCtrl_Newline);
#if XSubPPtmpAAAE
        newXS_deffile("Wx::RichTextCtrl::LineBreak", XS_Wx__RichTextCtrl_LineBreak);
#endif
        newXS_deffile("Wx::RichTextCtrl::BeginStyle", XS_Wx__RichTextCtrl_BeginStyle);
        newXS_deffile("Wx::RichTextCtrl::EndStyle", XS_Wx__RichTextCtrl_EndStyle);
        newXS_deffile("Wx::RichTextCtrl::EndAllStyles", XS_Wx__RichTextCtrl_EndAllStyles);
        newXS_deffile("Wx::RichTextCtrl::BeginBold", XS_Wx__RichTextCtrl_BeginBold);
        newXS_deffile("Wx::RichTextCtrl::EndBold", XS_Wx__RichTextCtrl_EndBold);
        newXS_deffile("Wx::RichTextCtrl::BeginItalic", XS_Wx__RichTextCtrl_BeginItalic);
        newXS_deffile("Wx::RichTextCtrl::EndItalic", XS_Wx__RichTextCtrl_EndItalic);
        newXS_deffile("Wx::RichTextCtrl::BeginUnderline", XS_Wx__RichTextCtrl_BeginUnderline);
        newXS_deffile("Wx::RichTextCtrl::EndUnderline", XS_Wx__RichTextCtrl_EndUnderline);
        newXS_deffile("Wx::RichTextCtrl::BeginFontSize", XS_Wx__RichTextCtrl_BeginFontSize);
        newXS_deffile("Wx::RichTextCtrl::EndFontSize", XS_Wx__RichTextCtrl_EndFontSize);
        newXS_deffile("Wx::RichTextCtrl::BeginFont", XS_Wx__RichTextCtrl_BeginFont);
        newXS_deffile("Wx::RichTextCtrl::EndFont", XS_Wx__RichTextCtrl_EndFont);
        newXS_deffile("Wx::RichTextCtrl::BeginTextColour", XS_Wx__RichTextCtrl_BeginTextColour);
        newXS_deffile("Wx::RichTextCtrl::EndTextColour", XS_Wx__RichTextCtrl_EndTextColour);
        newXS_deffile("Wx::RichTextCtrl::BeginAlignment", XS_Wx__RichTextCtrl_BeginAlignment);
        newXS_deffile("Wx::RichTextCtrl::EndAlignment", XS_Wx__RichTextCtrl_EndAlignment);
        newXS_deffile("Wx::RichTextCtrl::BeginLeftIndent", XS_Wx__RichTextCtrl_BeginLeftIndent);
        newXS_deffile("Wx::RichTextCtrl::EndLeftIndent", XS_Wx__RichTextCtrl_EndLeftIndent);
        newXS_deffile("Wx::RichTextCtrl::BeginRightIndent", XS_Wx__RichTextCtrl_BeginRightIndent);
        newXS_deffile("Wx::RichTextCtrl::EndRightIndent", XS_Wx__RichTextCtrl_EndRightIndent);
        newXS_deffile("Wx::RichTextCtrl::BeginParagraphSpacing", XS_Wx__RichTextCtrl_BeginParagraphSpacing);
        newXS_deffile("Wx::RichTextCtrl::EndParagraphSpacing", XS_Wx__RichTextCtrl_EndParagraphSpacing);
        newXS_deffile("Wx::RichTextCtrl::BeginLineSpacing", XS_Wx__RichTextCtrl_BeginLineSpacing);
        newXS_deffile("Wx::RichTextCtrl::EndLineSpacing", XS_Wx__RichTextCtrl_EndLineSpacing);
        newXS_deffile("Wx::RichTextCtrl::BeginNumberedBullet", XS_Wx__RichTextCtrl_BeginNumberedBullet);
        newXS_deffile("Wx::RichTextCtrl::EndNumberedBullet", XS_Wx__RichTextCtrl_EndNumberedBullet);
#if XSubPPtmpAAAF
        newXS_deffile("Wx::RichTextCtrl::BeginSymbolBullet", XS_Wx__RichTextCtrl_BeginSymbolBullet);
#endif
#if XSubPPtmpAAAG
        newXS_deffile("Wx::RichTextCtrl::BeginSymbolBullet", XS_Wx__RichTextCtrl_BeginSymbolBullet);
#endif
        newXS_deffile("Wx::RichTextCtrl::EndSymbolBullet", XS_Wx__RichTextCtrl_EndSymbolBullet);
#if XSubPPtmpAAAH
        newXS_deffile("Wx::RichTextCtrl::BeginStandardBullet", XS_Wx__RichTextCtrl_BeginStandardBullet);
        newXS_deffile("Wx::RichTextCtrl::EndStandardBullet", XS_Wx__RichTextCtrl_EndStandardBullet);
#endif
        newXS_deffile("Wx::RichTextCtrl::BeginCharacterStyle", XS_Wx__RichTextCtrl_BeginCharacterStyle);
        newXS_deffile("Wx::RichTextCtrl::EndCharacterStyle", XS_Wx__RichTextCtrl_EndCharacterStyle);
        newXS_deffile("Wx::RichTextCtrl::BeginParagraphStyle", XS_Wx__RichTextCtrl_BeginParagraphStyle);
        newXS_deffile("Wx::RichTextCtrl::EndParagraphStyle", XS_Wx__RichTextCtrl_EndParagraphStyle);
#if XSubPPtmpAAAI
        newXS_deffile("Wx::RichTextCtrl::BeginListStyle", XS_Wx__RichTextCtrl_BeginListStyle);
        newXS_deffile("Wx::RichTextCtrl::EndListStyle", XS_Wx__RichTextCtrl_EndListStyle);
        newXS_deffile("Wx::RichTextCtrl::BeginURL", XS_Wx__RichTextCtrl_BeginURL);
        newXS_deffile("Wx::RichTextCtrl::EndURL", XS_Wx__RichTextCtrl_EndURL);
#endif
        newXS_deffile("Wx::RichTextCtrl::SetDefaultStyleToCursorStyle", XS_Wx__RichTextCtrl_SetDefaultStyleToCursorStyle);
#if XSubPPtmpAAAJ
        newXS_deffile("Wx::RichTextCtrl::ClearListStyle", XS_Wx__RichTextCtrl_ClearListStyle);
#endif
        newXS_deffile("Wx::RichTextCtrl::SelectNone", XS_Wx__RichTextCtrl_SelectNone);
#if XSubPPtmpAAAK
        newXS_deffile("Wx::RichTextCtrl::SelectWord", XS_Wx__RichTextCtrl_SelectWord);
#endif
        newXS_deffile("Wx::RichTextCtrl::GetSelectionRange", XS_Wx__RichTextCtrl_GetSelectionRange);
        newXS_deffile("Wx::RichTextCtrl::SetSelectionRange", XS_Wx__RichTextCtrl_SetSelectionRange);
#if XSubPPtmpAAAL
        newXS_deffile("Wx::RichTextCtrl::GetInternalSelectionRange", XS_Wx__RichTextCtrl_GetInternalSelectionRange);
        newXS_deffile("Wx::RichTextCtrl::SetInternalSelectionRange", XS_Wx__RichTextCtrl_SetInternalSelectionRange);
#endif
#if XSubPPtmpAAAM
        newXS_deffile("Wx::RichTextCtrl::HasSelection", XS_Wx__RichTextCtrl_HasSelection);
#endif
        newXS_deffile("Wx::RichTextCtrl::AddParagraph", XS_Wx__RichTextCtrl_AddParagraph);
        newXS_deffile("Wx::RichTextCtrl::AddImage", XS_Wx__RichTextCtrl_AddImage);
        newXS_deffile("Wx::RichTextCtrl::LayoutContent", XS_Wx__RichTextCtrl_LayoutContent);
        newXS_deffile("Wx::RichTextCtrl::MoveCaret", XS_Wx__RichTextCtrl_MoveCaret);
        newXS_deffile("Wx::RichTextCtrl::MoveRight", XS_Wx__RichTextCtrl_MoveRight);
        newXS_deffile("Wx::RichTextCtrl::MoveLeft", XS_Wx__RichTextCtrl_MoveLeft);
        newXS_deffile("Wx::RichTextCtrl::MoveUp", XS_Wx__RichTextCtrl_MoveUp);
        newXS_deffile("Wx::RichTextCtrl::MoveDown", XS_Wx__RichTextCtrl_MoveDown);
        newXS_deffile("Wx::RichTextCtrl::MoveToLineEnd", XS_Wx__RichTextCtrl_MoveToLineEnd);
        newXS_deffile("Wx::RichTextCtrl::MoveToLineStart", XS_Wx__RichTextCtrl_MoveToLineStart);
        newXS_deffile("Wx::RichTextCtrl::MoveToParagraphEnd", XS_Wx__RichTextCtrl_MoveToParagraphEnd);
        newXS_deffile("Wx::RichTextCtrl::MoveToParagraphStart", XS_Wx__RichTextCtrl_MoveToParagraphStart);
        newXS_deffile("Wx::RichTextCtrl::MoveHome", XS_Wx__RichTextCtrl_MoveHome);
        newXS_deffile("Wx::RichTextCtrl::MoveEnd", XS_Wx__RichTextCtrl_MoveEnd);
        newXS_deffile("Wx::RichTextCtrl::PageUp", XS_Wx__RichTextCtrl_PageUp);
        newXS_deffile("Wx::RichTextCtrl::PageDown", XS_Wx__RichTextCtrl_PageDown);
        newXS_deffile("Wx::RichTextCtrl::WordLeft", XS_Wx__RichTextCtrl_WordLeft);
        newXS_deffile("Wx::RichTextCtrl::WordRight", XS_Wx__RichTextCtrl_WordRight);
        newXS_deffile("Wx::RichTextCtrl::BeginBatchUndo", XS_Wx__RichTextCtrl_BeginBatchUndo);
        newXS_deffile("Wx::RichTextCtrl::EndBatchUndo", XS_Wx__RichTextCtrl_EndBatchUndo);
        newXS_deffile("Wx::RichTextCtrl::BatchingUndo", XS_Wx__RichTextCtrl_BatchingUndo);
        newXS_deffile("Wx::RichTextCtrl::BeginSuppressUndo", XS_Wx__RichTextCtrl_BeginSuppressUndo);
        newXS_deffile("Wx::RichTextCtrl::EndSuppressUndo", XS_Wx__RichTextCtrl_EndSuppressUndo);
        newXS_deffile("Wx::RichTextCtrl::SuppressingUndo", XS_Wx__RichTextCtrl_SuppressingUndo);
        newXS_deffile("Wx::RichTextCtrl::CanDeleteSelection", XS_Wx__RichTextCtrl_CanDeleteSelection);
        newXS_deffile("Wx::RichTextCtrl::DeleteSelection", XS_Wx__RichTextCtrl_DeleteSelection);
        newXS_deffile("Wx::RichTextCtrl::HasCAEx", XS_Wx__RichTextCtrl_HasCAEx);
        newXS_deffile("Wx::RichTextCtrl::HasCARich", XS_Wx__RichTextCtrl_HasCARich);
        newXS_deffile("Wx::RichTextCtrl::HasPAEx", XS_Wx__RichTextCtrl_HasPAEx);
        newXS_deffile("Wx::RichTextCtrl::HasPARich", XS_Wx__RichTextCtrl_HasPARich);
        newXS_deffile("Wx::RichTextCtrl::IsSelectionBold", XS_Wx__RichTextCtrl_IsSelectionBold);
        newXS_deffile("Wx::RichTextCtrl::IsSelectionItalics", XS_Wx__RichTextCtrl_IsSelectionItalics);
        newXS_deffile("Wx::RichTextCtrl::IsSelectionUnderlined", XS_Wx__RichTextCtrl_IsSelectionUnderlined);
        newXS_deffile("Wx::RichTextCtrl::IsSelectionAligned", XS_Wx__RichTextCtrl_IsSelectionAligned);
        newXS_deffile("Wx::RichTextCtrl::ApplyBoldToSelection", XS_Wx__RichTextCtrl_ApplyBoldToSelection);
        newXS_deffile("Wx::RichTextCtrl::ApplyItalicToSelection", XS_Wx__RichTextCtrl_ApplyItalicToSelection);
        newXS_deffile("Wx::RichTextCtrl::ApplyUnderlineToSelection", XS_Wx__RichTextCtrl_ApplyUnderlineToSelection);
        newXS_deffile("Wx::RichTextCtrl::ApplyAlignmentToSelection", XS_Wx__RichTextCtrl_ApplyAlignmentToSelection);
#if XSubPPtmpAAAN
        newXS_deffile("Wx::RichTextCtrl::ApplyStyle", XS_Wx__RichTextCtrl_ApplyStyle);
        newXS_deffile("Wx::RichTextCtrl::SetStyleSheet", XS_Wx__RichTextCtrl_SetStyleSheet);
        newXS_deffile("Wx::RichTextCtrl::GetStyleSheet", XS_Wx__RichTextCtrl_GetStyleSheet);
        newXS_deffile("Wx::RichTextCtrl::ApplyStyleSheet", XS_Wx__RichTextCtrl_ApplyStyleSheet);
#endif
#if XSubPPtmpAAAO
        newXS_deffile("Wx::RichTextCtrl::PushStyleSheet", XS_Wx__RichTextCtrl_PushStyleSheet);
        newXS_deffile("Wx::RichTextCtrl::PopStyleSheet", XS_Wx__RichTextCtrl_PopStyleSheet);
#endif
        newXS_deffile("Wx::RichTextCtrl::PositionCaret", XS_Wx__RichTextCtrl_PositionCaret);
        newXS_deffile("Wx::RichTextCtrl::ExtendSelection", XS_Wx__RichTextCtrl_ExtendSelection);
        newXS_deffile("Wx::RichTextCtrl::ScrollIntoView", XS_Wx__RichTextCtrl_ScrollIntoView);
        newXS_deffile("Wx::RichTextCtrl::SetCaretPosition", XS_Wx__RichTextCtrl_SetCaretPosition);
        newXS_deffile("Wx::RichTextCtrl::GetCaretPosition", XS_Wx__RichTextCtrl_GetCaretPosition);
#if XSubPPtmpAAAP
        newXS_deffile("Wx::RichTextCtrl::GetAdjustedCaretPosition", XS_Wx__RichTextCtrl_GetAdjustedCaretPosition);
#endif
        newXS_deffile("Wx::RichTextCtrl::MoveCaretForward", XS_Wx__RichTextCtrl_MoveCaretForward);
        newXS_deffile("Wx::RichTextCtrl::MoveCaretBack", XS_Wx__RichTextCtrl_MoveCaretBack);
        newXS_deffile("Wx::RichTextCtrl::GetPhysicalPoint", XS_Wx__RichTextCtrl_GetPhysicalPoint);
        newXS_deffile("Wx::RichTextCtrl::GetLogicalPoint", XS_Wx__RichTextCtrl_GetLogicalPoint);
        newXS_deffile("Wx::RichTextCtrl::FindNextWordPosition", XS_Wx__RichTextCtrl_FindNextWordPosition);
        newXS_deffile("Wx::RichTextCtrl::IsPositionVisible", XS_Wx__RichTextCtrl_IsPositionVisible);
        newXS_deffile("Wx::RichTextCtrl::GetFirstVisiblePosition", XS_Wx__RichTextCtrl_GetFirstVisiblePosition);
#if XSubPPtmpAAAQ
        newXS_deffile("Wx::RichTextCtrl::GetCaretPositionForDefaultStyle", XS_Wx__RichTextCtrl_GetCaretPositionForDefaultStyle);
        newXS_deffile("Wx::RichTextCtrl::SetCaretPositionForDefaultStyle", XS_Wx__RichTextCtrl_SetCaretPositionForDefaultStyle);
        newXS_deffile("Wx::RichTextCtrl::IsDefaultStyleShowing", XS_Wx__RichTextCtrl_IsDefaultStyleShowing);
        newXS_deffile("Wx::RichTextCtrl::SetAndShowDefaultStyle", XS_Wx__RichTextCtrl_SetAndShowDefaultStyle);
#endif
#if XSubPPtmpAAAR
        newXS_deffile("Wx::RichTextCtrl::GetFirstVisiblePoint", XS_Wx__RichTextCtrl_GetFirstVisiblePoint);
#endif
        newXS_deffile("Wx::RichTextCtrl::WriteImageFile", XS_Wx__RichTextCtrl_WriteImageFile);
        newXS_deffile("Wx::RichTextCtrl::WriteImageBitmap", XS_Wx__RichTextCtrl_WriteImageBitmap);
        newXS_deffile("Wx::RichTextCtrl::WriteImageImage", XS_Wx__RichTextCtrl_WriteImageImage);
        newXS_deffile("Wx::RichTextCtrl::SetBasicStyleRich", XS_Wx__RichTextCtrl_SetBasicStyleRich);
        newXS_deffile("Wx::RichTextCtrl::SetBasicStyleEx", XS_Wx__RichTextCtrl_SetBasicStyleEx);
        newXS_deffile("Wx::RichTextCtrl::SetDefaultStyleEx", XS_Wx__RichTextCtrl_SetDefaultStyleEx);
        newXS_deffile("Wx::RichTextCtrl::SetDefaultStyleDefault", XS_Wx__RichTextCtrl_SetDefaultStyleDefault);
        newXS_deffile("Wx::RichTextCtrl::SetBasicStyle", XS_Wx__RichTextCtrl_SetBasicStyle);
        newXS_deffile("Wx::RichTextCtrl::SetDefaultStyle", XS_Wx__RichTextCtrl_SetDefaultStyle);
        newXS_deffile("Wx::RichTextCtrl::GetBuffer", XS_Wx__RichTextCtrl_GetBuffer);
        newXS_deffile("Wx::RichTextCtrl::new", XS_Wx__RichTextCtrl_new);
        newXS_deffile("Wx::RichTextCtrl::SetStyle", XS_Wx__RichTextCtrl_SetStyle);
#if XSubPPtmpAAAS
        newXS_deffile("Wx::RichTextCtrl::SetStyleEx", XS_Wx__RichTextCtrl_SetStyleEx);
#endif
        newXS_deffile("Wx::RichTextCtrl::HasCharacterAttributes", XS_Wx__RichTextCtrl_HasCharacterAttributes);
        newXS_deffile("Wx::RichTextCtrl::HasParagraphAttributes", XS_Wx__RichTextCtrl_HasParagraphAttributes);
        newXS_deffile("Wx::RichTextCtrl::DeleteSelectedContent", XS_Wx__RichTextCtrl_DeleteSelectedContent);
        newXS_deffile("Wx::RichTextCtrl::GetCaretPositionForIndex", XS_Wx__RichTextCtrl_GetCaretPositionForIndex);
        newXS_deffile("Wx::RichTextCtrl::GetRichTextAttrStyle", XS_Wx__RichTextCtrl_GetRichTextAttrStyle);
        newXS_deffile("Wx::RichTextCtrl::GetTextAttrExStyle", XS_Wx__RichTextCtrl_GetTextAttrExStyle);
        newXS_deffile("Wx::RichTextCtrl::GetTextAttrStyle", XS_Wx__RichTextCtrl_GetTextAttrStyle);
#if XSubPPtmpAAAT
        newXS_deffile("Wx::RichTextCtrl::GetStyle", XS_Wx__RichTextCtrl_GetStyle);
#endif
#if XSubPPtmpAAAU
        newXS_deffile("Wx::RichTextCtrl::GetRichTextAttrUncombinedStyle", XS_Wx__RichTextCtrl_GetRichTextAttrUncombinedStyle);
#endif
#if XSubPPtmpAAAV
        newXS_deffile("Wx::RichTextCtrl::GetTextAttrExUncombinedStyle", XS_Wx__RichTextCtrl_GetTextAttrExUncombinedStyle);
        newXS_deffile("Wx::RichTextCtrl::GetTextAttrUncombinedStyle", XS_Wx__RichTextCtrl_GetTextAttrUncombinedStyle);
#endif
#if XSubPPtmpAAAW
        newXS_deffile("Wx::RichTextCtrl::GetUncombinedStyle", XS_Wx__RichTextCtrl_GetUncombinedStyle);
#endif
#if XSubPPtmpAAAX
        newXS_deffile("Wx::RichTextCtrl::GetRichTextAttrStyleForRange", XS_Wx__RichTextCtrl_GetRichTextAttrStyleForRange);
        newXS_deffile("Wx::RichTextCtrl::GetTextAttrExStyleForRange", XS_Wx__RichTextCtrl_GetTextAttrExStyleForRange);
#endif
#if XSubPPtmpAAAY
        newXS_deffile("Wx::RichTextCtrl::GetStyleForRange", XS_Wx__RichTextCtrl_GetStyleForRange);
#endif
        newXS_deffile("Wx::RichTextCtrl::WriteImage", XS_Wx__RichTextCtrl_WriteImage);
#if XSubPPtmpAAAZ
#if XSubPPtmpAABA
        newXS_deffile("Wx::RichTextCtrl::GetValue", XS_Wx__RichTextCtrl_GetValue);
        newXS_deffile("Wx::RichTextCtrl::SetValue", XS_Wx__RichTextCtrl_SetValue);
        newXS_deffile("Wx::RichTextCtrl::ChangeValue", XS_Wx__RichTextCtrl_ChangeValue);
        newXS_deffile("Wx::RichTextCtrl::GetRange", XS_Wx__RichTextCtrl_GetRange);
        newXS_deffile("Wx::RichTextCtrl::WriteText", XS_Wx__RichTextCtrl_WriteText);
        newXS_deffile("Wx::RichTextCtrl::AppendText", XS_Wx__RichTextCtrl_AppendText);
        newXS_deffile("Wx::RichTextCtrl::IsEmpty", XS_Wx__RichTextCtrl_IsEmpty);
        newXS_deffile("Wx::RichTextCtrl::Clear", XS_Wx__RichTextCtrl_Clear);
        newXS_deffile("Wx::RichTextCtrl::Replace", XS_Wx__RichTextCtrl_Replace);
        newXS_deffile("Wx::RichTextCtrl::Remove", XS_Wx__RichTextCtrl_Remove);
        newXS_deffile("Wx::RichTextCtrl::RemoveSelection", XS_Wx__RichTextCtrl_RemoveSelection);
        newXS_deffile("Wx::RichTextCtrl::Copy", XS_Wx__RichTextCtrl_Copy);
        newXS_deffile("Wx::RichTextCtrl::Cut", XS_Wx__RichTextCtrl_Cut);
        newXS_deffile("Wx::RichTextCtrl::Paste", XS_Wx__RichTextCtrl_Paste);
        newXS_deffile("Wx::RichTextCtrl::CanCopy", XS_Wx__RichTextCtrl_CanCopy);
        newXS_deffile("Wx::RichTextCtrl::CanCut", XS_Wx__RichTextCtrl_CanCut);
        newXS_deffile("Wx::RichTextCtrl::CanPaste", XS_Wx__RichTextCtrl_CanPaste);
        newXS_deffile("Wx::RichTextCtrl::Undo", XS_Wx__RichTextCtrl_Undo);
        newXS_deffile("Wx::RichTextCtrl::Redo", XS_Wx__RichTextCtrl_Redo);
        newXS_deffile("Wx::RichTextCtrl::CanUndo", XS_Wx__RichTextCtrl_CanUndo);
        newXS_deffile("Wx::RichTextCtrl::CanRedo", XS_Wx__RichTextCtrl_CanRedo);
        newXS_deffile("Wx::RichTextCtrl::SetInsertionPoint", XS_Wx__RichTextCtrl_SetInsertionPoint);
        newXS_deffile("Wx::RichTextCtrl::SetInsertionPointEnd", XS_Wx__RichTextCtrl_SetInsertionPointEnd);
        newXS_deffile("Wx::RichTextCtrl::GetInsertionPoint", XS_Wx__RichTextCtrl_GetInsertionPoint);
        newXS_deffile("Wx::RichTextCtrl::GetLastPosition", XS_Wx__RichTextCtrl_GetLastPosition);
        newXS_deffile("Wx::RichTextCtrl::SetSelection", XS_Wx__RichTextCtrl_SetSelection);
        newXS_deffile("Wx::RichTextCtrl::SelectAll", XS_Wx__RichTextCtrl_SelectAll);
        newXS_deffile("Wx::RichTextCtrl::HasSelection", XS_Wx__RichTextCtrl_HasSelection);
        newXS_deffile("Wx::RichTextCtrl::GetStringSelection", XS_Wx__RichTextCtrl_GetStringSelection);
        newXS_deffile("Wx::RichTextCtrl::AutoCompleteFileNames", XS_Wx__RichTextCtrl_AutoCompleteFileNames);
        newXS_deffile("Wx::RichTextCtrl::AutoComplete", XS_Wx__RichTextCtrl_AutoComplete);
        newXS_deffile("Wx::RichTextCtrl::IsEditable", XS_Wx__RichTextCtrl_IsEditable);
        newXS_deffile("Wx::RichTextCtrl::SetEditable", XS_Wx__RichTextCtrl_SetEditable);
        newXS_deffile("Wx::RichTextCtrl::SetMaxLength", XS_Wx__RichTextCtrl_SetMaxLength);
        newXS_deffile("Wx::RichTextCtrl::SetHint", XS_Wx__RichTextCtrl_SetHint);
        newXS_deffile("Wx::RichTextCtrl::GetHint", XS_Wx__RichTextCtrl_GetHint);
        newXS_deffile("Wx::RichTextCtrl::SetMargins", XS_Wx__RichTextCtrl_SetMargins);
        newXS_deffile("Wx::RichTextCtrl::GetMargins", XS_Wx__RichTextCtrl_GetMargins);
        newXS_deffile("Wx::RichTextCtrl::GetLineLength", XS_Wx__RichTextCtrl_GetLineLength);
        newXS_deffile("Wx::RichTextCtrl::GetLineText", XS_Wx__RichTextCtrl_GetLineText);
        newXS_deffile("Wx::RichTextCtrl::GetNumberOfLines", XS_Wx__RichTextCtrl_GetNumberOfLines);
#if XSubPPtmpAABB
        newXS_deffile("Wx::RichTextCtrl::LoadFile", XS_Wx__RichTextCtrl_LoadFile);
        newXS_deffile("Wx::RichTextCtrl::SaveFile", XS_Wx__RichTextCtrl_SaveFile);
#endif
        newXS_deffile("Wx::RichTextCtrl::IsModified", XS_Wx__RichTextCtrl_IsModified);
        newXS_deffile("Wx::RichTextCtrl::MarkDirty", XS_Wx__RichTextCtrl_MarkDirty);
        newXS_deffile("Wx::RichTextCtrl::DiscardEdits", XS_Wx__RichTextCtrl_DiscardEdits);
        newXS_deffile("Wx::RichTextCtrl::SetModified", XS_Wx__RichTextCtrl_SetModified);
#if XSubPPtmpAABC
        newXS_deffile("Wx::RichTextCtrl::SetStyle", XS_Wx__RichTextCtrl_SetStyle);
#endif
#if XSubPPtmpAABD
        newXS_deffile("Wx::RichTextCtrl::SetDefaultStyle", XS_Wx__RichTextCtrl_SetDefaultStyle);
#endif
        newXS_deffile("Wx::RichTextCtrl::GetDefaultStyle", XS_Wx__RichTextCtrl_GetDefaultStyle);
        newXS_deffile("Wx::RichTextCtrl::XYToPosition", XS_Wx__RichTextCtrl_XYToPosition);
        newXS_deffile("Wx::RichTextCtrl::ShowPosition", XS_Wx__RichTextCtrl_ShowPosition);
        newXS_deffile("Wx::RichTextCtrl::GetSelection", XS_Wx__RichTextCtrl_GetSelection);
#if XSubPPtmpAABE
        newXS_deffile("Wx::RichTextCtrl::GetStyle", XS_Wx__RichTextCtrl_GetStyle);
#endif
        newXS_deffile("Wx::RichTextCtrl::PositionToXY", XS_Wx__RichTextCtrl_PositionToXY);
        newXS_deffile("Wx::RichTextCtrl::HitTest", XS_Wx__RichTextCtrl_HitTest);
#endif
#endif
        newXS_deffile("Wx::RichTextRange::newDefault", XS_Wx__RichTextRange_newDefault);
        newXS_deffile("Wx::RichTextRange::newFromTo", XS_Wx__RichTextRange_newFromTo);
        newXS_deffile("Wx::RichTextRange::newCopy", XS_Wx__RichTextRange_newCopy);
        newXS_deffile("Wx::RichTextRange::CLONE", XS_Wx__RichTextRange_CLONE);
        newXS_deffile("Wx::RichTextRange::DESTROY", XS_Wx__RichTextRange_DESTROY);
        newXS_deffile("Wx::RichTextRange::SetRange", XS_Wx__RichTextRange_SetRange);
        newXS_deffile("Wx::RichTextRange::SetStart", XS_Wx__RichTextRange_SetStart);
        newXS_deffile("Wx::RichTextRange::GetStart", XS_Wx__RichTextRange_GetStart);
        newXS_deffile("Wx::RichTextRange::SetEnd", XS_Wx__RichTextRange_SetEnd);
        newXS_deffile("Wx::RichTextRange::GetEnd", XS_Wx__RichTextRange_GetEnd);
        newXS_deffile("Wx::RichTextRange::IsOutside", XS_Wx__RichTextRange_IsOutside);
        newXS_deffile("Wx::RichTextRange::IsWithin", XS_Wx__RichTextRange_IsWithin);
        newXS_deffile("Wx::RichTextRange::Contains", XS_Wx__RichTextRange_Contains);
        newXS_deffile("Wx::RichTextRange::LimitTo", XS_Wx__RichTextRange_LimitTo);
        newXS_deffile("Wx::RichTextRange::GetLength", XS_Wx__RichTextRange_GetLength);
        newXS_deffile("Wx::RichTextRange::new", XS_Wx__RichTextRange_new);
        newXS_deffile("Wx::TextAttrEx::newDefault", XS_Wx__TextAttrEx_newDefault);
        newXS_deffile("Wx::TextAttrEx::newCopy", XS_Wx__TextAttrEx_newCopy);
        newXS_deffile("Wx::TextAttrEx::newAttr", XS_Wx__TextAttrEx_newAttr);
        newXS_deffile("Wx::TextAttrEx::CLONE", XS_Wx__TextAttrEx_CLONE);
        newXS_deffile("Wx::TextAttrEx::DESTROY", XS_Wx__TextAttrEx_DESTROY);
        newXS_deffile("Wx::TextAttrEx::SetCharacterStyleName", XS_Wx__TextAttrEx_SetCharacterStyleName);
        newXS_deffile("Wx::TextAttrEx::SetParagraphStyleName", XS_Wx__TextAttrEx_SetParagraphStyleName);
#if XSubPPtmpAABF
        newXS_deffile("Wx::TextAttrEx::SetListStyleName", XS_Wx__TextAttrEx_SetListStyleName);
#endif
        newXS_deffile("Wx::TextAttrEx::SetParagraphSpacingAfter", XS_Wx__TextAttrEx_SetParagraphSpacingAfter);
        newXS_deffile("Wx::TextAttrEx::SetParagraphSpacingBefore", XS_Wx__TextAttrEx_SetParagraphSpacingBefore);
        newXS_deffile("Wx::TextAttrEx::SetLineSpacing", XS_Wx__TextAttrEx_SetLineSpacing);
        newXS_deffile("Wx::TextAttrEx::SetBulletStyle", XS_Wx__TextAttrEx_SetBulletStyle);
        newXS_deffile("Wx::TextAttrEx::SetBulletNumber", XS_Wx__TextAttrEx_SetBulletNumber);
#if XSubPPtmpAABG
        newXS_deffile("Wx::TextAttrEx::SetBulletText", XS_Wx__TextAttrEx_SetBulletText);
        newXS_deffile("Wx::TextAttrEx::SetBulletName", XS_Wx__TextAttrEx_SetBulletName);
        newXS_deffile("Wx::TextAttrEx::SetBulletFont", XS_Wx__TextAttrEx_SetBulletFont);
        newXS_deffile("Wx::TextAttrEx::SetURL", XS_Wx__TextAttrEx_SetURL);
        newXS_deffile("Wx::TextAttrEx::SetPageBreak", XS_Wx__TextAttrEx_SetPageBreak);
#endif
        newXS_deffile("Wx::TextAttrEx::GetCharacterStyleName", XS_Wx__TextAttrEx_GetCharacterStyleName);
        newXS_deffile("Wx::TextAttrEx::GetParagraphStyleName", XS_Wx__TextAttrEx_GetParagraphStyleName);
#if XSubPPtmpAABH
        newXS_deffile("Wx::TextAttrEx::GetListStyleName", XS_Wx__TextAttrEx_GetListStyleName);
#endif
        newXS_deffile("Wx::TextAttrEx::GetParagraphSpacingAfter", XS_Wx__TextAttrEx_GetParagraphSpacingAfter);
        newXS_deffile("Wx::TextAttrEx::GetParagraphSpacingBefore", XS_Wx__TextAttrEx_GetParagraphSpacingBefore);
        newXS_deffile("Wx::TextAttrEx::GetLineSpacing", XS_Wx__TextAttrEx_GetLineSpacing);
        newXS_deffile("Wx::TextAttrEx::GetBulletStyle", XS_Wx__TextAttrEx_GetBulletStyle);
        newXS_deffile("Wx::TextAttrEx::GetBulletNumber", XS_Wx__TextAttrEx_GetBulletNumber);
#if XSubPPtmpAABI
        newXS_deffile("Wx::TextAttrEx::GetBulletText", XS_Wx__TextAttrEx_GetBulletText);
        newXS_deffile("Wx::TextAttrEx::GetBulletName", XS_Wx__TextAttrEx_GetBulletName);
        newXS_deffile("Wx::TextAttrEx::GetBulletFont", XS_Wx__TextAttrEx_GetBulletFont);
        newXS_deffile("Wx::TextAttrEx::GetURL", XS_Wx__TextAttrEx_GetURL);
#endif
#if XSubPPtmpAABJ
        newXS_deffile("Wx::TextAttrEx::HasWeight", XS_Wx__TextAttrEx_HasWeight);
        newXS_deffile("Wx::TextAttrEx::HasSize", XS_Wx__TextAttrEx_HasSize);
        newXS_deffile("Wx::TextAttrEx::HasItalic", XS_Wx__TextAttrEx_HasItalic);
        newXS_deffile("Wx::TextAttrEx::HasUnderlined", XS_Wx__TextAttrEx_HasUnderlined);
        newXS_deffile("Wx::TextAttrEx::HasFaceName", XS_Wx__TextAttrEx_HasFaceName);
#endif
        newXS_deffile("Wx::TextAttrEx::HasParagraphSpacingAfter", XS_Wx__TextAttrEx_HasParagraphSpacingAfter);
        newXS_deffile("Wx::TextAttrEx::HasParagraphSpacingBefore", XS_Wx__TextAttrEx_HasParagraphSpacingBefore);
        newXS_deffile("Wx::TextAttrEx::HasLineSpacing", XS_Wx__TextAttrEx_HasLineSpacing);
        newXS_deffile("Wx::TextAttrEx::HasCharacterStyleName", XS_Wx__TextAttrEx_HasCharacterStyleName);
        newXS_deffile("Wx::TextAttrEx::HasParagraphStyleName", XS_Wx__TextAttrEx_HasParagraphStyleName);
#if XSubPPtmpAABK
        newXS_deffile("Wx::TextAttrEx::HasListStyleName", XS_Wx__TextAttrEx_HasListStyleName);
#endif
        newXS_deffile("Wx::TextAttrEx::HasBulletStyle", XS_Wx__TextAttrEx_HasBulletStyle);
        newXS_deffile("Wx::TextAttrEx::HasBulletNumber", XS_Wx__TextAttrEx_HasBulletNumber);
#if XSubPPtmpAABL
        newXS_deffile("Wx::TextAttrEx::HasBulletText", XS_Wx__TextAttrEx_HasBulletText);
        newXS_deffile("Wx::TextAttrEx::HasBulletName", XS_Wx__TextAttrEx_HasBulletName);
        newXS_deffile("Wx::TextAttrEx::HasURL", XS_Wx__TextAttrEx_HasURL);
        newXS_deffile("Wx::TextAttrEx::HasPageBreak", XS_Wx__TextAttrEx_HasPageBreak);
#endif
        newXS_deffile("Wx::TextAttrEx::IsCharacterStyle", XS_Wx__TextAttrEx_IsCharacterStyle);
        newXS_deffile("Wx::TextAttrEx::IsParagraphStyle", XS_Wx__TextAttrEx_IsParagraphStyle);
        newXS_deffile("Wx::TextAttrEx::IsDefault", XS_Wx__TextAttrEx_IsDefault);
#if XSubPPtmpAABM
        newXS_deffile("Wx::TextAttrEx::GetOutlineLevel", XS_Wx__TextAttrEx_GetOutlineLevel);
        newXS_deffile("Wx::TextAttrEx::HasOutlineLevel", XS_Wx__TextAttrEx_HasOutlineLevel);
        newXS_deffile("Wx::TextAttrEx::SetOutlineLevel", XS_Wx__TextAttrEx_SetOutlineLevel);
        newXS_deffile("Wx::TextAttrEx::GetTextEffects", XS_Wx__TextAttrEx_GetTextEffects);
        newXS_deffile("Wx::TextAttrEx::HasTextEffects", XS_Wx__TextAttrEx_HasTextEffects);
        newXS_deffile("Wx::TextAttrEx::SetTextEffects", XS_Wx__TextAttrEx_SetTextEffects);
        newXS_deffile("Wx::TextAttrEx::GetTextEffectFlags", XS_Wx__TextAttrEx_GetTextEffectFlags);
        newXS_deffile("Wx::TextAttrEx::HasTextEffect", XS_Wx__TextAttrEx_HasTextEffect);
        newXS_deffile("Wx::TextAttrEx::SetTextEffectFlags", XS_Wx__TextAttrEx_SetTextEffectFlags);
#endif
        newXS_deffile("Wx::TextAttrEx::new", XS_Wx__TextAttrEx_new);
        newXS_deffile("Wx::RichTextAttr::newDefault", XS_Wx__RichTextAttr_newDefault);
        newXS_deffile("Wx::RichTextAttr::newCopy", XS_Wx__RichTextAttr_newCopy);
        newXS_deffile("Wx::RichTextAttr::newAttrEx", XS_Wx__RichTextAttr_newAttrEx);
        newXS_deffile("Wx::RichTextAttr::newAttr", XS_Wx__RichTextAttr_newAttr);
#if XSubPPtmpAABN
        newXS_deffile("Wx::RichTextAttr::newFull", XS_Wx__RichTextAttr_newFull);
#endif
#if XSubPPtmpAABO
        newXS_deffile("Wx::RichTextAttr::newFull", XS_Wx__RichTextAttr_newFull);
#endif
        newXS_deffile("Wx::RichTextAttr::CLONE", XS_Wx__RichTextAttr_CLONE);
        newXS_deffile("Wx::RichTextAttr::DESTROY", XS_Wx__RichTextAttr_DESTROY);
#if XSubPPtmpAABP
        newXS_deffile("Wx::RichTextAttr::CreateFont", XS_Wx__RichTextAttr_CreateFont);
#endif
        newXS_deffile("Wx::RichTextAttr::GetFontAttributes", XS_Wx__RichTextAttr_GetFontAttributes);
        newXS_deffile("Wx::RichTextAttr::SetTextColour", XS_Wx__RichTextAttr_SetTextColour);
        newXS_deffile("Wx::RichTextAttr::SetBackgroundColour", XS_Wx__RichTextAttr_SetBackgroundColour);
        newXS_deffile("Wx::RichTextAttr::SetAlignment", XS_Wx__RichTextAttr_SetAlignment);
        newXS_deffile("Wx::RichTextAttr::SetTabs", XS_Wx__RichTextAttr_SetTabs);
        newXS_deffile("Wx::RichTextAttr::SetLeftIndent", XS_Wx__RichTextAttr_SetLeftIndent);
        newXS_deffile("Wx::RichTextAttr::SetRightIndent", XS_Wx__RichTextAttr_SetRightIndent);
        newXS_deffile("Wx::RichTextAttr::SetFontSize", XS_Wx__RichTextAttr_SetFontSize);
        newXS_deffile("Wx::RichTextAttr::SetFontStyle", XS_Wx__RichTextAttr_SetFontStyle);
        newXS_deffile("Wx::RichTextAttr::SetFontWeight", XS_Wx__RichTextAttr_SetFontWeight);
        newXS_deffile("Wx::RichTextAttr::SetFontFaceName", XS_Wx__RichTextAttr_SetFontFaceName);
        newXS_deffile("Wx::RichTextAttr::SetFontUnderlined", XS_Wx__RichTextAttr_SetFontUnderlined);
        newXS_deffile("Wx::RichTextAttr::SetFlags", XS_Wx__RichTextAttr_SetFlags);
        newXS_deffile("Wx::RichTextAttr::SetCharacterStyleName", XS_Wx__RichTextAttr_SetCharacterStyleName);
        newXS_deffile("Wx::RichTextAttr::SetParagraphStyleName", XS_Wx__RichTextAttr_SetParagraphStyleName);
#if XSubPPtmpAABQ
        newXS_deffile("Wx::RichTextAttr::SetListStyleName", XS_Wx__RichTextAttr_SetListStyleName);
#endif
        newXS_deffile("Wx::RichTextAttr::SetParagraphSpacingAfter", XS_Wx__RichTextAttr_SetParagraphSpacingAfter);
        newXS_deffile("Wx::RichTextAttr::SetParagraphSpacingBefore", XS_Wx__RichTextAttr_SetParagraphSpacingBefore);
        newXS_deffile("Wx::RichTextAttr::SetLineSpacing", XS_Wx__RichTextAttr_SetLineSpacing);
        newXS_deffile("Wx::RichTextAttr::SetBulletStyle", XS_Wx__RichTextAttr_SetBulletStyle);
        newXS_deffile("Wx::RichTextAttr::SetBulletNumber", XS_Wx__RichTextAttr_SetBulletNumber);
#if XSubPPtmpAABR
        newXS_deffile("Wx::RichTextAttr::SetBulletText", XS_Wx__RichTextAttr_SetBulletText);
        newXS_deffile("Wx::RichTextAttr::SetBulletFont", XS_Wx__RichTextAttr_SetBulletFont);
        newXS_deffile("Wx::RichTextAttr::SetBulletName", XS_Wx__RichTextAttr_SetBulletName);
        newXS_deffile("Wx::RichTextAttr::SetURL", XS_Wx__RichTextAttr_SetURL);
        newXS_deffile("Wx::RichTextAttr::SetPageBreak", XS_Wx__RichTextAttr_SetPageBreak);
#endif
        newXS_deffile("Wx::RichTextAttr::GetTextColour", XS_Wx__RichTextAttr_GetTextColour);
        newXS_deffile("Wx::RichTextAttr::GetBackgroundColour", XS_Wx__RichTextAttr_GetBackgroundColour);
        newXS_deffile("Wx::RichTextAttr::GetAlignment", XS_Wx__RichTextAttr_GetAlignment);
        newXS_deffile("Wx::RichTextAttr::GetLeftIndent", XS_Wx__RichTextAttr_GetLeftIndent);
        newXS_deffile("Wx::RichTextAttr::GetLeftSubIndent", XS_Wx__RichTextAttr_GetLeftSubIndent);
        newXS_deffile("Wx::RichTextAttr::GetRightIndent", XS_Wx__RichTextAttr_GetRightIndent);
        newXS_deffile("Wx::RichTextAttr::GetFlags", XS_Wx__RichTextAttr_GetFlags);
        newXS_deffile("Wx::RichTextAttr::GetFontSize", XS_Wx__RichTextAttr_GetFontSize);
#if XSubPPtmpAABS
        newXS_deffile("Wx::RichTextAttr::GetFontStyle", XS_Wx__RichTextAttr_GetFontStyle);
        newXS_deffile("Wx::RichTextAttr::GetFontWeight", XS_Wx__RichTextAttr_GetFontWeight);
#endif
#if XSubPPtmpAABT
        newXS_deffile("Wx::RichTextAttr::GetFontStyle", XS_Wx__RichTextAttr_GetFontStyle);
        newXS_deffile("Wx::RichTextAttr::GetFontWeight", XS_Wx__RichTextAttr_GetFontWeight);
#endif
        newXS_deffile("Wx::RichTextAttr::GetFontUnderlined", XS_Wx__RichTextAttr_GetFontUnderlined);
        newXS_deffile("Wx::RichTextAttr::GetFontFaceName", XS_Wx__RichTextAttr_GetFontFaceName);
        newXS_deffile("Wx::RichTextAttr::GetCharacterStyleName", XS_Wx__RichTextAttr_GetCharacterStyleName);
        newXS_deffile("Wx::RichTextAttr::GetParagraphStyleName", XS_Wx__RichTextAttr_GetParagraphStyleName);
#if XSubPPtmpAABU
        newXS_deffile("Wx::RichTextAttr::GetListStyleName", XS_Wx__RichTextAttr_GetListStyleName);
#endif
        newXS_deffile("Wx::RichTextAttr::GetParagraphSpacingAfter", XS_Wx__RichTextAttr_GetParagraphSpacingAfter);
        newXS_deffile("Wx::RichTextAttr::GetParagraphSpacingBefore", XS_Wx__RichTextAttr_GetParagraphSpacingBefore);
        newXS_deffile("Wx::RichTextAttr::GetLineSpacing", XS_Wx__RichTextAttr_GetLineSpacing);
        newXS_deffile("Wx::RichTextAttr::GetBulletStyle", XS_Wx__RichTextAttr_GetBulletStyle);
        newXS_deffile("Wx::RichTextAttr::GetBulletNumber", XS_Wx__RichTextAttr_GetBulletNumber);
#if XSubPPtmpAABV
        newXS_deffile("Wx::RichTextAttr::GetBulletText", XS_Wx__RichTextAttr_GetBulletText);
        newXS_deffile("Wx::RichTextAttr::GetBulletFont", XS_Wx__RichTextAttr_GetBulletFont);
        newXS_deffile("Wx::RichTextAttr::GetBulletName", XS_Wx__RichTextAttr_GetBulletName);
        newXS_deffile("Wx::RichTextAttr::GetURL", XS_Wx__RichTextAttr_GetURL);
#endif
        newXS_deffile("Wx::RichTextAttr::HasTextColour", XS_Wx__RichTextAttr_HasTextColour);
        newXS_deffile("Wx::RichTextAttr::HasBackgroundColour", XS_Wx__RichTextAttr_HasBackgroundColour);
        newXS_deffile("Wx::RichTextAttr::HasAlignment", XS_Wx__RichTextAttr_HasAlignment);
        newXS_deffile("Wx::RichTextAttr::HasTabs", XS_Wx__RichTextAttr_HasTabs);
        newXS_deffile("Wx::RichTextAttr::HasLeftIndent", XS_Wx__RichTextAttr_HasLeftIndent);
        newXS_deffile("Wx::RichTextAttr::HasRightIndent", XS_Wx__RichTextAttr_HasRightIndent);
#if XSubPPtmpAABW
        newXS_deffile("Wx::RichTextAttr::HasWeight", XS_Wx__RichTextAttr_HasWeight);
        newXS_deffile("Wx::RichTextAttr::HasSize", XS_Wx__RichTextAttr_HasSize);
        newXS_deffile("Wx::RichTextAttr::HasItalic", XS_Wx__RichTextAttr_HasItalic);
        newXS_deffile("Wx::RichTextAttr::HasUnderlined", XS_Wx__RichTextAttr_HasUnderlined);
        newXS_deffile("Wx::RichTextAttr::HasFaceName", XS_Wx__RichTextAttr_HasFaceName);
#endif
        newXS_deffile("Wx::RichTextAttr::HasFont", XS_Wx__RichTextAttr_HasFont);
        newXS_deffile("Wx::RichTextAttr::HasParagraphSpacingAfter", XS_Wx__RichTextAttr_HasParagraphSpacingAfter);
        newXS_deffile("Wx::RichTextAttr::HasParagraphSpacingBefore", XS_Wx__RichTextAttr_HasParagraphSpacingBefore);
        newXS_deffile("Wx::RichTextAttr::HasLineSpacing", XS_Wx__RichTextAttr_HasLineSpacing);
        newXS_deffile("Wx::RichTextAttr::HasCharacterStyleName", XS_Wx__RichTextAttr_HasCharacterStyleName);
        newXS_deffile("Wx::RichTextAttr::HasParagraphStyleName", XS_Wx__RichTextAttr_HasParagraphStyleName);
#if XSubPPtmpAABX
        newXS_deffile("Wx::RichTextAttr::HasListStyleName", XS_Wx__RichTextAttr_HasListStyleName);
#endif
        newXS_deffile("Wx::RichTextAttr::HasBulletStyle", XS_Wx__RichTextAttr_HasBulletStyle);
        newXS_deffile("Wx::RichTextAttr::HasBulletNumber", XS_Wx__RichTextAttr_HasBulletNumber);
#if XSubPPtmpAABY
        newXS_deffile("Wx::RichTextAttr::HasBulletText", XS_Wx__RichTextAttr_HasBulletText);
        newXS_deffile("Wx::RichTextAttr::HasBulletName", XS_Wx__RichTextAttr_HasBulletName);
        newXS_deffile("Wx::RichTextAttr::HasURL", XS_Wx__RichTextAttr_HasURL);
        newXS_deffile("Wx::RichTextAttr::HasPageBreak", XS_Wx__RichTextAttr_HasPageBreak);
#endif
        newXS_deffile("Wx::RichTextAttr::IsCharacterStyle", XS_Wx__RichTextAttr_IsCharacterStyle);
        newXS_deffile("Wx::RichTextAttr::IsParagraphStyle", XS_Wx__RichTextAttr_IsParagraphStyle);
        newXS_deffile("Wx::RichTextAttr::IsDefault", XS_Wx__RichTextAttr_IsDefault);
        newXS_deffile("Wx::RichTextAttr::new", XS_Wx__RichTextAttr_new);
        newXS_deffile("Wx::RichTextAttr::GetTabs", XS_Wx__RichTextAttr_GetTabs);
        newXS_deffile("Wx::RichTextStyleDefinition::CLONE", XS_Wx__RichTextStyleDefinition_CLONE);
        newXS_deffile("Wx::RichTextStyleDefinition::DESTROY", XS_Wx__RichTextStyleDefinition_DESTROY);
#if XSubPPtmpAABZ
        newXS_deffile("Wx::RichTextStyleDefinition::Copy", XS_Wx__RichTextStyleDefinition_Copy);
        newXS_deffile("Wx::RichTextStyleDefinition::Eq", XS_Wx__RichTextStyleDefinition_Eq);
#endif
        newXS_deffile("Wx::RichTextStyleDefinition::SetName", XS_Wx__RichTextStyleDefinition_SetName);
        newXS_deffile("Wx::RichTextStyleDefinition::GetName", XS_Wx__RichTextStyleDefinition_GetName);
#if XSubPPtmpAACA
        newXS_deffile("Wx::RichTextStyleDefinition::SetDescription", XS_Wx__RichTextStyleDefinition_SetDescription);
        newXS_deffile("Wx::RichTextStyleDefinition::GetDescription", XS_Wx__RichTextStyleDefinition_GetDescription);
#endif
        newXS_deffile("Wx::RichTextStyleDefinition::SetBaseStyle", XS_Wx__RichTextStyleDefinition_SetBaseStyle);
        newXS_deffile("Wx::RichTextStyleDefinition::GetBaseStyle", XS_Wx__RichTextStyleDefinition_GetBaseStyle);
        newXS_deffile("Wx::RichTextStyleDefinition::SetStyle", XS_Wx__RichTextStyleDefinition_SetStyle);
        newXS_deffile("Wx::RichTextStyleDefinition::GetStyle", XS_Wx__RichTextStyleDefinition_GetStyle);
#if XSubPPtmpAACB
        newXS_deffile("Wx::RichTextStyleDefinition::GetStyleMergedWithBase", XS_Wx__RichTextStyleDefinition_GetStyleMergedWithBase);
#endif
        newXS_deffile("Wx::RichTextCharacterStyleDefinition::new", XS_Wx__RichTextCharacterStyleDefinition_new);
        newXS_deffile("Wx::RichTextParagraphStyleDefinition::new", XS_Wx__RichTextParagraphStyleDefinition_new);
#if XSubPPtmpAACC
        newXS_deffile("Wx::RichTextParagraphStyleDefinition::Copy", XS_Wx__RichTextParagraphStyleDefinition_Copy);
#endif
        newXS_deffile("Wx::RichTextParagraphStyleDefinition::SetNextStyle", XS_Wx__RichTextParagraphStyleDefinition_SetNextStyle);
        newXS_deffile("Wx::RichTextParagraphStyleDefinition::GetNextStyle", XS_Wx__RichTextParagraphStyleDefinition_GetNextStyle);
#if XSubPPtmpAACD
        newXS_deffile("Wx::RichTextListStyleDefinition::new", XS_Wx__RichTextListStyleDefinition_new);
        newXS_deffile("Wx::RichTextListStyleDefinition::Copy", XS_Wx__RichTextListStyleDefinition_Copy);
        newXS_deffile("Wx::RichTextListStyleDefinition::SetLevelAttributes", XS_Wx__RichTextListStyleDefinition_SetLevelAttributes);
        newXS_deffile("Wx::RichTextListStyleDefinition::GetLevelAttributes", XS_Wx__RichTextListStyleDefinition_GetLevelAttributes);
        newXS_deffile("Wx::RichTextListStyleDefinition::SetAttributes", XS_Wx__RichTextListStyleDefinition_SetAttributes);
        newXS_deffile("Wx::RichTextListStyleDefinition::FindLevelForIndent", XS_Wx__RichTextListStyleDefinition_FindLevelForIndent);
        newXS_deffile("Wx::RichTextListStyleDefinition::CombineWithParagraphStyle", XS_Wx__RichTextListStyleDefinition_CombineWithParagraphStyle);
        newXS_deffile("Wx::RichTextListStyleDefinition::GetCombinedStyle", XS_Wx__RichTextListStyleDefinition_GetCombinedStyle);
        newXS_deffile("Wx::RichTextListStyleDefinition::GetCombinedStyleForLevel", XS_Wx__RichTextListStyleDefinition_GetCombinedStyleForLevel);
        newXS_deffile("Wx::RichTextListStyleDefinition::GetLevelCount", XS_Wx__RichTextListStyleDefinition_GetLevelCount);
        newXS_deffile("Wx::RichTextListStyleDefinition::IsNumbered", XS_Wx__RichTextListStyleDefinition_IsNumbered);
#endif
        newXS_deffile("Wx::RichTextStyleSheet::new", XS_Wx__RichTextStyleSheet_new);
        newXS_deffile("Wx::RichTextStyleSheet::CLONE", XS_Wx__RichTextStyleSheet_CLONE);
        newXS_deffile("Wx::RichTextStyleSheet::DESTROY", XS_Wx__RichTextStyleSheet_DESTROY);
#if XSubPPtmpAACE
        newXS_deffile("Wx::RichTextStyleSheet::AddStyle", XS_Wx__RichTextStyleSheet_AddStyle);
        newXS_deffile("Wx::RichTextStyleSheet::FindStyle", XS_Wx__RichTextStyleSheet_FindStyle);
        newXS_deffile("Wx::RichTextStyleSheet::RemoveStyle", XS_Wx__RichTextStyleSheet_RemoveStyle);
#endif
#if XSubPPtmpAACF
        newXS_deffile("Wx::RichTextStyleSheet::Copy", XS_Wx__RichTextStyleSheet_Copy);
#endif
        newXS_deffile("Wx::RichTextStyleSheet::AddCharacterStyle", XS_Wx__RichTextStyleSheet_AddCharacterStyle);
        newXS_deffile("Wx::RichTextStyleSheet::AddParagraphStyle", XS_Wx__RichTextStyleSheet_AddParagraphStyle);
#if XSubPPtmpAACG
        newXS_deffile("Wx::RichTextStyleSheet::AddListStyle", XS_Wx__RichTextStyleSheet_AddListStyle);
#endif
        newXS_deffile("Wx::RichTextStyleSheet::RemoveCharacterStyle", XS_Wx__RichTextStyleSheet_RemoveCharacterStyle);
        newXS_deffile("Wx::RichTextStyleSheet::RemoveParagraphStyle", XS_Wx__RichTextStyleSheet_RemoveParagraphStyle);
#if XSubPPtmpAACH
        newXS_deffile("Wx::RichTextStyleSheet::RemoveListStyle", XS_Wx__RichTextStyleSheet_RemoveListStyle);
#endif
#if XSubPPtmpAACI
        newXS_deffile("Wx::RichTextStyleSheet::FindCharacterStyle", XS_Wx__RichTextStyleSheet_FindCharacterStyle);
        newXS_deffile("Wx::RichTextStyleSheet::FindParagraphStyle", XS_Wx__RichTextStyleSheet_FindParagraphStyle);
        newXS_deffile("Wx::RichTextStyleSheet::FindListStyle", XS_Wx__RichTextStyleSheet_FindListStyle);
#endif
        newXS_deffile("Wx::RichTextStyleSheet::GetCharacterStyleCount", XS_Wx__RichTextStyleSheet_GetCharacterStyleCount);
        newXS_deffile("Wx::RichTextStyleSheet::GetParagraphStyleCount", XS_Wx__RichTextStyleSheet_GetParagraphStyleCount);
#if XSubPPtmpAACJ
        newXS_deffile("Wx::RichTextStyleSheet::GetListStyleCount", XS_Wx__RichTextStyleSheet_GetListStyleCount);
#endif
        newXS_deffile("Wx::RichTextStyleSheet::GetCharacterStyle", XS_Wx__RichTextStyleSheet_GetCharacterStyle);
        newXS_deffile("Wx::RichTextStyleSheet::GetParagraphStyle", XS_Wx__RichTextStyleSheet_GetParagraphStyle);
#if XSubPPtmpAACK
        newXS_deffile("Wx::RichTextStyleSheet::GetListStyle", XS_Wx__RichTextStyleSheet_GetListStyle);
#endif
        newXS_deffile("Wx::RichTextStyleSheet::DeleteStyles", XS_Wx__RichTextStyleSheet_DeleteStyles);
#if XSubPPtmpAACL
        newXS_deffile("Wx::RichTextStyleSheet::InsertSheet", XS_Wx__RichTextStyleSheet_InsertSheet);
        newXS_deffile("Wx::RichTextStyleSheet::AppendSheet", XS_Wx__RichTextStyleSheet_AppendSheet);
        newXS_deffile("Wx::RichTextStyleSheet::Unlink", XS_Wx__RichTextStyleSheet_Unlink);
        newXS_deffile("Wx::RichTextStyleSheet::GetNextSheet", XS_Wx__RichTextStyleSheet_GetNextSheet);
        newXS_deffile("Wx::RichTextStyleSheet::SetNextSheet", XS_Wx__RichTextStyleSheet_SetNextSheet);
        newXS_deffile("Wx::RichTextStyleSheet::GetPreviousSheet", XS_Wx__RichTextStyleSheet_GetPreviousSheet);
        newXS_deffile("Wx::RichTextStyleSheet::SetPreviousSheet", XS_Wx__RichTextStyleSheet_SetPreviousSheet);
#endif
#if XSubPPtmpAACM
        newXS_deffile("Wx::RichTextStyleSheet::SetName", XS_Wx__RichTextStyleSheet_SetName);
        newXS_deffile("Wx::RichTextStyleSheet::GetName", XS_Wx__RichTextStyleSheet_GetName);
        newXS_deffile("Wx::RichTextStyleSheet::SetDescription", XS_Wx__RichTextStyleSheet_SetDescription);
        newXS_deffile("Wx::RichTextStyleSheet::GetDescription", XS_Wx__RichTextStyleSheet_GetDescription);
#endif
#if XSubPPtmpAACN
        newXS_deffile("Wx::RichTextStyleListBox::newDefault", XS_Wx__RichTextStyleListBox_newDefault);
#endif
        newXS_deffile("Wx::RichTextStyleListBox::newFull", XS_Wx__RichTextStyleListBox_newFull);
        newXS_deffile("Wx::RichTextStyleListBox::new", XS_Wx__RichTextStyleListBox_new);
        newXS_deffile("Wx::RichTextStyleListBox::Create", XS_Wx__RichTextStyleListBox_Create);
        newXS_deffile("Wx::RichTextStyleListBox::SetStyleSheet", XS_Wx__RichTextStyleListBox_SetStyleSheet);
        newXS_deffile("Wx::RichTextStyleListBox::GetStyleSheet", XS_Wx__RichTextStyleListBox_GetStyleSheet);
        newXS_deffile("Wx::RichTextStyleListBox::SetRichTextCtrl", XS_Wx__RichTextStyleListBox_SetRichTextCtrl);
        newXS_deffile("Wx::RichTextStyleListBox::GetRichTextCtrl", XS_Wx__RichTextStyleListBox_GetRichTextCtrl);
        newXS_deffile("Wx::RichTextStyleListBox::GetStyle", XS_Wx__RichTextStyleListBox_GetStyle);
#if XSubPPtmpAACO
        newXS_deffile("Wx::RichTextStyleListBox::GetIndexForStyle", XS_Wx__RichTextStyleListBox_GetIndexForStyle);
        newXS_deffile("Wx::RichTextStyleListBox::SetStyleSelection", XS_Wx__RichTextStyleListBox_SetStyleSelection);
#endif
        newXS_deffile("Wx::RichTextStyleListBox::UpdateStyles", XS_Wx__RichTextStyleListBox_UpdateStyles);
#if XSubPPtmpAACP
        newXS_deffile("Wx::RichTextStyleListBox::ApplyStyle", XS_Wx__RichTextStyleListBox_ApplyStyle);
        newXS_deffile("Wx::RichTextStyleListBox::SetApplyOnSelection", XS_Wx__RichTextStyleListBox_SetApplyOnSelection);
        newXS_deffile("Wx::RichTextStyleListBox::GetApplyOnSelection", XS_Wx__RichTextStyleListBox_GetApplyOnSelection);
#endif
#if XSubPPtmpAACQ
        newXS_deffile("Wx::RichTextStyleListBox::SetStyleType", XS_Wx__RichTextStyleListBox_SetStyleType);
        newXS_deffile("Wx::RichTextStyleListBox::GetStyleType", XS_Wx__RichTextStyleListBox_GetStyleType);
#endif
        newXS_deffile("Wx::RichTextStyleListBox::ConvertTenthsMMToPixels", XS_Wx__RichTextStyleListBox_ConvertTenthsMMToPixels);
        newXS_deffile("Wx::RichTextStyleListBox::CreateHTML", XS_Wx__RichTextStyleListBox_CreateHTML);
#if XSubPPtmpAACR
        newXS_deffile("Wx::RichTextStyleListCtrl::newDefault", XS_Wx__RichTextStyleListCtrl_newDefault);
        newXS_deffile("Wx::RichTextStyleListCtrl::newFull", XS_Wx__RichTextStyleListCtrl_newFull);
        newXS_deffile("Wx::RichTextStyleListCtrl::new", XS_Wx__RichTextStyleListCtrl_new);
        newXS_deffile("Wx::RichTextStyleListCtrl::Create", XS_Wx__RichTextStyleListCtrl_Create);
        newXS_deffile("Wx::RichTextStyleListCtrl::SetStyleSheet", XS_Wx__RichTextStyleListCtrl_SetStyleSheet);
        newXS_deffile("Wx::RichTextStyleListCtrl::GetStyleSheet", XS_Wx__RichTextStyleListCtrl_GetStyleSheet);
        newXS_deffile("Wx::RichTextStyleListCtrl::SetRichTextCtrl", XS_Wx__RichTextStyleListCtrl_SetRichTextCtrl);
        newXS_deffile("Wx::RichTextStyleListCtrl::GetRichTextCtrl", XS_Wx__RichTextStyleListCtrl_GetRichTextCtrl);
        newXS_deffile("Wx::RichTextStyleListCtrl::UpdateStyles", XS_Wx__RichTextStyleListCtrl_UpdateStyles);
        newXS_deffile("Wx::RichTextStyleListCtrl::SetStyleType", XS_Wx__RichTextStyleListCtrl_SetStyleType);
        newXS_deffile("Wx::RichTextStyleListCtrl::GetStyleType", XS_Wx__RichTextStyleListCtrl_GetStyleType);
        newXS_deffile("Wx::RichTextStyleListCtrl::StyleTypeToIndex", XS_Wx__RichTextStyleListCtrl_StyleTypeToIndex);
        newXS_deffile("Wx::RichTextStyleListCtrl::StyleIndexToType", XS_Wx__RichTextStyleListCtrl_StyleIndexToType);
        newXS_deffile("Wx::RichTextStyleListCtrl::GetStyleListBox", XS_Wx__RichTextStyleListCtrl_GetStyleListBox);
        newXS_deffile("Wx::RichTextStyleListCtrl::GetStyleChoice", XS_Wx__RichTextStyleListCtrl_GetStyleChoice);
#endif
#if XSubPPtmpAACS
        newXS_deffile("Wx::RichTextStyleComboCtrl::newDefault", XS_Wx__RichTextStyleComboCtrl_newDefault);
        newXS_deffile("Wx::RichTextStyleComboCtrl::newFull", XS_Wx__RichTextStyleComboCtrl_newFull);
        newXS_deffile("Wx::RichTextStyleComboCtrl::new", XS_Wx__RichTextStyleComboCtrl_new);
        newXS_deffile("Wx::RichTextStyleComboCtrl::Create", XS_Wx__RichTextStyleComboCtrl_Create);
        newXS_deffile("Wx::RichTextStyleComboCtrl::UpdateStyles", XS_Wx__RichTextStyleComboCtrl_UpdateStyles);
        newXS_deffile("Wx::RichTextStyleComboCtrl::SetStyleSheet", XS_Wx__RichTextStyleComboCtrl_SetStyleSheet);
        newXS_deffile("Wx::RichTextStyleComboCtrl::GetStyleSheet", XS_Wx__RichTextStyleComboCtrl_GetStyleSheet);
        newXS_deffile("Wx::RichTextStyleComboCtrl::SetRichTextCtrl", XS_Wx__RichTextStyleComboCtrl_SetRichTextCtrl);
        newXS_deffile("Wx::RichTextStyleComboCtrl::GetRichTextCtrl", XS_Wx__RichTextStyleComboCtrl_GetRichTextCtrl);
#endif
        newXS_deffile("Wx::RichTextFormattingDialog::newDefault", XS_Wx__RichTextFormattingDialog_newDefault);
        newXS_deffile("Wx::RichTextFormattingDialog::newFull", XS_Wx__RichTextFormattingDialog_newFull);
        newXS_deffile("Wx::RichTextFormattingDialog::new", XS_Wx__RichTextFormattingDialog_new);
        newXS_deffile("Wx::RichTextFormattingDialog::Create", XS_Wx__RichTextFormattingDialog_Create);
        newXS_deffile("Wx::RichTextFormattingDialog::GetStyle", XS_Wx__RichTextFormattingDialog_GetStyle);
        newXS_deffile("Wx::RichTextFormattingDialog::SetStyle", XS_Wx__RichTextFormattingDialog_SetStyle);
        newXS_deffile("Wx::RichTextFormattingDialog::SetStyleDefinition", XS_Wx__RichTextFormattingDialog_SetStyleDefinition);
        newXS_deffile("Wx::RichTextFormattingDialog::GetStyleDefinition", XS_Wx__RichTextFormattingDialog_GetStyleDefinition);
        newXS_deffile("Wx::RichTextFormattingDialog::GetDialogStyleDefinition", XS_Wx__RichTextFormattingDialog_GetDialogStyleDefinition);
        newXS_deffile("Wx::RichTextFormattingDialog::GetStyleSheet", XS_Wx__RichTextFormattingDialog_GetStyleSheet);
        newXS_deffile("Wx::RichTextFormattingDialog::UpdateDisplay", XS_Wx__RichTextFormattingDialog_UpdateDisplay);
        newXS_deffile("Wx::RichTextFormattingDialog::ApplyStyle", XS_Wx__RichTextFormattingDialog_ApplyStyle);
        newXS_deffile("Wx::RichTextFormattingDialog::GetAttributes", XS_Wx__RichTextFormattingDialog_GetAttributes);
        newXS_deffile("Wx::RichTextFormattingDialog::SetAttributes", XS_Wx__RichTextFormattingDialog_SetAttributes);
        newXS_deffile("Wx::RichTextFormattingDialog::SetImageList", XS_Wx__RichTextFormattingDialog_SetImageList);
        newXS_deffile("Wx::RichTextFormattingDialog::GetImageList", XS_Wx__RichTextFormattingDialog_GetImageList);
        newXS_deffile("Wx::RichTextFormattingDialog::ShowToolTips", XS_Wx__RichTextFormattingDialog_ShowToolTips);
        newXS_deffile("Wx::RichTextFormattingDialog::SetShowToolTips", XS_Wx__RichTextFormattingDialog_SetShowToolTips);
        newXS_deffile("Wx::RichTextFormattingDialog::AddPageId", XS_Wx__RichTextFormattingDialog_AddPageId);
        newXS_deffile("Wx::RichTextFileHandler::CanHandle", XS_Wx__RichTextFileHandler_CanHandle);
        newXS_deffile("Wx::RichTextFileHandler::CanLoad", XS_Wx__RichTextFileHandler_CanLoad);
        newXS_deffile("Wx::RichTextFileHandler::CanSave", XS_Wx__RichTextFileHandler_CanSave);
        newXS_deffile("Wx::RichTextFileHandler::LoadFile", XS_Wx__RichTextFileHandler_LoadFile);
        newXS_deffile("Wx::RichTextFileHandler::SaveFile", XS_Wx__RichTextFileHandler_SaveFile);
        newXS_deffile("Wx::RichTextFileHandler::SetName", XS_Wx__RichTextFileHandler_SetName);
        newXS_deffile("Wx::RichTextFileHandler::GetName", XS_Wx__RichTextFileHandler_GetName);
        newXS_deffile("Wx::RichTextFileHandler::SetExtension", XS_Wx__RichTextFileHandler_SetExtension);
        newXS_deffile("Wx::RichTextFileHandler::GetExtension", XS_Wx__RichTextFileHandler_GetExtension);
        newXS_deffile("Wx::RichTextFileHandler::SetType", XS_Wx__RichTextFileHandler_SetType);
        newXS_deffile("Wx::RichTextFileHandler::GetType", XS_Wx__RichTextFileHandler_GetType);
        newXS_deffile("Wx::RichTextFileHandler::SetEncoding", XS_Wx__RichTextFileHandler_SetEncoding);
        newXS_deffile("Wx::RichTextFileHandler::GetEncoding", XS_Wx__RichTextFileHandler_GetEncoding);
        newXS_deffile("Wx::RichTextFileHandler::IsVisible", XS_Wx__RichTextFileHandler_IsVisible);
        newXS_deffile("Wx::RichTextFileHandler::SetVisible", XS_Wx__RichTextFileHandler_SetVisible);
        newXS_deffile("Wx::PlRichTextFileHandler::new", XS_Wx__PlRichTextFileHandler_new);
        newXS_deffile("Wx::PlRichTextFileHandler::CanHandle", XS_Wx__PlRichTextFileHandler_CanHandle);
        newXS_deffile("Wx::PlRichTextFileHandler::CanLoad", XS_Wx__PlRichTextFileHandler_CanLoad);
        newXS_deffile("Wx::PlRichTextFileHandler::CanSave", XS_Wx__PlRichTextFileHandler_CanSave);
        newXS_deffile("Wx::RichTextXMLHandler::new", XS_Wx__RichTextXMLHandler_new);
#if XSubPPtmpAACT
        newXS_deffile("Wx::RichTextHTMLHandler::new", XS_Wx__RichTextHTMLHandler_new);
        newXS_deffile("Wx::RichTextHTMLHandler::ClearTemporaryImageLocations", XS_Wx__RichTextHTMLHandler_ClearTemporaryImageLocations);
        newXS_deffile("Wx::RichTextHTMLHandler::DeleteTemporaryImages", XS_Wx__RichTextHTMLHandler_DeleteTemporaryImages);
        newXS_deffile("Wx::RichTextHTMLHandler::GetFontSizeMapping", XS_Wx__RichTextHTMLHandler_GetFontSizeMapping);
        newXS_deffile("Wx::RichTextHTMLHandler::GetTemporaryImageLocations", XS_Wx__RichTextHTMLHandler_GetTemporaryImageLocations);
        newXS_deffile("Wx::RichTextHTMLHandler::GetTempDir", XS_Wx__RichTextHTMLHandler_GetTempDir);
        newXS_deffile("Wx::RichTextHTMLHandler::SetFileCounter", XS_Wx__RichTextHTMLHandler_SetFileCounter);
        newXS_deffile("Wx::RichTextHTMLHandler::SetFontSizeMapping", XS_Wx__RichTextHTMLHandler_SetFontSizeMapping);
        newXS_deffile("Wx::RichTextHTMLHandler::SetTempDir", XS_Wx__RichTextHTMLHandler_SetTempDir);
        newXS_deffile("Wx::RichTextHTMLHandler::SetTemporaryImageLocations", XS_Wx__RichTextHTMLHandler_SetTemporaryImageLocations);
#endif
        newXS_deffile("Wx::RichTextBuffer::CLONE", XS_Wx__RichTextBuffer_CLONE);
        newXS_deffile("Wx::RichTextBuffer::new", XS_Wx__RichTextBuffer_new);
        newXS_deffile("Wx::RichTextBuffer::Destroy", XS_Wx__RichTextBuffer_Destroy);
        newXS_deffile("Wx::RichTextBuffer::ResetAndClearCommands", XS_Wx__RichTextBuffer_ResetAndClearCommands);
        newXS_deffile("Wx::RichTextBuffer::AddEventHandler", XS_Wx__RichTextBuffer_AddEventHandler);
        newXS_deffile("Wx::RichTextBuffer::AddHandler", XS_Wx__RichTextBuffer_AddHandler);
#if XSubPPtmpAACU
        newXS_deffile("Wx::RichTextBuffer::SetStyleEx", XS_Wx__RichTextBuffer_SetStyleEx);
        newXS_deffile("Wx::RichTextBuffer::SetStyleRich", XS_Wx__RichTextBuffer_SetStyleRich);
        newXS_deffile("Wx::RichTextBuffer::SetStyle", XS_Wx__RichTextBuffer_SetStyle);
#endif
        newXS_deffile("Wx::RichTextBuffer::InsertTextWithUndo", XS_Wx__RichTextBuffer_InsertTextWithUndo);
        newXS_deffile("Wx::RichTextBuffer::InsertNewlineWithUndo", XS_Wx__RichTextBuffer_InsertNewlineWithUndo);
        newXS_deffile("Wx::RichTextBuffer::GetBasicStyle", XS_Wx__RichTextBuffer_GetBasicStyle);
        newXS_deffile("Wx::RichTextBuffer::GetDefaultStyle", XS_Wx__RichTextBuffer_GetDefaultStyle);
        newXS_deffile("Wx::RichTextBuffer::BeginStyle", XS_Wx__RichTextBuffer_BeginStyle);
        newXS_deffile("Wx::RichTextBuffer::EndStyle", XS_Wx__RichTextBuffer_EndStyle);
        newXS_deffile("Wx::RichTextBuffer::EndAllStyles", XS_Wx__RichTextBuffer_EndAllStyles);
        newXS_deffile("Wx::RichTextBuffer::BeginBold", XS_Wx__RichTextBuffer_BeginBold);
        newXS_deffile("Wx::RichTextBuffer::EndBold", XS_Wx__RichTextBuffer_EndBold);
        newXS_deffile("Wx::RichTextBuffer::BeginItalic", XS_Wx__RichTextBuffer_BeginItalic);
        newXS_deffile("Wx::RichTextBuffer::EndItalic", XS_Wx__RichTextBuffer_EndItalic);
        newXS_deffile("Wx::RichTextBuffer::BeginUnderline", XS_Wx__RichTextBuffer_BeginUnderline);
        newXS_deffile("Wx::RichTextBuffer::EndUnderline", XS_Wx__RichTextBuffer_EndUnderline);
        newXS_deffile("Wx::RichTextBuffer::BeginFontSize", XS_Wx__RichTextBuffer_BeginFontSize);
        newXS_deffile("Wx::RichTextBuffer::EndFontSize", XS_Wx__RichTextBuffer_EndFontSize);
        newXS_deffile("Wx::RichTextBuffer::BeginFont", XS_Wx__RichTextBuffer_BeginFont);
        newXS_deffile("Wx::RichTextBuffer::EndFont", XS_Wx__RichTextBuffer_EndFont);
        newXS_deffile("Wx::RichTextBuffer::BeginTextColour", XS_Wx__RichTextBuffer_BeginTextColour);
        newXS_deffile("Wx::RichTextBuffer::EndTextColour", XS_Wx__RichTextBuffer_EndTextColour);
        newXS_deffile("Wx::RichTextBuffer::BeginAlignment", XS_Wx__RichTextBuffer_BeginAlignment);
        newXS_deffile("Wx::RichTextBuffer::EndAlignment", XS_Wx__RichTextBuffer_EndAlignment);
        newXS_deffile("Wx::RichTextBuffer::BeginLeftIndent", XS_Wx__RichTextBuffer_BeginLeftIndent);
        newXS_deffile("Wx::RichTextBuffer::EndLeftIndent", XS_Wx__RichTextBuffer_EndLeftIndent);
        newXS_deffile("Wx::RichTextBuffer::BeginRightIndent", XS_Wx__RichTextBuffer_BeginRightIndent);
        newXS_deffile("Wx::RichTextBuffer::EndRightIndent", XS_Wx__RichTextBuffer_EndRightIndent);
        newXS_deffile("Wx::RichTextBuffer::BeginParagraphSpacing", XS_Wx__RichTextBuffer_BeginParagraphSpacing);
        newXS_deffile("Wx::RichTextBuffer::EndParagraphSpacing", XS_Wx__RichTextBuffer_EndParagraphSpacing);
        newXS_deffile("Wx::RichTextBuffer::BeginLineSpacing", XS_Wx__RichTextBuffer_BeginLineSpacing);
        newXS_deffile("Wx::RichTextBuffer::EndLineSpacing", XS_Wx__RichTextBuffer_EndLineSpacing);
        newXS_deffile("Wx::RichTextBuffer::BeginNumberedBullet", XS_Wx__RichTextBuffer_BeginNumberedBullet);
        newXS_deffile("Wx::RichTextBuffer::EndNumberedBullet", XS_Wx__RichTextBuffer_EndNumberedBullet);
#if XSubPPtmpAACV
        newXS_deffile("Wx::RichTextBuffer::BeginSymbolBullet0", XS_Wx__RichTextBuffer_BeginSymbolBullet0);
#endif
#if XSubPPtmpAACW
        newXS_deffile("Wx::RichTextBuffer::BeginSymbolBullet1", XS_Wx__RichTextBuffer_BeginSymbolBullet1);
#endif
        newXS_deffile("Wx::RichTextBuffer::EndSymbolBullet", XS_Wx__RichTextBuffer_EndSymbolBullet);
#if XSubPPtmpAACX
        newXS_deffile("Wx::RichTextBuffer::BeginStandardBullet", XS_Wx__RichTextBuffer_BeginStandardBullet);
        newXS_deffile("Wx::RichTextBuffer::EndStandardBullet", XS_Wx__RichTextBuffer_EndStandardBullet);
#endif
        newXS_deffile("Wx::RichTextBuffer::BeginCharacterStyle", XS_Wx__RichTextBuffer_BeginCharacterStyle);
        newXS_deffile("Wx::RichTextBuffer::EndCharacterStyle", XS_Wx__RichTextBuffer_EndCharacterStyle);
        newXS_deffile("Wx::RichTextBuffer::BeginParagraphStyle", XS_Wx__RichTextBuffer_BeginParagraphStyle);
        newXS_deffile("Wx::RichTextBuffer::EndParagraphStyle", XS_Wx__RichTextBuffer_EndParagraphStyle);
#if XSubPPtmpAACY
        newXS_deffile("Wx::RichTextBuffer::BeginListStyle", XS_Wx__RichTextBuffer_BeginListStyle);
        newXS_deffile("Wx::RichTextBuffer::EndListStyle", XS_Wx__RichTextBuffer_EndListStyle);
        newXS_deffile("Wx::RichTextBuffer::BeginURL", XS_Wx__RichTextBuffer_BeginURL);
        newXS_deffile("Wx::RichTextBuffer::EndURL", XS_Wx__RichTextBuffer_EndURL);
#endif
#if XSubPPtmpAACZ
        newXS_deffile("Wx::RichTextBuffer::ClearListStyle", XS_Wx__RichTextBuffer_ClearListStyle);
#endif
        newXS_deffile("Wx::RichTextBuffer::AddParagraph", XS_Wx__RichTextBuffer_AddParagraph);
        newXS_deffile("Wx::RichTextBuffer::AddImage", XS_Wx__RichTextBuffer_AddImage);
        newXS_deffile("Wx::RichTextBuffer::BeginBatchUndo", XS_Wx__RichTextBuffer_BeginBatchUndo);
        newXS_deffile("Wx::RichTextBuffer::EndBatchUndo", XS_Wx__RichTextBuffer_EndBatchUndo);
        newXS_deffile("Wx::RichTextBuffer::BatchingUndo", XS_Wx__RichTextBuffer_BatchingUndo);
        newXS_deffile("Wx::RichTextBuffer::BeginSuppressUndo", XS_Wx__RichTextBuffer_BeginSuppressUndo);
        newXS_deffile("Wx::RichTextBuffer::EndSuppressUndo", XS_Wx__RichTextBuffer_EndSuppressUndo);
        newXS_deffile("Wx::RichTextBuffer::SuppressingUndo", XS_Wx__RichTextBuffer_SuppressingUndo);
        newXS_deffile("Wx::RichTextBuffer::SetStyleSheet", XS_Wx__RichTextBuffer_SetStyleSheet);
        newXS_deffile("Wx::RichTextBuffer::GetStyleSheet", XS_Wx__RichTextBuffer_GetStyleSheet);
#if XSubPPtmpAADA
        newXS_deffile("Wx::RichTextBuffer::PushStyleSheet", XS_Wx__RichTextBuffer_PushStyleSheet);
        newXS_deffile("Wx::RichTextBuffer::PopStyleSheet", XS_Wx__RichTextBuffer_PopStyleSheet);
#endif
        newXS_deffile("Wx::RichTextBuffer::SetBasicStyleRich", XS_Wx__RichTextBuffer_SetBasicStyleRich);
        newXS_deffile("Wx::RichTextBuffer::SetBasicStyleEx", XS_Wx__RichTextBuffer_SetBasicStyleEx);
        newXS_deffile("Wx::RichTextBuffer::SetBasicStyle", XS_Wx__RichTextBuffer_SetBasicStyle);
#if XSubPPtmpAADB
        newXS_deffile("Wx::RichTextBuffer::BeginSymbolBullet", XS_Wx__RichTextBuffer_BeginSymbolBullet);
#endif
        newXS_deffile("Wx::RichTextBuffer::GetRichTextAttrStyle", XS_Wx__RichTextBuffer_GetRichTextAttrStyle);
#if XSubPPtmpAADC
        newXS_deffile("Wx::RichTextBuffer::GetTextAttrExStyle", XS_Wx__RichTextBuffer_GetTextAttrExStyle);
#endif
#if XSubPPtmpAADD
        newXS_deffile("Wx::RichTextBuffer::GetRichTextAttrUncombinedStyle", XS_Wx__RichTextBuffer_GetRichTextAttrUncombinedStyle);
#if XSubPPtmpAADE
        newXS_deffile("Wx::RichTextBuffer::GetTextAttrExUncombinedStyle", XS_Wx__RichTextBuffer_GetTextAttrExUncombinedStyle);
#endif
#endif
#if XSubPPtmpAADF
        newXS_deffile("Wx::RichTextBuffer::GetTextAttrExStyleForRange", XS_Wx__RichTextBuffer_GetTextAttrExStyleForRange);
#endif
#if XSubPPtmpAADG
        newXS_deffile("Wx::RichTextBuffer::GetRichTextAttrStyleForRange", XS_Wx__RichTextBuffer_GetRichTextAttrStyleForRange);
#endif
        newXS_deffile("Wx::SymbolPickerDialog::new", XS_Wx__SymbolPickerDialog_new);
        newXS_deffile("Wx::SymbolPickerDialog::newDefault", XS_Wx__SymbolPickerDialog_newDefault);
        newXS_deffile("Wx::SymbolPickerDialog::newFull", XS_Wx__SymbolPickerDialog_newFull);
        newXS_deffile("Wx::SymbolPickerDialog::Create", XS_Wx__SymbolPickerDialog_Create);
        newXS_deffile("Wx::SymbolPickerDialog::SetUnicodeMode", XS_Wx__SymbolPickerDialog_SetUnicodeMode);
        newXS_deffile("Wx::SymbolPickerDialog::GetSymbolChar", XS_Wx__SymbolPickerDialog_GetSymbolChar);
        newXS_deffile("Wx::SymbolPickerDialog::HasSelection", XS_Wx__SymbolPickerDialog_HasSelection);
        newXS_deffile("Wx::SymbolPickerDialog::UseNormalFont", XS_Wx__SymbolPickerDialog_UseNormalFont);
        newXS_deffile("Wx::SymbolPickerDialog::GetFontName", XS_Wx__SymbolPickerDialog_GetFontName);
        newXS_deffile("Wx::SymbolPickerDialog::SetFontName", XS_Wx__SymbolPickerDialog_SetFontName);
        newXS_deffile("Wx::SymbolPickerDialog::GetSymbol", XS_Wx__SymbolPickerDialog_GetSymbol);
        newXS_deffile("Wx::SymbolPickerDialog::SetSymbol", XS_Wx__SymbolPickerDialog_SetSymbol);
        newXS_deffile("Wx::SymbolPickerDialog::GetFromUnicode", XS_Wx__SymbolPickerDialog_GetFromUnicode);
        newXS_deffile("Wx::SymbolPickerDialog::SetFromUnicode", XS_Wx__SymbolPickerDialog_SetFromUnicode);
        newXS_deffile("Wx::SymbolPickerDialog::GetNormalTextFontName", XS_Wx__SymbolPickerDialog_GetNormalTextFontName);
        newXS_deffile("Wx::SymbolPickerDialog::SetNormalTextFontName", XS_Wx__SymbolPickerDialog_SetNormalTextFontName);
        newXS_deffile("Wx::RichTextStyleOrganiserDialog::new", XS_Wx__RichTextStyleOrganiserDialog_new);
        newXS_deffile("Wx::RichTextStyleOrganiserDialog::newDefault", XS_Wx__RichTextStyleOrganiserDialog_newDefault);
        newXS_deffile("Wx::RichTextStyleOrganiserDialog::newFull", XS_Wx__RichTextStyleOrganiserDialog_newFull);
        newXS_deffile("Wx::RichTextStyleOrganiserDialog::Create", XS_Wx__RichTextStyleOrganiserDialog_Create);
        newXS_deffile("Wx::RichTextStyleOrganiserDialog::SetStyleSheet", XS_Wx__RichTextStyleOrganiserDialog_SetStyleSheet);
        newXS_deffile("Wx::RichTextStyleOrganiserDialog::GetStyleSheet", XS_Wx__RichTextStyleOrganiserDialog_GetStyleSheet);
        newXS_deffile("Wx::RichTextStyleOrganiserDialog::SetRichTextCtrl", XS_Wx__RichTextStyleOrganiserDialog_SetRichTextCtrl);
        newXS_deffile("Wx::RichTextStyleOrganiserDialog::GetRichTextCtrl", XS_Wx__RichTextStyleOrganiserDialog_GetRichTextCtrl);
        newXS_deffile("Wx::RichTextStyleOrganiserDialog::SetFlags", XS_Wx__RichTextStyleOrganiserDialog_SetFlags);
        newXS_deffile("Wx::RichTextStyleOrganiserDialog::GetFlags", XS_Wx__RichTextStyleOrganiserDialog_GetFlags);
        newXS_deffile("Wx::RichTextStyleOrganiserDialog::GetRestartNumbering", XS_Wx__RichTextStyleOrganiserDialog_GetRestartNumbering);
        newXS_deffile("Wx::RichTextStyleOrganiserDialog::SetRestartNumbering", XS_Wx__RichTextStyleOrganiserDialog_SetRestartNumbering);
        newXS_deffile("Wx::RichTextStyleOrganiserDialog::GetSelectedStyle", XS_Wx__RichTextStyleOrganiserDialog_GetSelectedStyle);
        newXS_deffile("Wx::RichTextStyleOrganiserDialog::GetSelectedStyleDefinition", XS_Wx__RichTextStyleOrganiserDialog_GetSelectedStyleDefinition);
        newXS_deffile("Wx::RichTextStyleOrganiserDialog::ApplyStyle", XS_Wx__RichTextStyleOrganiserDialog_ApplyStyle);
        newXS_deffile("Wx::RichTextStyleOrganiserDialog::ShowToolTips", XS_Wx__RichTextStyleOrganiserDialog_ShowToolTips);
        newXS_deffile("Wx::RichTextStyleOrganiserDialog::SetShowToolTips", XS_Wx__RichTextStyleOrganiserDialog_SetShowToolTips);
#if XSubPPtmpAADH
        newXS_deffile("Wx::RichTextPrintout::new", XS_Wx__RichTextPrintout_new);
        newXS_deffile("Wx::RichTextPrintout::Destroy", XS_Wx__RichTextPrintout_Destroy);
        newXS_deffile("Wx::RichTextPrintout::SetRichTextBuffer", XS_Wx__RichTextPrintout_SetRichTextBuffer);
        newXS_deffile("Wx::RichTextPrintout::GetRichTextBuffer", XS_Wx__RichTextPrintout_GetRichTextBuffer);
        newXS_deffile("Wx::RichTextPrintout::SetHeaderFooterData", XS_Wx__RichTextPrintout_SetHeaderFooterData);
        newXS_deffile("Wx::RichTextPrintout::GetHeaderFooterData", XS_Wx__RichTextPrintout_GetHeaderFooterData);
        newXS_deffile("Wx::RichTextPrintout::SetMargins", XS_Wx__RichTextPrintout_SetMargins);
        newXS_deffile("Wx::RichTextPrintout::CalculateScaling", XS_Wx__RichTextPrintout_CalculateScaling);
        newXS_deffile("Wx::RichTextPrintout::OnPrintPage", XS_Wx__RichTextPrintout_OnPrintPage);
        newXS_deffile("Wx::RichTextPrintout::HasPage", XS_Wx__RichTextPrintout_HasPage);
        newXS_deffile("Wx::RichTextPrintout::OnBeginDocument", XS_Wx__RichTextPrintout_OnBeginDocument);
        newXS_deffile("Wx::RichTextPrintout::OnPreparePrinting", XS_Wx__RichTextPrintout_OnPreparePrinting);
        newXS_deffile("Wx::RichTextPrintout::GetPageInfo", XS_Wx__RichTextPrintout_GetPageInfo);
        newXS_deffile("Wx::RichTextPrinting::new", XS_Wx__RichTextPrinting_new);
        newXS_deffile("Wx::RichTextPrinting::DESTROY", XS_Wx__RichTextPrinting_DESTROY);
        newXS_deffile("Wx::RichTextPrinting::CLONE", XS_Wx__RichTextPrinting_CLONE);
        newXS_deffile("Wx::RichTextPrinting::PreviewFile", XS_Wx__RichTextPrinting_PreviewFile);
        newXS_deffile("Wx::RichTextPrinting::PreviewBuffer", XS_Wx__RichTextPrinting_PreviewBuffer);
#if XSubPPtmpAADI
        newXS_deffile("Wx::RichTextPrinting::PrintFile", XS_Wx__RichTextPrinting_PrintFile);
        newXS_deffile("Wx::RichTextPrinting::PrintBuffer", XS_Wx__RichTextPrinting_PrintBuffer);
#endif
#if XSubPPtmpAADJ
        newXS_deffile("Wx::RichTextPrinting::PrintFile", XS_Wx__RichTextPrinting_PrintFile);
        newXS_deffile("Wx::RichTextPrinting::PrintBuffer", XS_Wx__RichTextPrinting_PrintBuffer);
#endif
        newXS_deffile("Wx::RichTextPrinting::PageSetup", XS_Wx__RichTextPrinting_PageSetup);
        newXS_deffile("Wx::RichTextPrinting::SetHeaderFooterData", XS_Wx__RichTextPrinting_SetHeaderFooterData);
        newXS_deffile("Wx::RichTextPrinting::GetHeaderFooterData", XS_Wx__RichTextPrinting_GetHeaderFooterData);
        newXS_deffile("Wx::RichTextPrinting::SetHeaderText", XS_Wx__RichTextPrinting_SetHeaderText);
        newXS_deffile("Wx::RichTextPrinting::GetHeaderText", XS_Wx__RichTextPrinting_GetHeaderText);
        newXS_deffile("Wx::RichTextPrinting::SetFooterText", XS_Wx__RichTextPrinting_SetFooterText);
        newXS_deffile("Wx::RichTextPrinting::GetFooterText", XS_Wx__RichTextPrinting_GetFooterText);
        newXS_deffile("Wx::RichTextPrinting::SetShowOnFirstPage", XS_Wx__RichTextPrinting_SetShowOnFirstPage);
        newXS_deffile("Wx::RichTextPrinting::SetHeaderFooterFont", XS_Wx__RichTextPrinting_SetHeaderFooterFont);
        newXS_deffile("Wx::RichTextPrinting::SetHeaderFooterTextColour", XS_Wx__RichTextPrinting_SetHeaderFooterTextColour);
        newXS_deffile("Wx::RichTextPrinting::GetPrintData", XS_Wx__RichTextPrinting_GetPrintData);
        newXS_deffile("Wx::RichTextPrinting::SetPrintData", XS_Wx__RichTextPrinting_SetPrintData);
        newXS_deffile("Wx::RichTextPrinting::GetPageSetupData", XS_Wx__RichTextPrinting_GetPageSetupData);
        newXS_deffile("Wx::RichTextPrinting::SetPageSetupData", XS_Wx__RichTextPrinting_SetPageSetupData);
        newXS_deffile("Wx::RichTextPrinting::SetRichTextBufferPreview", XS_Wx__RichTextPrinting_SetRichTextBufferPreview);
        newXS_deffile("Wx::RichTextPrinting::GetRichTextBufferPreview", XS_Wx__RichTextPrinting_GetRichTextBufferPreview);
        newXS_deffile("Wx::RichTextPrinting::SetRichTextBufferPrinting", XS_Wx__RichTextPrinting_SetRichTextBufferPrinting);
        newXS_deffile("Wx::RichTextPrinting::GetRichTextBufferPrinting", XS_Wx__RichTextPrinting_GetRichTextBufferPrinting);
        newXS_deffile("Wx::RichTextPrinting::SetParentWindow", XS_Wx__RichTextPrinting_SetParentWindow);
        newXS_deffile("Wx::RichTextPrinting::GetParentWindow", XS_Wx__RichTextPrinting_GetParentWindow);
        newXS_deffile("Wx::RichTextPrinting::SetTitle", XS_Wx__RichTextPrinting_SetTitle);
        newXS_deffile("Wx::RichTextPrinting::GetTitle", XS_Wx__RichTextPrinting_GetTitle);
        newXS_deffile("Wx::RichTextPrinting::SetPreviewRect", XS_Wx__RichTextPrinting_SetPreviewRect);
        newXS_deffile("Wx::RichTextPrinting::GetPreviewRect", XS_Wx__RichTextPrinting_GetPreviewRect);
        newXS_deffile("Wx::RichTextHeaderFooterData::newDefault", XS_Wx__RichTextHeaderFooterData_newDefault);
        newXS_deffile("Wx::RichTextHeaderFooterData::newCopy", XS_Wx__RichTextHeaderFooterData_newCopy);
        newXS_deffile("Wx::RichTextHeaderFooterData::DESTROY", XS_Wx__RichTextHeaderFooterData_DESTROY);
        newXS_deffile("Wx::RichTextHeaderFooterData::CLONE", XS_Wx__RichTextHeaderFooterData_CLONE);
        newXS_deffile("Wx::RichTextHeaderFooterData::SetHeaderText", XS_Wx__RichTextHeaderFooterData_SetHeaderText);
        newXS_deffile("Wx::RichTextHeaderFooterData::GetHeaderText", XS_Wx__RichTextHeaderFooterData_GetHeaderText);
        newXS_deffile("Wx::RichTextHeaderFooterData::SetFooterText", XS_Wx__RichTextHeaderFooterData_SetFooterText);
        newXS_deffile("Wx::RichTextHeaderFooterData::GetFooterText", XS_Wx__RichTextHeaderFooterData_GetFooterText);
        newXS_deffile("Wx::RichTextHeaderFooterData::SetText", XS_Wx__RichTextHeaderFooterData_SetText);
        newXS_deffile("Wx::RichTextHeaderFooterData::GetText", XS_Wx__RichTextHeaderFooterData_GetText);
        newXS_deffile("Wx::RichTextHeaderFooterData::SetMargins", XS_Wx__RichTextHeaderFooterData_SetMargins);
        newXS_deffile("Wx::RichTextHeaderFooterData::GetHeaderMargin", XS_Wx__RichTextHeaderFooterData_GetHeaderMargin);
        newXS_deffile("Wx::RichTextHeaderFooterData::GetFooterMargin", XS_Wx__RichTextHeaderFooterData_GetFooterMargin);
        newXS_deffile("Wx::RichTextHeaderFooterData::SetShowOnFirstPage", XS_Wx__RichTextHeaderFooterData_SetShowOnFirstPage);
        newXS_deffile("Wx::RichTextHeaderFooterData::GetShowOnFirstPage", XS_Wx__RichTextHeaderFooterData_GetShowOnFirstPage);
        newXS_deffile("Wx::RichTextHeaderFooterData::Clear", XS_Wx__RichTextHeaderFooterData_Clear);
        newXS_deffile("Wx::RichTextHeaderFooterData::SetFont", XS_Wx__RichTextHeaderFooterData_SetFont);
        newXS_deffile("Wx::RichTextHeaderFooterData::GetFont", XS_Wx__RichTextHeaderFooterData_GetFont);
        newXS_deffile("Wx::RichTextHeaderFooterData::SetTextColour", XS_Wx__RichTextHeaderFooterData_SetTextColour);
        newXS_deffile("Wx::RichTextHeaderFooterData::GetTextColour", XS_Wx__RichTextHeaderFooterData_GetTextColour);
        newXS_deffile("Wx::RichTextHeaderFooterData::new", XS_Wx__RichTextHeaderFooterData_new);
#endif
        newXS_deffile("Wx::RichText::SetEvents", XS_Wx__RichText_SetEvents);

    /* Initialisation Section */

  INIT_PLI_HELPERS( wx_pli_helpers );

#if XSubPPtmpAAAA
#endif
#if XSubPPtmpAAAB
#endif
#if XSubPPtmpAAAC
#endif
#if XSubPPtmpAAAD
#endif
#if XSubPPtmpAAAE
#endif
#if XSubPPtmpAAAF
#endif
#if XSubPPtmpAAAG
#endif
#if XSubPPtmpAAAH
#endif
#if XSubPPtmpAAAI
#endif
#if XSubPPtmpAAAJ
#endif
#if XSubPPtmpAAAK
#endif
#if XSubPPtmpAAAL
#endif
#if XSubPPtmpAAAM
#endif
#if XSubPPtmpAAAN
#endif
#if XSubPPtmpAAAO
#endif
#if XSubPPtmpAAAP
#endif
#if XSubPPtmpAAAQ
#endif
#if XSubPPtmpAAAR
#endif
#if XSubPPtmpAAAS
#endif
#if XSubPPtmpAAAT
#endif
#if XSubPPtmpAAAU
#endif
#if XSubPPtmpAAAV
#endif
#if XSubPPtmpAAAW
#endif
#if XSubPPtmpAAAX
#endif
#if XSubPPtmpAAAY
#endif
#if XSubPPtmpAAAZ
#if XSubPPtmpAABA
#if XSubPPtmpAABB
#endif
#if XSubPPtmpAABC
#endif
#if XSubPPtmpAABD
#endif
#if XSubPPtmpAABE
#endif
#endif
#endif
#if XSubPPtmpAABF
#endif
#if XSubPPtmpAABG
#endif
#if XSubPPtmpAABH
#endif
#if XSubPPtmpAABI
#endif
#if XSubPPtmpAABJ
#endif
#if XSubPPtmpAABK
#endif
#if XSubPPtmpAABL
#endif
#if XSubPPtmpAABM
#endif
#if XSubPPtmpAABN
#endif
#if XSubPPtmpAABO
#endif
#if XSubPPtmpAABP
#endif
#if XSubPPtmpAABQ
#endif
#if XSubPPtmpAABR
#endif
#if XSubPPtmpAABS
#endif
#if XSubPPtmpAABT
#endif
#if XSubPPtmpAABU
#endif
#if XSubPPtmpAABV
#endif
#if XSubPPtmpAABW
#endif
#if XSubPPtmpAABX
#endif
#if XSubPPtmpAABY
#endif
#if XSubPPtmpAABZ
#endif
#if XSubPPtmpAACA
#endif
#if XSubPPtmpAACB
#endif
#if XSubPPtmpAACC
#endif
#if XSubPPtmpAACD
#endif
#if XSubPPtmpAACE
#endif
#if XSubPPtmpAACF
#endif
#if XSubPPtmpAACG
#endif
#if XSubPPtmpAACH
#endif
#if XSubPPtmpAACI
#endif
#if XSubPPtmpAACJ
#endif
#if XSubPPtmpAACK
#endif
#if XSubPPtmpAACL
#endif
#if XSubPPtmpAACM
#endif
#if XSubPPtmpAACN
#endif
#if XSubPPtmpAACO
#endif
#if XSubPPtmpAACP
#endif
#if XSubPPtmpAACQ
#endif
#if XSubPPtmpAACR
#endif
#if XSubPPtmpAACS
#endif
#if XSubPPtmpAACT
#endif
#if XSubPPtmpAACU
#endif
#if XSubPPtmpAACV
#endif
#if XSubPPtmpAACW
#endif
#if XSubPPtmpAACX
#endif
#if XSubPPtmpAACY
#endif
#if XSubPPtmpAACZ
#endif
#if XSubPPtmpAADA
#endif
#if XSubPPtmpAADB
#endif
#if XSubPPtmpAADC
#endif
#if XSubPPtmpAADD
#if XSubPPtmpAADE
#endif
#endif
#if XSubPPtmpAADF
#endif
#if XSubPPtmpAADG
#endif
#if XSubPPtmpAADH
    {
#ifdef XSpp_f0ca9466_064695
        AV* isa = get_av( "Wx::RichTextPrintout::ISA", 1 );
        av_store( isa, 0, newSVpv( "Wx::Printout", 0 ) );
#endif // XSpp_f0ca9466_064695
    } // blank line here is important

#if XSubPPtmpAADI
#endif
#if XSubPPtmpAADJ
#endif
    {
#ifdef XSpp_f0ca9466_064695
        AV* isa = get_av( "Wx::RichTextPrinting::ISA", 1 );
        av_store( isa, 0, newSVpv( "wxObject", 0 ) );
#endif // XSpp_f0ca9466_064695
    } // blank line here is important

    {
#ifdef XSpp_f0ca9466_064695
        AV* isa = get_av( "Wx::RichTextHeaderFooterData::ISA", 1 );
        av_store( isa, 0, newSVpv( "wxObject", 0 ) );
#endif // XSpp_f0ca9466_064695
    } // blank line here is important

#endif

    /* End of Initialisation Section */

#if PERL_VERSION_LE(5, 21, 5)
#  if PERL_VERSION_GE(5, 9, 0)
    if (PL_unitcheckav)
        call_list(PL_scopestack_ix, PL_unitcheckav);
#  endif
    XSRETURN_YES;
#else
    Perl_xs_boot_epilog(aTHX_ ax);
#endif
}

